searchData={"items":[{"type":"module","title":"RDF","doc":"The top-level module of RDF.ex.\n\nRDF.ex consists of:\n\n- structs for the nodes of an RDF graph\n  - `RDF.IRI`\n  - `RDF.BlankNode`\n  - `RDF.Literal`\n- various modules making working with the nodes of an RDF graph easier\n  - `RDF.Term`\n  - `RDF.Sigils`\n  - `RDF.Guards`\n- the `RDF.Literal.Datatype` system\n- a facility for the mapping of URIs of a vocabulary to Elixir modules and\n  functions: `RDF.Vocabulary.Namespace`\n- a facility for the automatic generation of resource identifiers: `RDF.Resource.Generator`\n- modules for the construction of statements\n  - `RDF.Triple`\n  - `RDF.Quad`\n  - `RDF.Statement`\n- structs for collections of statements\n  - `RDF.Description`\n  - `RDF.Graph`\n  - `RDF.Dataset`\n  - `RDF.Data`\n  - `RDF.List`\n  - `RDF.Diff`\n- functions to construct and execute basic graph pattern queries: `RDF.Query`\n- functions for working with RDF serializations: `RDF.Serialization`\n- behaviours for the definition of RDF serialization formats\n  - `RDF.Serialization.Format`\n  - `RDF.Serialization.Decoder`\n  - `RDF.Serialization.Encoder`\n- and the implementation of various RDF serialization formats\n  - `RDF.NTriples`\n  - `RDF.NQuads`\n  - `RDF.Turtle`\n  - `RDF.TriG`\n\nThis top-level module provides shortcut functions for the construction of the\nbasic elements and structures of RDF and some general helper functions.\n\nIt also can be `use`'ed to add basic imports and aliases for working with RDF.ex\non any module. See `__using__/1` for details.\n\nFor a general introduction you may refer to the guides on the [homepage](https://rdf-elixir.dev).","ref":"RDF.html"},{"type":"function","title":"RDF./0","doc":"","ref":"RDF.html#nil/0"},{"type":"macro","title":"RDF.__using__/1","doc":"Adds basic imports and aliases for working with RDF.ex.\n\nThis allows to write\n\n    use RDF\n\ninstead of the following\n\n    import RDF.Sigils\n    import RDF.Guards\n    import RDF.Namespace.IRI\n  \n    require RDF.Graph\n\n    alias RDF.{XSD, NTriples, NQuads, Turtle}","ref":"RDF.html#__using__/1"},{"type":"function","title":"RDF.bnode/0","doc":"","ref":"RDF.html#bnode/0"},{"type":"function","title":"RDF.bnode/1","doc":"","ref":"RDF.html#bnode/1"},{"type":"function","title":"RDF.bnode?/1","doc":"Checks if the given value is a blank node.","ref":"RDF.html#bnode?/1"},{"type":"function","title":"Examples - RDF.bnode?/1","doc":"iex> RDF.bnode?(RDF.bnode)\n    true\n    iex> RDF.bnode?(RDF.iri(\"http://example.com/resource\"))\n    false\n    iex> RDF.bnode?(42)\n    false","ref":"RDF.html#bnode?/1-examples"},{"type":"function","title":"RDF.coerce_graph_name/1","doc":"","ref":"RDF.html#coerce_graph_name/1"},{"type":"function","title":"RDF.coerce_object/2","doc":"","ref":"RDF.html#coerce_object/2"},{"type":"function","title":"RDF.coerce_predicate/1","doc":"","ref":"RDF.html#coerce_predicate/1"},{"type":"function","title":"RDF.coerce_predicate/2","doc":"","ref":"RDF.html#coerce_predicate/2"},{"type":"function","title":"RDF.coerce_subject/2","doc":"","ref":"RDF.html#coerce_subject/2"},{"type":"function","title":"RDF.dataset/0","doc":"","ref":"RDF.html#dataset/0"},{"type":"function","title":"RDF.dataset/1","doc":"","ref":"RDF.html#dataset/1"},{"type":"function","title":"RDF.dataset/2","doc":"","ref":"RDF.html#dataset/2"},{"type":"function","title":"RDF.default_base_iri/0","doc":"","ref":"RDF.html#default_base_iri/0"},{"type":"function","title":"RDF.default_prefixes/0","doc":"A user-defined `RDF.PrefixMap` of prefixes to IRI namespaces.\n\nThis prefix map will be used implicitly wherever a prefix map is expected, but\nnot provided. For example, when you don't pass a prefix map to the Turtle serializer,\nthis prefix map will be used.\n\nBy default, the `standard_prefixes/0` are part of this prefix map, but you can\ndefine additional default prefixes via the `default_prefixes` compile-time\nconfiguration.\n\nFor example:\n\n    config :rdf,\n      default_prefixes: %{\n        ex: \"http://example.com/\"\n      }\n\nYou can also set `:default_prefixes` to a module-function tuple `{mod, fun}`\nwith a function which should be called to determine the default prefixes.\n\nIf you don't want the `standard_prefixes/0` to be part of the default prefixes,\nor you want to map the standard prefixes to different namespaces (strongly discouraged!),\nyou can set the `use_standard_prefixes` compile-time configuration flag to `false`.\n\n    config :rdf,\n      use_standard_prefixes: false","ref":"RDF.html#default_prefixes/0"},{"type":"function","title":"RDF.default_prefixes/1","doc":"Returns the `default_prefixes/0` with additional prefix mappings.\n\nThe `prefix_mappings` can be given in any format accepted by `RDF.PrefixMap.new/1`.","ref":"RDF.html#default_prefixes/1"},{"type":"function","title":"RDF.description/2","doc":"","ref":"RDF.html#description/2"},{"type":"function","title":"RDF.diff/2","doc":"","ref":"RDF.html#diff/2"},{"type":"function","title":"RDF.first/0","doc":"","ref":"RDF.html#first/0"},{"type":"function","title":"RDF.graph/0","doc":"","ref":"RDF.html#graph/0"},{"type":"function","title":"RDF.graph/1","doc":"","ref":"RDF.html#graph/1"},{"type":"function","title":"RDF.graph/2","doc":"","ref":"RDF.html#graph/2"},{"type":"function","title":"RDF.iri/1","doc":"","ref":"RDF.html#iri/1"},{"type":"function","title":"RDF.iri!/1","doc":"","ref":"RDF.html#iri!/1"},{"type":"function","title":"RDF.iri?/1","doc":"","ref":"RDF.html#iri?/1"},{"type":"function","title":"RDF.lang_string/0","doc":"","ref":"RDF.html#lang_string/0"},{"type":"function","title":"RDF.lang_string/2","doc":"","ref":"RDF.html#lang_string/2"},{"type":"function","title":"RDF.langString/0","doc":"","ref":"RDF.html#langString/0"},{"type":"function","title":"RDF.langString/2","doc":"","ref":"RDF.html#langString/2"},{"type":"function","title":"RDF.list/1","doc":"","ref":"RDF.html#list/1"},{"type":"function","title":"RDF.list/2","doc":"","ref":"RDF.html#list/2"},{"type":"function","title":"RDF.list?/1","doc":"","ref":"RDF.html#list?/1"},{"type":"function","title":"RDF.list?/2","doc":"","ref":"RDF.html#list?/2"},{"type":"function","title":"RDF.literal/1","doc":"","ref":"RDF.html#literal/1"},{"type":"function","title":"RDF.literal/2","doc":"","ref":"RDF.html#literal/2"},{"type":"function","title":"RDF.literal?/1","doc":"Checks if the given value is an RDF literal.","ref":"RDF.html#literal?/1"},{"type":"function","title":"RDF.object/0","doc":"","ref":"RDF.html#object/0"},{"type":"function","title":"RDF.predicate/0","doc":"","ref":"RDF.html#predicate/0"},{"type":"function","title":"RDF.prefix_map/1","doc":"","ref":"RDF.html#prefix_map/1"},{"type":"function","title":"RDF.prefixes/1","doc":"","ref":"RDF.html#prefixes/1"},{"type":"function","title":"RDF.property_map/1","doc":"","ref":"RDF.html#property_map/1"},{"type":"function","title":"RDF.quad/2","doc":"","ref":"RDF.html#quad/2"},{"type":"function","title":"RDF.quad/5","doc":"","ref":"RDF.html#quad/5"},{"type":"function","title":"RDF.read_file/2","doc":"","ref":"RDF.html#read_file/2"},{"type":"function","title":"RDF.read_file!/2","doc":"","ref":"RDF.html#read_file!/2"},{"type":"function","title":"RDF.read_stream/2","doc":"","ref":"RDF.html#read_stream/2"},{"type":"function","title":"RDF.read_stream!/2","doc":"","ref":"RDF.html#read_stream!/2"},{"type":"function","title":"RDF.read_string/2","doc":"","ref":"RDF.html#read_string/2"},{"type":"function","title":"RDF.read_string!/2","doc":"","ref":"RDF.html#read_string!/2"},{"type":"function","title":"RDF.resource?/1","doc":"Checks if the given value is a `RDF.Resource`, i.e. a `RDF.IRI` or `RDF.BlankNode`.","ref":"RDF.html#resource?/1"},{"type":"function","title":"Examples - RDF.resource?/1","doc":"Supposed `EX` is a `RDF.Vocabulary.Namespace` and `Foo` is not.\n\n    iex> RDF.resource?(RDF.iri(\"http://example.com/resource\"))\n    true\n    iex> RDF.resource?(EX.resource)\n    true\n    iex> RDF.resource?(EX.Resource)\n    true\n    iex> RDF.resource?(Foo.Resource)\n    false\n    iex> RDF.resource?(RDF.bnode)\n    true\n    iex> RDF.resource?(RDF.XSD.integer(42))\n    false\n    iex> RDF.resource?(42)\n    false","ref":"RDF.html#resource?/1-examples"},{"type":"function","title":"RDF.rest/0","doc":"","ref":"RDF.html#rest/0"},{"type":"function","title":"RDF.sparql_prefixes/1","doc":"Returns a SPARQL encoded list of prefixes.\n\nThe `prefix_mappings` can be given in any format accepted by `RDF.PrefixMap.new/1`.","ref":"RDF.html#sparql_prefixes/1"},{"type":"function","title":"Examples - RDF.sparql_prefixes/1","doc":"iex> RDF.sparql_prefixes(\n    ...>  rdf: RDF,\n    ...>  rdfs: RDF.NS.RDFS,\n    ...>  xsd: RDF.NS.XSD,\n    ...>  ex1: EX,\n    ...>  ex2: \"http://example.com/ns2/\")\n    \"\"\"\n    PREFIX ex1:  \n    PREFIX ex2:  \n    PREFIX rdf:  \n    PREFIX rdfs:  \n    PREFIX xsd:  \n    \"\"\"","ref":"RDF.html#sparql_prefixes/1-examples"},{"type":"function","title":"RDF.standard_prefixes/0","doc":"A fixed set prefixes that will always be part of the `default_prefixes/0`.\n\n```elixir\nRDF.PrefixMap.new(%{\n  :rdf => ~I ,\n  :rdfs => ~I ,\n  :xsd => ~I \n})\n```\n\nSee `default_prefixes/0`, if you don't want these standard prefixes to be part\nof the default prefixes.","ref":"RDF.html#standard_prefixes/0"},{"type":"function","title":"RDF.star?/0","doc":"Returns whether RDF-star support is enabled.","ref":"RDF.html#star?/0"},{"type":"function","title":"RDF.statement/2","doc":"","ref":"RDF.html#statement/2"},{"type":"function","title":"RDF.statement/3","doc":"","ref":"RDF.html#statement/3"},{"type":"function","title":"RDF.statement/4","doc":"","ref":"RDF.html#statement/4"},{"type":"function","title":"RDF.subject/0","doc":"","ref":"RDF.html#subject/0"},{"type":"function","title":"RDF.term?/1","doc":"Checks if the given value is a `RDF.Term`, i.e. a `RDF.IRI`, `RDF.BlankNode` or `RDF.Literal`.","ref":"RDF.html#term?/1"},{"type":"function","title":"Examples - RDF.term?/1","doc":"Supposed `EX` is a `RDF.Vocabulary.Namespace` and `Foo` is not.\n\n    iex> RDF.term?(RDF.iri(\"http://example.com/resource\"))\n    true\n    iex> RDF.term?(EX.resource)\n    true\n    iex> RDF.term?(EX.Resource)\n    true\n    iex> RDF.term?(Foo.Resource)\n    false\n    iex> RDF.term?(RDF.bnode)\n    true\n    iex> RDF.term?(RDF.XSD.integer(42))\n    true\n    iex> RDF.term?(42)\n    false","ref":"RDF.html#term?/1-examples"},{"type":"function","title":"RDF.triple/2","doc":"","ref":"RDF.html#triple/2"},{"type":"function","title":"RDF.triple/4","doc":"","ref":"RDF.html#triple/4"},{"type":"function","title":"RDF.turtle_prefixes/1","doc":"Returns a Turtle encoded list of prefixes.\n\nThe `prefix_mappings` can be given in any format accepted by `RDF.PrefixMap.new/1`.","ref":"RDF.html#turtle_prefixes/1"},{"type":"function","title":"Examples - RDF.turtle_prefixes/1","doc":"iex> RDF.turtle_prefixes(\n    ...>  rdf: RDF,\n    ...>  rdfs: RDF.NS.RDFS,\n    ...>  xsd: RDF.NS.XSD,\n    ...>  ex1: EX,\n    ...>  ex2: \"http://example.com/ns2/\")\n    \"\"\"\n    @prefix ex1:   .\n    @prefix ex2:   .\n    @prefix rdf:   .\n    @prefix rdfs:   .\n    @prefix xsd:   .\n    \"\"\"","ref":"RDF.html#turtle_prefixes/1-examples"},{"type":"function","title":"RDF.type/0","doc":"","ref":"RDF.html#type/0"},{"type":"function","title":"RDF.uri/1","doc":"","ref":"RDF.html#uri/1"},{"type":"function","title":"RDF.uri!/1","doc":"","ref":"RDF.html#uri!/1"},{"type":"function","title":"RDF.uri?/1","doc":"","ref":"RDF.html#uri?/1"},{"type":"function","title":"RDF.value/0","doc":"","ref":"RDF.html#value/0"},{"type":"function","title":"RDF.write_file/3","doc":"","ref":"RDF.html#write_file/3"},{"type":"function","title":"RDF.write_file!/3","doc":"","ref":"RDF.html#write_file!/3"},{"type":"function","title":"RDF.write_stream/2","doc":"","ref":"RDF.html#write_stream/2"},{"type":"function","title":"RDF.write_string/2","doc":"","ref":"RDF.html#write_string/2"},{"type":"function","title":"RDF.write_string!/2","doc":"","ref":"RDF.html#write_string!/2"},{"type":"module","title":"RDF.Guards","doc":"A collection of guards.","ref":"RDF.Guards.html"},{"type":"macro","title":"RDF.Guards.is_plain_rdf_literal/1","doc":"Returns if the given term is a plain `RDF.Literal`, i.e. has either datatype `xsd:string` or `rdf:langString`.\n\n> #### Warning {: .warning}\n>\n> Due to [this bug in Elixir](https://github.com/elixir-lang/elixir/issues/10485)\n> a false warning is currently raised when the given `term` is not a `RDF.Literal`,\n> although the implementation works as expected. If you want to get rid of the warning\n> you'll have to catch non-`RDF.Literal` values in a separate clause before the one\n> calling this guard.","ref":"RDF.Guards.html#is_plain_rdf_literal/1"},{"type":"macro","title":"Examples - RDF.Guards.is_plain_rdf_literal/1","doc":"iex> is_plain_rdf_literal(~L\"foo\")\n    true\n\n    iex> is_plain_rdf_literal(~L\"foo\"en)\n    true\n\n    iex> is_plain_rdf_literal(XSD.Integer.new(42))\n    false","ref":"RDF.Guards.html#is_plain_rdf_literal/1-examples"},{"type":"macro","title":"RDF.Guards.is_quad/1","doc":"Returns if the given term is a quad, i.e. a tuple with four elements.","ref":"RDF.Guards.html#is_quad/1"},{"type":"macro","title":"Examples - RDF.Guards.is_quad/1","doc":"iex> is_quad({~I , EX.foo(), 42, EX.Graph})\n    true\n\n    iex> is_quad({~I , EX.foo(), 42})\n    false\n\n    iex> is_quad({~I , EX.foo()})\n    false","ref":"RDF.Guards.html#is_quad/1-examples"},{"type":"macro","title":"RDF.Guards.is_rdf_bnode/1","doc":"Returns if the given term is a `RDF.BlankNode`.","ref":"RDF.Guards.html#is_rdf_bnode/1"},{"type":"macro","title":"Examples - RDF.Guards.is_rdf_bnode/1","doc":"iex> is_rdf_bnode(~B )\n    true\n\n    iex> is_rdf_bnode(~L\"b1\")\n    false","ref":"RDF.Guards.html#is_rdf_bnode/1-examples"},{"type":"macro","title":"RDF.Guards.is_rdf_iri/1","doc":"Returns if the given term is a `RDF.IRI`.\n\nNote: This function does not recognize `RDF.IRI`s given as upper-cased\n`RDF.Namespace` terms. You'll have to use the `RDF.iri?/1` function for this.","ref":"RDF.Guards.html#is_rdf_iri/1"},{"type":"macro","title":"Examples - RDF.Guards.is_rdf_iri/1","doc":"iex> is_rdf_iri(~I )\n    true\n\n    iex> is_rdf_iri(\"http://example.com/\")\n    false\n\n    iex> is_rdf_iri(RDF.type())\n    true\n\n    iex> is_rdf_iri(RDF.NS.RDFS.Class)\n    false\n\n    iex> RDF.iri?(RDF.NS.RDFS.Class)\n    true","ref":"RDF.Guards.html#is_rdf_iri/1-examples"},{"type":"macro","title":"RDF.Guards.is_rdf_literal/1","doc":"Returns if the given term is a `RDF.Literal`.","ref":"RDF.Guards.html#is_rdf_literal/1"},{"type":"macro","title":"Examples - RDF.Guards.is_rdf_literal/1","doc":"iex> is_rdf_literal(~L\"foo\")\n    true\n\n    iex> is_rdf_literal(~L\"foo\"en)\n    true\n\n    iex> is_rdf_literal(XSD.integer(42))\n    true\n\n    iex> is_rdf_literal(42)\n    false","ref":"RDF.Guards.html#is_rdf_literal/1-examples"},{"type":"macro","title":"RDF.Guards.is_rdf_literal/2","doc":"Returns if the given term is a `RDF.Literal` with the given `RDF.Literal.Datatype`.\n\n> #### Warning {: .warning}\n>\n> Due to [this bug in Elixir](https://github.com/elixir-lang/elixir/issues/10485)\n> a false warning is currently raised when the given `term` is not a `RDF.Literal`,\n> although the implementation works as expected. If you want to get rid of the warning\n> you'll have to catch non-`RDF.Literal` values in a separate clause before the one\n> calling this guard.","ref":"RDF.Guards.html#is_rdf_literal/2"},{"type":"macro","title":"Examples - RDF.Guards.is_rdf_literal/2","doc":"iex> is_rdf_literal(~L\"foo\", XSD.String)\n    true\n\n    iex> is_rdf_literal(XSD.Integer.new(42), XSD.String)\n    false","ref":"RDF.Guards.html#is_rdf_literal/2-examples"},{"type":"macro","title":"RDF.Guards.is_rdf_quad/1","doc":"Returns if the given term is a `RDF.Quad`, i.e. a tuple with four elements where each element is a `RDF.Term`.","ref":"RDF.Guards.html#is_rdf_quad/1"},{"type":"macro","title":"Examples - RDF.Guards.is_rdf_quad/1","doc":"iex> is_rdf_quad({~I , EX.foo(), XSD.integer(42), RDF.iri(EX.Graph)})\n    true\n\n    iex> is_rdf_quad({~I , EX.foo(), 42, RDF.iri(EX.Graph)})\n    false\n\n    iex> is_rdf_quad({~L\"the subject can not be a literal\", EX.foo(), XSD.integer(42), RDF.iri(EX.Graph)})\n    false\n\n    iex> is_rdf_quad({~I , ~L\"the predicate can not be a literal\", XSD.integer(42), RDF.iri(EX.Graph)})\n    false\n\n    iex> is_rdf_quad({~I , EX.foo(), XSD.integer(42), ~L\"the graph context can not be a literal\"})\n    false\n\n    iex> is_rdf_quad({~I , EX.foo(), XSD.integer(42)})\n    false\n\n    iex> is_rdf_quad({~I , EX.foo()})\n    false","ref":"RDF.Guards.html#is_rdf_quad/1-examples"},{"type":"macro","title":"RDF.Guards.is_rdf_resource/1","doc":"Returns if the given term is a `RDF.Resource`, i.e. a `RDF.IRI` or `RDF.BlankNode`.\n\nNote: This function does not recognize `RDF.IRI`s given as upper-cased\n`RDF.Namespace` terms. You'll have to use the `RDF.resource?/1` function for this.","ref":"RDF.Guards.html#is_rdf_resource/1"},{"type":"macro","title":"Examples - RDF.Guards.is_rdf_resource/1","doc":"iex> is_rdf_resource(~I )\n    true\n\n    iex> is_rdf_resource(~B )\n    true\n\n    iex> is_rdf_resource(~L\"foo\")\n    false\n\n    iex> is_rdf_resource(RDF.type())\n    true\n\n    iex> is_rdf_resource(RDF.NS.RDFS.Class)\n    false\n\n    iex> RDF.resource?(RDF.NS.RDFS.Class)\n    true","ref":"RDF.Guards.html#is_rdf_resource/1-examples"},{"type":"macro","title":"RDF.Guards.is_rdf_statement/1","doc":"Returns if the given term is a `RDF.Statement` in terms of `is_rdf_triple/1` or `is_rdf_quad/1`.","ref":"RDF.Guards.html#is_rdf_statement/1"},{"type":"macro","title":"Examples - RDF.Guards.is_rdf_statement/1","doc":"iex> is_rdf_statement({~I , EX.foo(), XSD.integer(42)})\n    true\n\n    iex> is_rdf_statement({~I , EX.foo(), XSD.integer(42), RDF.iri(EX.Graph)})\n    true\n\n    iex> is_rdf_statement({~I , EX.foo()})\n    false\n\n    iex> is_rdf_statement({~L\"the subject can not be a literal\", EX.foo(), XSD.integer(42)})\n    false","ref":"RDF.Guards.html#is_rdf_statement/1-examples"},{"type":"macro","title":"RDF.Guards.is_rdf_term/1","doc":"Returns if the given term is a `RDF.Term`, i.e. a `RDF.IRI`, `RDF.BlankNode` or `RDF.Literal`.\n\nNote: This function does not recognize `RDF.IRI`s given as upper-cased\n`RDF.Namespace` terms. You'll have to use the `RDF.term?/1` function for this.","ref":"RDF.Guards.html#is_rdf_term/1"},{"type":"macro","title":"Examples - RDF.Guards.is_rdf_term/1","doc":"iex> is_rdf_term(~I )\n    true\n\n    iex> is_rdf_term(~B )\n    true\n\n    iex> is_rdf_term(~L\"foo\")\n    true\n\n    iex> is_rdf_term(RDF.type())\n    true\n\n    iex> is_rdf_term(RDF.NS.RDFS.Class)\n    false\n\n    iex> RDF.term?(RDF.NS.RDFS.Class)\n    true","ref":"RDF.Guards.html#is_rdf_term/1-examples"},{"type":"macro","title":"RDF.Guards.is_rdf_triple/1","doc":"Returns if the given term is a `RDF.Triple`, i.e. a tuple with three elements where each element is a `RDF.Term`.","ref":"RDF.Guards.html#is_rdf_triple/1"},{"type":"macro","title":"Examples - RDF.Guards.is_rdf_triple/1","doc":"iex> is_rdf_triple({~I , EX.foo(), XSD.integer(42)})\n    true\n\n    iex> is_rdf_triple({~I , EX.foo(), 42})\n    false\n\n    iex> is_rdf_triple({~L\"the subject can not be a literal\", EX.foo(), XSD.integer(42)})\n    false\n\n    iex> is_rdf_triple({~I , ~L\"the predicate can not be a literal\", XSD.integer(42)})\n    false\n\n    iex> is_rdf_triple({~I , EX.foo()})\n    false\n\n    iex> is_rdf_triple({~I , EX.foo(), XSD.integer(42), RDF.iri(EX.Graph)})\n    false","ref":"RDF.Guards.html#is_rdf_triple/1-examples"},{"type":"macro","title":"RDF.Guards.is_statement/1","doc":"Returns if the given term is a triple or a quad in terms of `is_triple/1` or `is_quad/1`.","ref":"RDF.Guards.html#is_statement/1"},{"type":"macro","title":"Examples - RDF.Guards.is_statement/1","doc":"iex> is_statement({~I , EX.foo(), 42, EX.Graph})\n    true\n\n    iex> is_statement({~I , EX.foo(), 42})\n    true\n\n    iex> is_statement({~I , EX.foo()})\n    false","ref":"RDF.Guards.html#is_statement/1-examples"},{"type":"macro","title":"RDF.Guards.is_triple/1","doc":"Returns if the given term is a triple, i.e. a tuple with three elements.\n\nNote: This","ref":"RDF.Guards.html#is_triple/1"},{"type":"macro","title":"Examples - RDF.Guards.is_triple/1","doc":"iex> is_triple({~I , EX.foo(), 42})\n    true\n\n    iex> is_triple({~I , EX.foo()})\n    false\n\n    iex> is_triple({~I , EX.foo(), 42, EX.Graph})\n    false","ref":"RDF.Guards.html#is_triple/1-examples"},{"type":"macro","title":"RDF.Guards.is_typed_rdf_literal/1","doc":"Returns if the given term is a typed `RDF.Literal`, i.e. has , i.e. has another datatype than `xsd:string` or `rdf:langString`.\n\n> #### Warning {: .warning}\n>\n> Due to [this bug in Elixir](https://github.com/elixir-lang/elixir/issues/10485)\n> a false warning is currently raised when the given `term` is not a `RDF.Literal`,\n> although the implementation works as expected. If you want to get rid of the warning\n> you'll have to catch non-`RDF.Literal` values in a separate clause before the one\n> calling this guard.","ref":"RDF.Guards.html#is_typed_rdf_literal/1"},{"type":"macro","title":"Examples - RDF.Guards.is_typed_rdf_literal/1","doc":"iex> is_typed_rdf_literal(XSD.Integer.new(42))\n    true\n\n    iex> is_typed_rdf_literal(~L\"foo\")\n    false\n\n    iex> is_typed_rdf_literal(~L\"foo\"en)\n    false","ref":"RDF.Guards.html#is_typed_rdf_literal/1-examples"},{"type":"macro","title":"RDF.Guards.maybe_ns_term/1","doc":"Returns if the given term is an atom which could potentially be an `RDF.Vocabulary.Namespace` term.","ref":"RDF.Guards.html#maybe_ns_term/1"},{"type":"macro","title":"Examples - RDF.Guards.maybe_ns_term/1","doc":"iex> maybe_ns_term(EX.Foo)\n    true\n\n    iex> maybe_ns_term(true)\n    false\n\n    iex> maybe_ns_term(false)\n    false\n\n    iex> maybe_ns_term(nil)\n    false","ref":"RDF.Guards.html#maybe_ns_term/1-examples"},{"type":"module","title":"RDF.Utils.Regex","doc":"Drop-in replacements for Elixir `Regex` functions.\n\nIn Elixir, each execution of a compiled regex includes a verification step to\nensure the PCRE version of the regex is compatible with the version compiled\nwith the local OTP. While this verification introduces a slight overhead, the\ncumulative effect can be significant, particularly since evaluating regular\nexpressions is crucial for performance in RDF.ex. This is especially notable\nduring deserialization, where regular expression are evaluated in quite tight\nloops.\n\nAll regular expressions are evaluated in RDF.ex through the functions in this\nmodule which can be configured with the `optimize_regexes` key in the\ncompile-time application environment to circumvent Elixir and call through to\nErlang `re` directly:\n\n    config :rdf,\n      optimize_regexes: true\n\nBy default this optimization is disabled and should be enabled only if your\napplication is running in a controlled environment.","ref":"RDF.Utils.Regex.html"},{"type":"function","title":"RDF.Utils.Regex.match?/2","doc":"","ref":"RDF.Utils.Regex.html#match?/2"},{"type":"function","title":"RDF.Utils.Regex.run/2","doc":"","ref":"RDF.Utils.Regex.html#run/2"},{"type":"module","title":"RDF.BlankNode","doc":"An RDF blank node (aka bnode) is a local node of a graph without an IRI.\n\nThis module can also be used as `RDF.Resource.Generator` for the generation\nof random identifiers, which is using the `new/0` function.\nFor the generation of value-based blank nodes, you can use `RDF.BlankNode.Generator`.\n\nsee  \nand","ref":"RDF.BlankNode.html"},{"type":"function","title":"RDF.BlankNode.equal_value?/2","doc":"Tests for value equality of blank nodes.\n\nReturns `nil` when the given arguments are not comparable as blank nodes.","ref":"RDF.BlankNode.html#equal_value?/2"},{"type":"function","title":"RDF.BlankNode.new/0","doc":"Creates a random `RDF.BlankNode`.","ref":"RDF.BlankNode.html#new/0"},{"type":"function","title":"RDF.BlankNode.new/1","doc":"Creates a `RDF.BlankNode` with a user-defined value for its identity.\n\nA `\"_:\"` prefix in a given string `value` will be automatically ignored.\n\nWhen given an integer as `value` it will be automatically converted to a\nstring prefixed with `\"b\"`.","ref":"RDF.BlankNode.html#new/1"},{"type":"function","title":"Examples - RDF.BlankNode.new/1","doc":"iex> RDF.BlankNode.new(:foo)\n    %RDF.BlankNode{value: \"foo\"}\n\n    iex> RDF.BlankNode.new(\"foo\")\n    %RDF.BlankNode{value: \"foo\"}\n\n    iex> RDF.BlankNode.new(\"_:foo\")\n    %RDF.BlankNode{value: \"foo\"}\n\n    iex> RDF.BlankNode.new(42)\n    %RDF.BlankNode{value: \"b42\"}","ref":"RDF.BlankNode.html#new/1-examples"},{"type":"function","title":"RDF.BlankNode.value/1","doc":"Returns the internal string representation of a blank node.","ref":"RDF.BlankNode.html#value/1"},{"type":"type","title":"RDF.BlankNode.t/0","doc":"","ref":"RDF.BlankNode.html#t:t/0"},{"type":"module","title":"RDF.IRI","doc":"A structure for IRIs.\n\nThis structure just wraps a plain IRI string and doesn't bother with the\ncomponents of the IRI, since in the context of RDF there are usually very many\nIRIs and parsing them isn't needed in most cases. For these reasons we don't\nuse Elixirs built-in `URI` structure, because it would be unnecessary\nexpensive in terms of performance and memory.\n\nThe component parts can always be retrieved with the `RDF.IRI.parse/1`\nfunction, which returns Elixirs built-in `URI` structure. Note, that `URI`\ndoesn't escape Unicode characters by default, so it's a suitable structure for\nIRIs.\n\nsee","ref":"RDF.IRI.html"},{"type":"function","title":"RDF.IRI.absolute/2","doc":"Resolves a relative IRI against a base IRI.\n\nas specified in [section 5.1 Establishing a Base URI of RFC3986](http://tools.ietf.org/html/rfc3986#section-5.1).\nOnly the basic algorithm in [section 5.2 of RFC3986](http://tools.ietf.org/html/rfc3986#section-5.2)\nis used; neither Syntax-Based Normalization nor Scheme-Based Normalization are performed.\n\nCharacters additionally allowed in IRI references are treated in the same way that unreserved\ncharacters are treated in URI references, per [section 6.5 of RFC3987](http://tools.ietf.org/html/rfc3987#section-6.5)\n\nIf the given `base` is not an absolute IRI `nil` is returned.","ref":"RDF.IRI.html#absolute/2"},{"type":"function","title":"RDF.IRI.absolute?/1","doc":"Checks if the given value is an absolute IRI.\n\nAn absolute IRI is defined in [RFC3987](http://www.ietf.org/rfc/rfc3987.txt)\ncontaining a scheme along with a path and optional query and fragment segments.","ref":"RDF.IRI.html#absolute?/1"},{"type":"function","title":"RDF.IRI.append/2","doc":"Appends a String to a `RDF.IRI`.","ref":"RDF.IRI.html#append/2"},{"type":"function","title":"Example - RDF.IRI.append/2","doc":"iex> ~I  |> RDF.IRI.append(\"foo\")\n    ~I \n\n    iex> EX.foo |> RDF.IRI.append(\"bar\")\n    EX.foobar\n\n    iex> EX.Foo |> RDF.IRI.append(\"bar\")\n    RDF.iri(EX.Foobar)","ref":"RDF.IRI.html#append/2-example"},{"type":"function","title":"RDF.IRI.coerce_base/1","doc":"Coerces an IRI serving as a base IRI.\n\nAs opposed to `new/1` this also accepts bare `RDF.Vocabulary.Namespace` modules\nand uses the base IRI from their definition.","ref":"RDF.IRI.html#coerce_base/1"},{"type":"function","title":"RDF.IRI.default_base/0","doc":"The default base IRI to be used when reading a serialization and no `base_iri` option is provided.\n\nThe value can be set via the `default_base_iri` configuration. For example:\n\n    config :rdf,\n      default_base_iri: \"http://my_app.example/\"\n\nYou can also set `:default_base_iri` to a module-function tuple `{mod, fun}`\nwith a function which should be called to determine the default base IRI.\n\nSee [section 5.1.4 of RFC 3987](https://tools.ietf.org/html/rfc3986#page-29)","ref":"RDF.IRI.html#default_base/0"},{"type":"function","title":"RDF.IRI.ends_with?/2","doc":"Checks whether `iri` end with any of the given suffixes.","ref":"RDF.IRI.html#ends_with?/2"},{"type":"function","title":"Examples - RDF.IRI.ends_with?/2","doc":"iex> RDF.IRI.ends_with?(~I , \"foo\")\n    true\n    iex> RDF.IRI.ends_with?(EX.Foo, \"Foo\")\n    true\n    iex> RDF.IRI.ends_with?(~I , [\"foo\", \"bar\"])\n    true\n    iex> RDF.IRI.ends_with?(~I , \"bar\")\n    false","ref":"RDF.IRI.html#ends_with?/2-examples"},{"type":"function","title":"RDF.IRI.equal_value?/2","doc":"Tests for value equality of IRIs.\n\nReturns `nil` when the given arguments are not comparable as IRIs.\n\nsee","ref":"RDF.IRI.html#equal_value?/2"},{"type":"function","title":"RDF.IRI.in_namespace?/2","doc":"Checks whether `iri` lies in `namespace`.","ref":"RDF.IRI.html#in_namespace?/2"},{"type":"function","title":"Examples - RDF.IRI.in_namespace?/2","doc":"iex> RDF.IRI.in_namespace?(~I , ~I )\n    true\n    iex> RDF.IRI.in_namespace?(EX.Foo, ~I )\n    true\n    iex> RDF.IRI.in_namespace?(~I , \"http://example.com/\")\n    true\n    iex> RDF.IRI.in_namespace?(~I , EX)\n    true","ref":"RDF.IRI.html#in_namespace?/2-examples"},{"type":"function","title":"RDF.IRI.merge/2","doc":"Merges two IRIs.\n\nThis function merges two IRIs as per\n[RFC 3986, section 5.2](https://tools.ietf.org/html/rfc3986#section-5.2).","ref":"RDF.IRI.html#merge/2"},{"type":"function","title":"RDF.IRI.new/1","doc":"Creates a `RDF.IRI`.","ref":"RDF.IRI.html#new/1"},{"type":"function","title":"RDF.IRI.new!/1","doc":"Creates a `RDF.IRI`, but checks if the given IRI is valid.\n\nIf the given IRI is not valid a `RDF.IRI.InvalidError` is raised.\n\nsee `valid?/1`","ref":"RDF.IRI.html#new!/1"},{"type":"function","title":"RDF.IRI.parse/1","doc":"Parses an IRI into its components and returns them as an `URI` struct.","ref":"RDF.IRI.html#parse/1"},{"type":"function","title":"RDF.IRI.scheme/1","doc":"Returns the scheme of the given IRI\n\nIf the given string is not a valid absolute IRI, `nil` is returned.","ref":"RDF.IRI.html#scheme/1"},{"type":"function","title":"Examples - RDF.IRI.scheme/1","doc":"iex> RDF.IRI.scheme(\"http://www.example.com/foo\")\n    \"http\"\n    iex> RDF.IRI.scheme(\"not an iri\")\n    nil","ref":"RDF.IRI.html#scheme/1-examples"},{"type":"function","title":"RDF.IRI.starts_with?/2","doc":"Checks whether `iri` starts with any of the given prefixes.","ref":"RDF.IRI.html#starts_with?/2"},{"type":"function","title":"Examples - RDF.IRI.starts_with?/2","doc":"iex> RDF.IRI.starts_with?(~I , \"http://example.com/\")\n    true\n    iex> RDF.IRI.starts_with?(EX.Foo, \"http://example.com/\")\n    true\n    iex> RDF.IRI.starts_with?(~I , [\"http://example.com/\", \"http://example.org/\"])\n    true\n    iex> RDF.IRI.starts_with?(~I , \"http://example.org/\")\n    false","ref":"RDF.IRI.html#starts_with?/2-examples"},{"type":"function","title":"RDF.IRI.to_string/1","doc":"Returns the given IRI as a string.\n\nNote that this function can also handle `RDF.Vocabulary.Namespace` terms.","ref":"RDF.IRI.html#to_string/1"},{"type":"function","title":"Examples - RDF.IRI.to_string/1","doc":"iex> RDF.IRI.to_string RDF.IRI.new(\"http://example.com/#foo\")\n    \"http://example.com/#foo\"\n    iex> RDF.IRI.to_string EX.foo\n    \"http://example.com/#foo\"\n    iex> RDF.IRI.to_string EX.Foo\n    \"http://example.com/#Foo\"","ref":"RDF.IRI.html#to_string/1-examples"},{"type":"function","title":"RDF.IRI.valid!/1","doc":"Returns the given value unchanged if it's a valid IRI, otherwise raises an exception.","ref":"RDF.IRI.html#valid!/1"},{"type":"function","title":"Examples - RDF.IRI.valid!/1","doc":"iex> RDF.IRI.valid!(\"http://www.example.com/foo\")\n    \"http://www.example.com/foo\"\n    iex> RDF.IRI.valid!(RDF.IRI.new(\"http://www.example.com/foo\"))\n    RDF.IRI.new(\"http://www.example.com/foo\")\n    iex> RDF.IRI.valid!(\"not an iri\")\n    ** (RDF.IRI.InvalidError) Invalid IRI: \"not an iri\"","ref":"RDF.IRI.html#valid!/1-examples"},{"type":"function","title":"RDF.IRI.valid?/1","doc":"Checks if the given IRI is valid.\n\nNote: This currently checks only if the given IRI is absolute.","ref":"RDF.IRI.html#valid?/1"},{"type":"function","title":"Examples - RDF.IRI.valid?/1","doc":"iex> RDF.IRI.valid?(\"http://www.example.com/foo\")\n    true\n    iex> RDF.IRI.valid?(\"not an iri\")\n    false","ref":"RDF.IRI.html#valid?/1-examples"},{"type":"type","title":"RDF.IRI.coercible/0","doc":"","ref":"RDF.IRI.html#t:coercible/0"},{"type":"type","title":"RDF.IRI.t/0","doc":"","ref":"RDF.IRI.html#t:t/0"},{"type":"module","title":"RDF.Literal","doc":"RDF literals are leaf nodes of an RDF graph containing raw data, like strings, numbers etc.\n\nA literal is a struct consisting of a `literal` field holding either a `RDF.Literal.Datatype` struct\nfor the respective known datatype of the literal or a `RDF.Literal.Generic` struct if the datatype\nis unknown, i.e. has no `RDF.Literal.Datatype` implementation.","ref":"RDF.Literal.html"},{"type":"function","title":"RDF.Literal.canonical/1","doc":"Transforms the given `literal` into its canonical form.","ref":"RDF.Literal.html#canonical/1"},{"type":"function","title":"RDF.Literal.canonical?/1","doc":"Returns if the lexical form of the given `literal` has the canonical form.","ref":"RDF.Literal.html#canonical?/1"},{"type":"function","title":"RDF.Literal.canonical_lexical/1","doc":"Returns the canonical lexical of the given `literal`.","ref":"RDF.Literal.html#canonical_lexical/1"},{"type":"function","title":"RDF.Literal.coerce/1","doc":"Coerces a new `RDF.Literal` from another value.\n\nThe following mapping of Elixir types to XSD datatypes is applied:\n\n| Elixir datatype | XSD datatype   |\n| :-------------- | :------------- |\n| `string`        | `xsd:string`   |\n| `boolean`       | `xsd:boolean`  |\n| `integer`       | `xsd:integer`  |\n| `float`         | `xsd:double`   |\n| `Decimal`       | `xsd:decimal`  |\n| `Time`          | `xsd:time`     |\n| `Date`          | `xsd:date`     |\n| `DateTime`      | `xsd:dateTime` |\n| `NaiveDateTime` | `xsd:dateTime` |\n| `URI`           | `xsd:AnyURI`   |\n\nWhen an `RDF.Literal` can not be coerced, `nil` is returned\n(as opposed to `new/1` which fails in this case).","ref":"RDF.Literal.html#coerce/1"},{"type":"function","title":"Examples - RDF.Literal.coerce/1","doc":"iex> RDF.Literal.coerce(42)\n    %RDF.Literal{literal: %RDF.XSD.Integer{value: 42}}","ref":"RDF.Literal.html#coerce/1-examples"},{"type":"function","title":"RDF.Literal.compare/2","doc":"","ref":"RDF.Literal.html#compare/2"},{"type":"function","title":"RDF.Literal.datatype?/1","doc":"Returns if the given value is a `RDF.Literal` or `RDF.Literal.Datatype` struct.\n\nIf you simply want to check for a `RDF.Literal` use pattern matching or `RDF.literal?/1`.\nThis function is a bit slower than those and most of the time only needed when\nimplementing `RDF.Literal.Datatype`s where you have to deal with the raw,\ni.e. unwrapped `RDF.Literal.Datatype` structs.","ref":"RDF.Literal.html#datatype?/1"},{"type":"function","title":"RDF.Literal.datatype_id/1","doc":"Returns the IRI of datatype of the given `literal`.","ref":"RDF.Literal.html#datatype_id/1"},{"type":"function","title":"RDF.Literal.equal?/2","doc":"Checks if two literals are equal.\n\nTwo literals are equal if they have the same datatype, value and lexical form.","ref":"RDF.Literal.html#equal?/2"},{"type":"function","title":"RDF.Literal.equal_value?/2","doc":"Checks if two literals have equal values.","ref":"RDF.Literal.html#equal_value?/2"},{"type":"function","title":"RDF.Literal.generic?/1","doc":"Returns if the literal uses the `RDF.Literal.Generic` datatype or on of the dedicated builtin or custom `RDF.Literal.Datatype`s.","ref":"RDF.Literal.html#generic?/1"},{"type":"function","title":"RDF.Literal.greater_than?/2","doc":"Checks if the first of two `RDF.Literal`s is greater than the other.","ref":"RDF.Literal.html#greater_than?/2"},{"type":"function","title":"RDF.Literal.has_datatype?/1","doc":"Returns if a literal is a datatyped literal.\n\nFor historical reasons, this excludes `xsd:string` and `rdf:langString`.\n\nsee","ref":"RDF.Literal.html#has_datatype?/1"},{"type":"function","title":"RDF.Literal.has_language?/1","doc":"Returns if a literal is a language-tagged literal.\n\nsee","ref":"RDF.Literal.html#has_language?/1"},{"type":"function","title":"RDF.Literal.is_a?/2","doc":"Checks if 'literal' is literal with the given `datatype`.\n\n`datatype` can be one of the following:\n\n- a `RDF.Literal.Datatype` module  which checks if the literal is of this datatype or derived from it\n- `RDF.XSD.Numeric` which checks if the literal is one of the numeric XSD datatypes or derived of one of them\n- `RDF.XSD.Datatype` which checks if the literal is a XSD datatype or derived of one of them","ref":"RDF.Literal.html#is_a?/2"},{"type":"function","title":"RDF.Literal.language/1","doc":"Returns the language of the given `literal` if present.","ref":"RDF.Literal.html#language/1"},{"type":"function","title":"RDF.Literal.less_than?/2","doc":"Checks if the first of two `RDF.Literal`s is smaller than the other.","ref":"RDF.Literal.html#less_than?/2"},{"type":"function","title":"RDF.Literal.lexical/1","doc":"Returns the lexical form of the given `literal`.","ref":"RDF.Literal.html#lexical/1"},{"type":"function","title":"RDF.Literal.matches?/3","doc":"Matches the lexical form of the given `RDF.Literal` against a XPath and XQuery regular expression pattern with flags.\n\nThe regular expression language is defined in _XQuery 1.0 and XPath 2.0 Functions and Operators_.\n\nsee","ref":"RDF.Literal.html#matches?/3"},{"type":"function","title":"RDF.Literal.new/1","doc":"Creates a new `RDF.Literal` of the given value and tries to infer an appropriate XSD datatype.\n\nSee `coerce/1` for applied mapping of Elixir types to XSD datatypes.\n\nNote: The `RDF.literal` function is a shortcut to this function.","ref":"RDF.Literal.html#new/1"},{"type":"function","title":"Examples - RDF.Literal.new/1","doc":"iex> RDF.Literal.new(42)\n    %RDF.Literal{literal: %RDF.XSD.Integer{value: 42}}","ref":"RDF.Literal.html#new/1-examples"},{"type":"function","title":"RDF.Literal.new/2","doc":"Creates a new `RDF.Literal` with the given datatype or language tag.","ref":"RDF.Literal.html#new/2"},{"type":"function","title":"RDF.Literal.new!/2","doc":"Creates a new `RDF.Literal`, but fails if it's not valid.\n\nNote: Validation is only possible if an `RDF.Datatype` with an implementation of\n  `RDF.Datatype.valid?/1` exists.","ref":"RDF.Literal.html#new!/2"},{"type":"function","title":"Examples - RDF.Literal.new!/2","doc":"iex> RDF.Literal.new(\"foo\")\n    %RDF.Literal{literal: %RDF.XSD.String{value: \"foo\"}}\n\n    iex> RDF.Literal.new!(\"foo\", datatype: RDF.NS.XSD.integer)\n    ** (RDF.Literal.InvalidError) invalid RDF.Literal: %RDF.XSD.Integer{value: nil, lexical: \"foo\"}\n\n    iex> RDF.Literal.new!(\"foo\", datatype: RDF.langString)\n    ** (RDF.Literal.InvalidError) invalid RDF.Literal: %RDF.LangString{value: \"foo\", language: nil}","ref":"RDF.Literal.html#new!/2-examples"},{"type":"function","title":"RDF.Literal.plain?/1","doc":"Returns if a literal is a plain literal.\n\nA plain literal may have a language, but may not have a datatype.\nFor all practical purposes, this includes `xsd:string` literals too.\n\nsee","ref":"RDF.Literal.html#plain?/1"},{"type":"function","title":"RDF.Literal.simple?/1","doc":"Returns if a literal is a simple literal.\n\nA simple literal has no datatype or language.\n\nsee","ref":"RDF.Literal.html#simple?/1"},{"type":"function","title":"RDF.Literal.update/3","doc":"Updates the value of a `RDF.Literal` without changing everything else.\n\nThe optional second argument allows to specify what will be passed to `fun` with the `:as` option,\ne.g. with `as: :lexical` the lexical is passed to the function.","ref":"RDF.Literal.html#update/3"},{"type":"function","title":"Example - RDF.Literal.update/3","doc":"iex> RDF.XSD.integer(42) |> RDF.Literal.update(fn value -> value + 1 end)\n    RDF.XSD.integer(43)\n    iex> ~L\"foo\"de |> RDF.Literal.update(fn _ -> \"bar\" end)\n    ~L\"bar\"de\n    iex> RDF.literal(\"foo\", datatype: \"http://example.com/dt\") |> RDF.Literal.update(fn _ -> \"bar\" end)\n    RDF.literal(\"bar\", datatype: \"http://example.com/dt\")\n    iex> RDF.XSD.integer(42) |> RDF.XSD.Integer.update(\n    ...>   fn value -> value <> \"1\" end, as: :lexical)\n    RDF.XSD.integer(421)","ref":"RDF.Literal.html#update/3-example"},{"type":"function","title":"RDF.Literal.valid?/1","doc":"Returns if the given `literal` is valid with respect to its datatype.","ref":"RDF.Literal.html#valid?/1"},{"type":"function","title":"RDF.Literal.value/1","doc":"Returns the value of the given `literal`.","ref":"RDF.Literal.html#value/1"},{"type":"type","title":"RDF.Literal.t/0","doc":"","ref":"RDF.Literal.html#t:t/0"},{"type":"module","title":"RDF.Resource","doc":"Shared functions over `RDF.IRI`s and `RDF.BlankNode`s.","ref":"RDF.Resource.html"},{"type":"type","title":"RDF.Resource.coercible/0","doc":"","ref":"RDF.Resource.html#t:coercible/0"},{"type":"type","title":"RDF.Resource.t/0","doc":"","ref":"RDF.Resource.html#t:t/0"},{"type":"module","title":"RDF.Sigils","doc":"Sigils for the most common types of RDF nodes.","ref":"RDF.Sigils.html"},{"type":"macro","title":"RDF.Sigils.sigil_B/2","doc":"Handles the sigil `~B` for blank nodes.\n\nIt returns an `RDF.BlankNode` from the given string without interpolations\nand without escape characters, except for the escaping of the closing sigil\ncharacter itself.","ref":"RDF.Sigils.html#sigil_B/2"},{"type":"macro","title":"Examples - RDF.Sigils.sigil_B/2","doc":"iex> import RDF.Sigils\n    iex> ~B \n    RDF.bnode(\"foo\")","ref":"RDF.Sigils.html#sigil_B/2-examples"},{"type":"macro","title":"RDF.Sigils.sigil_b/2","doc":"Handles the sigil `~b` for blank nodes.\n\nIt returns an `RDF.BlankNode` from the given string as if it was a double-quoted\nstring, unescaping characters and replacing interpolations.","ref":"RDF.Sigils.html#sigil_b/2"},{"type":"macro","title":"Examples - RDF.Sigils.sigil_b/2","doc":"iex> import RDF.Sigils\n    iex> ~b \n    RDF.bnode(\"foobar\")","ref":"RDF.Sigils.html#sigil_b/2-examples"},{"type":"macro","title":"RDF.Sigils.sigil_I/2","doc":"Handles the sigil `~I` for IRIs.\n\nIt returns an `RDF.IRI` from the given string without interpolations and\nwithout escape characters, except for the escaping of the closing sigil\ncharacter itself.","ref":"RDF.Sigils.html#sigil_I/2"},{"type":"macro","title":"Examples - RDF.Sigils.sigil_I/2","doc":"iex> import RDF.Sigils\n    iex> ~I \n    RDF.iri(\"http://example.com\")","ref":"RDF.Sigils.html#sigil_I/2-examples"},{"type":"macro","title":"RDF.Sigils.sigil_i/2","doc":"Handles the sigil `~i` for IRIs.\n\nIt returns an `RDF.IRI` from the given string as if it was a double-quoted\nstring, unescaping characters and replacing interpolations.","ref":"RDF.Sigils.html#sigil_i/2"},{"type":"macro","title":"Examples - RDF.Sigils.sigil_i/2","doc":"iex> import RDF.Sigils\n    iex> ~i \n    RDF.iri(\"http://example.com/foo\")","ref":"RDF.Sigils.html#sigil_i/2-examples"},{"type":"macro","title":"RDF.Sigils.sigil_L/2","doc":"Handles the sigil `~L` for plain Literals.\n\nIt returns an `RDF.Literal` from the given string without interpolations and without escape characters, except for the escaping of the closing sigil character itself.\n\nThe sigil modifier can be used to specify a language tag.\n\nNote: Languages with subtags are not supported.","ref":"RDF.Sigils.html#sigil_L/2"},{"type":"macro","title":"Examples - RDF.Sigils.sigil_L/2","doc":"iex> import RDF.Sigils\n    iex> ~L\"foo\"\n    RDF.literal(\"foo\")\n    iex> ~L\"foo\"en\n    RDF.literal(\"foo\", language: \"en\")","ref":"RDF.Sigils.html#sigil_L/2-examples"},{"type":"macro","title":"RDF.Sigils.sigil_l/2","doc":"Handles the sigil `~l` for blank nodes.\n\nIt returns an `RDF.Literal` from the given string as if it was a double-quoted\nstring, unescaping characters and replacing interpolations.","ref":"RDF.Sigils.html#sigil_l/2"},{"type":"macro","title":"Examples - RDF.Sigils.sigil_l/2","doc":"iex> import RDF.Sigils\n    iex> ~l\"foo #{String.downcase(\"Bar\")}\"\n    RDF.literal(\"foo bar\")\n    iex> ~l\"foo #{String.downcase(\"Bar\")}\"en\n    RDF.literal(\"foo bar\", language: \"en\")","ref":"RDF.Sigils.html#sigil_l/2-examples"},{"type":"protocol","title":"RDF.Term","doc":"Shared behaviour for all RDF terms.\n\nA `RDF.Term` is anything which can be an element of RDF statements of an RDF graph:\n\n- `RDF.IRI`s\n- `RDF.BlankNode`s\n- `RDF.Literal`s\n\nsee","ref":"RDF.Term.html"},{"type":"function","title":"RDF.Term.coerce/1","doc":"Converts a given value into an RDF term.\n\nReturns `nil` if the given value is not convertible into any valid RDF.Term.","ref":"RDF.Term.html#coerce/1"},{"type":"function","title":"Examples - RDF.Term.coerce/1","doc":"iex> RDF.Term.coerce(\"foo\")\n    ~L\"foo\"\n    iex> RDF.Term.coerce(42)\n    RDF.XSD.integer(42)","ref":"RDF.Term.html#coerce/1-examples"},{"type":"function","title":"RDF.Term.equal?/2","doc":"Tests for term equality.\n\nsee","ref":"RDF.Term.html#equal?/2"},{"type":"function","title":"RDF.Term.equal_value?/2","doc":"Tests for equality of values.\n\nNon-RDF terms are tried to be coerced via `RDF.Term.coerce/1` before comparison.\n\nReturns `nil` if the given terms are not comparable.\n\nsee  \nand the value equality semantics of the different literal datatypes here:","ref":"RDF.Term.html#equal_value?/2"},{"type":"function","title":"RDF.Term.term?/1","doc":"Checks if the given value is an RDF term.\n\nNote: As opposed to `RDF.term?` this function returns `false` on atoms and does\nnot try to resolve them to IRIs.","ref":"RDF.Term.html#term?/1"},{"type":"function","title":"Examples - RDF.Term.term?/1","doc":"iex> RDF.Term.term?(RDF.iri(\"http://example.com/resource\"))\n    true\n    iex> RDF.Term.term?(EX.Resource)\n    false\n    iex> RDF.Term.term?(RDF.bnode)\n    true\n    iex> RDF.Term.term?(RDF.XSD.integer(42))\n    true\n    iex> RDF.Term.term?(42)\n    false","ref":"RDF.Term.html#term?/1-examples"},{"type":"function","title":"RDF.Term.value/1","doc":"Returns the native Elixir value of an RDF term.\n\nReturns `nil` if the given value is not a valid RDF term or a value convertible to an RDF term.","ref":"RDF.Term.html#value/1"},{"type":"function","title":"Examples - RDF.Term.value/1","doc":"iex> RDF.Term.value(~I )\n    \"http://example.com/\"\n    iex> RDF.Term.value(~L\"foo\")\n    \"foo\"\n    iex> RDF.XSD.integer(42) |> RDF.Term.value()\n    42","ref":"RDF.Term.html#value/1-examples"},{"type":"type","title":"RDF.Term.t/0","doc":"","ref":"RDF.Term.html#t:t/0"},{"type":"protocol","title":"RDF.Data","doc":"An abstraction over the different data structures for collections of RDF statements.","ref":"RDF.Data.html"},{"type":"function","title":"RDF.Data.delete/3","doc":"Deletes statements from an RDF data structure.\n\nAs opposed to the `delete` functions on RDF data structures directly, this\nfunction only deletes exactly matching structures.","ref":"RDF.Data.html#delete/3"},{"type":"function","title":"RDF.Data.describes?/2","doc":"Checks if an RDF data structure contains statements about the given resource.","ref":"RDF.Data.html#describes?/2"},{"type":"function","title":"RDF.Data.description/2","doc":"Returns a `RDF.Description` of the given subject.\n\nNote: On a `RDF.Dataset` this will return an aggregated `RDF.Description` with\nthe statements about this subject from all graphs.","ref":"RDF.Data.html#description/2"},{"type":"function","title":"RDF.Data.descriptions/1","doc":"Returns all `RDF.Description`s within an RDF data structure.\n\nNote: On a `RDF.Dataset` this will return aggregated `RDF.Description`s about\nthe same subject from all graphs.","ref":"RDF.Data.html#descriptions/1"},{"type":"function","title":"RDF.Data.empty?/1","doc":"Returns if the given RDF data structure is empty.","ref":"RDF.Data.html#empty?/1"},{"type":"function","title":"RDF.Data.equal?/2","doc":"Checks if two RDF data structures are equal.\n\nTwo RDF data structures are considered to be equal if they contain the same triples.\n\n- comparing two `RDF.Description`s it's just the same as `RDF.Description.equal?/2`\n- comparing two `RDF.Graph`s differs in `RDF.Graph.equal?/2` in that the graph\n  name is ignored\n- comparing two `RDF.Dataset`s differs in `RDF.Dataset.equal?/2` in that the\n  dataset name is ignored\n- a `RDF.Description` is equal to a `RDF.Graph`, if the graph has just one\n  description which equals the given description\n- a `RDF.Description` is equal to a `RDF.Dataset`, if the dataset has just one\n  graph which contains only the given description\n- a `RDF.Graph` is equal to a `RDF.Dataset`, if the dataset has just one\n  graph which equals the given graph; note that in this case the graph names\n  must match","ref":"RDF.Data.html#equal?/2"},{"type":"function","title":"RDF.Data.include?/3","doc":"Checks if the given statement exists within an RDF data structure.","ref":"RDF.Data.html#include?/3"},{"type":"function","title":"RDF.Data.map/2","doc":"Returns a map representation of an RDF data structure where each element from its statements is mapped with the given function.","ref":"RDF.Data.html#map/2"},{"type":"function","title":"RDF.Data.merge/3","doc":"Adds statements to an RDF data structure.\n\nAs opposed to the specific `add` functions on the RDF data structures, which\nalways return the same structure type than the first argument, `merge` might\nresult in another RDF data structure, e.g. merging two `RDF.Description` with\ndifferent subjects results in a `RDF.Graph` or adding a quad to a `RDF.Graph`\nwith a different name than the graph context of the quad results in a\n`RDF.Dataset`. But it is always guaranteed that the resulting structure has\na `RDF.Data` implementation.","ref":"RDF.Data.html#merge/3"},{"type":"function","title":"RDF.Data.objects/1","doc":"Returns the set of all resources used in the objects within the statements of an RDF data structure.","ref":"RDF.Data.html#objects/1"},{"type":"function","title":"RDF.Data.pop/1","doc":"Deletes one statement from an RDF data structure and returns a tuple with deleted statement and the changed data structure.","ref":"RDF.Data.html#pop/1"},{"type":"function","title":"RDF.Data.predicates/1","doc":"Returns the set of all properties used within the statements of an RDF data structure.","ref":"RDF.Data.html#predicates/1"},{"type":"function","title":"RDF.Data.resources/1","doc":"Returns the set of all resources used within the statements of an RDF data structure","ref":"RDF.Data.html#resources/1"},{"type":"function","title":"RDF.Data.statement_count/1","doc":"Returns the count of all statements of an RDF data structure.","ref":"RDF.Data.html#statement_count/1"},{"type":"function","title":"RDF.Data.statements/1","doc":"Returns the list of all statements of an RDF data structure.","ref":"RDF.Data.html#statements/1"},{"type":"function","title":"RDF.Data.subject_count/1","doc":"Returns the count of all resources which are subject of the statements of an RDF data structure.","ref":"RDF.Data.html#subject_count/1"},{"type":"function","title":"RDF.Data.subjects/1","doc":"Returns the set of all resources which are subject of the statements of an RDF data structure.","ref":"RDF.Data.html#subjects/1"},{"type":"function","title":"RDF.Data.values/2","doc":"Returns a nested map of the native Elixir values of an RDF data structure.\n\nWhen a `:context` option is given with a `RDF.PropertyMap`, predicates will\nbe mapped to the terms defined in the `RDF.PropertyMap`, if present.","ref":"RDF.Data.html#values/2"},{"type":"type","title":"RDF.Data.t/0","doc":"All the types that implement this protocol.","ref":"RDF.Data.html#t:t/0"},{"type":"module","title":"RDF.Dataset","doc":"A set of `RDF.Graph`s.\n\nIt may have multiple named graphs and at most one unnamed (\"default\") graph.\n\n`RDF.Dataset` implements:\n\n- Elixir's `Access` behaviour\n- Elixir's `Enumerable` protocol\n- Elixir's `Collectable` protocol\n- Elixir's `Inspect` protocol\n- the `RDF.Data` protocol","ref":"RDF.Dataset.html"},{"type":"function","title":"RDF.Dataset.add/3","doc":"Adds triples and quads to a `RDF.Dataset`.\n\nThe triples can be provided in any form accepted by `add/2`.\n\n- as a single statement tuple\n- an `RDF.Description`\n- an `RDF.Graph`\n- an `RDF.Dataset`\n- or a list with any combination of the former\n\nThe `graph` option allows to set a different destination graph to which the\nstatements should be added, ignoring the graph context of given quads or the\nname of given graphs in `input`.\n\nNote: When the statements to be added are given as another `RDF.Dataset` and\na destination graph is set with the `graph` option, the descriptions of the\nsubjects in the different graphs are aggregated.","ref":"RDF.Dataset.html#add/3"},{"type":"function","title":"RDF.Dataset.canonical_hash/2","doc":"Returns a hash of the canonical form of the given dataset.\n\nThis hash is computed as follows:\n\n1. Compute the canonical form of the dataset according to the RDF Dataset Canonicalization spec\n   using `canonicalize/1`.\n2. Serialize this canonical dataset to N-Quads sorted by Unicode code point order.\n3. Compute the SHA-256 of this N-Quads serialization.\n\nNote that the data structure is not relevant for the canonical hash, i.e.\nthe same hash is generated for the same data regardless of whether it is\npassed in an `RDF.Graph`, `RDF.Dataset` or `RDF.Description`.","ref":"RDF.Dataset.html#canonical_hash/2"},{"type":"function","title":"Options - RDF.Dataset.canonical_hash/2","doc":"- `:hash_algorithm` (default: `:sha256`): Allows to set the hash algorithm to be used in step 3.\n  Any of the `:crypto.hash_algorithm()` values of Erlang's `:crypto` module are allowed.\n  Note that this does NOT affect the hash function used during the","ref":"RDF.Dataset.html#canonical_hash/2-options"},{"type":"function","title":"Example - RDF.Dataset.canonical_hash/2","doc":"iex> RDF.Dataset.new([{~B , EX.p(), ~B }, {~B , EX.p(), ~B }])\n    ...> |> RDF.Dataset.canonical_hash()\n    \"053688e09a20a49acc3e1a5e6403c827b817eef9e4c90bfd71f2360e2a6446aa\"\n\n    iex> RDF.Graph.new([{~B , EX.p(), ~B }, {~B , EX.p(), ~B }])\n    ...> |> RDF.Graph.canonical_hash()\n    \"053688e09a20a49acc3e1a5e6403c827b817eef9e4c90bfd71f2360e2a6446aa\"","ref":"RDF.Dataset.html#canonical_hash/2-example"},{"type":"function","title":"RDF.Dataset.canonicalize/2","doc":"Canonicalizes the blank nodes of a dataset according to the RDF Dataset Canonicalization spec.\n\nSee the `RDF.Canonicalization` module documentation on available options.","ref":"RDF.Dataset.html#canonicalize/2"},{"type":"function","title":"Example - RDF.Dataset.canonicalize/2","doc":"iex> RDF.Dataset.new([{~B , EX.p(), ~B }, {~B , EX.p(), ~B }])\n    ...> |> RDF.Dataset.canonicalize()\n    RDF.Dataset.new([{~B , EX.p(), ~B }, {~B , EX.p(), ~B }])","ref":"RDF.Dataset.html#canonicalize/2-example"},{"type":"function","title":"RDF.Dataset.change_name/2","doc":"Changes the dataset name of `dataset`.","ref":"RDF.Dataset.html#change_name/2"},{"type":"function","title":"RDF.Dataset.default_graph/1","doc":"The default graph of a `RDF.Dataset`.","ref":"RDF.Dataset.html#default_graph/1"},{"type":"function","title":"Examples - RDF.Dataset.default_graph/1","doc":"iex> RDF.Dataset.new([\n    ...>   {EX.S1, EX.p1, EX.O1},\n    ...>   {EX.S2, EX.p2, EX.O2, EX.Graph1},\n    ...>   {EX.S1, EX.p2, EX.O3, EX.Graph2}])\n    ...> |> RDF.Dataset.default_graph()\n    Graph.new({EX.S1, EX.p1, EX.O1})","ref":"RDF.Dataset.html#default_graph/1-examples"},{"type":"function","title":"RDF.Dataset.delete/3","doc":"Deletes statements from a `RDF.Dataset`.\n\nThe `graph` option allows to set a different destination graph from which the\nstatements should be deleted, ignoring the graph context of given quads or the\nname of given graphs.\n\nNote: When the statements to be deleted are given as another `RDF.Dataset`,\nthe dataset name must not match dataset name of the dataset from which the statements\nare deleted. If you want to delete only datasets with matching names, you can\nuse `RDF.Data.delete/2`.","ref":"RDF.Dataset.html#delete/3"},{"type":"function","title":"RDF.Dataset.delete_default_graph/1","doc":"Deletes the default graph.","ref":"RDF.Dataset.html#delete_default_graph/1"},{"type":"function","title":"RDF.Dataset.delete_graph/2","doc":"Deletes the given graph.","ref":"RDF.Dataset.html#delete_graph/2"},{"type":"function","title":"RDF.Dataset.describes?/3","doc":"Checks if a graph of a `RDF.Dataset` contains statements about the given resource.","ref":"RDF.Dataset.html#describes?/3"},{"type":"function","title":"Examples - RDF.Dataset.describes?/3","doc":"iex> RDF.Dataset.new([{EX.S1, EX.p1, EX.O1}]) |> RDF.Dataset.describes?(EX.S1)\n      true\n      iex> RDF.Dataset.new([{EX.S1, EX.p1, EX.O1}]) |> RDF.Dataset.describes?(EX.S2)\n      false","ref":"RDF.Dataset.html#describes?/3-examples"},{"type":"function","title":"RDF.Dataset.empty?/1","doc":"Returns if the given `dataset` is empty.\n\nNote: You should always prefer this over the use of `Enum.empty?/1` as it is significantly faster.","ref":"RDF.Dataset.html#empty?/1"},{"type":"function","title":"RDF.Dataset.equal?/2","doc":"Checks if two `RDF.Dataset`s are equal.\n\nTwo `RDF.Dataset`s are considered to be equal if they contain the same triples\nand have the same name.","ref":"RDF.Dataset.html#equal?/2"},{"type":"function","title":"RDF.Dataset.fetch/2","doc":"Fetches the `RDF.Graph` with the given name.\n\nWhen a graph with the given name can not be found can not be found `:error` is returned.","ref":"RDF.Dataset.html#fetch/2"},{"type":"function","title":"Examples - RDF.Dataset.fetch/2","doc":"iex> dataset = RDF.Dataset.new([{EX.S1, EX.P1, EX.O1, EX.Graph}, {EX.S2, EX.P2, EX.O2}])\n    ...> RDF.Dataset.fetch(dataset, EX.Graph)\n    {:ok, RDF.Graph.new({EX.S1, EX.P1, EX.O1}, name: EX.Graph)}\n    iex> RDF.Dataset.fetch(dataset, nil)\n    {:ok, RDF.Graph.new({EX.S2, EX.P2, EX.O2})}\n    iex> RDF.Dataset.fetch(dataset, EX.Foo)\n    :error","ref":"RDF.Dataset.html#fetch/2-examples"},{"type":"function","title":"RDF.Dataset.get/3","doc":"Fetches the `RDF.Graph` with the given name.\n\nWhen a graph with the given name can not be found can not be found the optionally\ngiven default value or `nil` is returned","ref":"RDF.Dataset.html#get/3"},{"type":"function","title":"Examples - RDF.Dataset.get/3","doc":"iex> dataset = RDF.Dataset.new([{EX.S1, EX.P1, EX.O1, EX.Graph}, {EX.S2, EX.P2, EX.O2}])\n    ...> RDF.Dataset.get(dataset, EX.Graph)\n    RDF.Graph.new({EX.S1, EX.P1, EX.O1}, name: EX.Graph)\n    iex> RDF.Dataset.get(dataset, nil)\n    RDF.Graph.new({EX.S2, EX.P2, EX.O2})\n    iex> RDF.Dataset.get(dataset, EX.Foo)\n    nil\n    iex> RDF.Dataset.get(dataset, EX.Foo, :bar)\n    :bar","ref":"RDF.Dataset.html#get/3-examples"},{"type":"function","title":"RDF.Dataset.get_and_update/3","doc":"Gets and updates the graph with the given name, in a single pass.\n\nInvokes the passed function on the `RDF.Graph` with the given name;\nthis function should return either `{graph_to_return, new_graph}` or `:pop`.\n\nIf the passed function returns `{graph_to_return, new_graph}`, the\nreturn value of `get_and_update` is `{graph_to_return, new_dataset}` where\n`new_dataset` is the input `Dataset` updated with `new_graph` for\nthe given name.\n\nIf the passed function returns `:pop` the graph with the given name is\nremoved and a `{removed_graph, new_dataset}` tuple gets returned.","ref":"RDF.Dataset.html#get_and_update/3"},{"type":"function","title":"Examples - RDF.Dataset.get_and_update/3","doc":"iex> dataset = RDF.Dataset.new({EX.S, EX.P, EX.O, EX.Graph})\n    ...> RDF.Dataset.get_and_update(dataset, EX.Graph, fn current_graph ->\n    ...>     {current_graph, {EX.S, EX.P, EX.NEW}}\n    ...>   end)\n    {RDF.Graph.new({EX.S, EX.P, EX.O}, name: EX.Graph), RDF.Dataset.new({EX.S, EX.P, EX.NEW, EX.Graph})}","ref":"RDF.Dataset.html#get_and_update/3-examples"},{"type":"function","title":"RDF.Dataset.graph/2","doc":"The graph with given name.","ref":"RDF.Dataset.html#graph/2"},{"type":"function","title":"RDF.Dataset.graph_count/1","doc":"The number of graphs within a `RDF.Dataset`.","ref":"RDF.Dataset.html#graph_count/1"},{"type":"function","title":"Examples - RDF.Dataset.graph_count/1","doc":"iex> RDF.Dataset.new([\n    ...>   {EX.S1, EX.p1, EX.O1},\n    ...>   {EX.S2, EX.p2, EX.O2},\n    ...>   {EX.S1, EX.p2, EX.O3, EX.Graph}])\n    ...> |> RDF.Dataset.graph_count()\n    2","ref":"RDF.Dataset.html#graph_count/1-examples"},{"type":"function","title":"RDF.Dataset.graph_names/1","doc":"A list of all graph names within the dataset.\n\nNote, that this includes `nil` when the dataset has a default graph.","ref":"RDF.Dataset.html#graph_names/1"},{"type":"function","title":"Examples - RDF.Dataset.graph_names/1","doc":"iex> RDF.Dataset.new([\n    ...>   {EX.S1, EX.p1, EX.O1},\n    ...>   {EX.S2, EX.p2, EX.O2, EX.Graph1},\n    ...>   {EX.S1, EX.p2, EX.O3, EX.Graph2}])\n    ...> |> RDF.Dataset.graph_names()\n    [nil, RDF.iri(EX.Graph1), RDF.iri(EX.Graph2)]","ref":"RDF.Dataset.html#graph_names/1-examples"},{"type":"function","title":"RDF.Dataset.graphs/1","doc":"A list of all graphs within the dataset.","ref":"RDF.Dataset.html#graphs/1"},{"type":"function","title":"RDF.Dataset.include?/3","doc":"Checks if the given `input` statements exist within `dataset`.\n\nThe `graph` option allows to set a different destination graph in which the\nstatements should be checked, ignoring the graph context of given quads or the\nname of given graphs.","ref":"RDF.Dataset.html#include?/3"},{"type":"function","title":"Examples - RDF.Dataset.include?/3","doc":"iex> dataset = RDF.Dataset.new([\n      ...>   {EX.S1, EX.p1, EX.O1, EX.Graph},\n      ...>   {EX.S2, EX.p2, EX.O2},\n      ...>   {EX.S1, EX.p2, EX.O3}])\n      ...> RDF.Dataset.include?(dataset, {EX.S1, EX.p1, EX.O1, EX.Graph})\n      true","ref":"RDF.Dataset.html#include?/3-examples"},{"type":"function","title":"RDF.Dataset.intersection/2","doc":"Returns a new dataset that is the intersection of the given `dataset` with the given `data`.\n\nThe `data` can be given in any form an `RDF.Dataset` can be created from.","ref":"RDF.Dataset.html#intersection/2"},{"type":"function","title":"Examples - RDF.Dataset.intersection/2","doc":"iex> RDF.Dataset.new([\n    ...>   {EX.S1, EX.p(), [EX.O1, EX.O2]},\n    ...>   {EX.S2, EX.p(), EX.O3, EX.Graph}\n    ...> ])\n    ...> |> RDF.Dataset.intersection([\n    ...>     {EX.S1, EX.p(), EX.O2},\n    ...>     {EX.S2, EX.p(), EX.O3}\n    ...>   ])\n    RDF.Dataset.new({EX.S1, EX.p(), EX.O2})","ref":"RDF.Dataset.html#intersection/2-examples"},{"type":"function","title":"RDF.Dataset.isomorphic?/2","doc":"","ref":"RDF.Dataset.html#isomorphic?/2"},{"type":"function","title":"RDF.Dataset.map/2","doc":"Returns a nested map of a `RDF.Dataset` where each element from its quads is mapped with the given function.\n\nThe function `fun` will receive a tuple `{statement_position, rdf_term}` where\n`statement_position` is one of the atoms `:subject`, `:predicate`, `:object` or\n`:graph_name` while `rdf_term` is the RDF term to be mapped. When the given function\nreturns `nil` this will be interpreted as an error and will become the overhaul\nresult of the `map/2` call.","ref":"RDF.Dataset.html#map/2"},{"type":"function","title":"Examples - RDF.Dataset.map/2","doc":"iex> [\n    ...>   {~I , ~I , ~L\"Foo\", ~I },\n    ...>   {~I , ~I , RDF.XSD.integer(42), }\n    ...> ]\n    ...> |> RDF.Dataset.new()\n    ...> |> RDF.Dataset.map(fn\n    ...>      {:graph_name, graph_name} ->\n    ...>        graph_name\n    ...>      {:predicate, predicate} ->\n    ...>        predicate\n    ...>        |> to_string()\n    ...>        |> String.split(\"/\")\n    ...>        |> List.last()\n    ...>        |> String.to_atom()\n    ...>    {_, term} ->\n    ...>      RDF.Term.value(term)\n    ...>    end)\n    %{\n      ~I  => %{\n        \"http://example.com/S\" => %{p: [\"Foo\"]}\n      },\n      nil => %{\n        \"http://example.com/S\" => %{p: [42]}\n      }\n    }","ref":"RDF.Dataset.html#map/2-examples"},{"type":"function","title":"RDF.Dataset.name/1","doc":"Returns the dataset name IRI of `dataset`.","ref":"RDF.Dataset.html#name/1"},{"type":"function","title":"RDF.Dataset.named_graphs/1","doc":"The named graphs of a `RDF.Dataset`.","ref":"RDF.Dataset.html#named_graphs/1"},{"type":"function","title":"Examples - RDF.Dataset.named_graphs/1","doc":"iex> RDF.Dataset.new([\n    ...>   {EX.S1, EX.p1, EX.O1},\n    ...>   {EX.S2, EX.p2, EX.O2, EX.Graph1},\n    ...>   {EX.S1, EX.p2, EX.O3, EX.Graph2}])\n    ...> |> RDF.Dataset.named_graphs()\n    [\n      Graph.new({EX.S2, EX.p2, EX.O2}, name: EX.Graph1),\n      Graph.new({EX.S1, EX.p2, EX.O3}, name: EX.Graph2)\n    ]","ref":"RDF.Dataset.html#named_graphs/1-examples"},{"type":"function","title":"RDF.Dataset.new/0","doc":"Creates an empty unnamed `RDF.Dataset`.","ref":"RDF.Dataset.html#new/0"},{"type":"function","title":"RDF.Dataset.new/1","doc":"Creates an `RDF.Dataset`.\n\nIf a keyword list is given an empty dataset is created.\nOtherwise, an unnamed dataset initialized with the given data is created.\n\nSee `new/2` for available arguments and the different ways to provide data.","ref":"RDF.Dataset.html#new/1"},{"type":"function","title":"Examples - RDF.Dataset.new/1","doc":"RDF.Dataset.new(name: EX.GraphName)\n\n    RDF.Dataset.new(init: {EX.S, EX.p, EX.O})\n\n    RDF.Dataset.new({EX.S, EX.p, EX.O})","ref":"RDF.Dataset.html#new/1-examples"},{"type":"function","title":"RDF.Dataset.new/2","doc":"Creates an `RDF.Dataset` initialized with data.\n\nThe initial RDF triples can be provided in any form accepted by `add/3`.\n\nAvailable options:\n\n- `name`: the name of the dataset to be created\n- `init`: some data with which the dataset should be initialized; the data can be\n  provided in any form accepted by `add/3` and above that also with a function returning\n  the initialization data in any of these forms","ref":"RDF.Dataset.html#new/2"},{"type":"function","title":"RDF.Dataset.objects/1","doc":"The set of all resources used in the objects within a `RDF.Dataset`.\n\nNote: This function does collect only IRIs and BlankNodes, not Literals.","ref":"RDF.Dataset.html#objects/1"},{"type":"function","title":"Examples - RDF.Dataset.objects/1","doc":"iex> RDF.Dataset.new([\n    ...>   {EX.S1, EX.p1, EX.O1, EX.Graph},\n    ...>   {EX.S2, EX.p2, EX.O2, EX.Graph},\n    ...>   {EX.S3, EX.p1, EX.O2},\n    ...>   {EX.S4, EX.p2, RDF.bnode(:bnode)},\n    ...>   {EX.S5, EX.p3, \"foo\"}\n    ...> ]) |> RDF.Dataset.objects()\n    MapSet.new([RDF.iri(EX.O1), RDF.iri(EX.O2), RDF.bnode(:bnode)])","ref":"RDF.Dataset.html#objects/1-examples"},{"type":"function","title":"RDF.Dataset.pop/1","doc":"Pops an arbitrary statement from a `RDF.Dataset`.","ref":"RDF.Dataset.html#pop/1"},{"type":"function","title":"RDF.Dataset.pop/2","doc":"Pops the graph with the given name.\n\nRemoves the graph of the given `graph_name` from `dataset`.\n\nReturns a tuple containing the graph of the given name\nand the updated dataset without this graph.\n`nil` is returned instead of the graph if `dataset` does\nnot contain a graph_name of the given `graph_name`.","ref":"RDF.Dataset.html#pop/2"},{"type":"function","title":"Examples - RDF.Dataset.pop/2","doc":"iex> dataset = RDF.Dataset.new([\n    ...>   {EX.S1, EX.P1, EX.O1, EX.Graph},\n    ...>   {EX.S2, EX.P2, EX.O2}])\n    ...> RDF.Dataset.pop(dataset, EX.Graph)\n    {\n      RDF.Graph.new({EX.S1, EX.P1, EX.O1}, name: EX.Graph),\n      RDF.Dataset.new({EX.S2, EX.P2, EX.O2})\n    }\n    iex> RDF.Dataset.pop(dataset, EX.Foo)\n    {nil, dataset}","ref":"RDF.Dataset.html#pop/2-examples"},{"type":"function","title":"RDF.Dataset.predicates/1","doc":"The set of all properties used in the predicates within all graphs of a `RDF.Dataset`.","ref":"RDF.Dataset.html#predicates/1"},{"type":"function","title":"Examples - RDF.Dataset.predicates/1","doc":"iex> RDF.Dataset.new([\n    ...>   {EX.S1, EX.p1, EX.O1, EX.Graph},\n    ...>   {EX.S2, EX.p2, EX.O2},\n    ...>   {EX.S1, EX.p2, EX.O3}]) |>\n    ...>   RDF.Dataset.predicates()\n    MapSet.new([EX.p1, EX.p2])","ref":"RDF.Dataset.html#predicates/1-examples"},{"type":"function","title":"RDF.Dataset.prefixes/1","doc":"Returns the aggregated prefixes of all graphs of `dataset` as a `RDF.PrefixMap`.","ref":"RDF.Dataset.html#prefixes/1"},{"type":"function","title":"RDF.Dataset.put/3","doc":"Adds statements to a `RDF.Dataset` overwriting existing statements with the subjects given in the `input` data.\n\nBy overwriting statements with the same subject, this function has a similar\nsemantics as `RDF.Graph.put/3`, if you want to replace whole graphs use\n`put_graph/3` instead.\n\nThe `graph` option allows to set a different destination graph to which the\nstatements should be added, ignoring the graph context of given quads or the\nname of given graphs in `input`.\n\nNote: When the statements to be added are given as another `RDF.Dataset` and\na destination graph is set with the `graph` option, the descriptions of the\nsubjects in the different graphs are aggregated.","ref":"RDF.Dataset.html#put/3"},{"type":"function","title":"Examples - RDF.Dataset.put/3","doc":"iex> dataset = RDF.Dataset.new({EX.S, EX.P1, EX.O1})\n    ...> RDF.Dataset.put(dataset, {EX.S, EX.P2, EX.O2})\n    RDF.Dataset.new({EX.S, EX.P2, EX.O2})\n    iex> RDF.Dataset.put(dataset, {EX.S2, EX.P2, EX.O2})\n    RDF.Dataset.new([{EX.S, EX.P1, EX.O1}, {EX.S2, EX.P2, EX.O2}])","ref":"RDF.Dataset.html#put/3-examples"},{"type":"function","title":"RDF.Dataset.put_graph/3","doc":"Adds new graphs to a `RDF.Dataset` overwriting any existing graphs with the same name.\n\nThe `graph` option allows to set a different destination graph to which the\nstatements should be added, ignoring the graph context of given quads or the\nname of given graphs in `input`.\n\nNote: When the statements to be added are given as another `RDF.Dataset` and\na destination graph is set with the `graph` option, the descriptions of the\nsubjects in the different graphs are aggregated.","ref":"RDF.Dataset.html#put_graph/3"},{"type":"function","title":"RDF.Dataset.put_properties/3","doc":"Adds statements to a `RDF.Dataset` and overwrites all existing statements with the same subject-predicate combinations given in the `input` data.\n\nThe `graph` option allows to set a different destination graph to which the\nstatements should be added, ignoring the graph context of given quads or the\nname of given graphs in `input`.\n\nNote: When the statements to be added are given as another `RDF.Dataset` and\na destination graph is set with the `graph` option, the descriptions of the\nsubjects in the different graphs are aggregated.","ref":"RDF.Dataset.html#put_properties/3"},{"type":"function","title":"Examples - RDF.Dataset.put_properties/3","doc":"iex> dataset = RDF.Dataset.new({EX.S, EX.P1, EX.O1})\n    ...> RDF.Dataset.put_properties(dataset, {EX.S, EX.P1, EX.O2})\n    RDF.Dataset.new({EX.S, EX.P1, EX.O2})\n    iex> RDF.Dataset.put_properties(dataset, {EX.S, EX.P2, EX.O2})\n    RDF.Dataset.new([{EX.S, EX.P1, EX.O1}, {EX.S, EX.P2, EX.O2}])\n    iex> RDF.Dataset.new([{EX.S1, EX.P1, EX.O1}, {EX.S2, EX.P2, EX.O2}])\n    ...> |> RDF.Dataset.put_properties([{EX.S1, EX.P2, EX.O3}, {EX.S2, EX.P2, EX.O3}])\n    RDF.Dataset.new([{EX.S1, EX.P1, EX.O1}, {EX.S1, EX.P2, EX.O3}, {EX.S2, EX.P2, EX.O3}])","ref":"RDF.Dataset.html#put_properties/3-examples"},{"type":"function","title":"RDF.Dataset.quads/2","doc":"All statements within all graphs of a `RDF.Dataset` as quads.\n\nWhen the optional `:filter_star` flag is set to `true` RDF-star statements with\na triple as subject or object will be filtered. The default value is `false`.","ref":"RDF.Dataset.html#quads/2"},{"type":"function","title":"Examples - RDF.Dataset.quads/2","doc":"iex> RDF.Dataset.new([\n      ...>   {EX.S1, EX.p1, EX.O1, EX.Graph},\n      ...>   {EX.S2, EX.p2, EX.O2},\n      ...>   {EX.S1, EX.p2, EX.O3}])\n      ...> |> RDF.Dataset.quads()\n      [{RDF.iri(EX.S1), RDF.iri(EX.p2), RDF.iri(EX.O3), nil},\n       {RDF.iri(EX.S2), RDF.iri(EX.p2), RDF.iri(EX.O2), nil},\n       {RDF.iri(EX.S1), RDF.iri(EX.p1), RDF.iri(EX.O1), RDF.iri(EX.Graph)}]","ref":"RDF.Dataset.html#quads/2-examples"},{"type":"function","title":"RDF.Dataset.resources/1","doc":"The set of all resources used within a `RDF.Dataset`.","ref":"RDF.Dataset.html#resources/1"},{"type":"function","title":"Examples - RDF.Dataset.resources/1","doc":"iex> RDF.Dataset.new([\n  ...>   {EX.S1, EX.p1, EX.O1, EX.Graph},\n  ...>   {EX.S2, EX.p1, EX.O2, EX.Graph},\n  ...>   {EX.S2, EX.p2, RDF.bnode(:bnode)},\n  ...>   {EX.S3, EX.p1, \"foo\"}\n  ...> ]) |> RDF.Dataset.resources()\n  MapSet.new([RDF.iri(EX.S1), RDF.iri(EX.S2), RDF.iri(EX.S3),\n    RDF.iri(EX.O1), RDF.iri(EX.O2), RDF.bnode(:bnode), EX.p1, EX.p2])","ref":"RDF.Dataset.html#resources/1-examples"},{"type":"function","title":"RDF.Dataset.statement_count/1","doc":"The number of statements within a `RDF.Dataset`.","ref":"RDF.Dataset.html#statement_count/1"},{"type":"function","title":"Examples - RDF.Dataset.statement_count/1","doc":"iex> RDF.Dataset.new([\n    ...>   {EX.S1, EX.p1, EX.O1, EX.Graph},\n    ...>   {EX.S2, EX.p2, EX.O2},\n    ...>   {EX.S1, EX.p2, EX.O3}]) |>\n    ...>   RDF.Dataset.statement_count()\n    3","ref":"RDF.Dataset.html#statement_count/1-examples"},{"type":"function","title":"RDF.Dataset.statements/2","doc":"All statements within all graphs of a `RDF.Dataset`.\n\nWhile the statements of named graphs are returned as quad tuples, the statements\nof the default graph are returned as triples. If you want to get quads or triples\nuniformly, use the `quads/2` resp. `triples/2` functions instead.\n\nWhen the optional `:filter_star` flag is set to `true` RDF-star statements with\na triple as subject or object will be filtered. The default value is `false`.","ref":"RDF.Dataset.html#statements/2"},{"type":"function","title":"Examples - RDF.Dataset.statements/2","doc":"iex> RDF.Dataset.new([\n      ...>   {EX.S1, EX.p1, EX.O1, EX.Graph},\n      ...>   {EX.S2, EX.p2, EX.O2},\n      ...>   {EX.S1, EX.p2, EX.O3}])\n      ...> |> RDF.Dataset.statements()\n      [{RDF.iri(EX.S1), RDF.iri(EX.p2), RDF.iri(EX.O3)},\n       {RDF.iri(EX.S2), RDF.iri(EX.p2), RDF.iri(EX.O2)},\n       {RDF.iri(EX.S1), RDF.iri(EX.p1), RDF.iri(EX.O1), RDF.iri(EX.Graph)}]","ref":"RDF.Dataset.html#statements/2-examples"},{"type":"function","title":"RDF.Dataset.subjects/1","doc":"The set of all subjects used in the statement within all graphs of a `RDF.Dataset`.","ref":"RDF.Dataset.html#subjects/1"},{"type":"function","title":"Examples - RDF.Dataset.subjects/1","doc":"iex> RDF.Dataset.new([\n    ...>   {EX.S1, EX.p1, EX.O1, EX.Graph},\n    ...>   {EX.S2, EX.p2, EX.O2},\n    ...>   {EX.S1, EX.p2, EX.O3}]) |>\n    ...>   RDF.Dataset.subjects()\n    MapSet.new([RDF.iri(EX.S1), RDF.iri(EX.S2)])","ref":"RDF.Dataset.html#subjects/1-examples"},{"type":"function","title":"RDF.Dataset.triples/2","doc":"All statements within all graphs of a `RDF.Dataset` as triples.\n\nWhen the optional `:filter_star` flag is set to `true` RDF-star statements with\na triple as subject or object will be filtered. The default value is `false`.\n\nNote: When a triple is present in multiple graphs it will be present in the resulting\nlist of triples multiple times for performance reasons. If you want to get a list with\nunique triples, you'll have to apply `Enum.uniq/1` on the result.","ref":"RDF.Dataset.html#triples/2"},{"type":"function","title":"Examples - RDF.Dataset.triples/2","doc":"iex> RDF.Dataset.new([\n      ...>   {EX.S1, EX.p1, EX.O1, EX.Graph},\n      ...>   {EX.S2, EX.p2, EX.O2},\n      ...>   {EX.S1, EX.p2, EX.O3}])\n      ...> |> RDF.Dataset.triples()\n      [{RDF.iri(EX.S1), RDF.iri(EX.p2), RDF.iri(EX.O3)},\n       {RDF.iri(EX.S2), RDF.iri(EX.p2), RDF.iri(EX.O2)},\n       {RDF.iri(EX.S1), RDF.iri(EX.p1), RDF.iri(EX.O1)}]","ref":"RDF.Dataset.html#triples/2-examples"},{"type":"function","title":"RDF.Dataset.update/4","doc":"Updates a graph in `dataset` with the given function.\n\nIf `graph_name` is present in `dataset`, `fun` is invoked with argument `graph`\nand its result is used as the new graph with the given `graph_name`.\nIf `graph_name` is not present in `dataset`, `initial` is inserted with the\ngiven `graph_name`. If no `initial` value is given, the `dataset` remains unchanged.\nIf `nil` is returned by `fun`, the respective graph will be removed from `dataset`.\n\nThe initial value and the returned values by the update function will be\ncoerced to proper RDF graphs before added. If the initial or returned\ngraph is a `RDF.Graph` with another graph name, it will still be added\nusing the given `graph_name`.","ref":"RDF.Dataset.html#update/4"},{"type":"function","title":"Examples - RDF.Dataset.update/4","doc":"iex> RDF.Dataset.new({EX.S, EX.p, EX.O, EX.Graph})\n    ...> |> RDF.Dataset.update(EX.Graph,\n    ...>      fn graph -> RDF.Graph.add(graph, {EX.S, EX.p, EX.O2})\n    ...>    end)\n    RDF.Dataset.new([{EX.S, EX.p, EX.O, EX.Graph}, {EX.S, EX.p, EX.O2, EX.Graph}])\n\n    iex> RDF.Dataset.new()\n    ...> |> RDF.Dataset.update(EX.Graph, RDF.Graph.new({EX.S, EX.p, EX.O}),\n    ...>      fn graph -> RDF.Graph.add(graph, {EX.S, EX.p, EX.O2})\n    ...>    end)\n    RDF.Dataset.new([{EX.S, EX.p, EX.O, EX.Graph}])","ref":"RDF.Dataset.html#update/4-examples"},{"type":"function","title":"RDF.Dataset.update_all_graphs/2","doc":"Updates all graphs in `dataset` with the given function.\n\nThe same behaviour as described in `RDF.Dataset.update/4` apply.\nIf `nil` is returned by `fun`, the respective graph will be removed from `dataset`.\nThe returned values by the update function will be coerced to proper RDF graphs before added.\nIf the returned graph is a `RDF.Graph` with another graph name, it will still be added\nusing the old graph name.","ref":"RDF.Dataset.html#update_all_graphs/2"},{"type":"function","title":"Examples - RDF.Dataset.update_all_graphs/2","doc":"iex> RDF.Dataset.new([{EX.S1, EX.p1, EX.O1}, {EX.S2, EX.p2, EX.O2, EX.Graph}])\n    ...> |> RDF.Dataset.update_all_graphs(&(RDF.Graph.add_prefixes(&1, ex: EX )))\n    [\n      RDF.Graph.new({EX.S1, EX.p1, EX.O1}, prefixes: [ex: EX]),\n      RDF.Graph.new({EX.S2, EX.p2, EX.O2}, prefixes: [ex: EX], name: EX.Graph)\n    ] |> RDF.Dataset.new()","ref":"RDF.Dataset.html#update_all_graphs/2-examples"},{"type":"function","title":"RDF.Dataset.values/2","doc":"Returns a nested map of the native Elixir values of a `RDF.Dataset`.\n\nWhen a `:context` option is given with a `RDF.PropertyMap`, predicates will\nbe mapped to the terms defined in the `RDF.PropertyMap`, if present.","ref":"RDF.Dataset.html#values/2"},{"type":"function","title":"Examples - RDF.Dataset.values/2","doc":"iex> [\n    ...>   {~I , ~I , ~L\"Foo\", ~I },\n    ...>   {~I , ~I , RDF.XSD.integer(42), }\n    ...> ]\n    ...> |> RDF.Dataset.new()\n    ...> |> RDF.Dataset.values()\n    %{\n      \"http://example.com/Graph\" => %{\n        \"http://example.com/S\" => %{\"http://example.com/p\" => [\"Foo\"]}\n      },\n      nil => %{\n        \"http://example.com/S\" => %{\"http://example.com/p\" => [42]}\n      }\n    }","ref":"RDF.Dataset.html#values/2-examples"},{"type":"function","title":"RDF.Dataset.who_describes/2","doc":"Returns the names of all graphs of a `RDF.Dataset` containing statements about the given subject.","ref":"RDF.Dataset.html#who_describes/2"},{"type":"function","title":"Examples - RDF.Dataset.who_describes/2","doc":"iex> dataset = RDF.Dataset.new([\n      ...>   {EX.S1, EX.p, EX.O},\n      ...>   {EX.S2, EX.p, EX.O},\n      ...>   {EX.S1, EX.p, EX.O, EX.Graph1},\n      ...>   {EX.S2, EX.p, EX.O, EX.Graph2}])\n      ...> RDF.Dataset.who_describes(dataset, EX.S1)\n      [nil, RDF.iri(EX.Graph1)]","ref":"RDF.Dataset.html#who_describes/2-examples"},{"type":"type","title":"RDF.Dataset.get_and_update_graph_fun/0","doc":"","ref":"RDF.Dataset.html#t:get_and_update_graph_fun/0"},{"type":"type","title":"RDF.Dataset.graph_name/0","doc":"","ref":"RDF.Dataset.html#t:graph_name/0"},{"type":"type","title":"RDF.Dataset.input/0","doc":"","ref":"RDF.Dataset.html#t:input/0"},{"type":"type","title":"RDF.Dataset.t/0","doc":"","ref":"RDF.Dataset.html#t:t/0"},{"type":"type","title":"RDF.Dataset.update_graph_fun/0","doc":"","ref":"RDF.Dataset.html#t:update_graph_fun/0"},{"type":"module","title":"RDF.Description","doc":"A set of RDF triples about the same subject.\n\n`RDF.Description` implements:\n\n- Elixir's `Access` behaviour\n- Elixir's `Enumerable` protocol\n- Elixir's `Collectable` protocol\n- Elixir's `Inspect` protocol\n- the `RDF.Data` protocol","ref":"RDF.Description.html"},{"type":"function","title":"RDF.Description.add/3","doc":"Add statements to a `RDF.Description`.\n\nNote: When the statements to be added are given as another `RDF.Description`,\nthe subject must not match subject of the description to which the statements\nare added. As opposed to that `RDF.Data.merge/2` will produce a `RDF.Graph`\ncontaining both descriptions.","ref":"RDF.Description.html#add/3"},{"type":"function","title":"Examples - RDF.Description.add/3","doc":"iex> RDF.Description.new(EX.S, init: {EX.P1, EX.O1})\n    ...> |> RDF.Description.add({EX.P2, EX.O2})\n    RDF.Description.new(EX.S, init: [{EX.P1, EX.O1}, {EX.P2, EX.O2}])\n\n    iex> RDF.Description.new(EX.S, init: {EX.P, EX.O1})\n    ...> |> RDF.Description.add({EX.P, [EX.O2, EX.O3]})\n    RDF.Description.new(EX.S, init: [{EX.P, EX.O1}, {EX.P, EX.O2}, {EX.P, EX.O3}])","ref":"RDF.Description.html#add/3-examples"},{"type":"function","title":"RDF.Description.canonical_hash/2","doc":"Returns a hash of the canonical form of the given description.\n\nSee `RDF.Dataset.canonical_hash/2` for more information.","ref":"RDF.Description.html#canonical_hash/2"},{"type":"function","title":"Example - RDF.Description.canonical_hash/2","doc":"iex> RDF.Description.new(EX.S, init: {EX.p(), EX.O})\n    ...> |> RDF.Description.canonical_hash()\n    \"4a883e60f7b38b89b72492f16114ea62cf9a21d0e232d066b1f59ef61c69ea12\"","ref":"RDF.Description.html#canonical_hash/2-example"},{"type":"function","title":"RDF.Description.change_subject/2","doc":"Changes the subject of a description.","ref":"RDF.Description.html#change_subject/2"},{"type":"function","title":"RDF.Description.count/1","doc":"","ref":"RDF.Description.html#count/1"},{"type":"function","title":"RDF.Description.delete/3","doc":"Deletes statements from a `RDF.Description`.\n\nNote: When the statements to be deleted are given as another `RDF.Description`,\nthe subject must not match subject of the description from which the statements\nare deleted. If you want to delete only a matching description subject, you can\nuse `RDF.Data.delete/2`.","ref":"RDF.Description.html#delete/3"},{"type":"function","title":"RDF.Description.delete_predicates/2","doc":"Deletes all statements with the given properties.","ref":"RDF.Description.html#delete_predicates/2"},{"type":"function","title":"RDF.Description.describes?/2","doc":"Checks if a `RDF.Description` has the given resource as subject.","ref":"RDF.Description.html#describes?/2"},{"type":"function","title":"Examples - RDF.Description.describes?/2","doc":"iex> RDF.Description.new(EX.S1, init: {EX.p1, EX.O1})\n      ...> |> RDF.Description.describes?(EX.S1)\n      true\n      iex> RDF.Description.new(EX.S1, init: {EX.p1, EX.O1})\n      ...> |> RDF.Description.describes?(EX.S2)\n      false","ref":"RDF.Description.html#describes?/2-examples"},{"type":"function","title":"RDF.Description.empty?/1","doc":"Returns if the given `description` is empty.\n\nNote: You should always prefer this over the use of `Enum.empty?/1` as it is significantly faster.","ref":"RDF.Description.html#empty?/1"},{"type":"function","title":"RDF.Description.equal?/2","doc":"Checks if two `RDF.Description`s are equal.\n\nTwo `RDF.Description`s are considered to be equal if they contain the same triples.","ref":"RDF.Description.html#equal?/2"},{"type":"function","title":"RDF.Description.fetch/2","doc":"Fetches the objects for the given predicate of a Description.\n\nWhen the predicate can not be found `:error` is returned.","ref":"RDF.Description.html#fetch/2"},{"type":"function","title":"Examples - RDF.Description.fetch/2","doc":"iex> RDF.Description.new(EX.S, init: {EX.p, EX.O}) |> RDF.Description.fetch(EX.p)\n    {:ok, [RDF.iri(EX.O)]}\n    iex> RDF.Description.new(EX.S, init: [{EX.P, EX.O1}, {EX.P, EX.O2}])\n    ...> |> RDF.Description.fetch(EX.P)\n    {:ok, [RDF.iri(EX.O1), RDF.iri(EX.O2)]}\n    iex> RDF.Description.new(EX.S) |> RDF.Description.fetch(EX.foo)\n    :error","ref":"RDF.Description.html#fetch/2-examples"},{"type":"function","title":"RDF.Description.first/3","doc":"Gets a single object for the given predicate of a Description.\n\nWhen the predicate can not be found, the optionally given default value or `nil` is returned.","ref":"RDF.Description.html#first/3"},{"type":"function","title":"Examples - RDF.Description.first/3","doc":"iex> RDF.Description.new(EX.S, init: {EX.P, EX.O}) |> RDF.Description.first(EX.P)\n    RDF.iri(EX.O)\n    iex> RDF.Description.new(EX.S) |> RDF.Description.first(EX.foo)\n    nil\n    iex> RDF.Description.new(EX.S) |> RDF.Description.first(EX.foo, :bar)\n    :bar","ref":"RDF.Description.html#first/3-examples"},{"type":"function","title":"RDF.Description.get/3","doc":"Gets the objects for the given predicate of a Description.\n\nWhen the predicate can not be found, the optionally given default value or `nil` is returned.","ref":"RDF.Description.html#get/3"},{"type":"function","title":"Examples - RDF.Description.get/3","doc":"iex> RDF.Description.new(EX.S, init: {EX.P, EX.O}) |> RDF.Description.get(EX.P)\n    [RDF.iri(EX.O)]\n    iex> RDF.Description.new(EX.S) |> RDF.Description.get(EX.foo)\n    nil\n    iex> RDF.Description.new(EX.S) |> RDF.Description.get(EX.foo, :bar)\n    :bar","ref":"RDF.Description.html#get/3-examples"},{"type":"function","title":"RDF.Description.get_and_update/3","doc":"Gets and updates the objects of the given predicate of a Description, in a single pass.\n\nInvokes the passed function on the objects of the given predicate; this\nfunction should return either `{objects_to_return, new_object}` or `:pop`.\n\nIf the passed function returns `{objects_to_return, new_objects}`, the return\nvalue of `get_and_update` is `{objects_to_return, new_description}` where\n`new_description` is the input `Description` updated with `new_objects` for\nthe given predicate.\n\nIf the passed function returns `:pop` the objects for the given predicate are\nremoved and a `{removed_objects, new_description}` tuple gets returned.","ref":"RDF.Description.html#get_and_update/3"},{"type":"function","title":"Examples - RDF.Description.get_and_update/3","doc":"iex> RDF.Description.new(EX.S, init: {EX.P, EX.O})\n    ...> |> RDF.Description.get_and_update(EX.P, fn current_objects ->\n    ...>      {current_objects, EX.New}\n    ...>    end)\n    {[RDF.iri(EX.O)], RDF.Description.new(EX.S, init: {EX.P, EX.New})}\n    iex> RDF.Graph.new([{EX.S, EX.P1, EX.O1}, {EX.S, EX.P2, EX.O2}])\n    ...> |> RDF.Graph.description(EX.S)\n    ...> |> RDF.Description.get_and_update(EX.P1, fn _ -> :pop end)\n    {[RDF.iri(EX.O1)], RDF.Description.new(EX.S, init: {EX.P2, EX.O2})}","ref":"RDF.Description.html#get_and_update/3-examples"},{"type":"function","title":"RDF.Description.include?/3","doc":"Checks if the given `input` statements exist within `description`.","ref":"RDF.Description.html#include?/3"},{"type":"function","title":"RDF.Description.intersection/2","doc":"Returns a new description that is the intersection of the given `description` with the given `data`.\n\nThe `data` can be given in any form an `RDF.Graph` can be created from.\nWhen a `RDF.Dataset` is given, the aggregated description of the subject of\n`description` is used for the intersection.","ref":"RDF.Description.html#intersection/2"},{"type":"function","title":"Examples - RDF.Description.intersection/2","doc":"iex> EX.S\n    ...> |> EX.p(EX.O1, EX.O2)\n    ...> |> RDF.Description.intersection(EX.S |> EX.p(EX.O2, EX.O3))\n    EX.S |> EX.p(EX.O2)\n\n    iex> EX.S\n    ...> |> EX.p(EX.O1, EX.O2)\n    ...> |> RDF.Description.intersection({EX.Other, EX.p, EX.O2, EX.O3})\n    RDF.Description.new(EX.S)","ref":"RDF.Description.html#intersection/2-examples"},{"type":"function","title":"RDF.Description.map/2","doc":"Returns a map of a `RDF.Description` where each element from its triples is mapped with the given function.\n\nThe subject is not part of the result. If you want the subject in an outer map,\njust put the description in a graph and use `RDF.Graph.map/2`.\n\nThe function `fun` will receive a tuple `{statement_position, rdf_term}` where\n`statement_position` is one of the atoms `:predicate` or `:object`, while\n`rdf_term` is the RDF term to be mapped. When the given function returns\n`nil` this will be interpreted as an error and will become the overhaul result\nof the `map/2` call.\n\nNote: RDF-star statements where the object is a triple will be ignored.","ref":"RDF.Description.html#map/2"},{"type":"function","title":"Examples - RDF.Description.map/2","doc":"iex> RDF.Description.new(~I , init: {~I , ~L\"Foo\"})\n    ...> |> RDF.Description.map(fn\n    ...>      {:predicate, predicate} ->\n    ...>        predicate\n    ...>        |> to_string()\n    ...>        |> String.split(\"/\")\n    ...>        |> List.last()\n    ...>        |> String.to_atom()\n    ...>    {_, term} ->\n    ...>      RDF.Term.value(term)\n    ...>    end)\n    %{p: [\"Foo\"]}","ref":"RDF.Description.html#map/2-examples"},{"type":"function","title":"RDF.Description.new/2","doc":"Creates an `RDF.Description` about the given subject.\n\nThe created `RDF.Description` can be initialized with any form of data which\n`add/2` understands with the `:init` option. Additionally, a function returning\nthe initialization data in any of these forms can be as the `:init` value.","ref":"RDF.Description.html#new/2"},{"type":"function","title":"Examples - RDF.Description.new/2","doc":"RDF.Description.new(EX.S)\n    RDF.Description.new(EX.S, init: {EX.S, EX.p, EX.O})\n    RDF.Description.new(EX.S, init: {EX.p, [EX.O1, EX.O2]})\n    RDF.Description.new(EX.S, init: [{EX.p1, EX.O1}, {EX.p2, EX.O2}])\n    RDF.Description.new(EX.S, init: RDF.Description.new(EX.S, init: {EX.P, EX.O}))\n    RDF.Description.new(EX.S, init: fn -> {EX.p, EX.O} end)","ref":"RDF.Description.html#new/2-examples"},{"type":"function","title":"RDF.Description.objects/1","doc":"The set of all resources used in the objects within a `RDF.Description`.\n\nNote: This function does collect only IRIs and BlankNodes, not Literals.","ref":"RDF.Description.html#objects/1"},{"type":"function","title":"Examples - RDF.Description.objects/1","doc":"iex> RDF.Description.new(EX.S1, init: [\n    ...>   {EX.p1, EX.O1},\n    ...>   {EX.p2, EX.O2},\n    ...>   {EX.p3, EX.O2},\n    ...>   {EX.p4, RDF.bnode(:bnode)},\n    ...>   {EX.p3, \"foo\"}])\n    ...> |> RDF.Description.objects()\n    MapSet.new([RDF.iri(EX.O1), RDF.iri(EX.O2), RDF.bnode(:bnode)])","ref":"RDF.Description.html#objects/1-examples"},{"type":"function","title":"RDF.Description.objects/2","doc":"The set of all resources used in the objects within a `RDF.Description` satisfying the given filter criterion.","ref":"RDF.Description.html#objects/2"},{"type":"function","title":"RDF.Description.pop/1","doc":"Pops an arbitrary triple from a `RDF.Description`.","ref":"RDF.Description.html#pop/1"},{"type":"function","title":"RDF.Description.pop/2","doc":"Pops the objects of the given predicate of a Description.\n\nRemoves the objects for the given `predicate` from `description`.\n\nReturns a tuple containing a list the objects for the given predicate\nand the updated description without the respective statements.\n`nil` is returned instead of the objects if `description` does\nnot contain any statements with the given `predicate`.","ref":"RDF.Description.html#pop/2"},{"type":"function","title":"Examples - RDF.Description.pop/2","doc":"iex> RDF.Description.new(EX.S, init: {EX.P, EX.O})\n    ...> |> RDF.Description.pop(EX.P)\n    {[RDF.iri(EX.O)], RDF.Description.new(EX.S)}\n\n    iex> RDF.Description.new(EX.S, init: {EX.P, EX.O})\n    ...> |> RDF.Description.pop(EX.Missing)\n    {nil, RDF.Description.new(EX.S, init: {EX.P, EX.O})}","ref":"RDF.Description.html#pop/2-examples"},{"type":"function","title":"RDF.Description.predicates/1","doc":"The set of all properties used in the predicates within a `RDF.Description`.","ref":"RDF.Description.html#predicates/1"},{"type":"function","title":"Examples - RDF.Description.predicates/1","doc":"iex> RDF.Description.new(EX.S1, init: [\n    ...>   {EX.p1, EX.O1},\n    ...>   {EX.p2, EX.O2},\n    ...>   {EX.p2, EX.O3}])\n    ...> |> RDF.Description.predicates()\n    MapSet.new([EX.p1, EX.p2])","ref":"RDF.Description.html#predicates/1-examples"},{"type":"function","title":"RDF.Description.put/3","doc":"Adds statements to a `RDF.Description` and overwrites all existing statements with already used predicates.\n\nNote: As it is a destructive function this function is stricter in its handling of\n`RDF.Description`s than `add/3`. The subject of a `RDF.Description` to be put must\nmatch. If you want to overwrite existing statements with those from the description of\nanother subject, you'll have to explicitly change the subject with `change_subject/2`\nfirst before using `put/3`.","ref":"RDF.Description.html#put/3"},{"type":"function","title":"Examples - RDF.Description.put/3","doc":"iex> RDF.Description.new(EX.S, init: {EX.P, EX.O1})\n    ...> |> RDF.Description.put({EX.P, EX.O2})\n    RDF.Description.new(EX.S, init: {EX.P, EX.O2})","ref":"RDF.Description.html#put/3-examples"},{"type":"function","title":"RDF.Description.rename_resource/3","doc":"Replaces all occurrences of `old_id` in `description` with `new_id`.","ref":"RDF.Description.html#rename_resource/3"},{"type":"function","title":"RDF.Description.resources/1","doc":"The set of all resources used within a `RDF.Description`.","ref":"RDF.Description.html#resources/1"},{"type":"function","title":"Examples - RDF.Description.resources/1","doc":"iex> RDF.Description.new(EX.S1, init: [\n    ...>   {EX.p1, EX.O1},\n    ...>   {EX.p2, EX.O2},\n    ...>   {EX.p1, EX.O2},\n    ...>   {EX.p2, RDF.bnode(:bnode)},\n    ...>   {EX.p3, \"foo\"}])\n    ...> |> RDF.Description.resources()\n    MapSet.new([RDF.iri(EX.O1), RDF.iri(EX.O2), RDF.bnode(:bnode), EX.p1, EX.p2, EX.p3])","ref":"RDF.Description.html#resources/1-examples"},{"type":"function","title":"RDF.Description.statement_count/1","doc":"Returns the number of statements of a `RDF.Description`.","ref":"RDF.Description.html#statement_count/1"},{"type":"function","title":"RDF.Description.statements/2","doc":"","ref":"RDF.Description.html#statements/2"},{"type":"function","title":"RDF.Description.subject/1","doc":"Returns the subject IRI or blank node of a description.","ref":"RDF.Description.html#subject/1"},{"type":"function","title":"RDF.Description.take/2","doc":"Creates a description from another one by limiting its statements to those using one of the given `predicates`.\n\nIf `predicates` contains properties that are not used in the `description`, they're simply ignored.\n\nIf `nil` is passed, the description is left untouched.","ref":"RDF.Description.html#take/2"},{"type":"function","title":"RDF.Description.triples/2","doc":"The list of all triples within a `RDF.Description`.\n\nWhen the optional `:filter_star` flag is set to `true` RDF-star triples with a triple as subject or object\nwill be filtered. So, for a description with a triple as a subject you'll always get an empty list.\nThe default value of the `:filter_star` flag is `false`.","ref":"RDF.Description.html#triples/2"},{"type":"function","title":"RDF.Description.update/4","doc":"Updates the objects of the `predicate` in `description` with the given function.\n\nIf `predicate` is present in `description` with `objects` as value,\n`fun` is invoked with argument `objects` and its result is used as the new\nlist of objects of `predicate`. If `predicate` is not present in `description`,\n`initial` is inserted as the objects of `predicate`. The initial value will\nnot be passed through the update function.\n\nThe initial value and the returned objects by the update function will be automatically\ncoerced to proper RDF object values before added.","ref":"RDF.Description.html#update/4"},{"type":"function","title":"Examples - RDF.Description.update/4","doc":"iex> RDF.Description.new(EX.S, init: {EX.p, EX.O})\n    ...> |> RDF.Description.update(EX.p, fn objects -> [EX.O2 | objects] end)\n    RDF.Description.new(EX.S, init: [{EX.p, EX.O}, {EX.p, EX.O2}])\n    iex> RDF.Description.new(EX.S)\n    ...> |> RDF.Description.update(EX.p, EX.O, fn _ -> EX.O2 end)\n    RDF.Description.new(EX.S, init: {EX.p, EX.O})","ref":"RDF.Description.html#update/4-examples"},{"type":"function","title":"RDF.Description.update_all_objects/2","doc":"Updates all objects in `description` with the given function.\n\n`fun` is invoked for each object in `description` with the predicate and the object as two arguments.\nIf `nil` is returned by `fun`, the respective object will be removed from `description`.\nThe returned values by the update function will be coerced to proper RDF object values before added.","ref":"RDF.Description.html#update_all_objects/2"},{"type":"function","title":"Examples - RDF.Description.update_all_objects/2","doc":"iex> EX.S |> EX.p1(1) |> EX.p2([2, 3])\n    ...> |> RDF.Description.update_all_objects(fn _predicate, object ->\n    ...>      RDF.XSD.Numeric.add(object, 1)\n    ...>    end)\n    EX.S\n    |> EX.p1(2)\n    |> EX.p2([3, 4])","ref":"RDF.Description.html#update_all_objects/2-examples"},{"type":"function","title":"RDF.Description.update_all_predicates/2","doc":"Updates all predications in `description` with the given function.\n\n`fun` is invoked with a tuple `{predicate, objects}` for each predicate in `description`.\nIf `nil` is returned by `fun`, the respective predications will be removed from `description`.\nThe returned values by the update function will be coerced to proper RDF object values before added.","ref":"RDF.Description.html#update_all_predicates/2"},{"type":"function","title":"Examples - RDF.Description.update_all_predicates/2","doc":"iex> EX.S |> EX.p1(1) |> EX.p2([2, 3])\n    ...> |> RDF.Description.update_all_predicates(fn {_predicate, objects} -> [\"foo\" | objects] end)\n    EX.S\n    |> EX.p1([1, \"foo\"])\n    |> EX.p2([2, 3, \"foo\"])","ref":"RDF.Description.html#update_all_predicates/2-examples"},{"type":"function","title":"RDF.Description.values/2","doc":"Returns a map of the native Elixir values of a `RDF.Description`.\n\nThe subject is not part of the result. It can be converted separately with\n`RDF.Term.value/1`, or, if you want the subject in an outer map, just put the\ndescription in a graph and use `RDF.Graph.values/2`.\n\nWhen a `:context` option is given with a `RDF.PropertyMap`, predicates will\nbe mapped to the terms defined in the `RDF.PropertyMap`, if present.\n\nNote: RDF-star statements where the object is a triple will be ignored.","ref":"RDF.Description.html#values/2"},{"type":"function","title":"Examples - RDF.Description.values/2","doc":"iex> RDF.Description.new(~I , init: {~I , ~L\"Foo\"})\n    ...> |> RDF.Description.values()\n    %{\"http://example.com/p\" => [\"Foo\"]}\n\n    iex> RDF.Description.new(~I , init: {~I , ~L\"Foo\"})\n    ...> |> RDF.Description.values(context: %{p: ~I })\n    %{p: [\"Foo\"]}","ref":"RDF.Description.html#values/2-examples"},{"type":"function","title":"RDF.Description.without_quoted_triple_objects/1","doc":"Removes all objects from a description which are quoted triples.","ref":"RDF.Description.html#without_quoted_triple_objects/1"},{"type":"type","title":"RDF.Description.input/0","doc":"","ref":"RDF.Description.html#t:input/0"},{"type":"type","title":"RDF.Description.predications/0","doc":"","ref":"RDF.Description.html#t:predications/0"},{"type":"type","title":"RDF.Description.t/0","doc":"","ref":"RDF.Description.html#t:t/0"},{"type":"module","title":"RDF.Diff","doc":"A data structure for diffs between `RDF.Graph`s and `RDF.Description`s.\n\nA `RDF.Diff` is a struct consisting of two fields `additions` and `deletions`\nwith `RDF.Graph`s of added and deleted statements.","ref":"RDF.Diff.html"},{"type":"function","title":"RDF.Diff.apply/2","doc":"Applies a diff to a `RDF.Graph` or `RDF.Description` by deleting the `deletions` and adding the `additions` of the `diff`.\n\nDeletions of statements which are not present in the given graph or description\nare simply ignored.\n\nThe result of an application is always a `RDF.Graph`, even if a `RDF.Description`\nis given and the additions from the diff are all about the subject of this description.","ref":"RDF.Diff.html#apply/2"},{"type":"function","title":"RDF.Diff.diff/2","doc":"Computes a diff between two `RDF.Graph`s or `RDF.Description`s.\n\nThe first argument represents the original and the second argument the new version\nof the RDF data to be compared. Any combination of `RDF.Graph`s or\n`RDF.Description`s can be passed as first and second argument.","ref":"RDF.Diff.html#diff/2"},{"type":"function","title":"Examples - RDF.Diff.diff/2","doc":"iex> RDF.Diff.diff(\n  ...>   RDF.description(EX.S1, init: {EX.S1, EX.p1, [EX.O1, EX.O2]}),\n  ...>   RDF.graph([\n  ...>    {EX.S1, EX.p1, [EX.O2, EX.O3]},\n  ...>    {EX.S2, EX.p2, EX.O4}\n  ...>   ]))\n  %RDF.Diff{\n    additions: RDF.graph([\n      {EX.S1, EX.p1, EX.O3},\n      {EX.S2, EX.p2, EX.O4}\n    ]),\n    deletions: RDF.graph({EX.S1, EX.p1, EX.O1})\n  }","ref":"RDF.Diff.html#diff/2-examples"},{"type":"function","title":"RDF.Diff.empty?/1","doc":"Determines if a diff is empty.\n\nA `RDF.Diff` is empty, if its `additions` and `deletions` graphs are empty.","ref":"RDF.Diff.html#empty?/1"},{"type":"function","title":"RDF.Diff.new/1","doc":"Creates a `RDF.Diff` struct.\n\nSome initial additions and deletions can be provided optionally with the resp.\n`additions` and `deletions` keywords. The statements for the additions and\ndeletions can be provided in any form supported by the `RDF.Graph.new/1` function.","ref":"RDF.Diff.html#new/1"},{"type":"function","title":"RDF.Diff.union/2","doc":"Returns the union of two diffs.\n\nThe diffs are merged by adding up the `additions` and `deletions` of both\ndiffs respectively.","ref":"RDF.Diff.html#union/2"},{"type":"type","title":"RDF.Diff.t/0","doc":"","ref":"RDF.Diff.html#t:t/0"},{"type":"module","title":"RDF.Graph","doc":"A set of RDF triples with an optional name.\n\n`RDF.Graph` implements:\n\n- Elixir's `Access` behaviour\n- Elixir's `Enumerable` protocol\n- Elixir's `Collectable` protocol\n- Elixir's `Inspect` protocol\n- the `RDF.Data` protocol","ref":"RDF.Graph.html"},{"type":"function","title":"RDF.Graph.add/3","doc":"Add triples to a `RDF.Graph`.\n\nThe `input` can be provided\n\n- as a single statement tuple\n- a nested subject-predicate-object map\n- a `RDF.Description`\n- a `RDF.Graph`\n- a `RDF.Dataset`\n- or a list with any combination of the former\n\nWhen the statements to be added are given as another `RDF.Graph`,\nthe graph name must not match graph name of the graph to which the statements\nare added. As opposed to that, `RDF.Data.merge/2` will produce a `RDF.Dataset`\ncontaining both graphs.\n\nAlso, when the statements to be added are given as another `RDF.Graph`, the\nprefixes of this graph will be added. In case of conflicting prefix mappings\nthe original prefix from `graph` will be kept.\n\nWhen the statements to be added are given as a `RDF.Dataset` the data from\nall of its graphs are added.\n\nRDF-star annotations to be added to all the given statements can be specified with\nthe `:add_annotations`, `:put_annotations` or `:put_annotation_properties` keyword\noptions. They have different addition semantics similar to the `add_annotations/3`,\n`put_annotations/3` and `put_annotation_properties/3` counterparts.","ref":"RDF.Graph.html#add/3"},{"type":"function","title":"RDF.Graph.add_annotations/3","doc":"Adds RDF-star annotations to the given set of statements.\n\nThe set of `statements` can be given in any input form (see `add/3`).\n\nThe predicate-objects pairs to be added as annotations can be given as a tuple,\na list of tuples or a map.","ref":"RDF.Graph.html#add_annotations/3"},{"type":"function","title":"RDF.Graph.add_prefixes/3","doc":"Adds `prefixes` to the given `graph`.\n\nThe `prefixes` mappings can be given as any structure convertible to a\n`RDF.PrefixMap`.\n\nWhen a prefix with another mapping already exists it will be overwritten with\nthe new one. This behaviour can be customized by providing a `conflict_resolver`\nfunction. See `RDF.PrefixMap.merge/3` for more on that.","ref":"RDF.Graph.html#add_prefixes/3"},{"type":"function","title":"RDF.Graph.annotations/1","doc":"Returns the `RDF.Graph` of all annotations.\n\nNote: The graph includes only triples where the subject is a quoted triple.\nTriples where only the object is a quoted triple are NOT included.","ref":"RDF.Graph.html#annotations/1"},{"type":"function","title":"RDF.Graph.base_iri/1","doc":"Returns the base IRI of the given `graph`.","ref":"RDF.Graph.html#base_iri/1"},{"type":"macro","title":"RDF.Graph.build/3","doc":"Builds an `RDF.Graph` from a description of its content in a graph DSL.\n\nAll available opts of `new/2` are also supported here.\n\nFor a description of the DSL see [this guide](https://rdf-elixir.dev/rdf-ex/description-and-graph-dsl.html).","ref":"RDF.Graph.html#build/3"},{"type":"function","title":"RDF.Graph.canonical_hash/2","doc":"","ref":"RDF.Graph.html#canonical_hash/2"},{"type":"function","title":"RDF.Graph.canonicalize/2","doc":"Canonicalizes the blank nodes of a graph according to the RDF Dataset Canonicalization spec.\n\nSee the `RDF.Canonicalization` module documentation on available options.","ref":"RDF.Graph.html#canonicalize/2"},{"type":"function","title":"Example - RDF.Graph.canonicalize/2","doc":"iex> RDF.Graph.new([{~B , EX.p(), ~B }, {~B , EX.p(), ~B }])\n    ...> |> RDF.Graph.canonicalize()\n    RDF.Graph.new([{~B , EX.p(), ~B }, {~B , EX.p(), ~B }])","ref":"RDF.Graph.html#canonicalize/2-example"},{"type":"function","title":"RDF.Graph.change_name/2","doc":"Changes the graph name of `graph`.","ref":"RDF.Graph.html#change_name/2"},{"type":"function","title":"RDF.Graph.clear/1","doc":"Removes all triples from `graph`.\n\nThis function is useful for getting an empty graph based on the settings of\nanother graph, as this function keeps graph name, base IRI and default prefixes\nas they are and just removes the triples.","ref":"RDF.Graph.html#clear/1"},{"type":"function","title":"RDF.Graph.clear_base_iri/1","doc":"Clears the base IRI of the given `graph`.","ref":"RDF.Graph.html#clear_base_iri/1"},{"type":"function","title":"RDF.Graph.clear_metadata/1","doc":"Clears the base IRI and all prefixes of the given `graph`.","ref":"RDF.Graph.html#clear_metadata/1"},{"type":"function","title":"RDF.Graph.clear_prefixes/1","doc":"Clears all prefixes of the given `graph`.","ref":"RDF.Graph.html#clear_prefixes/1"},{"type":"function","title":"RDF.Graph.delete/3","doc":"Deletes statements from a `RDF.Graph`.\n\nWhen the statements to be deleted are given as another `RDF.Graph`,\nthe graph name must not match graph name of the graph from which the statements\nare deleted. If you want to delete only statements with matching graph names, you can\nuse `RDF.Data.delete/2`.\n\nThe optional `:delete_annotations` keyword option allows to set which of\nthe RDF-star annotations of the deleted statements should be deleted.\nAny of the possible values of `delete_annotations/3` can be provided here.\nBy default, no annotations of the deleted statements will be removed.\nAlternatively, the `:add_annotations`, `:put_annotations` or `:put_annotation_properties`\nkeyword options can be used to add annotations about the deleted statements\nwith the addition semantics similar to the respective `add_annotations/3`,\n`put_annotations/3` and `put_annotation_properties/3` counterparts.","ref":"RDF.Graph.html#delete/3"},{"type":"function","title":"RDF.Graph.delete_annotations/3","doc":"Deletes RDF-star annotations of a given set of statements.\n\nThe `statements` can be given in any input form (see `add/3`).\n\nIf `true` is given as the third argument or is `delete_annotations/2` is used,\nall annotations of the given `statements` are deleted.\n\nIf a single predicate or list of predicates is given only statements with\nthese predicates from the annotations of the given `statements` are deleted.","ref":"RDF.Graph.html#delete_annotations/3"},{"type":"function","title":"RDF.Graph.delete_descriptions/3","doc":"Deletes all statements with the given `subjects`.\n\nIf `subjects` contains subjects that are not in `graph`, they're simply ignored.\n\nThe optional `:delete_annotations` keyword option allows to set which of\nthe RDF-star annotations of the deleted statements should be deleted.\nAny of the possible values of `delete_annotations/3` can be provided here.\nBy default, no annotations of the deleted statements will be removed.\nAlternatively, the `:add_annotations`, `:put_annotations` or `:put_annotation_properties`\nkeyword options can be used to add annotations about the deleted statements\nwith the addition semantics similar to the respective `add_annotations/3`,\n`put_annotations/3` and `put_annotation_properties/3` counterparts.","ref":"RDF.Graph.html#delete_descriptions/3"},{"type":"function","title":"RDF.Graph.delete_predications/3","doc":"Deletes all statements with the given subject-predicate pairs.\n\nIf `predications` contains subject-predicate pairs that are not in `graph`, they're simply ignored.\n\nThe optional `:delete_annotations` keyword option allows to set which of\nthe RDF-star annotations of the deleted statements should be deleted.\nAny of the possible values of `delete_annotations/3` can be provided here.\nBy default, no annotations of the deleted statements will be removed.\nAlternatively, the `:add_annotations`, `:put_annotations` or `:put_annotation_properties`\nkeyword options can be used to add annotations about the deleted statements\nwith the addition semantics similar to the respective `add_annotations/3`,\n`put_annotations/3` and `put_annotation_properties/3` counterparts.","ref":"RDF.Graph.html#delete_predications/3"},{"type":"function","title":"RDF.Graph.delete_prefixes/2","doc":"Deletes `prefixes` from the given `graph`.\n\nThe `prefixes` can be a single prefix or a list of prefixes.\nPrefixes not in prefixes of the graph are simply ignored.","ref":"RDF.Graph.html#delete_prefixes/2"},{"type":"function","title":"RDF.Graph.delete_subjects/2","doc":"","ref":"RDF.Graph.html#delete_subjects/2"},{"type":"function","title":"RDF.Graph.delete_subjects/3","doc":"","ref":"RDF.Graph.html#delete_subjects/3"},{"type":"function","title":"RDF.Graph.describes?/2","doc":"Checks if a `RDF.Graph` contains statements about the given resource.","ref":"RDF.Graph.html#describes?/2"},{"type":"function","title":"Examples - RDF.Graph.describes?/2","doc":"iex> RDF.Graph.new([{EX.S1, EX.p1, EX.O1}]) |> RDF.Graph.describes?(EX.S1)\n      true\n      iex> RDF.Graph.new([{EX.S1, EX.p1, EX.O1}]) |> RDF.Graph.describes?(EX.S2)\n      false","ref":"RDF.Graph.html#describes?/2-examples"},{"type":"function","title":"RDF.Graph.description/2","doc":"Returns the description of the given `subject` in the given `graph`.\n\nAs opposed to `get/3` this function returns an empty `RDF.Description` when\nthe subject does not exist in the given `graph`.","ref":"RDF.Graph.html#description/2"},{"type":"function","title":"Examples - RDF.Graph.description/2","doc":"iex> RDF.Graph.new([{EX.S1, EX.P1, EX.O1}, {EX.S2, EX.P2, EX.O2}])\n    ...> |> RDF.Graph.description(EX.S1)\n    RDF.Description.new(EX.S1, init: {EX.P1, EX.O1})\n\n    iex> RDF.Graph.description(RDF.Graph.new(), EX.Foo)\n    RDF.Description.new(EX.Foo)","ref":"RDF.Graph.html#description/2-examples"},{"type":"function","title":"RDF.Graph.descriptions/1","doc":"All `RDF.Description`s within a `RDF.Graph`.","ref":"RDF.Graph.html#descriptions/1"},{"type":"function","title":"RDF.Graph.empty?/1","doc":"Returns if the given `graph` is empty.\n\nNote: You should always prefer this over the use of `Enum.empty?/1` as it is significantly faster.","ref":"RDF.Graph.html#empty?/1"},{"type":"function","title":"RDF.Graph.equal?/2","doc":"Checks if two `RDF.Graph`s are equal.\n\nTwo `RDF.Graph`s are considered to be equal if they contain the same triples\nand have the same name. The prefixes of the graph are irrelevant for equality.","ref":"RDF.Graph.html#equal?/2"},{"type":"function","title":"RDF.Graph.fetch/2","doc":"Fetches the description of the given subject.\n\nWhen the subject can not be found `:error` is returned.","ref":"RDF.Graph.html#fetch/2"},{"type":"function","title":"Examples - RDF.Graph.fetch/2","doc":"iex> RDF.Graph.new([{EX.S1, EX.P1, EX.O1}, {EX.S2, EX.P2, EX.O2}])\n    ...> |> RDF.Graph.fetch(EX.S1)\n    {:ok, RDF.Description.new(EX.S1, init: {EX.P1, EX.O1})}\n    iex> RDF.Graph.new() |> RDF.Graph.fetch(EX.foo)\n    :error","ref":"RDF.Graph.html#fetch/2-examples"},{"type":"function","title":"RDF.Graph.get/3","doc":"Gets the description of the given `subject` in the given `graph`.\n\nWhen the subject can not be found the optionally given default value or\n`nil` is returned.","ref":"RDF.Graph.html#get/3"},{"type":"function","title":"Examples - RDF.Graph.get/3","doc":"iex> RDF.Graph.new([{EX.S1, EX.P1, EX.O1}, {EX.S2, EX.P2, EX.O2}])\n    ...> |> RDF.Graph.get(EX.S1)\n    RDF.Description.new(EX.S1, init: {EX.P1, EX.O1})\n\n    iex> RDF.Graph.get(RDF.Graph.new(), EX.Foo)\n    nil\n\n    iex> RDF.Graph.get(RDF.Graph.new(), EX.Foo, :bar)\n    :bar","ref":"RDF.Graph.html#get/3-examples"},{"type":"function","title":"RDF.Graph.get_and_update/3","doc":"Gets and updates the description of the given subject, in a single pass.\n\nInvokes the passed function on the `RDF.Description` of the given subject;\nthis function should return either `{description_to_return, new_description}` or `:pop`.\n\nIf the passed function returns `{description_to_return, new_description}`, the\nreturn value of `get_and_update` is `{description_to_return, new_graph}` where\n`new_graph` is the input `Graph` updated with `new_description` for\nthe given subject.\n\nIf the passed function returns `:pop` the description for the given subject is\nremoved and a `{removed_description, new_graph}` tuple gets returned.","ref":"RDF.Graph.html#get_and_update/3"},{"type":"function","title":"Examples - RDF.Graph.get_and_update/3","doc":"iex> RDF.Graph.new({EX.S, EX.P, EX.O})\n    ...> |> RDF.Graph.get_and_update(EX.S, fn current_description ->\n    ...>      {current_description, {EX.P, EX.NEW}}\n    ...>    end)\n    {RDF.Description.new(EX.S, init: {EX.P, EX.O}), RDF.Graph.new({EX.S, EX.P, EX.NEW})}","ref":"RDF.Graph.html#get_and_update/3-examples"},{"type":"function","title":"RDF.Graph.include?/3","doc":"Checks if the given `input` statements exist within `graph`.","ref":"RDF.Graph.html#include?/3"},{"type":"function","title":"RDF.Graph.intersection/2","doc":"Returns a new graph that is the intersection of the given `graph` with the given `data`.\n\nThe `data` can be given in any form an `RDF.Graph` can be created from.\nWhen a `RDF.Dataset` is given, the aggregation of all of its graphs is used\nfor the intersection.","ref":"RDF.Graph.html#intersection/2"},{"type":"function","title":"Examples - RDF.Graph.intersection/2","doc":"iex> RDF.Graph.new({EX.S1, EX.p(), [EX.O1, EX.O2]})\n    ...> |> RDF.Graph.intersection({EX.S1, EX.p(), [EX.O2, EX.O3]})\n    RDF.Graph.new({EX.S1, EX.p(), EX.O2})","ref":"RDF.Graph.html#intersection/2-examples"},{"type":"function","title":"RDF.Graph.isomorphic?/3","doc":"Checks whether two graphs are equal, regardless of the concrete names of the blank nodes they contain.\n\nSee the `RDF.Canonicalization` module documentation on available options.","ref":"RDF.Graph.html#isomorphic?/3"},{"type":"function","title":"Examples - RDF.Graph.isomorphic?/3","doc":"iex> RDF.Graph.new([{~B , EX.p(), ~B }, {~B , EX.p(), 42}])\n    ...> |> RDF.Graph.isomorphic?(\n    ...>      RDF.Graph.new([{~B , EX.p(), ~B }, {~B , EX.p(), 42}]))\n    true\n\n    iex> RDF.Graph.new([{~B , EX.p(), ~B }, {~B , EX.p(), 42}])\n    ...> |> RDF.Graph.isomorphic?(\n    ...>      RDF.Graph.new([{~B , EX.p(), ~B }, {~B , EX.p(), 42}]))\n    false","ref":"RDF.Graph.html#isomorphic?/3-examples"},{"type":"function","title":"RDF.Graph.map/2","doc":"Returns a nested map of a `RDF.Graph` where each element from its triples is mapped with the given function.\n\nThe function `fun` will receive a tuple `{statement_position, rdf_term}` where\n`statement_position` is one of the atoms `:subject`, `:predicate` or `:object`,\nwhile `rdf_term` is the RDF term to be mapped. When the given function returns\n`nil` this will be interpreted as an error and will become the overhaul result\nof the `map/2` call.\n\nNote: RDF-star statements where the subject or object is a triple will be ignored.","ref":"RDF.Graph.html#map/2"},{"type":"function","title":"Examples - RDF.Graph.map/2","doc":"iex> RDF.Graph.new([\n    ...>   {~I , ~I , ~L\"Foo\"},\n    ...>   {~I , ~I , RDF.XSD.integer(42)}\n    ...> ])\n    ...> |> RDF.Graph.map(fn\n    ...>      {:predicate, predicate} ->\n    ...>        predicate\n    ...>        |> to_string()\n    ...>        |> String.split(\"/\")\n    ...>        |> List.last()\n    ...>        |> String.to_atom()\n    ...>      {_, term} ->\n    ...>        RDF.Term.value(term)\n    ...>    end)\n    %{\n      \"http://example.com/S1\" => %{p: [\"Foo\"]},\n      \"http://example.com/S2\" => %{p: [42]}\n    }","ref":"RDF.Graph.html#map/2-examples"},{"type":"function","title":"RDF.Graph.name/1","doc":"Returns the graph name IRI of `graph`.","ref":"RDF.Graph.html#name/1"},{"type":"function","title":"RDF.Graph.new/0","doc":"Creates an empty unnamed `RDF.Graph`.","ref":"RDF.Graph.html#new/0"},{"type":"function","title":"RDF.Graph.new/1","doc":"Creates an `RDF.Graph`.\n\nIf a keyword list with options is given an empty graph is created.\nOtherwise, an unnamed graph initialized with the given data is created.\n\nSee `new/2` for available arguments and the different ways to provide data.\n\nWhen a `RDF.Dataset` is given, the created graph is the aggregation of all\nthe graphs of this dataset.","ref":"RDF.Graph.html#new/1"},{"type":"function","title":"Examples - RDF.Graph.new/1","doc":"RDF.Graph.new(name: EX.GraphName)\n\n    RDF.Graph.new(init: {EX.S, EX.p, EX.O})\n\n    RDF.Graph.new({EX.S, EX.p, EX.O})","ref":"RDF.Graph.html#new/1-examples"},{"type":"function","title":"RDF.Graph.new/2","doc":"Creates an `RDF.Graph` initialized with data.\n\nThe initial RDF triples can be provided\n\n- as a single statement tuple\n- a nested subject-predicate-object map\n- a `RDF.Description`\n- a `RDF.Graph`\n- a `RDF.Dataset`\n- or a list with any combination of the former\n\nAvailable options:\n\n- `name`: the name of the graph to be created\n- `prefixes`: some prefix mappings which should be stored alongside the graph\n  and will be used for example when serializing in a format with prefix support\n- `base_iri`: a base IRI which should be stored alongside the graph\n  and will be used for example when serializing in a format with base IRI support\n- `init`: some data with which the graph should be initialized; the data can be\n  provided in any form accepted by `add/3` and above that also with a function returning\n  the initialization data in any of these forms","ref":"RDF.Graph.html#new/2"},{"type":"function","title":"Examples - RDF.Graph.new/2","doc":"RDF.Graph.new({EX.S, EX.p, EX.O})\n    RDF.Graph.new({EX.S, EX.p, EX.O}, name: EX.GraphName)\n    RDF.Graph.new({EX.S, EX.p, [EX.O1, EX.O2]})\n    RDF.Graph.new([{EX.S1, EX.p1, EX.O1}, {EX.S2, EX.p2, EX.O2}])\n    RDF.Graph.new(RDF.Description.new(EX.S, EX.P, EX.O))\n    RDF.Graph.new([graph, description, triple])\n    RDF.Graph.new({EX.S, EX.p, EX.O}, name: EX.GraphName, base_iri: EX.base)","ref":"RDF.Graph.html#new/2-examples"},{"type":"function","title":"RDF.Graph.objects/1","doc":"The set of all resources used in the objects within a `RDF.Graph`.\n\nNote: This function does collect only IRIs and BlankNodes, not Literals.","ref":"RDF.Graph.html#objects/1"},{"type":"function","title":"Examples - RDF.Graph.objects/1","doc":"iex> RDF.Graph.new([\n    ...>   {EX.S1, EX.p1, EX.O1},\n    ...>   {EX.S2, EX.p2, EX.O2},\n    ...>   {EX.S3, EX.p1, EX.O2},\n    ...>   {EX.S4, EX.p2, RDF.bnode(:bnode)},\n    ...>   {EX.S5, EX.p3, \"foo\"}])\n    ...> |> RDF.Graph.objects()\n    MapSet.new([RDF.iri(EX.O1), RDF.iri(EX.O2), RDF.bnode(:bnode)])","ref":"RDF.Graph.html#objects/1-examples"},{"type":"function","title":"RDF.Graph.pop/1","doc":"Pops an arbitrary triple from a `RDF.Graph`.","ref":"RDF.Graph.html#pop/1"},{"type":"function","title":"RDF.Graph.pop/2","doc":"Pops the description of the given subject.\n\nRemoves the description of the given `subject` from `graph`.\n\nReturns a tuple containing the description of the given subject\nand the updated graph without this description.\n`nil` is returned instead of the description if `graph` does\nnot contain a description of the given `subject`.","ref":"RDF.Graph.html#pop/2"},{"type":"function","title":"Examples - RDF.Graph.pop/2","doc":"iex> RDF.Graph.new([{EX.S1, EX.P1, EX.O1}, {EX.S2, EX.P2, EX.O2}])\n    ...> |> RDF.Graph.pop(EX.S1)\n    {\n      RDF.Description.new(EX.S1, init: {EX.P1, EX.O1}),\n      RDF.Graph.new({EX.S2, EX.P2, EX.O2})\n    }\n\n    iex> RDF.Graph.new({EX.S, EX.P, EX.O})\n    ...> |> RDF.Graph.pop(EX.Missing)\n    {nil, RDF.Graph.new({EX.S, EX.P, EX.O})}","ref":"RDF.Graph.html#pop/2-examples"},{"type":"function","title":"RDF.Graph.predicates/1","doc":"The set of all properties used in the predicates of the statements within a `RDF.Graph`.","ref":"RDF.Graph.html#predicates/1"},{"type":"function","title":"Examples - RDF.Graph.predicates/1","doc":"iex> RDF.Graph.new([\n    ...>   {EX.S1, EX.p1, EX.O1},\n    ...>   {EX.S2, EX.p2, EX.O2},\n    ...>   {EX.S1, EX.p2, EX.O3}])\n    ...> |> RDF.Graph.predicates()\n    MapSet.new([EX.p1, EX.p2])","ref":"RDF.Graph.html#predicates/1-examples"},{"type":"function","title":"RDF.Graph.prefixes/1","doc":"Returns the prefixes of the given `graph` as a `RDF.PrefixMap`.","ref":"RDF.Graph.html#prefixes/1"},{"type":"function","title":"RDF.Graph.prefixes/2","doc":"Returns the prefixes of the given `graph` as a `RDF.PrefixMap` or returns the given default when empty.","ref":"RDF.Graph.html#prefixes/2"},{"type":"function","title":"RDF.Graph.put/3","doc":"Adds statements to a `RDF.Graph` overwriting existing statements with the subjects given in the `input` data.\n\nWhen the statements to be added are given as another `RDF.Graph`, the prefixes\nof this graph will be added. In case of conflicting prefix mappings the\noriginal prefix from `graph` will be kept.\n\nRDF-star annotations to be added to all the given statements can be specified with\nthe `:add_annotations`, `:put_annotations` or `:put_annotation_properties` keyword\noptions. They have different addition semantics similar to the `add_annotations/3`,\n`put_annotations/3` and `put_annotation_properties/3` counterparts.\n\nWhat should happen with the annotations of statements which got deleted during\noverwrite, can be controlled with these keyword options:\n\n- `:delete_annotations_on_deleted`: deletes all or some annotations of the deleted\n  statements (see `delete_annotations/3` on possible values)\n- `:add_annotations_on_deleted`, `:put_annotations_on_deleted`,\n  `:put_annotation_properties_on_deleted`: add annotations about the deleted\n  statements with the respective addition semantics similar to the keyword\n  options with the `_on_deleted` suffix mentioned above","ref":"RDF.Graph.html#put/3"},{"type":"function","title":"Examples - RDF.Graph.put/3","doc":"iex> RDF.Graph.new([{EX.S1, EX.P1, EX.O1}, {EX.S2, EX.P2, EX.O2}])\n    ...> |> RDF.Graph.put([{EX.S1, EX.P3, EX.O3}])\n    RDF.Graph.new([{EX.S1, EX.P3, EX.O3}, {EX.S2, EX.P2, EX.O2}])","ref":"RDF.Graph.html#put/3-examples"},{"type":"function","title":"RDF.Graph.put_annotation_properties/3","doc":"Adds RDF-star annotations to the given set of statements overwriting all existing annotations with the given properties.\n\nThe set of `statements` can be given in any input form (see `add/3`).\n\nThe predicate-objects pairs to be added as annotations can be given as a tuple,\na list of tuples or a map.","ref":"RDF.Graph.html#put_annotation_properties/3"},{"type":"function","title":"RDF.Graph.put_annotations/3","doc":"Adds RDF-star annotations to the given set of statements overwriting all existing annotations.\n\nThe set of `statements` can be given in any input form (see `add/3`).\n\nThe predicate-objects pairs to be added as annotations can be given as a tuple,\na list of tuples or a map.","ref":"RDF.Graph.html#put_annotations/3"},{"type":"function","title":"RDF.Graph.put_properties/3","doc":"Adds statements to a `RDF.Graph` and overwrites all existing statements with the same subject-predicate combinations given in the `input` data.\n\nWhen the statements to be added are given as another `RDF.Graph`, the prefixes\nof this graph will be added. In case of conflicting prefix mappings the\noriginal prefix from `graph` will be kept.\n\nRDF-star annotations to be added to all the given statements can be specified with\nthe `:add_annotations`, `:put_annotations` or `:put_annotation_properties` keyword\noptions. They have different addition semantics similar to the `add_annotations/3`,\n`put_annotations/3` and `put_annotation_properties/3` counterparts.\n\nWhat should happen with the annotations of statements which got deleted during\noverwrite, can be controlled with these keyword options:\n\n- `:delete_annotations_on_deleted`: deletes all or some annotations of the deleted\n  statements (see `delete_annotations/3` on possible values)\n- `:add_annotations_on_deleted`, `:put_annotations_on_deleted`,\n  `:put_annotation_properties_on_deleted`: add annotations about the deleted\n  statements with the respective addition semantics similar to the keyword\n  options with the `_on_deleted` suffix mentioned above","ref":"RDF.Graph.html#put_properties/3"},{"type":"function","title":"Examples - RDF.Graph.put_properties/3","doc":"iex> RDF.Graph.new([{EX.S1, EX.P1, EX.O1}, {EX.S2, EX.P2, EX.O2}])\n    ...> |> RDF.Graph.put_properties([{EX.S1, EX.P2, EX.O3}, {EX.S2, EX.P2, EX.O3}])\n    RDF.Graph.new([{EX.S1, EX.P1, EX.O1}, {EX.S1, EX.P2, EX.O3}, {EX.S2, EX.P2, EX.O3}])","ref":"RDF.Graph.html#put_properties/3-examples"},{"type":"function","title":"RDF.Graph.quads/2","doc":"The list of all statements within a `RDF.Graph` as quads.\n\nWhen the optional `:filter_star` flag is set to `true` RDF-star triples with\na triple as subject or object will be filtered. The default value is `false`.","ref":"RDF.Graph.html#quads/2"},{"type":"function","title":"Examples - RDF.Graph.quads/2","doc":"iex> RDF.Graph.new([\n      ...>   {EX.S1, EX.p1, EX.O1},\n      ...>   {EX.S2, EX.p2, EX.O2},\n      ...>   {EX.S1, EX.p2, EX.O3}\n      ...>  ], name: EX.Graph)\n      ...> |> RDF.Graph.quads()\n      [{RDF.iri(EX.S1), RDF.iri(EX.p1), RDF.iri(EX.O1), RDF.iri(EX.Graph)},\n       {RDF.iri(EX.S1), RDF.iri(EX.p2), RDF.iri(EX.O3), RDF.iri(EX.Graph)},\n       {RDF.iri(EX.S2), RDF.iri(EX.p2), RDF.iri(EX.O2), RDF.iri(EX.Graph)}]\n\n      iex> RDF.Graph.new([\n      ...>   {EX.S1, EX.p1, EX.O1},\n      ...>   {EX.S2, EX.p2, EX.O2},\n      ...>   {EX.S1, EX.p2, EX.O3}])\n      ...> |> RDF.Graph.quads()\n      [{RDF.iri(EX.S1), RDF.iri(EX.p1), RDF.iri(EX.O1), nil},\n       {RDF.iri(EX.S1), RDF.iri(EX.p2), RDF.iri(EX.O3), nil},\n       {RDF.iri(EX.S2), RDF.iri(EX.p2), RDF.iri(EX.O2), nil}]","ref":"RDF.Graph.html#quads/2-examples"},{"type":"function","title":"RDF.Graph.query/3","doc":"Execute the given `query` against the given `graph`.\n\nThis is just a convenience delegator function to `RDF.Query.execute!/3` with\nthe first two arguments swapped, so it can be used in a pipeline on a `RDF.Graph`.\n\nSee `RDF.Query.execute/3` and `RDF.Query.execute!/3` for more information and examples.","ref":"RDF.Graph.html#query/3"},{"type":"function","title":"RDF.Graph.query_stream/3","doc":"Returns a `Stream` for the execution of the given `query` against the given `graph`.\n\nThis is just a convenience delegator function to `RDF.Query.stream!/3` with\nthe first two arguments swapped, so it can be used in a pipeline on a `RDF.Graph`.\n\nSee `RDF.Query.stream/3` and `RDF.Query.stream!/3` for more information and examples.","ref":"RDF.Graph.html#query_stream/3"},{"type":"function","title":"RDF.Graph.rename_resource/3","doc":"Replaces all occurrences of `old_id` in `graph` with `new_id`.","ref":"RDF.Graph.html#rename_resource/3"},{"type":"function","title":"Examples - RDF.Graph.rename_resource/3","doc":"iex> RDF.Graph.new([\n    ...>  {EX.S, EX.p, ~B },\n    ...>  {~B , EX.p, [EX.O, EX.S]}])\n    ...> |> RDF.Graph.rename_resource(EX.S, EX.New)\n    ...> |> RDF.Graph.rename_resource(~B , EX.Skolemized)\n    [\n      EX.New |> EX.p(EX.Skolemized),\n      EX.Skolemized |> EX.p([EX.O, EX.New])\n    ] |> RDF.Graph.new()","ref":"RDF.Graph.html#rename_resource/3-examples"},{"type":"function","title":"RDF.Graph.resources/1","doc":"The set of all resources used within a `RDF.Graph`.","ref":"RDF.Graph.html#resources/1"},{"type":"function","title":"Examples - RDF.Graph.resources/1","doc":"iex> RDF.Graph.new([\n    ...>   {EX.S1, EX.p1, EX.O1},\n    ...>   {EX.S2, EX.p1, EX.O2},\n    ...>   {EX.S2, EX.p2, RDF.bnode(:bnode)},\n    ...>   {EX.S3, EX.p1, \"foo\"}])\n    ...> |> RDF.Graph.resources()\n    MapSet.new([RDF.iri(EX.S1), RDF.iri(EX.S2), RDF.iri(EX.S3),\n      RDF.iri(EX.O1), RDF.iri(EX.O2), RDF.bnode(:bnode), EX.p1, EX.p2])","ref":"RDF.Graph.html#resources/1-examples"},{"type":"function","title":"RDF.Graph.set_base_iri/2","doc":"Sets the base IRI of the given `graph`.\n\nThe `base_iri` can be given as anything accepted by `RDF.IRI.coerce_base/1`.","ref":"RDF.Graph.html#set_base_iri/2"},{"type":"function","title":"RDF.Graph.statement_count/1","doc":"The number of statements within a `RDF.Graph`.","ref":"RDF.Graph.html#statement_count/1"},{"type":"function","title":"Examples - RDF.Graph.statement_count/1","doc":"iex> RDF.Graph.new([\n    ...>   {EX.S1, EX.p1, EX.O1},\n    ...>   {EX.S2, EX.p2, EX.O2},\n    ...>   {EX.S1, EX.p2, EX.O3}])\n    ...> |> RDF.Graph.statement_count()\n    3","ref":"RDF.Graph.html#statement_count/1-examples"},{"type":"function","title":"RDF.Graph.statements/2","doc":"","ref":"RDF.Graph.html#statements/2"},{"type":"function","title":"RDF.Graph.subject_count/1","doc":"The number of subjects within a `RDF.Graph`.","ref":"RDF.Graph.html#subject_count/1"},{"type":"function","title":"Examples - RDF.Graph.subject_count/1","doc":"iex> RDF.Graph.new([\n    ...>   {EX.S1, EX.p1, EX.O1},\n    ...>   {EX.S2, EX.p2, EX.O2},\n    ...>   {EX.S1, EX.p2, EX.O3}])\n    ...> |> RDF.Graph.subject_count()\n    2","ref":"RDF.Graph.html#subject_count/1-examples"},{"type":"function","title":"RDF.Graph.subjects/1","doc":"The set of all subjects used in the statements within a `RDF.Graph`.","ref":"RDF.Graph.html#subjects/1"},{"type":"function","title":"Examples - RDF.Graph.subjects/1","doc":"iex> RDF.Graph.new([\n    ...>   {EX.S1, EX.p1, EX.O1},\n    ...>   {EX.S2, EX.p2, EX.O2},\n    ...>   {EX.S1, EX.p2, EX.O3}])\n    ...> |> RDF.Graph.subjects()\n    MapSet.new([RDF.iri(EX.S1), RDF.iri(EX.S2)])","ref":"RDF.Graph.html#subjects/1-examples"},{"type":"function","title":"RDF.Graph.take/3","doc":"Creates a graph from another one by limiting its statements to those using one of the given `subjects`.\n\nIf `subjects` contains IRIs that are not used in the `graph`, they're simply ignored.\n\nThe optional `properties` argument allows to limit also properties of the subject descriptions.\n\nIf `nil` is passed as the `subjects`, the subjects will not be limited.","ref":"RDF.Graph.html#take/3"},{"type":"function","title":"RDF.Graph.triple_count/1","doc":"","ref":"RDF.Graph.html#triple_count/1"},{"type":"function","title":"RDF.Graph.triples/2","doc":"The list of all statements within a `RDF.Graph`.\n\nWhen the optional `:filter_star` flag is set to `true` RDF-star triples with\na triple as subject or object will be filtered. The default value is `false`.","ref":"RDF.Graph.html#triples/2"},{"type":"function","title":"Examples - RDF.Graph.triples/2","doc":"iex> RDF.Graph.new([\n      ...>   {EX.S1, EX.p1, EX.O1},\n      ...>   {EX.S2, EX.p2, EX.O2},\n      ...>   {EX.S1, EX.p2, EX.O3}])\n      ...> |> RDF.Graph.triples()\n      [{RDF.iri(EX.S1), RDF.iri(EX.p1), RDF.iri(EX.O1)},\n       {RDF.iri(EX.S1), RDF.iri(EX.p2), RDF.iri(EX.O3)},\n       {RDF.iri(EX.S2), RDF.iri(EX.p2), RDF.iri(EX.O2)}]","ref":"RDF.Graph.html#triples/2-examples"},{"type":"function","title":"RDF.Graph.update/4","doc":"Updates the description of the `subject` in `graph` with the given function.\n\nIf `subject` is present in `graph` with `description` as description,\n`fun` is invoked with argument `description` and its result is used as the new\ndescription of `subject`. If `subject` is not present in `graph`,\n`initial` is inserted as the description of `subject`. If no `initial` value is\ngiven, the `graph` remains unchanged. If `nil` is returned by `fun`, the\nrespective description will be removed from `graph`.\n\nThe initial value and the returned objects by the update function will be\ncoerced to proper RDF descriptions before added. If the initial or returned\ndescription is a `RDF.Description` with another subject, the respective\nstatements are added with `subject` as subject.","ref":"RDF.Graph.html#update/4"},{"type":"function","title":"Examples - RDF.Graph.update/4","doc":"iex> RDF.Graph.new({EX.S, EX.p, EX.O})\n    ...> |> RDF.Graph.update(EX.S,\n    ...>      fn description -> Description.add(description, {EX.p, EX.O2})\n    ...>    end)\n    RDF.Graph.new([{EX.S, EX.p, EX.O}, {EX.S, EX.p, EX.O2}])\n    iex> RDF.Graph.new({EX.S, EX.p, EX.O})\n    ...> |> RDF.Graph.update(EX.S,\n    ...>      fn _ -> Description.new(EX.S2, init: {EX.p2, EX.O2})\n    ...>    end)\n    RDF.Graph.new([{EX.S, EX.p2, EX.O2}])\n    iex> RDF.Graph.new()\n    ...> |> RDF.Graph.update(EX.S, Description.new(EX.S, init: {EX.p, EX.O}),\n    ...>      fn description -> Description.add(description, {EX.p, EX.O2})\n    ...>    end)\n    RDF.Graph.new([{EX.S, EX.p, EX.O}])","ref":"RDF.Graph.html#update/4-examples"},{"type":"function","title":"RDF.Graph.update_all_descriptions/2","doc":"Updates all descriptions in `graph` with the given function.\n\nThe same behaviour as described in `RDF.Graph.update/4` apply.\nIf `nil` is returned by `fun`, the respective description will be removed from `graph`.\nThe returned values by the update function will be coerced to proper RDF descriptions before added.\nIf the returned description is a `RDF.Description` with another subject, it will still be added\nusing the old subject.","ref":"RDF.Graph.html#update_all_descriptions/2"},{"type":"function","title":"Examples - RDF.Graph.update_all_descriptions/2","doc":"iex> RDF.Graph.new([{EX.S1, EX.p1, EX.O1}, {EX.S2, EX.p2, EX.O2}])\n    ...> |> RDF.Graph.update_all_descriptions(&(&1 |> EX.foo(42)))\n    [\n      EX.S1 |> EX.p1(EX.O1) |> EX.foo(42),\n      EX.S2 |> EX.p2(EX.O2) |> EX.foo(42)\n    ] |> RDF.Graph.new()","ref":"RDF.Graph.html#update_all_descriptions/2-examples"},{"type":"function","title":"RDF.Graph.values/2","doc":"Returns a nested map of the native Elixir values of a `RDF.Graph`.\n\nWhen a `:context` option is given with a `RDF.PropertyMap`, predicates will\nbe mapped to the terms defined in the `RDF.PropertyMap`, if present.","ref":"RDF.Graph.html#values/2"},{"type":"function","title":"Examples - RDF.Graph.values/2","doc":"iex> RDF.Graph.new([\n    ...>   {~I , ~I , ~L\"Foo\"},\n    ...>   {~I , ~I , RDF.XSD.integer(42)}\n    ...> ])\n    ...> |> RDF.Graph.values()\n    %{\n      \"http://example.com/S1\" => %{\"http://example.com/p\" => [\"Foo\"]},\n      \"http://example.com/S2\" => %{\"http://example.com/p\" => [42]}\n    }\n\n    iex> RDF.Graph.new([\n    ...>   {~I , ~I , ~L\"Foo\"},\n    ...>   {~I , ~I , RDF.XSD.integer(42)}\n    ...> ])\n    ...> |> RDF.Graph.values(context: [p: ~I ])\n    %{\n      \"http://example.com/S1\" => %{p: [\"Foo\"]},\n      \"http://example.com/S2\" => %{p: [42]}\n    }","ref":"RDF.Graph.html#values/2-examples"},{"type":"function","title":"RDF.Graph.without_annotations/1","doc":"Returns the `RDF.Graph` without all annotations.\n\nNote: This function excludes only triples where the subject is a quoted triple.\nIf you want to exclude also triples where the object is a quoted triple,\nyou'll have to use `RDF.Graph.without_star_statements/1`.","ref":"RDF.Graph.html#without_annotations/1"},{"type":"function","title":"RDF.Graph.without_star_statements/1","doc":"Returns the `RDF.Graph` without all statements including quoted triples on subject or object position.\n\nThis function is relatively costly, since it requires a full walk-through of all triples.\nIn many cases quoted triples are only used on subject position, where you can use\nthe significantly faster `RDF.Graph.without_annotations/1`.","ref":"RDF.Graph.html#without_star_statements/1"},{"type":"type","title":"RDF.Graph.get_and_update_description_fun/0","doc":"","ref":"RDF.Graph.html#t:get_and_update_description_fun/0"},{"type":"type","title":"RDF.Graph.graph_description/0","doc":"","ref":"RDF.Graph.html#t:graph_description/0"},{"type":"type","title":"RDF.Graph.input/0","doc":"","ref":"RDF.Graph.html#t:input/0"},{"type":"type","title":"RDF.Graph.t/0","doc":"","ref":"RDF.Graph.html#t:t/0"},{"type":"type","title":"RDF.Graph.update_description_fun/0","doc":"","ref":"RDF.Graph.html#t:update_description_fun/0"},{"type":"module","title":"RDF.List","doc":"A structure for RDF lists.\n\nsee\n-  \n-","ref":"RDF.List.html"},{"type":"function","title":"RDF.List.empty?/1","doc":"Checks if a list is the empty list.","ref":"RDF.List.html#empty?/1"},{"type":"function","title":"RDF.List.from/2","doc":"Creates a `RDF.List` from a native Elixir list or any other `Enumerable` with coercible RDF values.\n\nBy default, the statements constituting the `Enumerable` are added to an empty graph. An\nalready existing graph to which the statements are added can be specified with\nthe `graph` option.\n\nThe name of the head node can be specified with the `head` option\n(default: `RDF.bnode()`, i.e. an arbitrary unique name).\nNote: When the given `Enumerable` is empty, the `name` option will be ignored -\nthe head node of the empty list is always `RDF.nil`.","ref":"RDF.List.html#from/2"},{"type":"function","title":"RDF.List.new/2","doc":"Creates a `RDF.List` for a given RDF list node of a given `RDF.Graph`.\n\nIf the given node does not refer to a well-formed list in the graph, `nil` is\nreturned. A well-formed list\n\n- consists of list nodes which have exactly one `rdf:first` and `rdf:rest`\n  statement each\n- does not contain cycles, i.e. `rdf:rest` statements don't refer to\n  preceding list nodes","ref":"RDF.List.html#new/2"},{"type":"function","title":"RDF.List.node?/1","doc":"Checks if the given `RDF.Description` describes an RDF list node.","ref":"RDF.List.html#node?/1"},{"type":"function","title":"RDF.List.node?/2","doc":"Checks if a given resource is an RDF list node in a given `RDF.Graph`.\n\nAlthough, technically a resource is a list, if it uses at least one `rdf:first`\nor `rdf:rest`, we pragmatically require the usage of both.\n\nNote: This function doesn't indicate if the list is valid.\n See `new/2` and `valid?/2` for validations.","ref":"RDF.List.html#node?/2"},{"type":"function","title":"RDF.List.nodes/1","doc":"The RDF nodes constituting a `RDF.List` as an Elixir list.","ref":"RDF.List.html#nodes/1"},{"type":"function","title":"RDF.List.valid?/1","doc":"Checks if the given list consists of list nodes which are all blank nodes.","ref":"RDF.List.html#valid?/1"},{"type":"function","title":"RDF.List.values/1","doc":"The values of a `RDF.List` as an Elixir list.\n\nNested lists are converted recursively.","ref":"RDF.List.html#values/1"},{"type":"type","title":"RDF.List.t/0","doc":"","ref":"RDF.List.html#t:t/0"},{"type":"module","title":"RDF.PrefixMap","doc":"A mapping of prefix atoms to IRI namespaces.\n\nThe empty prefix is represented as the `:\"\"` atom.\n\nThis module implements the `Enumerable` protocol.","ref":"RDF.PrefixMap.html"},{"type":"function","title":"RDF.PrefixMap.add/3","doc":"Adds a prefix mapping to `prefix_map`.\n\nUnless a mapping of `prefix` to a different namespace already exists,\nan `:ok` tuple is returned, otherwise an `:error` tuple.","ref":"RDF.PrefixMap.html#add/3"},{"type":"function","title":"RDF.PrefixMap.add!/3","doc":"Adds a prefix mapping to the given `RDF.PrefixMap` and raises an exception in error cases.","ref":"RDF.PrefixMap.html#add!/3"},{"type":"function","title":"RDF.PrefixMap.delete/2","doc":"Deletes the prefix mapping for `prefix` from `prefix_map`.\n\nIf no mapping for `prefix` exists, `prefix_map` is returned unchanged.","ref":"RDF.PrefixMap.html#delete/2"},{"type":"function","title":"RDF.PrefixMap.drop/2","doc":"Drops the given `prefixes` from `prefix_map`.\n\nIf `prefixes` contains prefixes that are not in `prefix_map`, they're simply ignored.","ref":"RDF.PrefixMap.html#drop/2"},{"type":"function","title":"RDF.PrefixMap.empty?/1","doc":"Returns if the given `prefix_map` is empty.","ref":"RDF.PrefixMap.html#empty?/1"},{"type":"function","title":"RDF.PrefixMap.has_prefix?/2","doc":"Returns whether the given prefix exists in the given `RDF.PrefixMap`.","ref":"RDF.PrefixMap.html#has_prefix?/2"},{"type":"function","title":"RDF.PrefixMap.limit/2","doc":"Returns a new prefix map limited to the given prefixes.","ref":"RDF.PrefixMap.html#limit/2"},{"type":"function","title":"Examples - RDF.PrefixMap.limit/2","doc":"iex> RDF.PrefixMap.new(ex1: \"http://example.com/ns1\", ex2: \"http://example.com/ns2\")\n    ...> |> RDF.PrefixMap.limit([:ex1])\n    RDF.PrefixMap.new(ex1: \"http://example.com/ns1\")\n    iex> RDF.PrefixMap.new(ex: \"http://example.com/\")\n    ...> |> RDF.PrefixMap.limit([:foo])\n    RDF.PrefixMap.new()","ref":"RDF.PrefixMap.html#limit/2-examples"},{"type":"function","title":"RDF.PrefixMap.merge/2","doc":"Merges two `RDF.PrefixMap`s.\n\nThe second prefix map can also be given as any structure which can converted\nto a `RDF.PrefixMap` via `new/1`.\n\nIf the prefix maps can be merged without conflicts, that is there are no\nprefixes mapped to different namespaces an `:ok` tuple is returned.\nOtherwise, an `:error` tuple with the list of prefixes with conflicting\nnamespaces is returned.\n\nSee also `merge/3` which allows you to resolve conflicts with a function.","ref":"RDF.PrefixMap.html#merge/2"},{"type":"function","title":"RDF.PrefixMap.merge/3","doc":"Merges two `RDF.PrefixMap`s, resolving conflicts through the given `conflict_resolver` function.\n\nThe second prefix map can also be given as any structure which can converted\nto a `RDF.PrefixMap` via `new/1`.\n\nThe given function will be invoked when there are conflicting mappings of\nprefixes to different namespaces; its arguments are `prefix`, `namespace1`\n(the namespace for the prefix in the first prefix map),\nand `namespace2` (the namespace for the prefix in the second prefix map).\nThe value returned by the `conflict_resolver` function is used as the namespace\nfor the prefix in the resulting prefix map.\nNon-`RDF.IRI` values will be tried to be converted to `RDF.IRI`s via\n`RDF.IRI.new` implicitly.\n\nThe most common conflict resolution strategies on can be chosen directly with\nthe following atoms:\n\n- `:ignore`: keep the original namespace from `prefix_map1`\n- `:overwrite`: use the other namespace from `prefix_map2`\n\nIf a conflict can't be resolved, the provided function can return `nil`.\nThis will result in an overall return of an `:error` tuple with the list of\nprefixes for which the conflict couldn't be resolved.\n\nIf everything could be merged, an `:ok` tuple is returned.","ref":"RDF.PrefixMap.html#merge/3"},{"type":"function","title":"RDF.PrefixMap.merge!/3","doc":"Merges two `RDF.PrefixMap`s and raises an exception in error cases.\n\nSee `merge/2` and `merge/3` for more information on merging prefix maps.","ref":"RDF.PrefixMap.html#merge!/3"},{"type":"function","title":"RDF.PrefixMap.namespace/2","doc":"Returns the namespace for the given `prefix` in `prefix_map`.\n\nReturns `nil`, when the given `prefix` is not present in `prefix_map`.","ref":"RDF.PrefixMap.html#namespace/2"},{"type":"function","title":"RDF.PrefixMap.namespaces/1","doc":"Returns all namespaces from the given `RDF.PrefixMap`.","ref":"RDF.PrefixMap.html#namespaces/1"},{"type":"function","title":"RDF.PrefixMap.new/0","doc":"Creates an empty `RDF.PrefixMap`.","ref":"RDF.PrefixMap.html#new/0"},{"type":"function","title":"RDF.PrefixMap.new/1","doc":"Creates a new `RDF.PrefixMap` with initial mappings.\n\nThe initial prefix mappings can be passed as keyword lists or maps.\nThe keys for the prefixes can be given as atoms or strings and will be normalized to atoms.\nThe namespaces can be given as `RDF.IRI`s or strings and will be normalized to `RDF.IRI`s.","ref":"RDF.PrefixMap.html#new/1"},{"type":"function","title":"RDF.PrefixMap.prefix/2","doc":"Returns the prefix for the given `namespace` in `prefix_map`.\n\nReturns `nil`, when the given `namespace` is not present in `prefix_map`.","ref":"RDF.PrefixMap.html#prefix/2"},{"type":"function","title":"RDF.PrefixMap.prefixed_name/2","doc":"Converts an IRI into a prefixed name.\n\nReturns `nil` when no prefix for the namespace of `iri` is defined in `prefix_map`.","ref":"RDF.PrefixMap.html#prefixed_name/2"},{"type":"function","title":"Examples - RDF.PrefixMap.prefixed_name/2","doc":"iex> RDF.PrefixMap.new(ex: \"http://example.com/\")\n    ...> |> RDF.PrefixMap.prefixed_name(~I )\n    \"ex:Foo\"\n    iex> RDF.PrefixMap.new(ex: \"http://example.com/\")\n    ...> |> RDF.PrefixMap.prefixed_name(\"http://example.com/Foo\")\n    \"ex:Foo\"","ref":"RDF.PrefixMap.html#prefixed_name/2-examples"},{"type":"function","title":"RDF.PrefixMap.prefixed_name_to_iri/2","doc":"Converts a prefixed name into an IRI.\n\nReturns `nil` when the prefix in `prefixed_name` is not defined in `prefix_map`.","ref":"RDF.PrefixMap.html#prefixed_name_to_iri/2"},{"type":"function","title":"Examples - RDF.PrefixMap.prefixed_name_to_iri/2","doc":"iex> RDF.PrefixMap.new(ex: \"http://example.com/\")\n    ...> |> RDF.PrefixMap.prefixed_name_to_iri(\"ex:Foo\")\n    ~I","ref":"RDF.PrefixMap.html#prefixed_name_to_iri/2-examples"},{"type":"function","title":"RDF.PrefixMap.prefixes/1","doc":"Returns all prefixes from the given `RDF.PrefixMap`.","ref":"RDF.PrefixMap.html#prefixes/1"},{"type":"function","title":"RDF.PrefixMap.put/3","doc":"Adds a prefix mapping to `prefix_map` overwriting an existing mapping.","ref":"RDF.PrefixMap.html#put/3"},{"type":"function","title":"RDF.PrefixMap.to_header/3","doc":"Converts the given `prefix_map` to a Turtle or SPARQL header string.\n\nThe `style` argument can be either `:sparql` or `:turtle`.","ref":"RDF.PrefixMap.html#to_header/3"},{"type":"function","title":"Options - RDF.PrefixMap.to_header/3","doc":"- `:indent`: allows to specify an integer by how many spaces the header\n  should be indented (default: `0`)\n- `:iodata`: return the header as an IO list","ref":"RDF.PrefixMap.html#to_header/3-options"},{"type":"function","title":"Examples - RDF.PrefixMap.to_header/3","doc":"iex> RDF.PrefixMap.new(\n    ...>   foo: \"http://example.com/foo\",\n    ...>   bar: \"http://example.com/bar\"\n    ...> ) |> RDF.PrefixMap.to_header(:sparql)\n    \"\"\"\n    PREFIX bar:  \n    PREFIX foo:  \n    \"\"\"\n\n    iex> RDF.PrefixMap.new(\n    ...>   foo: \"http://example.com/foo\",\n    ...>   bar: \"http://example.com/bar\"\n    ...> ) |> RDF.PrefixMap.to_header(:turtle)\n    \"\"\"\n    @prefix bar:   .\n    @prefix foo:   .\n    \"\"\"\n\n    iex> RDF.PrefixMap.new() |> RDF.PrefixMap.to_header(:sparql)\n    \"\"","ref":"RDF.PrefixMap.html#to_header/3-examples"},{"type":"function","title":"RDF.PrefixMap.to_list/1","doc":"Converts prefix map to a list.\n\nEach prefix-namespace pair in the prefix map is converted to a two-element tuple\n`{prefix, namespace_iri}` in the resulting list.","ref":"RDF.PrefixMap.html#to_list/1"},{"type":"function","title":"Examples - RDF.PrefixMap.to_list/1","doc":"iex> RDF.PrefixMap.new(ex: \"http://example.com/\") |> RDF.PrefixMap.to_list()\n    [ex: ~I ]","ref":"RDF.PrefixMap.html#to_list/1-examples"},{"type":"function","title":"RDF.PrefixMap.to_sorted_list/1","doc":"Converts prefix map to a list sorted by prefix.\n\nEach prefix-namespace pair in the prefix map is converted to a two-element tuple\n`{prefix, namespace_iri}` in the resulting list.","ref":"RDF.PrefixMap.html#to_sorted_list/1"},{"type":"function","title":"Examples - RDF.PrefixMap.to_sorted_list/1","doc":"iex> RDF.PrefixMap.new(\n    ...>   foo: \"http://example.com/foo\",\n    ...>   bar: \"http://example.com/bar\")\n    ...> |> RDF.PrefixMap.to_sorted_list()\n    [bar: ~I , foo: ~I ]\n\n    iex> RDF.PrefixMap.new(\n    ...>   a: \"http://example.com/foo\",\n    ...>   \"\": \"http://example.com/bar\")\n    ...> |> RDF.PrefixMap.to_sorted_list()\n    [\"\": ~I , a: ~I ]","ref":"RDF.PrefixMap.html#to_sorted_list/1-examples"},{"type":"function","title":"RDF.PrefixMap.to_sparql/1","doc":"Converts the given `prefix_map` to a SPARQL header string.","ref":"RDF.PrefixMap.html#to_sparql/1"},{"type":"function","title":"Examples - RDF.PrefixMap.to_sparql/1","doc":"iex> RDF.PrefixMap.new(\n    ...>   foo: \"http://example.com/foo\",\n    ...>   bar: \"http://example.com/bar\"\n    ...> ) |> RDF.PrefixMap.to_sparql()\n    \"\"\"\n    PREFIX bar:  \n    PREFIX foo:  \n    \"\"\"","ref":"RDF.PrefixMap.html#to_sparql/1-examples"},{"type":"function","title":"RDF.PrefixMap.to_turtle/1","doc":"Converts the given `prefix_map` to a Turtle header string.","ref":"RDF.PrefixMap.html#to_turtle/1"},{"type":"function","title":"Examples - RDF.PrefixMap.to_turtle/1","doc":"iex> RDF.PrefixMap.new(\n    ...>   foo: \"http://example.com/foo\",\n    ...>   bar: \"http://example.com/bar\"\n    ...> ) |> RDF.PrefixMap.to_turtle()\n    \"\"\"\n    @prefix bar:   .\n    @prefix foo:   .\n    \"\"\"","ref":"RDF.PrefixMap.html#to_turtle/1-examples"},{"type":"type","title":"RDF.PrefixMap.coercible_namespace/0","doc":"","ref":"RDF.PrefixMap.html#t:coercible_namespace/0"},{"type":"type","title":"RDF.PrefixMap.coercible_prefix/0","doc":"","ref":"RDF.PrefixMap.html#t:coercible_prefix/0"},{"type":"type","title":"RDF.PrefixMap.conflict_resolver/0","doc":"","ref":"RDF.PrefixMap.html#t:conflict_resolver/0"},{"type":"type","title":"RDF.PrefixMap.namespace/0","doc":"","ref":"RDF.PrefixMap.html#t:namespace/0"},{"type":"type","title":"RDF.PrefixMap.prefix/0","doc":"","ref":"RDF.PrefixMap.html#t:prefix/0"},{"type":"type","title":"RDF.PrefixMap.prefix_map/0","doc":"","ref":"RDF.PrefixMap.html#t:prefix_map/0"},{"type":"type","title":"RDF.PrefixMap.t/0","doc":"","ref":"RDF.PrefixMap.html#t:t/0"},{"type":"module","title":"RDF.PropertyMap","doc":"A bidirectional mapping from atom names to `RDF.IRI`s of properties.\n\nThese mappings can be used in all functions of the RDF data structures\nto provide the meaning of the predicate terms in input statements or\ndefine how the IRIs of predicates should be mapped with the value mapping\nfunctions like `RDF.Description.values/2` etc.\nThe `:context` option of these functions either take a `RDF.PropertyMap` directly\nor anything from which a `RDF.PropertyMap` can be created with `new/1`.\n\nBecause the mapping is bidirectional each term and IRI can be used only in\none mapping of a `RDF.PropertyMap`.\n\nThis module implements the `Enumerable` protocol and the `Access` behaviour.","ref":"RDF.PropertyMap.html"},{"type":"function","title":"RDF.PropertyMap.add/2","doc":"Adds a set of property mappings to `property_map`.\n\nThe mappings can be passed in various ways:\n\n- as keyword lists or maps where terms for the RDF properties can\n  be given as atoms or strings, while the property IRIs can be given as\n  `RDF.IRI`s or strings\n- a strict `RDF.Vocabulary.Namespace` from which all lowercase terms are added\n  with their respective IRI; since IRIs can also be once in a\n  `RDF.PropertyMap` a defined alias term is preferred over an original term\n- a `RDF.Namespace` from which all lowercase terms are added\n  with their respective IRI\n- another `RDF.PropertyMap` from which all mappings are merged\n\nUnless a mapping for any of the terms or IRIs in the `input` already exists,\nan `:ok` tuple is returned, otherwise an `:error` tuple.","ref":"RDF.PropertyMap.html#add/2"},{"type":"function","title":"RDF.PropertyMap.add/3","doc":"Adds a property mapping between `term` and `iri` to `property_map`.\n\nUnless another mapping for `term` or `iri` already exists, an `:ok` tuple\nis returned, otherwise an `:error` tuple.","ref":"RDF.PropertyMap.html#add/3"},{"type":"function","title":"RDF.PropertyMap.add!/2","doc":"Adds a set of property mappings to `property_map` and raises an error on conflicts.\n\nSee `add/2` for the different forms in which mappings can be provided.","ref":"RDF.PropertyMap.html#add!/2"},{"type":"function","title":"RDF.PropertyMap.delete/2","doc":"Deletes the property mapping for `term` from `property_map`.\n\nIf no mapping for `term` exists, `property_map` is returned unchanged.","ref":"RDF.PropertyMap.html#delete/2"},{"type":"function","title":"RDF.PropertyMap.drop/2","doc":"Drops the given `terms` from the `property_map`.\n\nIf `terms` contains terms that are not in `property_map`, they're simply ignored.","ref":"RDF.PropertyMap.html#drop/2"},{"type":"function","title":"RDF.PropertyMap.iri/2","doc":"Returns the IRI for the given `term` in `property_map`.\n\nReturns `nil`, when the given `term` is not present in `property_map`.","ref":"RDF.PropertyMap.html#iri/2"},{"type":"function","title":"RDF.PropertyMap.iri_defined?/2","doc":"Returns whether a mapping for the given `term` is defined in `property_map`.","ref":"RDF.PropertyMap.html#iri_defined?/2"},{"type":"function","title":"RDF.PropertyMap.iris/1","doc":"Returns the list of all IRIs in the given `property_map`.","ref":"RDF.PropertyMap.html#iris/1"},{"type":"function","title":"RDF.PropertyMap.new/0","doc":"Creates an empty `RDF.PropertyMap`.","ref":"RDF.PropertyMap.html#new/0"},{"type":"function","title":"RDF.PropertyMap.new/1","doc":"Creates a new `RDF.PropertyMap` with initial mappings.\n\nSee `add/2` for the different forms in which mappings can be provided.","ref":"RDF.PropertyMap.html#new/1"},{"type":"function","title":"RDF.PropertyMap.put/2","doc":"Adds a set of property mappings to `property_map` overwriting all existing mappings.\n\nSee `add/2` for the different forms in which mappings can be provided.\n\nNote, that not just all mappings with the used terms in the input `mappings`\nare overwritten, but also all mappings with IRIs in the input `mappings`","ref":"RDF.PropertyMap.html#put/2"},{"type":"function","title":"RDF.PropertyMap.put/3","doc":"Adds a property mapping between `term` and `iri` to `property_map` overwriting existing mappings.","ref":"RDF.PropertyMap.html#put/3"},{"type":"function","title":"RDF.PropertyMap.term/2","doc":"Returns the term for the given `namespace` in `prefix_map`.\n\nReturns `nil`, when the given `namespace` is not present in `prefix_map`.","ref":"RDF.PropertyMap.html#term/2"},{"type":"function","title":"RDF.PropertyMap.term_defined?/2","doc":"Returns whether a mapping for the given `iri` is defined in `property_map`.","ref":"RDF.PropertyMap.html#term_defined?/2"},{"type":"function","title":"RDF.PropertyMap.terms/1","doc":"Returns the list of all terms in the given `property_map`.","ref":"RDF.PropertyMap.html#terms/1"},{"type":"function","title":"RDF.PropertyMap.to_list/1","doc":"Converts property map to a list.\n\nEach term-IRI pair in the property map is converted to a two-element tuple\n`{term, iri}` in the resulting list.","ref":"RDF.PropertyMap.html#to_list/1"},{"type":"function","title":"Examples - RDF.PropertyMap.to_list/1","doc":"iex> RDF.PropertyMap.new(foo: \"http://example.com/foo\") |> RDF.PropertyMap.to_list()\n    [foo: ~I ]","ref":"RDF.PropertyMap.html#to_list/1-examples"},{"type":"function","title":"RDF.PropertyMap.to_sorted_list/1","doc":"Converts property map to a list sorted by property.\n\nEach term-IRI pair in the property map is converted to a two-element tuple\n`{term, iri}` in the resulting list.","ref":"RDF.PropertyMap.html#to_sorted_list/1"},{"type":"function","title":"Examples - RDF.PropertyMap.to_sorted_list/1","doc":"iex> RDF.PropertyMap.new(\n    ...>   foo: \"http://example.com/foo\",\n    ...>   bar: \"http://example.com/bar\")\n    ...> |> RDF.PropertyMap.to_sorted_list()\n    [bar: ~I , foo: ~I ]","ref":"RDF.PropertyMap.html#to_sorted_list/1-examples"},{"type":"type","title":"RDF.PropertyMap.coercible_term/0","doc":"","ref":"RDF.PropertyMap.html#t:coercible_term/0"},{"type":"type","title":"RDF.PropertyMap.input/0","doc":"","ref":"RDF.PropertyMap.html#t:input/0"},{"type":"type","title":"RDF.PropertyMap.t/0","doc":"","ref":"RDF.PropertyMap.html#t:t/0"},{"type":"module","title":"RDF.Quad","doc":"Helper functions for RDF quads.\n\nAn RDF Quad is represented as a plain Elixir tuple consisting of four valid\nRDF values for subject, predicate, object and a graph name.","ref":"RDF.Quad.html"},{"type":"function","title":"RDF.Quad.bnodes/1","doc":"Returns a list of all `RDF.BlankNode`s within the given `quad`.","ref":"RDF.Quad.html#bnodes/1"},{"type":"function","title":"RDF.Quad.has_bnode?/1","doc":"Returns whether the given `quad` contains a blank node.","ref":"RDF.Quad.html#has_bnode?/1"},{"type":"function","title":"RDF.Quad.include_value?/1","doc":"","ref":"RDF.Quad.html#include_value?/1"},{"type":"function","title":"RDF.Quad.include_value?/2","doc":"Returns whether the given `value` is a component of the given `triple`.","ref":"RDF.Quad.html#include_value?/2"},{"type":"function","title":"RDF.Quad.map/2","doc":"Returns a tuple where each element from a `RDF.Quad` is mapped with the given function.\n\nReturns `nil` if one of the components of the given tuple is not convertible via `RDF.Term.value/1`.\n\nThe function `fun` will receive a tuple `{statement_position, rdf_term}` where\n`statement_position` is one of the atoms `:subject`, `:predicate`, `:object` or\n`:graph_name` while `rdf_term` is the RDF term to be mapped. When the given function\nreturns `nil` this will be interpreted as an error and will become the overhaul\nresult of the `map/2` call.","ref":"RDF.Quad.html#map/2"},{"type":"function","title":"Examples - RDF.Quad.map/2","doc":"iex> {~I , ~I , RDF.literal(42), ~I }\n    ...> |> RDF.Quad.map(fn\n    ...>      {:object, object} ->\n    ...>        RDF.Term.value(object)\n    ...>      {:graph_name, graph_name} ->\n    ...>        graph_name\n    ...>      {_, resource} ->\n    ...>        resource |> to_string() |> String.last() |> String.to_atom()\n    ...>    end)\n    {:S, :p, 42, ~I }","ref":"RDF.Quad.html#map/2-examples"},{"type":"function","title":"RDF.Quad.new/2","doc":"Creates a `RDF.Quad` with proper RDF values.\n\nAn error is raised when the given elements are not coercible to RDF values.\n\nNote: The `RDF.quad` function is a shortcut to this function.","ref":"RDF.Quad.html#new/2"},{"type":"function","title":"Examples - RDF.Quad.new/2","doc":"iex> RDF.Quad.new {\"http://example.com/S\", \"http://example.com/p\", 42, \"http://example.com/Graph\"}\n    {~I , ~I , RDF.literal(42), ~I }\n\n    iex> RDF.Quad.new {EX.S, EX.p, 42, EX.Graph}\n    {RDF.iri(\"http://example.com/S\"), RDF.iri(\"http://example.com/p\"), RDF.literal(42), RDF.iri(\"http://example.com/Graph\")}\n\n    iex> RDF.Quad.new {EX.S, EX.p, 42}\n    {RDF.iri(\"http://example.com/S\"), RDF.iri(\"http://example.com/p\"), RDF.literal(42), nil}\n\n    iex> RDF.Quad.new {EX.S, :p, 42, EX.Graph}, RDF.PropertyMap.new(p: EX.p)\n    {RDF.iri(\"http://example.com/S\"), RDF.iri(\"http://example.com/p\"), RDF.literal(42), RDF.iri(\"http://example.com/Graph\")}","ref":"RDF.Quad.html#new/2-examples"},{"type":"function","title":"RDF.Quad.new/5","doc":"Creates a `RDF.Quad` with proper RDF values.\n\nAn error is raised when the given elements are not coercible to RDF values.\n\nNote: The `RDF.quad` function is a shortcut to this function.","ref":"RDF.Quad.html#new/5"},{"type":"function","title":"Examples - RDF.Quad.new/5","doc":"iex> RDF.Quad.new(\"http://example.com/S\", \"http://example.com/p\", 42, \"http://example.com/Graph\")\n    {~I , ~I , RDF.literal(42), ~I }\n\n    iex> RDF.Quad.new(EX.S, EX.p, 42, EX.Graph)\n    {RDF.iri(\"http://example.com/S\"), RDF.iri(\"http://example.com/p\"), RDF.literal(42), RDF.iri(\"http://example.com/Graph\")}\n\n    iex> RDF.Quad.new(EX.S, :p, 42, EX.Graph, RDF.PropertyMap.new(p: EX.p))\n    {RDF.iri(\"http://example.com/S\"), RDF.iri(\"http://example.com/p\"), RDF.literal(42), RDF.iri(\"http://example.com/Graph\")}","ref":"RDF.Quad.html#new/5-examples"},{"type":"function","title":"RDF.Quad.valid?/1","doc":"Checks if the given tuple is a valid RDF quad.\n\nThe elements of a valid RDF quad must be RDF terms. On the subject\nposition only IRIs and blank nodes allowed, while on the predicate and graph\nname position only IRIs allowed. The object position can be any RDF term.","ref":"RDF.Quad.html#valid?/1"},{"type":"function","title":"RDF.Quad.values/2","doc":"Returns a tuple of native Elixir values from a `RDF.Quad` of RDF terms.\n\nWhen a `:context` option is given with a `RDF.PropertyMap`, predicates will\nbe mapped to the terms defined in the `RDF.PropertyMap`, if present.\n\nReturns `nil` if one of the components of the given tuple is not convertible via `RDF.Term.value/1`.","ref":"RDF.Quad.html#values/2"},{"type":"function","title":"Examples - RDF.Quad.values/2","doc":"iex> RDF.Quad.values {~I , ~I , RDF.literal(42), ~I }\n    {\"http://example.com/S\", \"http://example.com/p\", 42, \"http://example.com/Graph\"}\n\n    iex> {~I , ~I , RDF.literal(42), ~I }\n    ...> |> RDF.Quad.values(context: %{p: ~I })\n    {\"http://example.com/S\", :p, 42,  \"http://example.com/Graph\"}","ref":"RDF.Quad.html#values/2-examples"},{"type":"type","title":"RDF.Quad.coercible/0","doc":"","ref":"RDF.Quad.html#t:coercible/0"},{"type":"type","title":"RDF.Quad.mapping_value/0","doc":"","ref":"RDF.Quad.html#t:mapping_value/0"},{"type":"type","title":"RDF.Quad.t/0","doc":"","ref":"RDF.Quad.html#t:t/0"},{"type":"module","title":"RDF.Statement","doc":"Helper functions for RDF statements.\n\nAn RDF statement is either a `RDF.Triple` or a `RDF.Quad`.","ref":"RDF.Statement.html"},{"type":"function","title":"RDF.Statement.bnodes/1","doc":"Returns a list of all `RDF.BlankNode`s within the given `statement`.","ref":"RDF.Statement.html#bnodes/1"},{"type":"function","title":"RDF.Statement.coerce/2","doc":"Creates a `RDF.Statement` tuple with proper RDF values.\n\nAn error is raised when the given elements are not coercible to RDF values.","ref":"RDF.Statement.html#coerce/2"},{"type":"function","title":"Examples - RDF.Statement.coerce/2","doc":"iex> RDF.Statement.coerce {\"http://example.com/S\", \"http://example.com/p\", 42}\n    {~I , ~I , RDF.literal(42)}\n    iex> RDF.Statement.coerce {\"http://example.com/S\", \"http://example.com/p\", 42, \"http://example.com/Graph\"}\n    {~I , ~I , RDF.literal(42), ~I }","ref":"RDF.Statement.html#coerce/2-examples"},{"type":"function","title":"RDF.Statement.coerce_graph_name/1","doc":"Coerces the given `value` to a valid graph context of an RDF statement.\n\nRaises an `RDF.Quad.InvalidGraphContextError` when the value can not be coerced.","ref":"RDF.Statement.html#coerce_graph_name/1"},{"type":"function","title":"RDF.Statement.coerce_object/1","doc":"Coerces the given `value` to a valid object of an RDF statement.","ref":"RDF.Statement.html#coerce_object/1"},{"type":"function","title":"RDF.Statement.coerce_predicate/1","doc":"Coerces the given `value` to a valid predicate of an RDF statement.\n\nRaises an `RDF.Triple.InvalidPredicateError` when the value can not be coerced.","ref":"RDF.Statement.html#coerce_predicate/1"},{"type":"function","title":"RDF.Statement.coerce_predicate/2","doc":"Coerces the given `term` to a valid predicate of an RDF statement using a `RDF.PropertyMap`.\n\nRaises an `RDF.Triple.InvalidPredicateError` when the value can not be coerced.","ref":"RDF.Statement.html#coerce_predicate/2"},{"type":"function","title":"RDF.Statement.coerce_subject/1","doc":"Coerces the given `value` to a valid subject of an RDF statement.\n\nRaises an `RDF.Triple.InvalidSubjectError` when the value can not be coerced.","ref":"RDF.Statement.html#coerce_subject/1"},{"type":"function","title":"RDF.Statement.default_property_mapping/1","doc":"","ref":"RDF.Statement.html#default_property_mapping/1"},{"type":"function","title":"RDF.Statement.graph_name/1","doc":"The graph name component of a statement.","ref":"RDF.Statement.html#graph_name/1"},{"type":"function","title":"Examples - RDF.Statement.graph_name/1","doc":"iex> RDF.Statement.graph_name {\"http://example.com/S\", \"http://example.com/p\", 42, \"http://example.com/Graph\"}\n    ~I \n    iex> RDF.Statement.graph_name {\"http://example.com/S\", \"http://example.com/p\", 42}\n    nil","ref":"RDF.Statement.html#graph_name/1-examples"},{"type":"function","title":"RDF.Statement.has_bnode?/1","doc":"Returns whether the given `statement` contains a blank node.","ref":"RDF.Statement.html#has_bnode?/1"},{"type":"function","title":"RDF.Statement.include_value?/2","doc":"Returns whether the given `value` is a component of the given `statement`.","ref":"RDF.Statement.html#include_value?/2"},{"type":"function","title":"RDF.Statement.map/2","doc":"Returns a tuple of native Elixir values from a `RDF.Statement` of RDF terms.\n\nReturns `nil` if one of the components of the given tuple is not convertible via `RDF.Term.value/1`.\n\nThe optional second argument allows to specify a custom mapping with a function\nwhich will receive a tuple `{statement_position, rdf_term}` where\n`statement_position` is one of the atoms `:subject`, `:predicate`, `:object` or\n`:graph_name`, while `rdf_term` is the RDF term to be mapped. When the given\nfunction returns `nil` this will be interpreted as an error and will become\nthe overhaul result of the `values/2` call.","ref":"RDF.Statement.html#map/2"},{"type":"function","title":"Examples - RDF.Statement.map/2","doc":"iex> {~I , ~I , RDF.literal(42), ~I }\n    ...> |> RDF.Statement.map(fn\n    ...>      {:subject, subject} ->\n    ...>        subject |> to_string() |> String.last()\n    ...>      {:predicate, predicate} ->\n    ...>        predicate |> to_string() |> String.last() |> String.to_atom()\n    ...>      {:object, object} ->\n    ...>        RDF.Term.value(object)\n    ...>      {:graph_name, graph_name} ->\n    ...>        graph_name\n    ...>    end)\n    {\"S\", :p, 42, ~I }","ref":"RDF.Statement.html#map/2-examples"},{"type":"function","title":"RDF.Statement.new/2","doc":"Creates a `RDF.Triple` or `RDF.Quad` with proper RDF values.\n\nAn error is raised when the given elements are not coercible to RDF values.\n\nNote: The `RDF.statement` function is a shortcut to this function.","ref":"RDF.Statement.html#new/2"},{"type":"function","title":"Examples - RDF.Statement.new/2","doc":"iex> RDF.Statement.new({EX.S, EX.p, 42})\n    {RDF.iri(\"http://example.com/S\"), RDF.iri(\"http://example.com/p\"), RDF.literal(42)}\n\n    iex> RDF.Statement.new({EX.S, EX.p, 42, EX.Graph})\n    {RDF.iri(\"http://example.com/S\"), RDF.iri(\"http://example.com/p\"), RDF.literal(42), RDF.iri(\"http://example.com/Graph\")}\n\n    iex> RDF.Statement.new({EX.S, :p, 42, EX.Graph}, RDF.PropertyMap.new(p: EX.p))\n    {RDF.iri(\"http://example.com/S\"), RDF.iri(\"http://example.com/p\"), RDF.literal(42), RDF.iri(\"http://example.com/Graph\")}","ref":"RDF.Statement.html#new/2-examples"},{"type":"function","title":"RDF.Statement.new/3","doc":"","ref":"RDF.Statement.html#new/3"},{"type":"function","title":"RDF.Statement.new/4","doc":"","ref":"RDF.Statement.html#new/4"},{"type":"function","title":"RDF.Statement.object/1","doc":"The object component of a statement.","ref":"RDF.Statement.html#object/1"},{"type":"function","title":"Examples - RDF.Statement.object/1","doc":"iex> RDF.Statement.object {\"http://example.com/S\", \"http://example.com/p\", 42}\n    RDF.literal(42)","ref":"RDF.Statement.html#object/1-examples"},{"type":"function","title":"RDF.Statement.predicate/1","doc":"The predicate component of a statement.","ref":"RDF.Statement.html#predicate/1"},{"type":"function","title":"Examples - RDF.Statement.predicate/1","doc":"iex> RDF.Statement.predicate {\"http://example.com/S\", \"http://example.com/p\", 42}\n    ~I","ref":"RDF.Statement.html#predicate/1-examples"},{"type":"function","title":"RDF.Statement.subject/1","doc":"The subject component of a statement.","ref":"RDF.Statement.html#subject/1"},{"type":"function","title":"Examples - RDF.Statement.subject/1","doc":"iex> RDF.Statement.subject {\"http://example.com/S\", \"http://example.com/p\", 42}\n    ~I","ref":"RDF.Statement.html#subject/1-examples"},{"type":"function","title":"RDF.Statement.valid?/1","doc":"Checks if the given tuple is a valid RDF statement, i.e. RDF triple or quad.\n\nThe elements of a valid RDF statement must be RDF terms. On the subject\nposition only IRIs and blank nodes allowed, while on the predicate and graph\ncontext position only IRIs allowed. The object position can be any RDF term.","ref":"RDF.Statement.html#valid?/1"},{"type":"function","title":"RDF.Statement.valid_graph_name?/1","doc":"","ref":"RDF.Statement.html#valid_graph_name?/1"},{"type":"function","title":"RDF.Statement.valid_object?/1","doc":"","ref":"RDF.Statement.html#valid_object?/1"},{"type":"function","title":"RDF.Statement.valid_predicate?/1","doc":"","ref":"RDF.Statement.html#valid_predicate?/1"},{"type":"function","title":"RDF.Statement.valid_subject?/1","doc":"","ref":"RDF.Statement.html#valid_subject?/1"},{"type":"function","title":"RDF.Statement.values/2","doc":"Returns a tuple of native Elixir values from a `RDF.Statement` of RDF terms.\n\nWhen a `:context` option is given with a `RDF.PropertyMap`, predicates will\nbe mapped to the terms defined in the `RDF.PropertyMap`, if present.\n\nReturns `nil` if one of the components of the given tuple is not convertible via `RDF.Term.value/1`.","ref":"RDF.Statement.html#values/2"},{"type":"function","title":"Examples - RDF.Statement.values/2","doc":"iex> RDF.Statement.values {~I , ~I , RDF.literal(42)}\n    {\"http://example.com/S\", \"http://example.com/p\", 42}\n\n    iex> RDF.Statement.values {~I , ~I , RDF.literal(42), ~I }\n    {\"http://example.com/S\", \"http://example.com/p\", 42, \"http://example.com/Graph\"}\n\n    iex> {~I , ~I , RDF.literal(42)}\n    ...> |> RDF.Statement.values(context: %{p: ~I })\n    {\"http://example.com/S\", :p, 42}","ref":"RDF.Statement.html#values/2-examples"},{"type":"type","title":"RDF.Statement.coercible/0","doc":"","ref":"RDF.Statement.html#t:coercible/0"},{"type":"type","title":"RDF.Statement.coercible_graph_name/0","doc":"","ref":"RDF.Statement.html#t:coercible_graph_name/0"},{"type":"type","title":"RDF.Statement.coercible_object/0","doc":"","ref":"RDF.Statement.html#t:coercible_object/0"},{"type":"type","title":"RDF.Statement.coercible_predicate/0","doc":"","ref":"RDF.Statement.html#t:coercible_predicate/0"},{"type":"type","title":"RDF.Statement.coercible_subject/0","doc":"","ref":"RDF.Statement.html#t:coercible_subject/0"},{"type":"type","title":"RDF.Statement.graph_name/0","doc":"","ref":"RDF.Statement.html#t:graph_name/0"},{"type":"type","title":"RDF.Statement.object/0","doc":"","ref":"RDF.Statement.html#t:object/0"},{"type":"type","title":"RDF.Statement.position/0","doc":"","ref":"RDF.Statement.html#t:position/0"},{"type":"type","title":"RDF.Statement.predicate/0","doc":"","ref":"RDF.Statement.html#t:predicate/0"},{"type":"type","title":"RDF.Statement.qualified_term/0","doc":"","ref":"RDF.Statement.html#t:qualified_term/0"},{"type":"type","title":"RDF.Statement.subject/0","doc":"","ref":"RDF.Statement.html#t:subject/0"},{"type":"type","title":"RDF.Statement.t/0","doc":"","ref":"RDF.Statement.html#t:t/0"},{"type":"type","title":"RDF.Statement.term_mapping/0","doc":"","ref":"RDF.Statement.html#t:term_mapping/0"},{"type":"module","title":"RDF.Triple","doc":"Helper functions for RDF triples.\n\nAn RDF Triple is represented as a plain Elixir tuple consisting of three valid\nRDF values for subject, predicate and object.","ref":"RDF.Triple.html"},{"type":"function","title":"RDF.Triple.bnodes/1","doc":"Returns a list of all `RDF.BlankNode`s within the given `triple`.","ref":"RDF.Triple.html#bnodes/1"},{"type":"function","title":"RDF.Triple.has_bnode?/1","doc":"Returns whether the given `triple` contains a blank node.","ref":"RDF.Triple.html#has_bnode?/1"},{"type":"function","title":"RDF.Triple.include_value?/1","doc":"","ref":"RDF.Triple.html#include_value?/1"},{"type":"function","title":"RDF.Triple.include_value?/2","doc":"Returns whether the given `value` is a component of the given `triple`.","ref":"RDF.Triple.html#include_value?/2"},{"type":"function","title":"RDF.Triple.map/2","doc":"Returns a triple where each element from a `RDF.Triple` is mapped with the given function.\n\nReturns `nil` if one of the components of the given tuple is not convertible via `RDF.Term.value/1`.\n\nThe function `fun` will receive a tuple `{statement_position, rdf_term}` where\n`statement_position` is one of the atoms `:subject`, `:predicate` or `:object`,\nwhile `rdf_term` is the RDF term to be mapped. When the given function returns\n`nil` this will be interpreted as an error and will become the overhaul result\nof the `map/2` call.","ref":"RDF.Triple.html#map/2"},{"type":"function","title":"Examples - RDF.Triple.map/2","doc":"iex> {~I , ~I , RDF.literal(42)}\n    ...> |> RDF.Triple.map(fn\n    ...>      {:object, object} -> RDF.Term.value(object)\n    ...>      {_, term}         -> term |> to_string() |> String.last()\n    ...>    end)\n    {\"S\", \"p\", 42}","ref":"RDF.Triple.html#map/2-examples"},{"type":"function","title":"RDF.Triple.new/2","doc":"Creates a `RDF.Triple` with proper RDF values.\n\nAn error is raised when the given elements are not coercible to RDF values.\n\nNote: The `RDF.triple` function is a shortcut to this function.","ref":"RDF.Triple.html#new/2"},{"type":"function","title":"Examples - RDF.Triple.new/2","doc":"iex> RDF.Triple.new {\"http://example.com/S\", \"http://example.com/p\", 42}\n    {~I , ~I , RDF.literal(42)}\n\n    iex> RDF.Triple.new {EX.S, EX.p, 42}\n    {RDF.iri(\"http://example.com/S\"), RDF.iri(\"http://example.com/p\"), RDF.literal(42)}\n\n    iex> RDF.Triple.new {EX.S, EX.p, 42, EX.Graph}\n    {RDF.iri(\"http://example.com/S\"), RDF.iri(\"http://example.com/p\"), RDF.literal(42)}\n\n    iex> RDF.Triple.new {EX.S, :p, 42}, RDF.PropertyMap.new(p: EX.p)\n    {RDF.iri(\"http://example.com/S\"), RDF.iri(\"http://example.com/p\"), RDF.literal(42)}","ref":"RDF.Triple.html#new/2-examples"},{"type":"function","title":"RDF.Triple.new/4","doc":"Creates a `RDF.Triple` with proper RDF values.\n\nAn error is raised when the given elements are not coercible to RDF values.\n\nNote: The `RDF.triple` function is a shortcut to this function.","ref":"RDF.Triple.html#new/4"},{"type":"function","title":"Examples - RDF.Triple.new/4","doc":"iex> RDF.Triple.new(\"http://example.com/S\", \"http://example.com/p\", 42)\n    {~I , ~I , RDF.literal(42)}\n\n    iex> RDF.Triple.new(EX.S, EX.p, 42)\n    {RDF.iri(\"http://example.com/S\"), RDF.iri(\"http://example.com/p\"), RDF.literal(42)}\n\n    iex> RDF.Triple.new(EX.S, :p, 42, RDF.PropertyMap.new(p: EX.p))\n    {RDF.iri(\"http://example.com/S\"), RDF.iri(\"http://example.com/p\"), RDF.literal(42)}","ref":"RDF.Triple.html#new/4-examples"},{"type":"function","title":"RDF.Triple.valid?/1","doc":"Checks if the given tuple is a valid RDF triple.\n\nThe elements of a valid RDF triple must be RDF terms. On the subject\nposition only IRIs and blank nodes allowed, while on the predicate position\nonly IRIs allowed. The object position can be any RDF term.","ref":"RDF.Triple.html#valid?/1"},{"type":"function","title":"RDF.Triple.values/2","doc":"Returns a tuple of native Elixir values from a `RDF.Triple` of RDF terms.\n\nWhen a `:context` option is given with a `RDF.PropertyMap`, predicates will\nbe mapped to the terms defined in the `RDF.PropertyMap`, if present.\n\nReturns `nil` if one of the components of the given tuple is not convertible via `RDF.Term.value/1`.","ref":"RDF.Triple.html#values/2"},{"type":"function","title":"Examples - RDF.Triple.values/2","doc":"iex> RDF.Triple.values {~I , ~I , RDF.literal(42)}\n    {\"http://example.com/S\", \"http://example.com/p\", 42}\n\n    iex> {~I , ~I , RDF.literal(42)}\n    ...> |> RDF.Triple.values(context: %{p: ~I })\n    {\"http://example.com/S\", :p, 42}","ref":"RDF.Triple.html#values/2-examples"},{"type":"type","title":"RDF.Triple.coercible/0","doc":"","ref":"RDF.Triple.html#t:coercible/0"},{"type":"type","title":"RDF.Triple.mapping_value/0","doc":"","ref":"RDF.Triple.html#t:mapping_value/0"},{"type":"type","title":"RDF.Triple.t/0","doc":"","ref":"RDF.Triple.html#t:t/0"},{"type":"behaviour","title":"RDF.Namespace","doc":"A behaviour and generator for modules of terms resolving to `RDF.IRI`s.\n\nNote: A `RDF.Namespace` is NOT a IRI namespace! The terms of a `RDF.Namespace` don't\nhave to necessarily refer to IRIs from the same IRI namespace. \"Namespace\" here is\njust meant in the sense that an Elixir module is a namespace. Most of the\n\nMost of the time you'll want to use a `RDF.Vocabulary.Namespace`, a special type of\n`RDF.Namespace` where all terms indeed resolve to IRIs of a shared base URI namespace.\n\nFor an introduction into `RDF.Namespace`s and `RDF.Vocabulary.Namespace`s see\n[this guide](https://rdf-elixir.dev/rdf-ex/namespaces.html).","ref":"RDF.Namespace.html"},{"type":"callback","title":"RDF.Namespace.__iris__/0","doc":"All `RDF.IRI`s of a `RDF.Namespace`.","ref":"RDF.Namespace.html#c:__iris__/0"},{"type":"callback","title":"RDF.Namespace.__resolve_term__/1","doc":"Resolves a term to a `RDF.IRI`.","ref":"RDF.Namespace.html#c:__resolve_term__/1"},{"type":"callback","title":"RDF.Namespace.__terms__/0","doc":"All terms of a `RDF.Namespace`.","ref":"RDF.Namespace.html#c:__terms__/0"},{"type":"macro","title":"RDF.Namespace.act_as_namespace/1","doc":"A macro to let a module act as a specified `RDF.Namespace` or `RDF.Vocabulary.Namespace`.","ref":"RDF.Namespace.html#act_as_namespace/1"},{"type":"macro","title":"Example - RDF.Namespace.act_as_namespace/1","doc":"defmodule Example.NS do\n      use RDF.Vocabulary.Namespace\n\n      defvocab Example,\n        base_iri: \"http://www.example.com/ns/\",\n        terms: [:Foo, :bar]\n    end\n\n    defmodule Example do\n      import RDF.Namespace\n\n      act_as_namespace Example.NS.Example\n\n      # your application functions\n    end\n\n    Example.Foo |> Example.bar(42)","ref":"RDF.Namespace.html#act_as_namespace/1-example"},{"type":"function","title":"RDF.Namespace.create/4","doc":"Creates a `RDF.Namespace` module with the given name and term mapping dynamically.\n\nThe line where the module is defined and its file must be passed as options.","ref":"RDF.Namespace.html#create/4"},{"type":"function","title":"RDF.Namespace.create!/4","doc":"Creates a `RDF.Namespace` module with the given name and term mapping dynamically.\n\nThe line where the module is defined and its file must be passed as options.","ref":"RDF.Namespace.html#create!/4"},{"type":"macro","title":"RDF.Namespace.defnamespace/3","doc":"A macro to define a `RDF.Namespace`.","ref":"RDF.Namespace.html#defnamespace/3"},{"type":"macro","title":"Example - RDF.Namespace.defnamespace/3","doc":"defmodule YourApp.NS do\n      import RDF.Namespace\n\n      defnamespace EX, [\n                     foo: ~I ,\n                     Bar: \"http://example2.com/Bar\",\n                   ]\n    end\n\n> #### Warning {: .warning}\n>\n> This macro is intended to be used at compile-time, i.e. in the body of a\n> `defmodule` definition. If you want to create `RDF.Namespace`s dynamically\n> at runtime, please use `create/4`.","ref":"RDF.Namespace.html#defnamespace/3-example"},{"type":"function","title":"RDF.Namespace.resolve_term/1","doc":"Resolves a qualified term to a `RDF.IRI`.\n\nIt determines a `RDF.Namespace` from the qualifier of the given term and\ndelegates to remaining part of the term to `__resolve_term__/1` of this\ndetermined namespace.","ref":"RDF.Namespace.html#resolve_term/1"},{"type":"function","title":"RDF.Namespace.resolve_term!/1","doc":"Resolves a qualified term to a `RDF.IRI` or raises an error when that's not possible.\n\nSee `resolve_term/1` for more.","ref":"RDF.Namespace.html#resolve_term!/1"},{"type":"type","title":"RDF.Namespace.t/0","doc":"","ref":"RDF.Namespace.html#t:t/0"},{"type":"module","title":"RDF.Namespace.IRI","doc":"Provides the `term_to_iri/1` macro to resolve IRI values inside of pattern matches.","ref":"RDF.Namespace.IRI.html"},{"type":"macro","title":"RDF.Namespace.IRI.term_to_iri/1","doc":"A macro which allows to resolve IRI values inside of pattern matches.\n\nTerms of a `RDF.Namespace` (which includes terms of `RDF.Vocabulary.Namespace`)\ncan't be resolved in pattern matches. This macro allows just that, by wrapping\nthe terms in a pattern match with a call of this macro.\n\nNote: Only literal values are allowed as arguments of this macro, since the argument\nexpression needs to be evaluated at compile-time.","ref":"RDF.Namespace.IRI.html#term_to_iri/1"},{"type":"macro","title":"Example - RDF.Namespace.IRI.term_to_iri/1","doc":"import RDF.Namespace.IRI\n\n    case expr do\n      term_to_iri(EX.Foo) -> ...\n      term_to_iri(EX.bar()) -> ...\n      ...\n    end","ref":"RDF.Namespace.IRI.html#term_to_iri/1-example"},{"type":"module","title":"RDF.Vocabulary","doc":"Various functions for working with RDF vocabularies and their URIs.","ref":"RDF.Vocabulary.html"},{"type":"function","title":"RDF.Vocabulary.path/1","doc":"Returns the path the vocabulary directory of the given application.","ref":"RDF.Vocabulary.html#path/1"},{"type":"function","title":"RDF.Vocabulary.path/2","doc":"Returns the path the given file or directory in the vocabulary directory of the given application.","ref":"RDF.Vocabulary.html#path/2"},{"type":"module","title":"RDF.Vocabulary.Namespace","doc":"An RDF vocabulary as a `RDF.Namespace`.\n\n`RDF.Vocabulary.Namespace` modules represent an RDF vocabulary as a `RDF.Namespace`.\nThey can be defined with the `defvocab/2` macro of this module.\n\nRDF.ex comes with predefined modules for some fundamental vocabularies in\nthe `RDF.NS` module.\n\nFor an introduction into `RDF.Vocabulary.Namespace`s see [this guide](https://rdf-elixir.dev/rdf-ex/namespaces.html).","ref":"RDF.Vocabulary.Namespace.html"},{"type":"function","title":"RDF.Vocabulary.Namespace.create/5","doc":"Creates a `RDF.Vocabulary.Namespace` module with the given name.\n\nExcept for the `:base_uri` and the value of one of the `:terms`, `:file` or `:data`\noptions of `defvocab/2`, which are given as second and third argument respectively,\nall options of `defvocab/2` can be given as `opts`. One notable difference is the\noverloaded use of the `:terms` option as a restriction of the terms loaded from a\n`:file` or `:data`. The term restriction in this case has to be provided with the\n`:term_restriction` keyword option.\n\nThe line where the module is defined and its file must be passed as `location`.\n\nIt returns a tuple of shape `{:module, module, binary, term}` where `module` is\nthe module name, `binary` is the module bytecode.\n\nSimilar to `Module.create/3`, the binary will only be written to disk as a\n`.beam` file if `RDF.Namespace.Vocabulary.create/3` is invoked in a file\nthat is currently being compiled.","ref":"RDF.Vocabulary.Namespace.html#create/5"},{"type":"function","title":"RDF.Vocabulary.Namespace.create!/5","doc":"","ref":"RDF.Vocabulary.Namespace.html#create!/5"},{"type":"macro","title":"RDF.Vocabulary.Namespace.defvocab/2","doc":"Defines a `RDF.Vocabulary.Namespace` module for a RDF vocabulary.","ref":"RDF.Vocabulary.Namespace.html#defvocab/2"},{"type":"macro","title":"Options - RDF.Vocabulary.Namespace.defvocab/2","doc":"- `:base_iri` (required): the base IRI of the vocabulary namespace\n- `:file`: a path to a file in the `priv/vocabs` directory from which terms starting\n  with the specified `base_iri` should be loaded\n- `:data`: a `RDF.Graph` or `RDF.Dataset` from which terms starting with the specified\n   `base_iri` should be loaded\n- `:terms`: the list of terms of the vocabulary namespace, which can also contain\n   aliases directly as keywords\n- `:alias`: a keyword list of aliases for terms with the aliases as keys and aliased\n   terms as values\n- `:ignore`: a list of terms to be ignored\n- `:strict`: when set to `false` terms not specified are nevertheless resolved by\n  simple concatenation of the specified base IRI with the term (default: `true`)\n- `:invalid_characters`: allows to specify what should happen when a term contains\n  invalid characters\n  - `:fail`: raises an error  (default)\n  - `:ignore`: ignores terms with invalid characters\n  - `:warn`: raises a warning and ignores terms with invalid characters\n- `:case_violations`: allows to specify what should happen with case violations of\n   the term, the following values are allowed\n  - `:warn`: raises a warning (default)\n  - `:fail`: raises an error\n  - `:ignore`: ignores terms with case violations\n  - `:auto_fix`: fixes a case violation by automatically defining an alias with\n    the proper casing of the first letter\n  - an anonymous function or `{module, fun_name}` tuple to an external function,\n    which receives a `:resource` or `:property` atom and a case violated term and\n    returns a properly cased alias in an ok tuple\n- `:allow_lowercase_resource_terms`: allows to specify that lower-cased non-property\n   terms are not considered a case violation by setting this option to `true`\n   (default: `false`)\n\nBesides `:base_iri` one of the `:terms`, `:file` or `:data` options must be provided.\nThe `:file` and `:data` options are not allowed to be provided together.\nWhen the `:terms` option is given in conjunction with one of the `:file` and `:data`\noptions, it has a different semantics as given alone: it restricts the terms loaded\nfrom the vocabulary data to the specified terms.","ref":"RDF.Vocabulary.Namespace.html#defvocab/2-options"},{"type":"macro","title":"Example - RDF.Vocabulary.Namespace.defvocab/2","doc":"defmodule YourApp.NS do\n      use RDF.Vocabulary.Namespace\n\n      defvocab EX1,\n        base_iri: \"http://www.example.com/ns1/\",\n        terms: [:Foo, :bar]\n\n      defvocab EX2,\n        base_iri: \"http://www.example.com/ns2/\",\n        file: \"your_vocabulary.ttl\",\n        case_violations: :fail,\n        terms: fn\n          _, \"_\" <> _     -> :ignore\n          _, \"erroneous\"  -> {:error, \"erroneous term\"}\n          :resource, term -> {:ok, Recase.to_pascal(term)}\n          :property, term -> {:ok, Recase.to_snake(term)}\n    end\n\n> #### Warning {: .warning}\n>\n> This macro is intended to be used at compile-time, i.e. in the body of a\n> `defmodule` definition. If you want to create `RDF.Vocabulary.Namespace`s\n> dynamically at runtime, please use `create/5`.","ref":"RDF.Vocabulary.Namespace.html#defvocab/2-example"},{"type":"type","title":"RDF.Vocabulary.Namespace.base_uri/0","doc":"","ref":"RDF.Vocabulary.Namespace.html#t:base_uri/0"},{"type":"type","title":"RDF.Vocabulary.Namespace.t/0","doc":"","ref":"RDF.Vocabulary.Namespace.html#t:t/0"},{"type":"module","title":"RDF.NS","doc":"`RDF.Namespace`s for fundamental RDF vocabularies.\n\nNamely:\n\n- `RDF.NS.RDF`\n- `RDF.NS.RDFS`\n- `RDF.NS.OWL`\n- `RDF.NS.SKOS`\n- `RDF.NS.XSD`","ref":"RDF.NS.html"},{"type":"module","title":"RDF.NS.OWL","doc":"The OWL vocabulary.\n\nSee","ref":"RDF.NS.OWL.html"},{"type":"function","title":"RDF.NS.OWL.__iris__/0","doc":"Returns all known IRIs of the vocabulary.","ref":"RDF.NS.OWL.html#__iris__/0"},{"type":"function","title":"RDF.NS.OWL.allValuesFrom/0","doc":"","ref":"RDF.NS.OWL.html#allValuesFrom/0"},{"type":"function","title":"RDF.NS.OWL.allValuesFrom/1","doc":"`RDF.Description` property accessor for `allValuesFrom/0`","ref":"RDF.NS.OWL.html#allValuesFrom/1"},{"type":"function","title":"RDF.NS.OWL.allValuesFrom/2","doc":"`RDF.Description` builder for `allValuesFrom/0`","ref":"RDF.NS.OWL.html#allValuesFrom/2"},{"type":"function","title":"RDF.NS.OWL.annotatedProperty/0","doc":"","ref":"RDF.NS.OWL.html#annotatedProperty/0"},{"type":"function","title":"RDF.NS.OWL.annotatedProperty/1","doc":"`RDF.Description` property accessor for `annotatedProperty/0`","ref":"RDF.NS.OWL.html#annotatedProperty/1"},{"type":"function","title":"RDF.NS.OWL.annotatedProperty/2","doc":"`RDF.Description` builder for `annotatedProperty/0`","ref":"RDF.NS.OWL.html#annotatedProperty/2"},{"type":"function","title":"RDF.NS.OWL.annotatedSource/0","doc":"","ref":"RDF.NS.OWL.html#annotatedSource/0"},{"type":"function","title":"RDF.NS.OWL.annotatedSource/1","doc":"`RDF.Description` property accessor for `annotatedSource/0`","ref":"RDF.NS.OWL.html#annotatedSource/1"},{"type":"function","title":"RDF.NS.OWL.annotatedSource/2","doc":"`RDF.Description` builder for `annotatedSource/0`","ref":"RDF.NS.OWL.html#annotatedSource/2"},{"type":"function","title":"RDF.NS.OWL.annotatedTarget/0","doc":"","ref":"RDF.NS.OWL.html#annotatedTarget/0"},{"type":"function","title":"RDF.NS.OWL.annotatedTarget/1","doc":"`RDF.Description` property accessor for `annotatedTarget/0`","ref":"RDF.NS.OWL.html#annotatedTarget/1"},{"type":"function","title":"RDF.NS.OWL.annotatedTarget/2","doc":"`RDF.Description` builder for `annotatedTarget/0`","ref":"RDF.NS.OWL.html#annotatedTarget/2"},{"type":"function","title":"RDF.NS.OWL.assertionProperty/0","doc":"","ref":"RDF.NS.OWL.html#assertionProperty/0"},{"type":"function","title":"RDF.NS.OWL.assertionProperty/1","doc":"`RDF.Description` property accessor for `assertionProperty/0`","ref":"RDF.NS.OWL.html#assertionProperty/1"},{"type":"function","title":"RDF.NS.OWL.assertionProperty/2","doc":"`RDF.Description` builder for `assertionProperty/0`","ref":"RDF.NS.OWL.html#assertionProperty/2"},{"type":"function","title":"RDF.NS.OWL.backwardCompatibleWith/0","doc":"","ref":"RDF.NS.OWL.html#backwardCompatibleWith/0"},{"type":"function","title":"RDF.NS.OWL.backwardCompatibleWith/1","doc":"`RDF.Description` property accessor for `backwardCompatibleWith/0`","ref":"RDF.NS.OWL.html#backwardCompatibleWith/1"},{"type":"function","title":"RDF.NS.OWL.backwardCompatibleWith/2","doc":"`RDF.Description` builder for `backwardCompatibleWith/0`","ref":"RDF.NS.OWL.html#backwardCompatibleWith/2"},{"type":"function","title":"RDF.NS.OWL.bottomDataProperty/0","doc":"","ref":"RDF.NS.OWL.html#bottomDataProperty/0"},{"type":"function","title":"RDF.NS.OWL.bottomDataProperty/1","doc":"`RDF.Description` property accessor for `bottomDataProperty/0`","ref":"RDF.NS.OWL.html#bottomDataProperty/1"},{"type":"function","title":"RDF.NS.OWL.bottomDataProperty/2","doc":"`RDF.Description` builder for `bottomDataProperty/0`","ref":"RDF.NS.OWL.html#bottomDataProperty/2"},{"type":"function","title":"RDF.NS.OWL.bottomObjectProperty/0","doc":"","ref":"RDF.NS.OWL.html#bottomObjectProperty/0"},{"type":"function","title":"RDF.NS.OWL.bottomObjectProperty/1","doc":"`RDF.Description` property accessor for `bottomObjectProperty/0`","ref":"RDF.NS.OWL.html#bottomObjectProperty/1"},{"type":"function","title":"RDF.NS.OWL.bottomObjectProperty/2","doc":"`RDF.Description` builder for `bottomObjectProperty/0`","ref":"RDF.NS.OWL.html#bottomObjectProperty/2"},{"type":"function","title":"RDF.NS.OWL.cardinality/0","doc":"","ref":"RDF.NS.OWL.html#cardinality/0"},{"type":"function","title":"RDF.NS.OWL.cardinality/1","doc":"`RDF.Description` property accessor for `cardinality/0`","ref":"RDF.NS.OWL.html#cardinality/1"},{"type":"function","title":"RDF.NS.OWL.cardinality/2","doc":"`RDF.Description` builder for `cardinality/0`","ref":"RDF.NS.OWL.html#cardinality/2"},{"type":"function","title":"RDF.NS.OWL.complementOf/0","doc":"","ref":"RDF.NS.OWL.html#complementOf/0"},{"type":"function","title":"RDF.NS.OWL.complementOf/1","doc":"`RDF.Description` property accessor for `complementOf/0`","ref":"RDF.NS.OWL.html#complementOf/1"},{"type":"function","title":"RDF.NS.OWL.complementOf/2","doc":"`RDF.Description` builder for `complementOf/0`","ref":"RDF.NS.OWL.html#complementOf/2"},{"type":"function","title":"RDF.NS.OWL.datatypeComplementOf/0","doc":"","ref":"RDF.NS.OWL.html#datatypeComplementOf/0"},{"type":"function","title":"RDF.NS.OWL.datatypeComplementOf/1","doc":"`RDF.Description` property accessor for `datatypeComplementOf/0`","ref":"RDF.NS.OWL.html#datatypeComplementOf/1"},{"type":"function","title":"RDF.NS.OWL.datatypeComplementOf/2","doc":"`RDF.Description` builder for `datatypeComplementOf/0`","ref":"RDF.NS.OWL.html#datatypeComplementOf/2"},{"type":"function","title":"RDF.NS.OWL.deprecated/0","doc":"","ref":"RDF.NS.OWL.html#deprecated/0"},{"type":"function","title":"RDF.NS.OWL.deprecated/1","doc":"`RDF.Description` property accessor for `deprecated/0`","ref":"RDF.NS.OWL.html#deprecated/1"},{"type":"function","title":"RDF.NS.OWL.deprecated/2","doc":"`RDF.Description` builder for `deprecated/0`","ref":"RDF.NS.OWL.html#deprecated/2"},{"type":"function","title":"RDF.NS.OWL.differentFrom/0","doc":"","ref":"RDF.NS.OWL.html#differentFrom/0"},{"type":"function","title":"RDF.NS.OWL.differentFrom/1","doc":"`RDF.Description` property accessor for `differentFrom/0`","ref":"RDF.NS.OWL.html#differentFrom/1"},{"type":"function","title":"RDF.NS.OWL.differentFrom/2","doc":"`RDF.Description` builder for `differentFrom/0`","ref":"RDF.NS.OWL.html#differentFrom/2"},{"type":"function","title":"RDF.NS.OWL.disjointUnionOf/0","doc":"","ref":"RDF.NS.OWL.html#disjointUnionOf/0"},{"type":"function","title":"RDF.NS.OWL.disjointUnionOf/1","doc":"`RDF.Description` property accessor for `disjointUnionOf/0`","ref":"RDF.NS.OWL.html#disjointUnionOf/1"},{"type":"function","title":"RDF.NS.OWL.disjointUnionOf/2","doc":"`RDF.Description` builder for `disjointUnionOf/0`","ref":"RDF.NS.OWL.html#disjointUnionOf/2"},{"type":"function","title":"RDF.NS.OWL.disjointWith/0","doc":"","ref":"RDF.NS.OWL.html#disjointWith/0"},{"type":"function","title":"RDF.NS.OWL.disjointWith/1","doc":"`RDF.Description` property accessor for `disjointWith/0`","ref":"RDF.NS.OWL.html#disjointWith/1"},{"type":"function","title":"RDF.NS.OWL.disjointWith/2","doc":"`RDF.Description` builder for `disjointWith/0`","ref":"RDF.NS.OWL.html#disjointWith/2"},{"type":"function","title":"RDF.NS.OWL.distinctMembers/0","doc":"","ref":"RDF.NS.OWL.html#distinctMembers/0"},{"type":"function","title":"RDF.NS.OWL.distinctMembers/1","doc":"`RDF.Description` property accessor for `distinctMembers/0`","ref":"RDF.NS.OWL.html#distinctMembers/1"},{"type":"function","title":"RDF.NS.OWL.distinctMembers/2","doc":"`RDF.Description` builder for `distinctMembers/0`","ref":"RDF.NS.OWL.html#distinctMembers/2"},{"type":"function","title":"RDF.NS.OWL.equivalentClass/0","doc":"","ref":"RDF.NS.OWL.html#equivalentClass/0"},{"type":"function","title":"RDF.NS.OWL.equivalentClass/1","doc":"`RDF.Description` property accessor for `equivalentClass/0`","ref":"RDF.NS.OWL.html#equivalentClass/1"},{"type":"function","title":"RDF.NS.OWL.equivalentClass/2","doc":"`RDF.Description` builder for `equivalentClass/0`","ref":"RDF.NS.OWL.html#equivalentClass/2"},{"type":"function","title":"RDF.NS.OWL.equivalentProperty/0","doc":"","ref":"RDF.NS.OWL.html#equivalentProperty/0"},{"type":"function","title":"RDF.NS.OWL.equivalentProperty/1","doc":"`RDF.Description` property accessor for `equivalentProperty/0`","ref":"RDF.NS.OWL.html#equivalentProperty/1"},{"type":"function","title":"RDF.NS.OWL.equivalentProperty/2","doc":"`RDF.Description` builder for `equivalentProperty/0`","ref":"RDF.NS.OWL.html#equivalentProperty/2"},{"type":"function","title":"RDF.NS.OWL.hasKey/0","doc":"","ref":"RDF.NS.OWL.html#hasKey/0"},{"type":"function","title":"RDF.NS.OWL.hasKey/1","doc":"`RDF.Description` property accessor for `hasKey/0`","ref":"RDF.NS.OWL.html#hasKey/1"},{"type":"function","title":"RDF.NS.OWL.hasKey/2","doc":"`RDF.Description` builder for `hasKey/0`","ref":"RDF.NS.OWL.html#hasKey/2"},{"type":"function","title":"RDF.NS.OWL.hasSelf/0","doc":"","ref":"RDF.NS.OWL.html#hasSelf/0"},{"type":"function","title":"RDF.NS.OWL.hasSelf/1","doc":"`RDF.Description` property accessor for `hasSelf/0`","ref":"RDF.NS.OWL.html#hasSelf/1"},{"type":"function","title":"RDF.NS.OWL.hasSelf/2","doc":"`RDF.Description` builder for `hasSelf/0`","ref":"RDF.NS.OWL.html#hasSelf/2"},{"type":"function","title":"RDF.NS.OWL.hasValue/0","doc":"","ref":"RDF.NS.OWL.html#hasValue/0"},{"type":"function","title":"RDF.NS.OWL.hasValue/1","doc":"`RDF.Description` property accessor for `hasValue/0`","ref":"RDF.NS.OWL.html#hasValue/1"},{"type":"function","title":"RDF.NS.OWL.hasValue/2","doc":"`RDF.Description` builder for `hasValue/0`","ref":"RDF.NS.OWL.html#hasValue/2"},{"type":"function","title":"RDF.NS.OWL.imports/0","doc":"","ref":"RDF.NS.OWL.html#imports/0"},{"type":"function","title":"RDF.NS.OWL.imports/1","doc":"`RDF.Description` property accessor for `imports/0`","ref":"RDF.NS.OWL.html#imports/1"},{"type":"function","title":"RDF.NS.OWL.imports/2","doc":"`RDF.Description` builder for `imports/0`","ref":"RDF.NS.OWL.html#imports/2"},{"type":"function","title":"RDF.NS.OWL.incompatibleWith/0","doc":"","ref":"RDF.NS.OWL.html#incompatibleWith/0"},{"type":"function","title":"RDF.NS.OWL.incompatibleWith/1","doc":"`RDF.Description` property accessor for `incompatibleWith/0`","ref":"RDF.NS.OWL.html#incompatibleWith/1"},{"type":"function","title":"RDF.NS.OWL.incompatibleWith/2","doc":"`RDF.Description` builder for `incompatibleWith/0`","ref":"RDF.NS.OWL.html#incompatibleWith/2"},{"type":"function","title":"RDF.NS.OWL.intersectionOf/0","doc":"","ref":"RDF.NS.OWL.html#intersectionOf/0"},{"type":"function","title":"RDF.NS.OWL.intersectionOf/1","doc":"`RDF.Description` property accessor for `intersectionOf/0`","ref":"RDF.NS.OWL.html#intersectionOf/1"},{"type":"function","title":"RDF.NS.OWL.intersectionOf/2","doc":"`RDF.Description` builder for `intersectionOf/0`","ref":"RDF.NS.OWL.html#intersectionOf/2"},{"type":"function","title":"RDF.NS.OWL.inverseOf/0","doc":"","ref":"RDF.NS.OWL.html#inverseOf/0"},{"type":"function","title":"RDF.NS.OWL.inverseOf/1","doc":"`RDF.Description` property accessor for `inverseOf/0`","ref":"RDF.NS.OWL.html#inverseOf/1"},{"type":"function","title":"RDF.NS.OWL.inverseOf/2","doc":"`RDF.Description` builder for `inverseOf/0`","ref":"RDF.NS.OWL.html#inverseOf/2"},{"type":"function","title":"RDF.NS.OWL.maxCardinality/0","doc":"","ref":"RDF.NS.OWL.html#maxCardinality/0"},{"type":"function","title":"RDF.NS.OWL.maxCardinality/1","doc":"`RDF.Description` property accessor for `maxCardinality/0`","ref":"RDF.NS.OWL.html#maxCardinality/1"},{"type":"function","title":"RDF.NS.OWL.maxCardinality/2","doc":"`RDF.Description` builder for `maxCardinality/0`","ref":"RDF.NS.OWL.html#maxCardinality/2"},{"type":"function","title":"RDF.NS.OWL.maxQualifiedCardinality/0","doc":"","ref":"RDF.NS.OWL.html#maxQualifiedCardinality/0"},{"type":"function","title":"RDF.NS.OWL.maxQualifiedCardinality/1","doc":"`RDF.Description` property accessor for `maxQualifiedCardinality/0`","ref":"RDF.NS.OWL.html#maxQualifiedCardinality/1"},{"type":"function","title":"RDF.NS.OWL.maxQualifiedCardinality/2","doc":"`RDF.Description` builder for `maxQualifiedCardinality/0`","ref":"RDF.NS.OWL.html#maxQualifiedCardinality/2"},{"type":"function","title":"RDF.NS.OWL.members/0","doc":"","ref":"RDF.NS.OWL.html#members/0"},{"type":"function","title":"RDF.NS.OWL.members/1","doc":"`RDF.Description` property accessor for `members/0`","ref":"RDF.NS.OWL.html#members/1"},{"type":"function","title":"RDF.NS.OWL.members/2","doc":"`RDF.Description` builder for `members/0`","ref":"RDF.NS.OWL.html#members/2"},{"type":"function","title":"RDF.NS.OWL.minCardinality/0","doc":"","ref":"RDF.NS.OWL.html#minCardinality/0"},{"type":"function","title":"RDF.NS.OWL.minCardinality/1","doc":"`RDF.Description` property accessor for `minCardinality/0`","ref":"RDF.NS.OWL.html#minCardinality/1"},{"type":"function","title":"RDF.NS.OWL.minCardinality/2","doc":"`RDF.Description` builder for `minCardinality/0`","ref":"RDF.NS.OWL.html#minCardinality/2"},{"type":"function","title":"RDF.NS.OWL.minQualifiedCardinality/0","doc":"","ref":"RDF.NS.OWL.html#minQualifiedCardinality/0"},{"type":"function","title":"RDF.NS.OWL.minQualifiedCardinality/1","doc":"`RDF.Description` property accessor for `minQualifiedCardinality/0`","ref":"RDF.NS.OWL.html#minQualifiedCardinality/1"},{"type":"function","title":"RDF.NS.OWL.minQualifiedCardinality/2","doc":"`RDF.Description` builder for `minQualifiedCardinality/0`","ref":"RDF.NS.OWL.html#minQualifiedCardinality/2"},{"type":"function","title":"RDF.NS.OWL.onClass/0","doc":"","ref":"RDF.NS.OWL.html#onClass/0"},{"type":"function","title":"RDF.NS.OWL.onClass/1","doc":"`RDF.Description` property accessor for `onClass/0`","ref":"RDF.NS.OWL.html#onClass/1"},{"type":"function","title":"RDF.NS.OWL.onClass/2","doc":"`RDF.Description` builder for `onClass/0`","ref":"RDF.NS.OWL.html#onClass/2"},{"type":"function","title":"RDF.NS.OWL.onDataRange/0","doc":"","ref":"RDF.NS.OWL.html#onDataRange/0"},{"type":"function","title":"RDF.NS.OWL.onDataRange/1","doc":"`RDF.Description` property accessor for `onDataRange/0`","ref":"RDF.NS.OWL.html#onDataRange/1"},{"type":"function","title":"RDF.NS.OWL.onDataRange/2","doc":"`RDF.Description` builder for `onDataRange/0`","ref":"RDF.NS.OWL.html#onDataRange/2"},{"type":"function","title":"RDF.NS.OWL.onDatatype/0","doc":"","ref":"RDF.NS.OWL.html#onDatatype/0"},{"type":"function","title":"RDF.NS.OWL.onDatatype/1","doc":"`RDF.Description` property accessor for `onDatatype/0`","ref":"RDF.NS.OWL.html#onDatatype/1"},{"type":"function","title":"RDF.NS.OWL.onDatatype/2","doc":"`RDF.Description` builder for `onDatatype/0`","ref":"RDF.NS.OWL.html#onDatatype/2"},{"type":"function","title":"RDF.NS.OWL.oneOf/0","doc":"","ref":"RDF.NS.OWL.html#oneOf/0"},{"type":"function","title":"RDF.NS.OWL.oneOf/1","doc":"`RDF.Description` property accessor for `oneOf/0`","ref":"RDF.NS.OWL.html#oneOf/1"},{"type":"function","title":"RDF.NS.OWL.oneOf/2","doc":"`RDF.Description` builder for `oneOf/0`","ref":"RDF.NS.OWL.html#oneOf/2"},{"type":"function","title":"RDF.NS.OWL.onProperties/0","doc":"","ref":"RDF.NS.OWL.html#onProperties/0"},{"type":"function","title":"RDF.NS.OWL.onProperties/1","doc":"`RDF.Description` property accessor for `onProperties/0`","ref":"RDF.NS.OWL.html#onProperties/1"},{"type":"function","title":"RDF.NS.OWL.onProperties/2","doc":"`RDF.Description` builder for `onProperties/0`","ref":"RDF.NS.OWL.html#onProperties/2"},{"type":"function","title":"RDF.NS.OWL.onProperty/0","doc":"","ref":"RDF.NS.OWL.html#onProperty/0"},{"type":"function","title":"RDF.NS.OWL.onProperty/1","doc":"`RDF.Description` property accessor for `onProperty/0`","ref":"RDF.NS.OWL.html#onProperty/1"},{"type":"function","title":"RDF.NS.OWL.onProperty/2","doc":"`RDF.Description` builder for `onProperty/0`","ref":"RDF.NS.OWL.html#onProperty/2"},{"type":"function","title":"RDF.NS.OWL.priorVersion/0","doc":"","ref":"RDF.NS.OWL.html#priorVersion/0"},{"type":"function","title":"RDF.NS.OWL.priorVersion/1","doc":"`RDF.Description` property accessor for `priorVersion/0`","ref":"RDF.NS.OWL.html#priorVersion/1"},{"type":"function","title":"RDF.NS.OWL.priorVersion/2","doc":"`RDF.Description` builder for `priorVersion/0`","ref":"RDF.NS.OWL.html#priorVersion/2"},{"type":"function","title":"RDF.NS.OWL.propertyChainAxiom/0","doc":"","ref":"RDF.NS.OWL.html#propertyChainAxiom/0"},{"type":"function","title":"RDF.NS.OWL.propertyChainAxiom/1","doc":"`RDF.Description` property accessor for `propertyChainAxiom/0`","ref":"RDF.NS.OWL.html#propertyChainAxiom/1"},{"type":"function","title":"RDF.NS.OWL.propertyChainAxiom/2","doc":"`RDF.Description` builder for `propertyChainAxiom/0`","ref":"RDF.NS.OWL.html#propertyChainAxiom/2"},{"type":"function","title":"RDF.NS.OWL.propertyDisjointWith/0","doc":"","ref":"RDF.NS.OWL.html#propertyDisjointWith/0"},{"type":"function","title":"RDF.NS.OWL.propertyDisjointWith/1","doc":"`RDF.Description` property accessor for `propertyDisjointWith/0`","ref":"RDF.NS.OWL.html#propertyDisjointWith/1"},{"type":"function","title":"RDF.NS.OWL.propertyDisjointWith/2","doc":"`RDF.Description` builder for `propertyDisjointWith/0`","ref":"RDF.NS.OWL.html#propertyDisjointWith/2"},{"type":"function","title":"RDF.NS.OWL.qualifiedCardinality/0","doc":"","ref":"RDF.NS.OWL.html#qualifiedCardinality/0"},{"type":"function","title":"RDF.NS.OWL.qualifiedCardinality/1","doc":"`RDF.Description` property accessor for `qualifiedCardinality/0`","ref":"RDF.NS.OWL.html#qualifiedCardinality/1"},{"type":"function","title":"RDF.NS.OWL.qualifiedCardinality/2","doc":"`RDF.Description` builder for `qualifiedCardinality/0`","ref":"RDF.NS.OWL.html#qualifiedCardinality/2"},{"type":"function","title":"RDF.NS.OWL.sameAs/0","doc":"","ref":"RDF.NS.OWL.html#sameAs/0"},{"type":"function","title":"RDF.NS.OWL.sameAs/1","doc":"`RDF.Description` property accessor for `sameAs/0`","ref":"RDF.NS.OWL.html#sameAs/1"},{"type":"function","title":"RDF.NS.OWL.sameAs/2","doc":"`RDF.Description` builder for `sameAs/0`","ref":"RDF.NS.OWL.html#sameAs/2"},{"type":"function","title":"RDF.NS.OWL.someValuesFrom/0","doc":"","ref":"RDF.NS.OWL.html#someValuesFrom/0"},{"type":"function","title":"RDF.NS.OWL.someValuesFrom/1","doc":"`RDF.Description` property accessor for `someValuesFrom/0`","ref":"RDF.NS.OWL.html#someValuesFrom/1"},{"type":"function","title":"RDF.NS.OWL.someValuesFrom/2","doc":"`RDF.Description` builder for `someValuesFrom/0`","ref":"RDF.NS.OWL.html#someValuesFrom/2"},{"type":"function","title":"RDF.NS.OWL.sourceIndividual/0","doc":"","ref":"RDF.NS.OWL.html#sourceIndividual/0"},{"type":"function","title":"RDF.NS.OWL.sourceIndividual/1","doc":"`RDF.Description` property accessor for `sourceIndividual/0`","ref":"RDF.NS.OWL.html#sourceIndividual/1"},{"type":"function","title":"RDF.NS.OWL.sourceIndividual/2","doc":"`RDF.Description` builder for `sourceIndividual/0`","ref":"RDF.NS.OWL.html#sourceIndividual/2"},{"type":"function","title":"RDF.NS.OWL.targetIndividual/0","doc":"","ref":"RDF.NS.OWL.html#targetIndividual/0"},{"type":"function","title":"RDF.NS.OWL.targetIndividual/1","doc":"`RDF.Description` property accessor for `targetIndividual/0`","ref":"RDF.NS.OWL.html#targetIndividual/1"},{"type":"function","title":"RDF.NS.OWL.targetIndividual/2","doc":"`RDF.Description` builder for `targetIndividual/0`","ref":"RDF.NS.OWL.html#targetIndividual/2"},{"type":"function","title":"RDF.NS.OWL.targetValue/0","doc":"","ref":"RDF.NS.OWL.html#targetValue/0"},{"type":"function","title":"RDF.NS.OWL.targetValue/1","doc":"`RDF.Description` property accessor for `targetValue/0`","ref":"RDF.NS.OWL.html#targetValue/1"},{"type":"function","title":"RDF.NS.OWL.targetValue/2","doc":"`RDF.Description` builder for `targetValue/0`","ref":"RDF.NS.OWL.html#targetValue/2"},{"type":"function","title":"RDF.NS.OWL.topDataProperty/0","doc":"","ref":"RDF.NS.OWL.html#topDataProperty/0"},{"type":"function","title":"RDF.NS.OWL.topDataProperty/1","doc":"`RDF.Description` property accessor for `topDataProperty/0`","ref":"RDF.NS.OWL.html#topDataProperty/1"},{"type":"function","title":"RDF.NS.OWL.topDataProperty/2","doc":"`RDF.Description` builder for `topDataProperty/0`","ref":"RDF.NS.OWL.html#topDataProperty/2"},{"type":"function","title":"RDF.NS.OWL.topObjectProperty/0","doc":"","ref":"RDF.NS.OWL.html#topObjectProperty/0"},{"type":"function","title":"RDF.NS.OWL.topObjectProperty/1","doc":"`RDF.Description` property accessor for `topObjectProperty/0`","ref":"RDF.NS.OWL.html#topObjectProperty/1"},{"type":"function","title":"RDF.NS.OWL.topObjectProperty/2","doc":"`RDF.Description` builder for `topObjectProperty/0`","ref":"RDF.NS.OWL.html#topObjectProperty/2"},{"type":"function","title":"RDF.NS.OWL.unionOf/0","doc":"","ref":"RDF.NS.OWL.html#unionOf/0"},{"type":"function","title":"RDF.NS.OWL.unionOf/1","doc":"`RDF.Description` property accessor for `unionOf/0`","ref":"RDF.NS.OWL.html#unionOf/1"},{"type":"function","title":"RDF.NS.OWL.unionOf/2","doc":"`RDF.Description` builder for `unionOf/0`","ref":"RDF.NS.OWL.html#unionOf/2"},{"type":"function","title":"RDF.NS.OWL.versionInfo/0","doc":"","ref":"RDF.NS.OWL.html#versionInfo/0"},{"type":"function","title":"RDF.NS.OWL.versionInfo/1","doc":"`RDF.Description` property accessor for `versionInfo/0`","ref":"RDF.NS.OWL.html#versionInfo/1"},{"type":"function","title":"RDF.NS.OWL.versionInfo/2","doc":"`RDF.Description` builder for `versionInfo/0`","ref":"RDF.NS.OWL.html#versionInfo/2"},{"type":"function","title":"RDF.NS.OWL.versionIRI/0","doc":"","ref":"RDF.NS.OWL.html#versionIRI/0"},{"type":"function","title":"RDF.NS.OWL.versionIRI/1","doc":"`RDF.Description` property accessor for `versionIRI/0`","ref":"RDF.NS.OWL.html#versionIRI/1"},{"type":"function","title":"RDF.NS.OWL.versionIRI/2","doc":"`RDF.Description` builder for `versionIRI/0`","ref":"RDF.NS.OWL.html#versionIRI/2"},{"type":"function","title":"RDF.NS.OWL.withRestrictions/0","doc":"","ref":"RDF.NS.OWL.html#withRestrictions/0"},{"type":"function","title":"RDF.NS.OWL.withRestrictions/1","doc":"`RDF.Description` property accessor for `withRestrictions/0`","ref":"RDF.NS.OWL.html#withRestrictions/1"},{"type":"function","title":"RDF.NS.OWL.withRestrictions/2","doc":"`RDF.Description` builder for `withRestrictions/0`","ref":"RDF.NS.OWL.html#withRestrictions/2"},{"type":"module","title":"RDF.NS.RDF","doc":"The RDF vocabulary.\n\nSince this module has the same basename as the top-level module, you can't\nalias it. Therefore, the top-level `RDF` module has delegators for all of the\nproperty functions in this module, so you can use them directly on the\ntop-level module without an alias.\n\nSee","ref":"RDF.NS.RDF.html"},{"type":"function","title":"RDF.NS.RDF./0","doc":"","ref":"RDF.NS.RDF.html#nil/0"},{"type":"function","title":"RDF.NS.RDF./1","doc":"`RDF.Description` property accessor for `/0`","ref":"RDF.NS.RDF.html#nil/1"},{"type":"function","title":"RDF.NS.RDF./2","doc":"`RDF.Description` builder for `/0`","ref":"RDF.NS.RDF.html#nil/2"},{"type":"function","title":"RDF.NS.RDF.__iris__/0","doc":"Returns all known IRIs of the vocabulary.","ref":"RDF.NS.RDF.html#__iris__/0"},{"type":"function","title":"RDF.NS.RDF.first/0","doc":"","ref":"RDF.NS.RDF.html#first/0"},{"type":"function","title":"RDF.NS.RDF.first/1","doc":"`RDF.Description` property accessor for `first/0`","ref":"RDF.NS.RDF.html#first/1"},{"type":"function","title":"RDF.NS.RDF.first/2","doc":"`RDF.Description` builder for `first/0`","ref":"RDF.NS.RDF.html#first/2"},{"type":"function","title":"RDF.NS.RDF.langString/0","doc":"","ref":"RDF.NS.RDF.html#langString/0"},{"type":"function","title":"RDF.NS.RDF.langString/1","doc":"`RDF.Description` property accessor for `langString/0`","ref":"RDF.NS.RDF.html#langString/1"},{"type":"function","title":"RDF.NS.RDF.langString/2","doc":"`RDF.Description` builder for `langString/0`","ref":"RDF.NS.RDF.html#langString/2"},{"type":"function","title":"RDF.NS.RDF.object/0","doc":"","ref":"RDF.NS.RDF.html#object/0"},{"type":"function","title":"RDF.NS.RDF.object/1","doc":"`RDF.Description` property accessor for `object/0`","ref":"RDF.NS.RDF.html#object/1"},{"type":"function","title":"RDF.NS.RDF.object/2","doc":"`RDF.Description` builder for `object/0`","ref":"RDF.NS.RDF.html#object/2"},{"type":"function","title":"RDF.NS.RDF.predicate/0","doc":"","ref":"RDF.NS.RDF.html#predicate/0"},{"type":"function","title":"RDF.NS.RDF.predicate/1","doc":"`RDF.Description` property accessor for `predicate/0`","ref":"RDF.NS.RDF.html#predicate/1"},{"type":"function","title":"RDF.NS.RDF.predicate/2","doc":"`RDF.Description` builder for `predicate/0`","ref":"RDF.NS.RDF.html#predicate/2"},{"type":"function","title":"RDF.NS.RDF.rest/0","doc":"","ref":"RDF.NS.RDF.html#rest/0"},{"type":"function","title":"RDF.NS.RDF.rest/1","doc":"`RDF.Description` property accessor for `rest/0`","ref":"RDF.NS.RDF.html#rest/1"},{"type":"function","title":"RDF.NS.RDF.rest/2","doc":"`RDF.Description` builder for `rest/0`","ref":"RDF.NS.RDF.html#rest/2"},{"type":"function","title":"RDF.NS.RDF.subject/0","doc":"","ref":"RDF.NS.RDF.html#subject/0"},{"type":"function","title":"RDF.NS.RDF.subject/1","doc":"`RDF.Description` property accessor for `subject/0`","ref":"RDF.NS.RDF.html#subject/1"},{"type":"function","title":"RDF.NS.RDF.subject/2","doc":"`RDF.Description` builder for `subject/0`","ref":"RDF.NS.RDF.html#subject/2"},{"type":"function","title":"RDF.NS.RDF.type/0","doc":"","ref":"RDF.NS.RDF.html#type/0"},{"type":"function","title":"RDF.NS.RDF.type/1","doc":"`RDF.Description` property accessor for `type/0`","ref":"RDF.NS.RDF.html#type/1"},{"type":"function","title":"RDF.NS.RDF.type/2","doc":"`RDF.Description` builder for `type/0`","ref":"RDF.NS.RDF.html#type/2"},{"type":"function","title":"RDF.NS.RDF.value/0","doc":"","ref":"RDF.NS.RDF.html#value/0"},{"type":"function","title":"RDF.NS.RDF.value/1","doc":"`RDF.Description` property accessor for `value/0`","ref":"RDF.NS.RDF.html#value/1"},{"type":"function","title":"RDF.NS.RDF.value/2","doc":"`RDF.Description` builder for `value/0`","ref":"RDF.NS.RDF.html#value/2"},{"type":"module","title":"RDF.NS.RDFS","doc":"The RDFS vocabulary.\n\nSee","ref":"RDF.NS.RDFS.html"},{"type":"function","title":"RDF.NS.RDFS.__iris__/0","doc":"Returns all known IRIs of the vocabulary.","ref":"RDF.NS.RDFS.html#__iris__/0"},{"type":"function","title":"RDF.NS.RDFS.comment/0","doc":"","ref":"RDF.NS.RDFS.html#comment/0"},{"type":"function","title":"RDF.NS.RDFS.comment/1","doc":"`RDF.Description` property accessor for `comment/0`","ref":"RDF.NS.RDFS.html#comment/1"},{"type":"function","title":"RDF.NS.RDFS.comment/2","doc":"`RDF.Description` builder for `comment/0`","ref":"RDF.NS.RDFS.html#comment/2"},{"type":"function","title":"RDF.NS.RDFS.domain/0","doc":"","ref":"RDF.NS.RDFS.html#domain/0"},{"type":"function","title":"RDF.NS.RDFS.domain/1","doc":"`RDF.Description` property accessor for `domain/0`","ref":"RDF.NS.RDFS.html#domain/1"},{"type":"function","title":"RDF.NS.RDFS.domain/2","doc":"`RDF.Description` builder for `domain/0`","ref":"RDF.NS.RDFS.html#domain/2"},{"type":"function","title":"RDF.NS.RDFS.isDefinedBy/0","doc":"","ref":"RDF.NS.RDFS.html#isDefinedBy/0"},{"type":"function","title":"RDF.NS.RDFS.isDefinedBy/1","doc":"`RDF.Description` property accessor for `isDefinedBy/0`","ref":"RDF.NS.RDFS.html#isDefinedBy/1"},{"type":"function","title":"RDF.NS.RDFS.isDefinedBy/2","doc":"`RDF.Description` builder for `isDefinedBy/0`","ref":"RDF.NS.RDFS.html#isDefinedBy/2"},{"type":"function","title":"RDF.NS.RDFS.label/0","doc":"","ref":"RDF.NS.RDFS.html#label/0"},{"type":"function","title":"RDF.NS.RDFS.label/1","doc":"`RDF.Description` property accessor for `label/0`","ref":"RDF.NS.RDFS.html#label/1"},{"type":"function","title":"RDF.NS.RDFS.label/2","doc":"`RDF.Description` builder for `label/0`","ref":"RDF.NS.RDFS.html#label/2"},{"type":"function","title":"RDF.NS.RDFS.member/0","doc":"","ref":"RDF.NS.RDFS.html#member/0"},{"type":"function","title":"RDF.NS.RDFS.member/1","doc":"`RDF.Description` property accessor for `member/0`","ref":"RDF.NS.RDFS.html#member/1"},{"type":"function","title":"RDF.NS.RDFS.member/2","doc":"`RDF.Description` builder for `member/0`","ref":"RDF.NS.RDFS.html#member/2"},{"type":"function","title":"RDF.NS.RDFS.range/0","doc":"","ref":"RDF.NS.RDFS.html#range/0"},{"type":"function","title":"RDF.NS.RDFS.range/1","doc":"`RDF.Description` property accessor for `range/0`","ref":"RDF.NS.RDFS.html#range/1"},{"type":"function","title":"RDF.NS.RDFS.range/2","doc":"`RDF.Description` builder for `range/0`","ref":"RDF.NS.RDFS.html#range/2"},{"type":"function","title":"RDF.NS.RDFS.seeAlso/0","doc":"","ref":"RDF.NS.RDFS.html#seeAlso/0"},{"type":"function","title":"RDF.NS.RDFS.seeAlso/1","doc":"`RDF.Description` property accessor for `seeAlso/0`","ref":"RDF.NS.RDFS.html#seeAlso/1"},{"type":"function","title":"RDF.NS.RDFS.seeAlso/2","doc":"`RDF.Description` builder for `seeAlso/0`","ref":"RDF.NS.RDFS.html#seeAlso/2"},{"type":"function","title":"RDF.NS.RDFS.subClassOf/0","doc":"","ref":"RDF.NS.RDFS.html#subClassOf/0"},{"type":"function","title":"RDF.NS.RDFS.subClassOf/1","doc":"`RDF.Description` property accessor for `subClassOf/0`","ref":"RDF.NS.RDFS.html#subClassOf/1"},{"type":"function","title":"RDF.NS.RDFS.subClassOf/2","doc":"`RDF.Description` builder for `subClassOf/0`","ref":"RDF.NS.RDFS.html#subClassOf/2"},{"type":"function","title":"RDF.NS.RDFS.subPropertyOf/0","doc":"","ref":"RDF.NS.RDFS.html#subPropertyOf/0"},{"type":"function","title":"RDF.NS.RDFS.subPropertyOf/1","doc":"`RDF.Description` property accessor for `subPropertyOf/0`","ref":"RDF.NS.RDFS.html#subPropertyOf/1"},{"type":"function","title":"RDF.NS.RDFS.subPropertyOf/2","doc":"`RDF.Description` builder for `subPropertyOf/0`","ref":"RDF.NS.RDFS.html#subPropertyOf/2"},{"type":"module","title":"RDF.NS.SKOS","doc":"The SKOS vocabulary.\n\nSee","ref":"RDF.NS.SKOS.html"},{"type":"function","title":"RDF.NS.SKOS.__iris__/0","doc":"Returns all known IRIs of the vocabulary.","ref":"RDF.NS.SKOS.html#__iris__/0"},{"type":"function","title":"RDF.NS.SKOS.altLabel/0","doc":"","ref":"RDF.NS.SKOS.html#altLabel/0"},{"type":"function","title":"RDF.NS.SKOS.altLabel/1","doc":"`RDF.Description` property accessor for `altLabel/0`","ref":"RDF.NS.SKOS.html#altLabel/1"},{"type":"function","title":"RDF.NS.SKOS.altLabel/2","doc":"`RDF.Description` builder for `altLabel/0`","ref":"RDF.NS.SKOS.html#altLabel/2"},{"type":"function","title":"RDF.NS.SKOS.broader/0","doc":"","ref":"RDF.NS.SKOS.html#broader/0"},{"type":"function","title":"RDF.NS.SKOS.broader/1","doc":"`RDF.Description` property accessor for `broader/0`","ref":"RDF.NS.SKOS.html#broader/1"},{"type":"function","title":"RDF.NS.SKOS.broader/2","doc":"`RDF.Description` builder for `broader/0`","ref":"RDF.NS.SKOS.html#broader/2"},{"type":"function","title":"RDF.NS.SKOS.broaderTransitive/0","doc":"","ref":"RDF.NS.SKOS.html#broaderTransitive/0"},{"type":"function","title":"RDF.NS.SKOS.broaderTransitive/1","doc":"`RDF.Description` property accessor for `broaderTransitive/0`","ref":"RDF.NS.SKOS.html#broaderTransitive/1"},{"type":"function","title":"RDF.NS.SKOS.broaderTransitive/2","doc":"`RDF.Description` builder for `broaderTransitive/0`","ref":"RDF.NS.SKOS.html#broaderTransitive/2"},{"type":"function","title":"RDF.NS.SKOS.broadMatch/0","doc":"","ref":"RDF.NS.SKOS.html#broadMatch/0"},{"type":"function","title":"RDF.NS.SKOS.broadMatch/1","doc":"`RDF.Description` property accessor for `broadMatch/0`","ref":"RDF.NS.SKOS.html#broadMatch/1"},{"type":"function","title":"RDF.NS.SKOS.broadMatch/2","doc":"`RDF.Description` builder for `broadMatch/0`","ref":"RDF.NS.SKOS.html#broadMatch/2"},{"type":"function","title":"RDF.NS.SKOS.changeNote/0","doc":"","ref":"RDF.NS.SKOS.html#changeNote/0"},{"type":"function","title":"RDF.NS.SKOS.changeNote/1","doc":"`RDF.Description` property accessor for `changeNote/0`","ref":"RDF.NS.SKOS.html#changeNote/1"},{"type":"function","title":"RDF.NS.SKOS.changeNote/2","doc":"`RDF.Description` builder for `changeNote/0`","ref":"RDF.NS.SKOS.html#changeNote/2"},{"type":"function","title":"RDF.NS.SKOS.closeMatch/0","doc":"","ref":"RDF.NS.SKOS.html#closeMatch/0"},{"type":"function","title":"RDF.NS.SKOS.closeMatch/1","doc":"`RDF.Description` property accessor for `closeMatch/0`","ref":"RDF.NS.SKOS.html#closeMatch/1"},{"type":"function","title":"RDF.NS.SKOS.closeMatch/2","doc":"`RDF.Description` builder for `closeMatch/0`","ref":"RDF.NS.SKOS.html#closeMatch/2"},{"type":"function","title":"RDF.NS.SKOS.definition/0","doc":"","ref":"RDF.NS.SKOS.html#definition/0"},{"type":"function","title":"RDF.NS.SKOS.definition/1","doc":"`RDF.Description` property accessor for `definition/0`","ref":"RDF.NS.SKOS.html#definition/1"},{"type":"function","title":"RDF.NS.SKOS.definition/2","doc":"`RDF.Description` builder for `definition/0`","ref":"RDF.NS.SKOS.html#definition/2"},{"type":"function","title":"RDF.NS.SKOS.editorialNote/0","doc":"","ref":"RDF.NS.SKOS.html#editorialNote/0"},{"type":"function","title":"RDF.NS.SKOS.editorialNote/1","doc":"`RDF.Description` property accessor for `editorialNote/0`","ref":"RDF.NS.SKOS.html#editorialNote/1"},{"type":"function","title":"RDF.NS.SKOS.editorialNote/2","doc":"`RDF.Description` builder for `editorialNote/0`","ref":"RDF.NS.SKOS.html#editorialNote/2"},{"type":"function","title":"RDF.NS.SKOS.exactMatch/0","doc":"","ref":"RDF.NS.SKOS.html#exactMatch/0"},{"type":"function","title":"RDF.NS.SKOS.exactMatch/1","doc":"`RDF.Description` property accessor for `exactMatch/0`","ref":"RDF.NS.SKOS.html#exactMatch/1"},{"type":"function","title":"RDF.NS.SKOS.exactMatch/2","doc":"`RDF.Description` builder for `exactMatch/0`","ref":"RDF.NS.SKOS.html#exactMatch/2"},{"type":"function","title":"RDF.NS.SKOS.example/0","doc":"","ref":"RDF.NS.SKOS.html#example/0"},{"type":"function","title":"RDF.NS.SKOS.example/1","doc":"`RDF.Description` property accessor for `example/0`","ref":"RDF.NS.SKOS.html#example/1"},{"type":"function","title":"RDF.NS.SKOS.example/2","doc":"`RDF.Description` builder for `example/0`","ref":"RDF.NS.SKOS.html#example/2"},{"type":"function","title":"RDF.NS.SKOS.hasTopConcept/0","doc":"","ref":"RDF.NS.SKOS.html#hasTopConcept/0"},{"type":"function","title":"RDF.NS.SKOS.hasTopConcept/1","doc":"`RDF.Description` property accessor for `hasTopConcept/0`","ref":"RDF.NS.SKOS.html#hasTopConcept/1"},{"type":"function","title":"RDF.NS.SKOS.hasTopConcept/2","doc":"`RDF.Description` builder for `hasTopConcept/0`","ref":"RDF.NS.SKOS.html#hasTopConcept/2"},{"type":"function","title":"RDF.NS.SKOS.hiddenLabel/0","doc":"","ref":"RDF.NS.SKOS.html#hiddenLabel/0"},{"type":"function","title":"RDF.NS.SKOS.hiddenLabel/1","doc":"`RDF.Description` property accessor for `hiddenLabel/0`","ref":"RDF.NS.SKOS.html#hiddenLabel/1"},{"type":"function","title":"RDF.NS.SKOS.hiddenLabel/2","doc":"`RDF.Description` builder for `hiddenLabel/0`","ref":"RDF.NS.SKOS.html#hiddenLabel/2"},{"type":"function","title":"RDF.NS.SKOS.historyNote/0","doc":"","ref":"RDF.NS.SKOS.html#historyNote/0"},{"type":"function","title":"RDF.NS.SKOS.historyNote/1","doc":"`RDF.Description` property accessor for `historyNote/0`","ref":"RDF.NS.SKOS.html#historyNote/1"},{"type":"function","title":"RDF.NS.SKOS.historyNote/2","doc":"`RDF.Description` builder for `historyNote/0`","ref":"RDF.NS.SKOS.html#historyNote/2"},{"type":"function","title":"RDF.NS.SKOS.inScheme/0","doc":"","ref":"RDF.NS.SKOS.html#inScheme/0"},{"type":"function","title":"RDF.NS.SKOS.inScheme/1","doc":"`RDF.Description` property accessor for `inScheme/0`","ref":"RDF.NS.SKOS.html#inScheme/1"},{"type":"function","title":"RDF.NS.SKOS.inScheme/2","doc":"`RDF.Description` builder for `inScheme/0`","ref":"RDF.NS.SKOS.html#inScheme/2"},{"type":"function","title":"RDF.NS.SKOS.mappingRelation/0","doc":"","ref":"RDF.NS.SKOS.html#mappingRelation/0"},{"type":"function","title":"RDF.NS.SKOS.mappingRelation/1","doc":"`RDF.Description` property accessor for `mappingRelation/0`","ref":"RDF.NS.SKOS.html#mappingRelation/1"},{"type":"function","title":"RDF.NS.SKOS.mappingRelation/2","doc":"`RDF.Description` builder for `mappingRelation/0`","ref":"RDF.NS.SKOS.html#mappingRelation/2"},{"type":"function","title":"RDF.NS.SKOS.member/0","doc":"","ref":"RDF.NS.SKOS.html#member/0"},{"type":"function","title":"RDF.NS.SKOS.member/1","doc":"`RDF.Description` property accessor for `member/0`","ref":"RDF.NS.SKOS.html#member/1"},{"type":"function","title":"RDF.NS.SKOS.member/2","doc":"`RDF.Description` builder for `member/0`","ref":"RDF.NS.SKOS.html#member/2"},{"type":"function","title":"RDF.NS.SKOS.memberList/0","doc":"","ref":"RDF.NS.SKOS.html#memberList/0"},{"type":"function","title":"RDF.NS.SKOS.memberList/1","doc":"`RDF.Description` property accessor for `memberList/0`","ref":"RDF.NS.SKOS.html#memberList/1"},{"type":"function","title":"RDF.NS.SKOS.memberList/2","doc":"`RDF.Description` builder for `memberList/0`","ref":"RDF.NS.SKOS.html#memberList/2"},{"type":"function","title":"RDF.NS.SKOS.narrower/0","doc":"","ref":"RDF.NS.SKOS.html#narrower/0"},{"type":"function","title":"RDF.NS.SKOS.narrower/1","doc":"`RDF.Description` property accessor for `narrower/0`","ref":"RDF.NS.SKOS.html#narrower/1"},{"type":"function","title":"RDF.NS.SKOS.narrower/2","doc":"`RDF.Description` builder for `narrower/0`","ref":"RDF.NS.SKOS.html#narrower/2"},{"type":"function","title":"RDF.NS.SKOS.narrowerTransitive/0","doc":"","ref":"RDF.NS.SKOS.html#narrowerTransitive/0"},{"type":"function","title":"RDF.NS.SKOS.narrowerTransitive/1","doc":"`RDF.Description` property accessor for `narrowerTransitive/0`","ref":"RDF.NS.SKOS.html#narrowerTransitive/1"},{"type":"function","title":"RDF.NS.SKOS.narrowerTransitive/2","doc":"`RDF.Description` builder for `narrowerTransitive/0`","ref":"RDF.NS.SKOS.html#narrowerTransitive/2"},{"type":"function","title":"RDF.NS.SKOS.narrowMatch/0","doc":"","ref":"RDF.NS.SKOS.html#narrowMatch/0"},{"type":"function","title":"RDF.NS.SKOS.narrowMatch/1","doc":"`RDF.Description` property accessor for `narrowMatch/0`","ref":"RDF.NS.SKOS.html#narrowMatch/1"},{"type":"function","title":"RDF.NS.SKOS.narrowMatch/2","doc":"`RDF.Description` builder for `narrowMatch/0`","ref":"RDF.NS.SKOS.html#narrowMatch/2"},{"type":"function","title":"RDF.NS.SKOS.notation/0","doc":"","ref":"RDF.NS.SKOS.html#notation/0"},{"type":"function","title":"RDF.NS.SKOS.notation/1","doc":"`RDF.Description` property accessor for `notation/0`","ref":"RDF.NS.SKOS.html#notation/1"},{"type":"function","title":"RDF.NS.SKOS.notation/2","doc":"`RDF.Description` builder for `notation/0`","ref":"RDF.NS.SKOS.html#notation/2"},{"type":"function","title":"RDF.NS.SKOS.note/0","doc":"","ref":"RDF.NS.SKOS.html#note/0"},{"type":"function","title":"RDF.NS.SKOS.note/1","doc":"`RDF.Description` property accessor for `note/0`","ref":"RDF.NS.SKOS.html#note/1"},{"type":"function","title":"RDF.NS.SKOS.note/2","doc":"`RDF.Description` builder for `note/0`","ref":"RDF.NS.SKOS.html#note/2"},{"type":"function","title":"RDF.NS.SKOS.prefLabel/0","doc":"","ref":"RDF.NS.SKOS.html#prefLabel/0"},{"type":"function","title":"RDF.NS.SKOS.prefLabel/1","doc":"`RDF.Description` property accessor for `prefLabel/0`","ref":"RDF.NS.SKOS.html#prefLabel/1"},{"type":"function","title":"RDF.NS.SKOS.prefLabel/2","doc":"`RDF.Description` builder for `prefLabel/0`","ref":"RDF.NS.SKOS.html#prefLabel/2"},{"type":"function","title":"RDF.NS.SKOS.related/0","doc":"","ref":"RDF.NS.SKOS.html#related/0"},{"type":"function","title":"RDF.NS.SKOS.related/1","doc":"`RDF.Description` property accessor for `related/0`","ref":"RDF.NS.SKOS.html#related/1"},{"type":"function","title":"RDF.NS.SKOS.related/2","doc":"`RDF.Description` builder for `related/0`","ref":"RDF.NS.SKOS.html#related/2"},{"type":"function","title":"RDF.NS.SKOS.relatedMatch/0","doc":"","ref":"RDF.NS.SKOS.html#relatedMatch/0"},{"type":"function","title":"RDF.NS.SKOS.relatedMatch/1","doc":"`RDF.Description` property accessor for `relatedMatch/0`","ref":"RDF.NS.SKOS.html#relatedMatch/1"},{"type":"function","title":"RDF.NS.SKOS.relatedMatch/2","doc":"`RDF.Description` builder for `relatedMatch/0`","ref":"RDF.NS.SKOS.html#relatedMatch/2"},{"type":"function","title":"RDF.NS.SKOS.scopeNote/0","doc":"","ref":"RDF.NS.SKOS.html#scopeNote/0"},{"type":"function","title":"RDF.NS.SKOS.scopeNote/1","doc":"`RDF.Description` property accessor for `scopeNote/0`","ref":"RDF.NS.SKOS.html#scopeNote/1"},{"type":"function","title":"RDF.NS.SKOS.scopeNote/2","doc":"`RDF.Description` builder for `scopeNote/0`","ref":"RDF.NS.SKOS.html#scopeNote/2"},{"type":"function","title":"RDF.NS.SKOS.semanticRelation/0","doc":"","ref":"RDF.NS.SKOS.html#semanticRelation/0"},{"type":"function","title":"RDF.NS.SKOS.semanticRelation/1","doc":"`RDF.Description` property accessor for `semanticRelation/0`","ref":"RDF.NS.SKOS.html#semanticRelation/1"},{"type":"function","title":"RDF.NS.SKOS.semanticRelation/2","doc":"`RDF.Description` builder for `semanticRelation/0`","ref":"RDF.NS.SKOS.html#semanticRelation/2"},{"type":"function","title":"RDF.NS.SKOS.topConceptOf/0","doc":"","ref":"RDF.NS.SKOS.html#topConceptOf/0"},{"type":"function","title":"RDF.NS.SKOS.topConceptOf/1","doc":"`RDF.Description` property accessor for `topConceptOf/0`","ref":"RDF.NS.SKOS.html#topConceptOf/1"},{"type":"function","title":"RDF.NS.SKOS.topConceptOf/2","doc":"`RDF.Description` builder for `topConceptOf/0`","ref":"RDF.NS.SKOS.html#topConceptOf/2"},{"type":"module","title":"RDF.NS.XSD","doc":"The XML Schema datatypes vocabulary.\n\nSee","ref":"RDF.NS.XSD.html"},{"type":"function","title":"RDF.NS.XSD.__iris__/0","doc":"Returns all known IRIs of the vocabulary.","ref":"RDF.NS.XSD.html#__iris__/0"},{"type":"function","title":"RDF.NS.XSD.anyURI/0","doc":"","ref":"RDF.NS.XSD.html#anyURI/0"},{"type":"function","title":"RDF.NS.XSD.anyURI/1","doc":"`RDF.Description` property accessor for `anyURI/0`","ref":"RDF.NS.XSD.html#anyURI/1"},{"type":"function","title":"RDF.NS.XSD.anyURI/2","doc":"`RDF.Description` builder for `anyURI/0`","ref":"RDF.NS.XSD.html#anyURI/2"},{"type":"function","title":"RDF.NS.XSD.base64Binary/0","doc":"","ref":"RDF.NS.XSD.html#base64Binary/0"},{"type":"function","title":"RDF.NS.XSD.base64Binary/1","doc":"`RDF.Description` property accessor for `base64Binary/0`","ref":"RDF.NS.XSD.html#base64Binary/1"},{"type":"function","title":"RDF.NS.XSD.base64Binary/2","doc":"`RDF.Description` builder for `base64Binary/0`","ref":"RDF.NS.XSD.html#base64Binary/2"},{"type":"function","title":"RDF.NS.XSD.boolean/0","doc":"","ref":"RDF.NS.XSD.html#boolean/0"},{"type":"function","title":"RDF.NS.XSD.boolean/1","doc":"`RDF.Description` property accessor for `boolean/0`","ref":"RDF.NS.XSD.html#boolean/1"},{"type":"function","title":"RDF.NS.XSD.boolean/2","doc":"`RDF.Description` builder for `boolean/0`","ref":"RDF.NS.XSD.html#boolean/2"},{"type":"function","title":"RDF.NS.XSD.byte/0","doc":"","ref":"RDF.NS.XSD.html#byte/0"},{"type":"function","title":"RDF.NS.XSD.byte/1","doc":"`RDF.Description` property accessor for `byte/0`","ref":"RDF.NS.XSD.html#byte/1"},{"type":"function","title":"RDF.NS.XSD.byte/2","doc":"`RDF.Description` builder for `byte/0`","ref":"RDF.NS.XSD.html#byte/2"},{"type":"function","title":"RDF.NS.XSD.date/0","doc":"","ref":"RDF.NS.XSD.html#date/0"},{"type":"function","title":"RDF.NS.XSD.date/1","doc":"`RDF.Description` property accessor for `date/0`","ref":"RDF.NS.XSD.html#date/1"},{"type":"function","title":"RDF.NS.XSD.date/2","doc":"`RDF.Description` builder for `date/0`","ref":"RDF.NS.XSD.html#date/2"},{"type":"function","title":"RDF.NS.XSD.dateTime/0","doc":"","ref":"RDF.NS.XSD.html#dateTime/0"},{"type":"function","title":"RDF.NS.XSD.dateTime/1","doc":"`RDF.Description` property accessor for `dateTime/0`","ref":"RDF.NS.XSD.html#dateTime/1"},{"type":"function","title":"RDF.NS.XSD.dateTime/2","doc":"`RDF.Description` builder for `dateTime/0`","ref":"RDF.NS.XSD.html#dateTime/2"},{"type":"function","title":"RDF.NS.XSD.dayTimeDuration/0","doc":"","ref":"RDF.NS.XSD.html#dayTimeDuration/0"},{"type":"function","title":"RDF.NS.XSD.dayTimeDuration/1","doc":"`RDF.Description` property accessor for `dayTimeDuration/0`","ref":"RDF.NS.XSD.html#dayTimeDuration/1"},{"type":"function","title":"RDF.NS.XSD.dayTimeDuration/2","doc":"`RDF.Description` builder for `dayTimeDuration/0`","ref":"RDF.NS.XSD.html#dayTimeDuration/2"},{"type":"function","title":"RDF.NS.XSD.decimal/0","doc":"","ref":"RDF.NS.XSD.html#decimal/0"},{"type":"function","title":"RDF.NS.XSD.decimal/1","doc":"`RDF.Description` property accessor for `decimal/0`","ref":"RDF.NS.XSD.html#decimal/1"},{"type":"function","title":"RDF.NS.XSD.decimal/2","doc":"`RDF.Description` builder for `decimal/0`","ref":"RDF.NS.XSD.html#decimal/2"},{"type":"function","title":"RDF.NS.XSD.double/0","doc":"","ref":"RDF.NS.XSD.html#double/0"},{"type":"function","title":"RDF.NS.XSD.double/1","doc":"`RDF.Description` property accessor for `double/0`","ref":"RDF.NS.XSD.html#double/1"},{"type":"function","title":"RDF.NS.XSD.double/2","doc":"`RDF.Description` builder for `double/0`","ref":"RDF.NS.XSD.html#double/2"},{"type":"function","title":"RDF.NS.XSD.duration/0","doc":"","ref":"RDF.NS.XSD.html#duration/0"},{"type":"function","title":"RDF.NS.XSD.duration/1","doc":"`RDF.Description` property accessor for `duration/0`","ref":"RDF.NS.XSD.html#duration/1"},{"type":"function","title":"RDF.NS.XSD.duration/2","doc":"`RDF.Description` builder for `duration/0`","ref":"RDF.NS.XSD.html#duration/2"},{"type":"function","title":"RDF.NS.XSD.float/0","doc":"","ref":"RDF.NS.XSD.html#float/0"},{"type":"function","title":"RDF.NS.XSD.float/1","doc":"`RDF.Description` property accessor for `float/0`","ref":"RDF.NS.XSD.html#float/1"},{"type":"function","title":"RDF.NS.XSD.float/2","doc":"`RDF.Description` builder for `float/0`","ref":"RDF.NS.XSD.html#float/2"},{"type":"function","title":"RDF.NS.XSD.gDay/0","doc":"","ref":"RDF.NS.XSD.html#gDay/0"},{"type":"function","title":"RDF.NS.XSD.gDay/1","doc":"`RDF.Description` property accessor for `gDay/0`","ref":"RDF.NS.XSD.html#gDay/1"},{"type":"function","title":"RDF.NS.XSD.gDay/2","doc":"`RDF.Description` builder for `gDay/0`","ref":"RDF.NS.XSD.html#gDay/2"},{"type":"function","title":"RDF.NS.XSD.gMonth/0","doc":"","ref":"RDF.NS.XSD.html#gMonth/0"},{"type":"function","title":"RDF.NS.XSD.gMonth/1","doc":"`RDF.Description` property accessor for `gMonth/0`","ref":"RDF.NS.XSD.html#gMonth/1"},{"type":"function","title":"RDF.NS.XSD.gMonth/2","doc":"`RDF.Description` builder for `gMonth/0`","ref":"RDF.NS.XSD.html#gMonth/2"},{"type":"function","title":"RDF.NS.XSD.gMonthDay/0","doc":"","ref":"RDF.NS.XSD.html#gMonthDay/0"},{"type":"function","title":"RDF.NS.XSD.gMonthDay/1","doc":"`RDF.Description` property accessor for `gMonthDay/0`","ref":"RDF.NS.XSD.html#gMonthDay/1"},{"type":"function","title":"RDF.NS.XSD.gMonthDay/2","doc":"`RDF.Description` builder for `gMonthDay/0`","ref":"RDF.NS.XSD.html#gMonthDay/2"},{"type":"function","title":"RDF.NS.XSD.gYear/0","doc":"","ref":"RDF.NS.XSD.html#gYear/0"},{"type":"function","title":"RDF.NS.XSD.gYear/1","doc":"`RDF.Description` property accessor for `gYear/0`","ref":"RDF.NS.XSD.html#gYear/1"},{"type":"function","title":"RDF.NS.XSD.gYear/2","doc":"`RDF.Description` builder for `gYear/0`","ref":"RDF.NS.XSD.html#gYear/2"},{"type":"function","title":"RDF.NS.XSD.gYearMonth/0","doc":"","ref":"RDF.NS.XSD.html#gYearMonth/0"},{"type":"function","title":"RDF.NS.XSD.gYearMonth/1","doc":"`RDF.Description` property accessor for `gYearMonth/0`","ref":"RDF.NS.XSD.html#gYearMonth/1"},{"type":"function","title":"RDF.NS.XSD.gYearMonth/2","doc":"`RDF.Description` builder for `gYearMonth/0`","ref":"RDF.NS.XSD.html#gYearMonth/2"},{"type":"function","title":"RDF.NS.XSD.hexBinary/0","doc":"","ref":"RDF.NS.XSD.html#hexBinary/0"},{"type":"function","title":"RDF.NS.XSD.hexBinary/1","doc":"`RDF.Description` property accessor for `hexBinary/0`","ref":"RDF.NS.XSD.html#hexBinary/1"},{"type":"function","title":"RDF.NS.XSD.hexBinary/2","doc":"`RDF.Description` builder for `hexBinary/0`","ref":"RDF.NS.XSD.html#hexBinary/2"},{"type":"function","title":"RDF.NS.XSD.int/0","doc":"","ref":"RDF.NS.XSD.html#int/0"},{"type":"function","title":"RDF.NS.XSD.int/1","doc":"`RDF.Description` property accessor for `int/0`","ref":"RDF.NS.XSD.html#int/1"},{"type":"function","title":"RDF.NS.XSD.int/2","doc":"`RDF.Description` builder for `int/0`","ref":"RDF.NS.XSD.html#int/2"},{"type":"function","title":"RDF.NS.XSD.integer/0","doc":"","ref":"RDF.NS.XSD.html#integer/0"},{"type":"function","title":"RDF.NS.XSD.integer/1","doc":"`RDF.Description` property accessor for `integer/0`","ref":"RDF.NS.XSD.html#integer/1"},{"type":"function","title":"RDF.NS.XSD.integer/2","doc":"`RDF.Description` builder for `integer/0`","ref":"RDF.NS.XSD.html#integer/2"},{"type":"function","title":"RDF.NS.XSD.language/0","doc":"","ref":"RDF.NS.XSD.html#language/0"},{"type":"function","title":"RDF.NS.XSD.language/1","doc":"`RDF.Description` property accessor for `language/0`","ref":"RDF.NS.XSD.html#language/1"},{"type":"function","title":"RDF.NS.XSD.language/2","doc":"`RDF.Description` builder for `language/0`","ref":"RDF.NS.XSD.html#language/2"},{"type":"function","title":"RDF.NS.XSD.long/0","doc":"","ref":"RDF.NS.XSD.html#long/0"},{"type":"function","title":"RDF.NS.XSD.long/1","doc":"`RDF.Description` property accessor for `long/0`","ref":"RDF.NS.XSD.html#long/1"},{"type":"function","title":"RDF.NS.XSD.long/2","doc":"`RDF.Description` builder for `long/0`","ref":"RDF.NS.XSD.html#long/2"},{"type":"function","title":"RDF.NS.XSD.negativeInteger/0","doc":"","ref":"RDF.NS.XSD.html#negativeInteger/0"},{"type":"function","title":"RDF.NS.XSD.negativeInteger/1","doc":"`RDF.Description` property accessor for `negativeInteger/0`","ref":"RDF.NS.XSD.html#negativeInteger/1"},{"type":"function","title":"RDF.NS.XSD.negativeInteger/2","doc":"`RDF.Description` builder for `negativeInteger/0`","ref":"RDF.NS.XSD.html#negativeInteger/2"},{"type":"function","title":"RDF.NS.XSD.nonNegativeInteger/0","doc":"","ref":"RDF.NS.XSD.html#nonNegativeInteger/0"},{"type":"function","title":"RDF.NS.XSD.nonNegativeInteger/1","doc":"`RDF.Description` property accessor for `nonNegativeInteger/0`","ref":"RDF.NS.XSD.html#nonNegativeInteger/1"},{"type":"function","title":"RDF.NS.XSD.nonNegativeInteger/2","doc":"`RDF.Description` builder for `nonNegativeInteger/0`","ref":"RDF.NS.XSD.html#nonNegativeInteger/2"},{"type":"function","title":"RDF.NS.XSD.nonPositiveInteger/0","doc":"","ref":"RDF.NS.XSD.html#nonPositiveInteger/0"},{"type":"function","title":"RDF.NS.XSD.nonPositiveInteger/1","doc":"`RDF.Description` property accessor for `nonPositiveInteger/0`","ref":"RDF.NS.XSD.html#nonPositiveInteger/1"},{"type":"function","title":"RDF.NS.XSD.nonPositiveInteger/2","doc":"`RDF.Description` builder for `nonPositiveInteger/0`","ref":"RDF.NS.XSD.html#nonPositiveInteger/2"},{"type":"function","title":"RDF.NS.XSD.normalizedString/0","doc":"","ref":"RDF.NS.XSD.html#normalizedString/0"},{"type":"function","title":"RDF.NS.XSD.normalizedString/1","doc":"`RDF.Description` property accessor for `normalizedString/0`","ref":"RDF.NS.XSD.html#normalizedString/1"},{"type":"function","title":"RDF.NS.XSD.normalizedString/2","doc":"`RDF.Description` builder for `normalizedString/0`","ref":"RDF.NS.XSD.html#normalizedString/2"},{"type":"function","title":"RDF.NS.XSD.positiveInteger/0","doc":"","ref":"RDF.NS.XSD.html#positiveInteger/0"},{"type":"function","title":"RDF.NS.XSD.positiveInteger/1","doc":"`RDF.Description` property accessor for `positiveInteger/0`","ref":"RDF.NS.XSD.html#positiveInteger/1"},{"type":"function","title":"RDF.NS.XSD.positiveInteger/2","doc":"`RDF.Description` builder for `positiveInteger/0`","ref":"RDF.NS.XSD.html#positiveInteger/2"},{"type":"function","title":"RDF.NS.XSD.short/0","doc":"","ref":"RDF.NS.XSD.html#short/0"},{"type":"function","title":"RDF.NS.XSD.short/1","doc":"`RDF.Description` property accessor for `short/0`","ref":"RDF.NS.XSD.html#short/1"},{"type":"function","title":"RDF.NS.XSD.short/2","doc":"`RDF.Description` builder for `short/0`","ref":"RDF.NS.XSD.html#short/2"},{"type":"function","title":"RDF.NS.XSD.string/0","doc":"","ref":"RDF.NS.XSD.html#string/0"},{"type":"function","title":"RDF.NS.XSD.string/1","doc":"`RDF.Description` property accessor for `string/0`","ref":"RDF.NS.XSD.html#string/1"},{"type":"function","title":"RDF.NS.XSD.string/2","doc":"`RDF.Description` builder for `string/0`","ref":"RDF.NS.XSD.html#string/2"},{"type":"function","title":"RDF.NS.XSD.time/0","doc":"","ref":"RDF.NS.XSD.html#time/0"},{"type":"function","title":"RDF.NS.XSD.time/1","doc":"`RDF.Description` property accessor for `time/0`","ref":"RDF.NS.XSD.html#time/1"},{"type":"function","title":"RDF.NS.XSD.time/2","doc":"`RDF.Description` builder for `time/0`","ref":"RDF.NS.XSD.html#time/2"},{"type":"function","title":"RDF.NS.XSD.token/0","doc":"","ref":"RDF.NS.XSD.html#token/0"},{"type":"function","title":"RDF.NS.XSD.token/1","doc":"`RDF.Description` property accessor for `token/0`","ref":"RDF.NS.XSD.html#token/1"},{"type":"function","title":"RDF.NS.XSD.token/2","doc":"`RDF.Description` builder for `token/0`","ref":"RDF.NS.XSD.html#token/2"},{"type":"function","title":"RDF.NS.XSD.unsignedByte/0","doc":"","ref":"RDF.NS.XSD.html#unsignedByte/0"},{"type":"function","title":"RDF.NS.XSD.unsignedByte/1","doc":"`RDF.Description` property accessor for `unsignedByte/0`","ref":"RDF.NS.XSD.html#unsignedByte/1"},{"type":"function","title":"RDF.NS.XSD.unsignedByte/2","doc":"`RDF.Description` builder for `unsignedByte/0`","ref":"RDF.NS.XSD.html#unsignedByte/2"},{"type":"function","title":"RDF.NS.XSD.unsignedInt/0","doc":"","ref":"RDF.NS.XSD.html#unsignedInt/0"},{"type":"function","title":"RDF.NS.XSD.unsignedInt/1","doc":"`RDF.Description` property accessor for `unsignedInt/0`","ref":"RDF.NS.XSD.html#unsignedInt/1"},{"type":"function","title":"RDF.NS.XSD.unsignedInt/2","doc":"`RDF.Description` builder for `unsignedInt/0`","ref":"RDF.NS.XSD.html#unsignedInt/2"},{"type":"function","title":"RDF.NS.XSD.unsignedLong/0","doc":"","ref":"RDF.NS.XSD.html#unsignedLong/0"},{"type":"function","title":"RDF.NS.XSD.unsignedLong/1","doc":"`RDF.Description` property accessor for `unsignedLong/0`","ref":"RDF.NS.XSD.html#unsignedLong/1"},{"type":"function","title":"RDF.NS.XSD.unsignedLong/2","doc":"`RDF.Description` builder for `unsignedLong/0`","ref":"RDF.NS.XSD.html#unsignedLong/2"},{"type":"function","title":"RDF.NS.XSD.unsignedShort/0","doc":"","ref":"RDF.NS.XSD.html#unsignedShort/0"},{"type":"function","title":"RDF.NS.XSD.unsignedShort/1","doc":"`RDF.Description` property accessor for `unsignedShort/0`","ref":"RDF.NS.XSD.html#unsignedShort/1"},{"type":"function","title":"RDF.NS.XSD.unsignedShort/2","doc":"`RDF.Description` builder for `unsignedShort/0`","ref":"RDF.NS.XSD.html#unsignedShort/2"},{"type":"function","title":"RDF.NS.XSD.yearMonthDuration/0","doc":"","ref":"RDF.NS.XSD.html#yearMonthDuration/0"},{"type":"function","title":"RDF.NS.XSD.yearMonthDuration/1","doc":"`RDF.Description` property accessor for `yearMonthDuration/0`","ref":"RDF.NS.XSD.html#yearMonthDuration/1"},{"type":"function","title":"RDF.NS.XSD.yearMonthDuration/2","doc":"`RDF.Description` builder for `yearMonthDuration/0`","ref":"RDF.NS.XSD.html#yearMonthDuration/2"},{"type":"module","title":"RDF.LangString","doc":"`RDF.Literal.Datatype` for `rdf:langString`s.","ref":"RDF.LangString.html"},{"type":"function","title":"RDF.LangString.canonical_lexical/1","doc":"Returns the canonical lexical form of a `RDF.Literal` of this datatype.","ref":"RDF.LangString.html#canonical_lexical/1"},{"type":"function","title":"RDF.LangString.cast/1","doc":"Casts a datatype literal of one type into a datatype literal of another type.\n\nReturns `nil` when the given arguments are not castable into this datatype or when the given argument is an\ninvalid literal.\n\nImplementations define the casting for a given value with the `c:RDF.Literal.Datatype.do_cast/1` callback.","ref":"RDF.LangString.html#cast/1"},{"type":"function","title":"RDF.LangString.compare/2","doc":"","ref":"RDF.LangString.html#compare/2"},{"type":"function","title":"RDF.LangString.datatype?/1","doc":"Checks if the given literal has this datatype.","ref":"RDF.LangString.html#datatype?/1"},{"type":"function","title":"RDF.LangString.equal_value?/2","doc":"Checks if two datatype literals are equal in terms of the values of their value space.\n\nNon-`RDF.Literal`s  are tried to be coerced via `RDF.Literal.coerce/1` before comparison.\n\nReturns `nil` when the given arguments are not comparable as literals of this\ndatatype.\n\nInvalid literals are only considered equal in this relation when both have the exact same\ndatatype and the same attributes (lexical form, language etc.).\n\nImplementations can customize this equivalence relation via the `c:RDF.Literal.Datatype.do_equal_value_different_datatypes?/2`\nand `c:RDF.Literal.Datatype.do_equal_value_different_datatypes?/2` callbacks.","ref":"RDF.LangString.html#equal_value?/2"},{"type":"function","title":"RDF.LangString.match_language?/2","doc":"Checks if a language tagged string literal or language tag matches a language range.\n\nThe check is performed per the basic filtering scheme defined in\n[RFC4647](http://www.ietf.org/rfc/rfc4647.txt) section 3.3.1.\nA language range is a basic language range per _Matching of Language Tags_ in\nRFC4647 section 2.1.\nA language range of `\"*\"` matches any non-empty language-tag string.\n\nsee","ref":"RDF.LangString.html#match_language?/2"},{"type":"function","title":"RDF.LangString.new/2","doc":"Creates a new `RDF.Literal` with this datatype and the given `value` and `language`.","ref":"RDF.LangString.html#new/2"},{"type":"function","title":"RDF.LangString.update/3","doc":"Updates the value of a `RDF.Literal` without changing everything else.","ref":"RDF.LangString.html#update/3"},{"type":"type","title":"RDF.LangString.t/0","doc":"","ref":"RDF.LangString.html#t:t/0"},{"type":"module","title":"RDF.Literal.Generic","doc":"A generic `RDF.Literal.Datatype` for literals of an unknown datatype.","ref":"RDF.Literal.Generic.html"},{"type":"function","title":"RDF.Literal.Generic.canonical_lexical/1","doc":"Returns the canonical lexical form of a `RDF.Literal` of this datatype.","ref":"RDF.Literal.Generic.html#canonical_lexical/1"},{"type":"function","title":"RDF.Literal.Generic.cast/1","doc":"Since generic literals don't support casting, always returns `nil`.","ref":"RDF.Literal.Generic.html#cast/1"},{"type":"function","title":"RDF.Literal.Generic.compare/2","doc":"","ref":"RDF.Literal.Generic.html#compare/2"},{"type":"function","title":"RDF.Literal.Generic.datatype?/1","doc":"Checks if the given literal has this datatype.","ref":"RDF.Literal.Generic.html#datatype?/1"},{"type":"function","title":"RDF.Literal.Generic.equal_value?/2","doc":"Checks if two datatype literals are equal in terms of the values of their value space.\n\nNon-`RDF.Literal`s  are tried to be coerced via `RDF.Literal.coerce/1` before comparison.\n\nReturns `nil` when the given arguments are not comparable as literals of this\ndatatype.\n\nInvalid literals are only considered equal in this relation when both have the exact same\ndatatype and the same attributes (lexical form, language etc.).\n\nImplementations can customize this equivalence relation via the `c:RDF.Literal.Datatype.do_equal_value_different_datatypes?/2`\nand `c:RDF.Literal.Datatype.do_equal_value_different_datatypes?/2` callbacks.","ref":"RDF.Literal.Generic.html#equal_value?/2"},{"type":"function","title":"RDF.Literal.Generic.update/3","doc":"Updates the value of a `RDF.Literal` without changing everything else.","ref":"RDF.Literal.Generic.html#update/3"},{"type":"type","title":"RDF.Literal.Generic.t/0","doc":"","ref":"RDF.Literal.Generic.html#t:t/0"},{"type":"module","title":"RDF.XSD.AnyURI","doc":"`RDF.XSD.Datatype` for `xsd:anyURI`.\n\nSee:","ref":"RDF.XSD.AnyURI.html"},{"type":"function","title":"RDF.XSD.AnyURI.canonical/1","doc":"Produces the canonical representation of a `RDF.Literal` of this datatype.","ref":"RDF.XSD.AnyURI.html#canonical/1"},{"type":"function","title":"RDF.XSD.AnyURI.canonical?/1","doc":"Determines if the lexical form of a `RDF.Literal` of this datatype is the canonical form.","ref":"RDF.XSD.AnyURI.html#canonical?/1"},{"type":"function","title":"RDF.XSD.AnyURI.canonical_lexical/1","doc":"Returns the canonical lexical form of a `RDF.Literal` of this datatype.","ref":"RDF.XSD.AnyURI.html#canonical_lexical/1"},{"type":"function","title":"RDF.XSD.AnyURI.cast/1","doc":"Casts a datatype literal of one type into a datatype literal of another type.\n\nReturns `nil` when the given arguments are not castable into this datatype or when the given argument is an\ninvalid literal.\n\nImplementations define the casting for a given value with the `c:RDF.Literal.Datatype.do_cast/1` callback.","ref":"RDF.XSD.AnyURI.html#cast/1"},{"type":"function","title":"RDF.XSD.AnyURI.compare/2","doc":"Compares two `RDF.Literal`s.\n\nIf the first literal is greater than the second `:gt` is returned, if less than `:lt` is returned.\nIf both literal are equal `:eq` is returned.\nIf the literals can not be compared either `nil` is returned, when they generally can be compared\ndue to their datatype, or `:indeterminate` is returned, when the order of the given values is\nnot defined on only partially ordered datatypes.","ref":"RDF.XSD.AnyURI.html#compare/2"},{"type":"function","title":"RDF.XSD.AnyURI.datatype?/1","doc":"Checks if the given literal has datatype this or a datatype that is derived of it.","ref":"RDF.XSD.AnyURI.html#datatype?/1"},{"type":"function","title":"RDF.XSD.AnyURI.equal_value?/2","doc":"Checks if two datatype literals are equal in terms of the values of their value space.\n\nNon-`RDF.Literal`s  are tried to be coerced via `RDF.Literal.coerce/1` before comparison.\n\nReturns `nil` when the given arguments are not comparable as literals of this\ndatatype.\n\nInvalid literals are only considered equal in this relation when both have the exact same\ndatatype and the same attributes (lexical form, language etc.).\n\nImplementations can customize this equivalence relation via the `c:RDF.Literal.Datatype.do_equal_value_different_datatypes?/2`\nand `c:RDF.Literal.Datatype.do_equal_value_different_datatypes?/2` callbacks.","ref":"RDF.XSD.AnyURI.html#equal_value?/2"},{"type":"function","title":"RDF.XSD.AnyURI.lexical/1","doc":"Returns the lexical form of a `RDF.Literal` of this datatype.","ref":"RDF.XSD.AnyURI.html#lexical/1"},{"type":"function","title":"RDF.XSD.AnyURI.new/2","doc":"Creates a new `RDF.Literal` with this datatype and the given `value`.","ref":"RDF.XSD.AnyURI.html#new/2"},{"type":"function","title":"RDF.XSD.AnyURI.new!/2","doc":"Creates a new `RDF.Literal` with this datatype and the given `value` or fails when it is not valid.","ref":"RDF.XSD.AnyURI.html#new!/2"},{"type":"function","title":"RDF.XSD.AnyURI.update/3","doc":"Updates the value of a `RDF.Literal` without changing everything else.","ref":"RDF.XSD.AnyURI.html#update/3"},{"type":"function","title":"RDF.XSD.AnyURI.valid?/1","doc":"Determines if a `RDF.Literal` of this or a derived datatype has a proper value of its value space.","ref":"RDF.XSD.AnyURI.html#valid?/1"},{"type":"function","title":"RDF.XSD.AnyURI.value/1","doc":"Returns the value of a `RDF.Literal` of this or a derived datatype.","ref":"RDF.XSD.AnyURI.html#value/1"},{"type":"type","title":"RDF.XSD.AnyURI.invalid_value/0","doc":"","ref":"RDF.XSD.AnyURI.html#t:invalid_value/0"},{"type":"type","title":"RDF.XSD.AnyURI.t/0","doc":"","ref":"RDF.XSD.AnyURI.html#t:t/0"},{"type":"type","title":"RDF.XSD.AnyURI.valid_value/0","doc":"","ref":"RDF.XSD.AnyURI.html#t:valid_value/0"},{"type":"type","title":"RDF.XSD.AnyURI.value/0","doc":"","ref":"RDF.XSD.AnyURI.html#t:value/0"},{"type":"module","title":"RDF.XSD.Base64Binary","doc":"`RDF.XSD.Datatype` for `xsd:base64Binary`.\n\nSee:","ref":"RDF.XSD.Base64Binary.html"},{"type":"function","title":"RDF.XSD.Base64Binary.canonical/1","doc":"Produces the canonical representation of a `RDF.Literal` of this datatype.","ref":"RDF.XSD.Base64Binary.html#canonical/1"},{"type":"function","title":"RDF.XSD.Base64Binary.canonical?/1","doc":"Determines if the lexical form of a `RDF.Literal` of this datatype is the canonical form.","ref":"RDF.XSD.Base64Binary.html#canonical?/1"},{"type":"function","title":"RDF.XSD.Base64Binary.canonical_lexical/1","doc":"Returns the canonical lexical form of a `RDF.Literal` of this datatype.","ref":"RDF.XSD.Base64Binary.html#canonical_lexical/1"},{"type":"function","title":"RDF.XSD.Base64Binary.cast/1","doc":"Casts a datatype literal of one type into a datatype literal of another type.\n\nReturns `nil` when the given arguments are not castable into this datatype or when the given argument is an\ninvalid literal.\n\nImplementations define the casting for a given value with the `c:RDF.Literal.Datatype.do_cast/1` callback.","ref":"RDF.XSD.Base64Binary.html#cast/1"},{"type":"function","title":"RDF.XSD.Base64Binary.compare/2","doc":"Compares two `RDF.Literal`s.\n\nIf the first literal is greater than the second `:gt` is returned, if less than `:lt` is returned.\nIf both literal are equal `:eq` is returned.\nIf the literals can not be compared either `nil` is returned, when they generally can be compared\ndue to their datatype, or `:indeterminate` is returned, when the order of the given values is\nnot defined on only partially ordered datatypes.","ref":"RDF.XSD.Base64Binary.html#compare/2"},{"type":"function","title":"RDF.XSD.Base64Binary.datatype?/1","doc":"Checks if the given literal has datatype this or a datatype that is derived of it.","ref":"RDF.XSD.Base64Binary.html#datatype?/1"},{"type":"function","title":"RDF.XSD.Base64Binary.equal_value?/2","doc":"Checks if two datatype literals are equal in terms of the values of their value space.\n\nNon-`RDF.Literal`s  are tried to be coerced via `RDF.Literal.coerce/1` before comparison.\n\nReturns `nil` when the given arguments are not comparable as literals of this\ndatatype.\n\nInvalid literals are only considered equal in this relation when both have the exact same\ndatatype and the same attributes (lexical form, language etc.).\n\nImplementations can customize this equivalence relation via the `c:RDF.Literal.Datatype.do_equal_value_different_datatypes?/2`\nand `c:RDF.Literal.Datatype.do_equal_value_different_datatypes?/2` callbacks.","ref":"RDF.XSD.Base64Binary.html#equal_value?/2"},{"type":"function","title":"RDF.XSD.Base64Binary.lexical/1","doc":"Returns the lexical form of a `RDF.Literal` of this datatype.","ref":"RDF.XSD.Base64Binary.html#lexical/1"},{"type":"function","title":"RDF.XSD.Base64Binary.new/2","doc":"Creates a new `RDF.Literal` with this datatype and the given `value`.","ref":"RDF.XSD.Base64Binary.html#new/2"},{"type":"function","title":"RDF.XSD.Base64Binary.new!/2","doc":"Creates a new `RDF.Literal` with this datatype and the given `value` or fails when it is not valid.","ref":"RDF.XSD.Base64Binary.html#new!/2"},{"type":"function","title":"RDF.XSD.Base64Binary.update/3","doc":"Updates the value of a `RDF.Literal` without changing everything else.","ref":"RDF.XSD.Base64Binary.html#update/3"},{"type":"function","title":"RDF.XSD.Base64Binary.valid?/1","doc":"Determines if a `RDF.Literal` of this or a derived datatype has a proper value of its value space.","ref":"RDF.XSD.Base64Binary.html#valid?/1"},{"type":"function","title":"RDF.XSD.Base64Binary.value/1","doc":"Returns the value of a `RDF.Literal` of this or a derived datatype.","ref":"RDF.XSD.Base64Binary.html#value/1"},{"type":"type","title":"RDF.XSD.Base64Binary.invalid_value/0","doc":"","ref":"RDF.XSD.Base64Binary.html#t:invalid_value/0"},{"type":"type","title":"RDF.XSD.Base64Binary.t/0","doc":"","ref":"RDF.XSD.Base64Binary.html#t:t/0"},{"type":"type","title":"RDF.XSD.Base64Binary.valid_value/0","doc":"","ref":"RDF.XSD.Base64Binary.html#t:valid_value/0"},{"type":"type","title":"RDF.XSD.Base64Binary.value/0","doc":"","ref":"RDF.XSD.Base64Binary.html#t:value/0"},{"type":"module","title":"RDF.XSD.Boolean","doc":"`RDF.XSD.Datatype` for `xsd:boolean`.\n\nSee:","ref":"RDF.XSD.Boolean.html"},{"type":"function","title":"RDF.XSD.Boolean.canonical/1","doc":"Produces the canonical representation of a `RDF.Literal` of this datatype.","ref":"RDF.XSD.Boolean.html#canonical/1"},{"type":"function","title":"RDF.XSD.Boolean.canonical?/1","doc":"Determines if the lexical form of a `RDF.Literal` of this datatype is the canonical form.","ref":"RDF.XSD.Boolean.html#canonical?/1"},{"type":"function","title":"RDF.XSD.Boolean.canonical_lexical/1","doc":"Returns the canonical lexical form of a `RDF.Literal` of this datatype.","ref":"RDF.XSD.Boolean.html#canonical_lexical/1"},{"type":"function","title":"RDF.XSD.Boolean.cast/1","doc":"Casts a datatype literal of one type into a datatype literal of another type.\n\nReturns `nil` when the given arguments are not castable into this datatype or when the given argument is an\ninvalid literal.\n\nImplementations define the casting for a given value with the `c:RDF.Literal.Datatype.do_cast/1` callback.","ref":"RDF.XSD.Boolean.html#cast/1"},{"type":"function","title":"RDF.XSD.Boolean.compare/2","doc":"Compares two `RDF.Literal`s.\n\nIf the first literal is greater than the second `:gt` is returned, if less than `:lt` is returned.\nIf both literal are equal `:eq` is returned.\nIf the literals can not be compared either `nil` is returned, when they generally can be compared\ndue to their datatype, or `:indeterminate` is returned, when the order of the given values is\nnot defined on only partially ordered datatypes.","ref":"RDF.XSD.Boolean.html#compare/2"},{"type":"function","title":"RDF.XSD.Boolean.datatype?/1","doc":"Checks if the given literal has datatype this or a datatype that is derived of it.","ref":"RDF.XSD.Boolean.html#datatype?/1"},{"type":"function","title":"RDF.XSD.Boolean.ebv/1","doc":"Returns an Effective Boolean Value (EBV).\n\nThe Effective Boolean Value is an algorithm to coerce values to a `RDF.XSD.Boolean`.\n\nIt is specified and used in the SPARQL query language and is based upon XPath's\n`fn:boolean`. Other than specified in these specs any value which can not be\nconverted into a boolean results in `nil`.\n\nsee\n-  \n-","ref":"RDF.XSD.Boolean.html#ebv/1"},{"type":"function","title":"RDF.XSD.Boolean.effective/1","doc":"Alias for `ebv/1`.","ref":"RDF.XSD.Boolean.html#effective/1"},{"type":"function","title":"RDF.XSD.Boolean.equal_value?/2","doc":"Checks if two datatype literals are equal in terms of the values of their value space.\n\nNon-`RDF.Literal`s  are tried to be coerced via `RDF.Literal.coerce/1` before comparison.\n\nReturns `nil` when the given arguments are not comparable as literals of this\ndatatype.\n\nInvalid literals are only considered equal in this relation when both have the exact same\ndatatype and the same attributes (lexical form, language etc.).\n\nImplementations can customize this equivalence relation via the `c:RDF.Literal.Datatype.do_equal_value_different_datatypes?/2`\nand `c:RDF.Literal.Datatype.do_equal_value_different_datatypes?/2` callbacks.","ref":"RDF.XSD.Boolean.html#equal_value?/2"},{"type":"function","title":"RDF.XSD.Boolean.fn_not/1","doc":"Returns `RDF.XSD.true` if the effective boolean value of the given argument is `RDF.XSD.false`, or `RDF.XSD.false` if it is `RDF.XSD.true`.\n\nOtherwise, it returns `nil`.","ref":"RDF.XSD.Boolean.html#fn_not/1"},{"type":"function","title":"Examples - RDF.XSD.Boolean.fn_not/1","doc":"iex> RDF.XSD.Boolean.fn_not(RDF.XSD.true)\n    RDF.XSD.false\n    iex> RDF.XSD.Boolean.fn_not(RDF.XSD.false)\n    RDF.XSD.true\n\n    iex> RDF.XSD.Boolean.fn_not(true)\n    RDF.XSD.false\n    iex> RDF.XSD.Boolean.fn_not(false)\n    RDF.XSD.true\n\n    iex> RDF.XSD.Boolean.fn_not(42)\n    RDF.XSD.false\n    iex> RDF.XSD.Boolean.fn_not(\"\")\n    RDF.XSD.true\n\n    iex> RDF.XSD.Boolean.fn_not(nil)\n    nil\n\nsee","ref":"RDF.XSD.Boolean.html#fn_not/1-examples"},{"type":"function","title":"RDF.XSD.Boolean.lexical/1","doc":"Returns the lexical form of a `RDF.Literal` of this datatype.","ref":"RDF.XSD.Boolean.html#lexical/1"},{"type":"function","title":"RDF.XSD.Boolean.logical_and/2","doc":"Returns the logical `AND` of the effective boolean value of the given arguments.\n\nIt returns `nil` if only one argument is `nil` and the other argument is\n`RDF.XSD.true` and `RDF.XSD.false` if the other argument is `RDF.XSD.false`.","ref":"RDF.XSD.Boolean.html#logical_and/2"},{"type":"function","title":"Examples - RDF.XSD.Boolean.logical_and/2","doc":"iex> RDF.XSD.Boolean.logical_and(RDF.XSD.true, RDF.XSD.true)\n    RDF.XSD.true\n    iex> RDF.XSD.Boolean.logical_and(RDF.XSD.true, RDF.XSD.false)\n    RDF.XSD.false\n\n    iex> RDF.XSD.Boolean.logical_and(RDF.XSD.true, nil)\n    nil\n    iex> RDF.XSD.Boolean.logical_and(nil, RDF.XSD.false)\n    RDF.XSD.false\n    iex> RDF.XSD.Boolean.logical_and(nil, nil)\n    nil\n\nsee","ref":"RDF.XSD.Boolean.html#logical_and/2-examples"},{"type":"function","title":"RDF.XSD.Boolean.logical_or/2","doc":"Returns the logical `OR` of the effective boolean value of the given arguments.\n\nIt returns `nil` if only one argument is `nil` and the other argument is\n`RDF.XSD.false` and `RDF.XSD.true` if the other argument is `RDF.XSD.true`.","ref":"RDF.XSD.Boolean.html#logical_or/2"},{"type":"function","title":"Examples - RDF.XSD.Boolean.logical_or/2","doc":"iex> RDF.XSD.Boolean.logical_or(RDF.XSD.true, RDF.XSD.false)\n    RDF.XSD.true\n    iex> RDF.XSD.Boolean.logical_or(RDF.XSD.false, RDF.XSD.false)\n    RDF.XSD.false\n\n    iex> RDF.XSD.Boolean.logical_or(RDF.XSD.true, nil)\n    RDF.XSD.true\n    iex> RDF.XSD.Boolean.logical_or(nil, RDF.XSD.false)\n    nil\n    iex> RDF.XSD.Boolean.logical_or(nil, nil)\n    nil\n\nsee","ref":"RDF.XSD.Boolean.html#logical_or/2-examples"},{"type":"function","title":"RDF.XSD.Boolean.new/2","doc":"Creates a new `RDF.Literal` with this datatype and the given `value`.","ref":"RDF.XSD.Boolean.html#new/2"},{"type":"function","title":"RDF.XSD.Boolean.new!/2","doc":"Creates a new `RDF.Literal` with this datatype and the given `value` or fails when it is not valid.","ref":"RDF.XSD.Boolean.html#new!/2"},{"type":"function","title":"RDF.XSD.Boolean.update/3","doc":"Updates the value of a `RDF.Literal` without changing everything else.","ref":"RDF.XSD.Boolean.html#update/3"},{"type":"function","title":"RDF.XSD.Boolean.valid?/1","doc":"Determines if a `RDF.Literal` of this or a derived datatype has a proper value of its value space.","ref":"RDF.XSD.Boolean.html#valid?/1"},{"type":"function","title":"RDF.XSD.Boolean.value/1","doc":"Returns the value of a `RDF.Literal` of this or a derived datatype.","ref":"RDF.XSD.Boolean.html#value/1"},{"type":"type","title":"RDF.XSD.Boolean.input_value/0","doc":"","ref":"RDF.XSD.Boolean.html#t:input_value/0"},{"type":"type","title":"RDF.XSD.Boolean.invalid_value/0","doc":"","ref":"RDF.XSD.Boolean.html#t:invalid_value/0"},{"type":"type","title":"RDF.XSD.Boolean.t/0","doc":"","ref":"RDF.XSD.Boolean.html#t:t/0"},{"type":"type","title":"RDF.XSD.Boolean.valid_value/0","doc":"","ref":"RDF.XSD.Boolean.html#t:valid_value/0"},{"type":"type","title":"RDF.XSD.Boolean.value/0","doc":"","ref":"RDF.XSD.Boolean.html#t:value/0"},{"type":"module","title":"RDF.XSD.Byte","doc":"`RDF.XSD.Datatype` for `xsd:byte`.\n\nSee:","ref":"RDF.XSD.Byte.html"},{"type":"function","title":"RDF.XSD.Byte.canonical/1","doc":"Produces the canonical representation of a `RDF.Literal` of this datatype.","ref":"RDF.XSD.Byte.html#canonical/1"},{"type":"function","title":"RDF.XSD.Byte.canonical?/1","doc":"Determines if the lexical form of a `RDF.Literal` of this datatype is the canonical form.","ref":"RDF.XSD.Byte.html#canonical?/1"},{"type":"function","title":"RDF.XSD.Byte.canonical_lexical/1","doc":"Returns the canonical lexical form of a `RDF.Literal` of this datatype.","ref":"RDF.XSD.Byte.html#canonical_lexical/1"},{"type":"function","title":"RDF.XSD.Byte.cast/1","doc":"Casts a datatype literal of one type into a datatype literal of another type.\n\nReturns `nil` when the given arguments are not castable into this datatype or when the given argument is an\ninvalid literal.\n\nImplementations define the casting for a given value with the `c:RDF.Literal.Datatype.do_cast/1` callback.","ref":"RDF.XSD.Byte.html#cast/1"},{"type":"function","title":"RDF.XSD.Byte.compare/2","doc":"Compares two `RDF.Literal`s.\n\nIf the first literal is greater than the second `:gt` is returned, if less than `:lt` is returned.\nIf both literal are equal `:eq` is returned.\nIf the literals can not be compared either `nil` is returned, when they generally can be compared\ndue to their datatype, or `:indeterminate` is returned, when the order of the given values is\nnot defined on only partially ordered datatypes.","ref":"RDF.XSD.Byte.html#compare/2"},{"type":"function","title":"RDF.XSD.Byte.datatype?/1","doc":"Checks if the given literal has datatype this or a datatype that is derived of it.","ref":"RDF.XSD.Byte.html#datatype?/1"},{"type":"function","title":"RDF.XSD.Byte.equal_value?/2","doc":"Checks if two datatype literals are equal in terms of the values of their value space.\n\nNon-`RDF.Literal`s  are tried to be coerced via `RDF.Literal.coerce/1` before comparison.\n\nReturns `nil` when the given arguments are not comparable as literals of this\ndatatype.\n\nInvalid literals are only considered equal in this relation when both have the exact same\ndatatype and the same attributes (lexical form, language etc.).\n\nImplementations can customize this equivalence relation via the `c:RDF.Literal.Datatype.do_equal_value_different_datatypes?/2`\nand `c:RDF.Literal.Datatype.do_equal_value_different_datatypes?/2` callbacks.","ref":"RDF.XSD.Byte.html#equal_value?/2"},{"type":"function","title":"RDF.XSD.Byte.lexical/1","doc":"Returns the lexical form of a `RDF.Literal` of this datatype.","ref":"RDF.XSD.Byte.html#lexical/1"},{"type":"function","title":"RDF.XSD.Byte.new/2","doc":"Creates a new `RDF.Literal` with this datatype and the given `value`.","ref":"RDF.XSD.Byte.html#new/2"},{"type":"function","title":"RDF.XSD.Byte.new!/2","doc":"Creates a new `RDF.Literal` with this datatype and the given `value` or fails when it is not valid.","ref":"RDF.XSD.Byte.html#new!/2"},{"type":"function","title":"RDF.XSD.Byte.update/3","doc":"Updates the value of a `RDF.Literal` without changing everything else.","ref":"RDF.XSD.Byte.html#update/3"},{"type":"function","title":"RDF.XSD.Byte.valid?/1","doc":"Determines if a `RDF.Literal` of this or a derived datatype has a proper value of its value space.","ref":"RDF.XSD.Byte.html#valid?/1"},{"type":"function","title":"RDF.XSD.Byte.value/1","doc":"Returns the value of a `RDF.Literal` of this or a derived datatype.","ref":"RDF.XSD.Byte.html#value/1"},{"type":"type","title":"RDF.XSD.Byte.invalid_value/0","doc":"","ref":"RDF.XSD.Byte.html#t:invalid_value/0"},{"type":"type","title":"RDF.XSD.Byte.t/0","doc":"","ref":"RDF.XSD.Byte.html#t:t/0"},{"type":"type","title":"RDF.XSD.Byte.valid_value/0","doc":"","ref":"RDF.XSD.Byte.html#t:valid_value/0"},{"type":"type","title":"RDF.XSD.Byte.value/0","doc":"","ref":"RDF.XSD.Byte.html#t:value/0"},{"type":"module","title":"RDF.XSD.Date","doc":"`RDF.XSD.Datatype` for `xsd:date`.\n\nOptions:\n\n- `tz`: this allows to specify a timezone which is not supported by Elixir's `Date` struct; note,\n  that it will also overwrite an eventually already present timezone in an input lexical\n\nSee:","ref":"RDF.XSD.Date.html"},{"type":"function","title":"RDF.XSD.Date.canonical/1","doc":"Produces the canonical representation of a `RDF.Literal` of this datatype.","ref":"RDF.XSD.Date.html#canonical/1"},{"type":"function","title":"RDF.XSD.Date.canonical?/1","doc":"Determines if the lexical form of a `RDF.Literal` of this datatype is the canonical form.","ref":"RDF.XSD.Date.html#canonical?/1"},{"type":"function","title":"RDF.XSD.Date.canonical_lexical/1","doc":"Returns the canonical lexical form of a `RDF.Literal` of this datatype.","ref":"RDF.XSD.Date.html#canonical_lexical/1"},{"type":"function","title":"RDF.XSD.Date.cast/1","doc":"Casts a datatype literal of one type into a datatype literal of another type.\n\nReturns `nil` when the given arguments are not castable into this datatype or when the given argument is an\ninvalid literal.\n\nImplementations define the casting for a given value with the `c:RDF.Literal.Datatype.do_cast/1` callback.","ref":"RDF.XSD.Date.html#cast/1"},{"type":"function","title":"RDF.XSD.Date.compare/2","doc":"Compares two `RDF.Literal`s.\n\nIf the first literal is greater than the second `:gt` is returned, if less than `:lt` is returned.\nIf both literal are equal `:eq` is returned.\nIf the literals can not be compared either `nil` is returned, when they generally can be compared\ndue to their datatype, or `:indeterminate` is returned, when the order of the given values is\nnot defined on only partially ordered datatypes.","ref":"RDF.XSD.Date.html#compare/2"},{"type":"function","title":"RDF.XSD.Date.datatype?/1","doc":"Checks if the given literal has datatype this or a datatype that is derived of it.","ref":"RDF.XSD.Date.html#datatype?/1"},{"type":"function","title":"RDF.XSD.Date.equal_value?/2","doc":"Checks if two datatype literals are equal in terms of the values of their value space.\n\nNon-`RDF.Literal`s  are tried to be coerced via `RDF.Literal.coerce/1` before comparison.\n\nReturns `nil` when the given arguments are not comparable as literals of this\ndatatype.\n\nInvalid literals are only considered equal in this relation when both have the exact same\ndatatype and the same attributes (lexical form, language etc.).\n\nImplementations can customize this equivalence relation via the `c:RDF.Literal.Datatype.do_equal_value_different_datatypes?/2`\nand `c:RDF.Literal.Datatype.do_equal_value_different_datatypes?/2` callbacks.","ref":"RDF.XSD.Date.html#equal_value?/2"},{"type":"function","title":"RDF.XSD.Date.lexical/1","doc":"Returns the lexical form of a `RDF.Literal` of this datatype.","ref":"RDF.XSD.Date.html#lexical/1"},{"type":"function","title":"RDF.XSD.Date.new/2","doc":"Creates a new `RDF.Literal` with this datatype and the given `value`.","ref":"RDF.XSD.Date.html#new/2"},{"type":"function","title":"RDF.XSD.Date.new!/2","doc":"Creates a new `RDF.Literal` with this datatype and the given `value` or fails when it is not valid.","ref":"RDF.XSD.Date.html#new!/2"},{"type":"function","title":"RDF.XSD.Date.update/3","doc":"Updates the value of a `RDF.Literal` without changing everything else.","ref":"RDF.XSD.Date.html#update/3"},{"type":"function","title":"RDF.XSD.Date.valid?/1","doc":"Determines if a `RDF.Literal` of this or a derived datatype has a proper value of its value space.","ref":"RDF.XSD.Date.html#valid?/1"},{"type":"function","title":"RDF.XSD.Date.value/1","doc":"Returns the value of a `RDF.Literal` of this or a derived datatype.","ref":"RDF.XSD.Date.html#value/1"},{"type":"type","title":"RDF.XSD.Date.invalid_value/0","doc":"","ref":"RDF.XSD.Date.html#t:invalid_value/0"},{"type":"type","title":"RDF.XSD.Date.t/0","doc":"","ref":"RDF.XSD.Date.html#t:t/0"},{"type":"type","title":"RDF.XSD.Date.valid_value/0","doc":"","ref":"RDF.XSD.Date.html#t:valid_value/0"},{"type":"type","title":"RDF.XSD.Date.value/0","doc":"","ref":"RDF.XSD.Date.html#t:value/0"},{"type":"module","title":"RDF.XSD.DateTime","doc":"`RDF.XSD.Datatype` for `xsd:dateTime`.\n\nSee:","ref":"RDF.XSD.DateTime.html"},{"type":"function","title":"RDF.XSD.DateTime.canonical/1","doc":"Produces the canonical representation of a `RDF.Literal` of this datatype.","ref":"RDF.XSD.DateTime.html#canonical/1"},{"type":"function","title":"RDF.XSD.DateTime.canonical?/1","doc":"Determines if the lexical form of a `RDF.Literal` of this datatype is the canonical form.","ref":"RDF.XSD.DateTime.html#canonical?/1"},{"type":"function","title":"RDF.XSD.DateTime.canonical_lexical/1","doc":"Returns the canonical lexical form of a `RDF.Literal` of this datatype.","ref":"RDF.XSD.DateTime.html#canonical_lexical/1"},{"type":"function","title":"RDF.XSD.DateTime.canonical_lexical_with_zone/1","doc":"Converts a datetime literal to a canonical string, preserving the zone information.","ref":"RDF.XSD.DateTime.html#canonical_lexical_with_zone/1"},{"type":"function","title":"RDF.XSD.DateTime.cast/1","doc":"Casts a datatype literal of one type into a datatype literal of another type.\n\nReturns `nil` when the given arguments are not castable into this datatype or when the given argument is an\ninvalid literal.\n\nImplementations define the casting for a given value with the `c:RDF.Literal.Datatype.do_cast/1` callback.","ref":"RDF.XSD.DateTime.html#cast/1"},{"type":"function","title":"RDF.XSD.DateTime.compare/2","doc":"Compares two `RDF.Literal`s.\n\nIf the first literal is greater than the second `:gt` is returned, if less than `:lt` is returned.\nIf both literal are equal `:eq` is returned.\nIf the literals can not be compared either `nil` is returned, when they generally can be compared\ndue to their datatype, or `:indeterminate` is returned, when the order of the given values is\nnot defined on only partially ordered datatypes.","ref":"RDF.XSD.DateTime.html#compare/2"},{"type":"function","title":"RDF.XSD.DateTime.datatype?/1","doc":"Checks if the given literal has datatype this or a datatype that is derived of it.","ref":"RDF.XSD.DateTime.html#datatype?/1"},{"type":"function","title":"RDF.XSD.DateTime.equal_value?/2","doc":"Checks if two datatype literals are equal in terms of the values of their value space.\n\nNon-`RDF.Literal`s  are tried to be coerced via `RDF.Literal.coerce/1` before comparison.\n\nReturns `nil` when the given arguments are not comparable as literals of this\ndatatype.\n\nInvalid literals are only considered equal in this relation when both have the exact same\ndatatype and the same attributes (lexical form, language etc.).\n\nImplementations can customize this equivalence relation via the `c:RDF.Literal.Datatype.do_equal_value_different_datatypes?/2`\nand `c:RDF.Literal.Datatype.do_equal_value_different_datatypes?/2` callbacks.","ref":"RDF.XSD.DateTime.html#equal_value?/2"},{"type":"function","title":"RDF.XSD.DateTime.lexical/1","doc":"Returns the lexical form of a `RDF.Literal` of this datatype.","ref":"RDF.XSD.DateTime.html#lexical/1"},{"type":"function","title":"RDF.XSD.DateTime.new/2","doc":"Creates a new `RDF.Literal` with this datatype and the given `value`.","ref":"RDF.XSD.DateTime.html#new/2"},{"type":"function","title":"RDF.XSD.DateTime.new!/2","doc":"Creates a new `RDF.Literal` with this datatype and the given `value` or fails when it is not valid.","ref":"RDF.XSD.DateTime.html#new!/2"},{"type":"function","title":"RDF.XSD.DateTime.now/0","doc":"Builds a `RDF.XSD.DateTime` literal for current moment in time.","ref":"RDF.XSD.DateTime.html#now/0"},{"type":"function","title":"RDF.XSD.DateTime.tz/1","doc":"Extracts the timezone string from a `RDF.XSD.DateTime` value.","ref":"RDF.XSD.DateTime.html#tz/1"},{"type":"function","title":"RDF.XSD.DateTime.update/3","doc":"Updates the value of a `RDF.Literal` without changing everything else.","ref":"RDF.XSD.DateTime.html#update/3"},{"type":"function","title":"RDF.XSD.DateTime.valid?/1","doc":"Determines if a `RDF.Literal` of this or a derived datatype has a proper value of its value space.","ref":"RDF.XSD.DateTime.html#valid?/1"},{"type":"function","title":"RDF.XSD.DateTime.value/1","doc":"Returns the value of a `RDF.Literal` of this or a derived datatype.","ref":"RDF.XSD.DateTime.html#value/1"},{"type":"type","title":"RDF.XSD.DateTime.invalid_value/0","doc":"","ref":"RDF.XSD.DateTime.html#t:invalid_value/0"},{"type":"type","title":"RDF.XSD.DateTime.t/0","doc":"","ref":"RDF.XSD.DateTime.html#t:t/0"},{"type":"type","title":"RDF.XSD.DateTime.valid_value/0","doc":"","ref":"RDF.XSD.DateTime.html#t:valid_value/0"},{"type":"type","title":"RDF.XSD.DateTime.value/0","doc":"","ref":"RDF.XSD.DateTime.html#t:value/0"},{"type":"module","title":"RDF.XSD.Decimal","doc":"`RDF.XSD.Datatype` for `xsd:decimal`.\n\nSee:","ref":"RDF.XSD.Decimal.html"},{"type":"function","title":"RDF.XSD.Decimal.canonical/1","doc":"Produces the canonical representation of a `RDF.Literal` of this datatype.","ref":"RDF.XSD.Decimal.html#canonical/1"},{"type":"function","title":"RDF.XSD.Decimal.canonical?/1","doc":"Determines if the lexical form of a `RDF.Literal` of this datatype is the canonical form.","ref":"RDF.XSD.Decimal.html#canonical?/1"},{"type":"function","title":"RDF.XSD.Decimal.canonical_lexical/1","doc":"Returns the canonical lexical form of a `RDF.Literal` of this datatype.","ref":"RDF.XSD.Decimal.html#canonical_lexical/1"},{"type":"function","title":"RDF.XSD.Decimal.cast/1","doc":"Casts a datatype literal of one type into a datatype literal of another type.\n\nReturns `nil` when the given arguments are not castable into this datatype or when the given argument is an\ninvalid literal.\n\nImplementations define the casting for a given value with the `c:RDF.Literal.Datatype.do_cast/1` callback.","ref":"RDF.XSD.Decimal.html#cast/1"},{"type":"function","title":"RDF.XSD.Decimal.compare/2","doc":"Compares two `RDF.Literal`s.\n\nIf the first literal is greater than the second `:gt` is returned, if less than `:lt` is returned.\nIf both literal are equal `:eq` is returned.\nIf the literals can not be compared either `nil` is returned, when they generally can be compared\ndue to their datatype, or `:indeterminate` is returned, when the order of the given values is\nnot defined on only partially ordered datatypes.","ref":"RDF.XSD.Decimal.html#compare/2"},{"type":"function","title":"RDF.XSD.Decimal.datatype?/1","doc":"Checks if the given literal has datatype this or a datatype that is derived of it.","ref":"RDF.XSD.Decimal.html#datatype?/1"},{"type":"function","title":"RDF.XSD.Decimal.digit_count/1","doc":"The number of digits in the XML Schema canonical form of the literal value.","ref":"RDF.XSD.Decimal.html#digit_count/1"},{"type":"function","title":"RDF.XSD.Decimal.equal_value?/2","doc":"Checks if two datatype literals are equal in terms of the values of their value space.\n\nNon-`RDF.Literal`s  are tried to be coerced via `RDF.Literal.coerce/1` before comparison.\n\nReturns `nil` when the given arguments are not comparable as literals of this\ndatatype.\n\nInvalid literals are only considered equal in this relation when both have the exact same\ndatatype and the same attributes (lexical form, language etc.).\n\nImplementations can customize this equivalence relation via the `c:RDF.Literal.Datatype.do_equal_value_different_datatypes?/2`\nand `c:RDF.Literal.Datatype.do_equal_value_different_datatypes?/2` callbacks.","ref":"RDF.XSD.Decimal.html#equal_value?/2"},{"type":"function","title":"RDF.XSD.Decimal.fraction_digit_count/1","doc":"The number of digits to the right of the decimal point in the XML Schema canonical form of the literal value.","ref":"RDF.XSD.Decimal.html#fraction_digit_count/1"},{"type":"function","title":"RDF.XSD.Decimal.lexical/1","doc":"Returns the lexical form of a `RDF.Literal` of this datatype.","ref":"RDF.XSD.Decimal.html#lexical/1"},{"type":"function","title":"RDF.XSD.Decimal.new/2","doc":"Creates a new `RDF.Literal` with this datatype and the given `value`.","ref":"RDF.XSD.Decimal.html#new/2"},{"type":"function","title":"RDF.XSD.Decimal.new!/2","doc":"Creates a new `RDF.Literal` with this datatype and the given `value` or fails when it is not valid.","ref":"RDF.XSD.Decimal.html#new!/2"},{"type":"function","title":"RDF.XSD.Decimal.update/3","doc":"Updates the value of a `RDF.Literal` without changing everything else.","ref":"RDF.XSD.Decimal.html#update/3"},{"type":"function","title":"RDF.XSD.Decimal.valid?/1","doc":"Determines if a `RDF.Literal` of this or a derived datatype has a proper value of its value space.","ref":"RDF.XSD.Decimal.html#valid?/1"},{"type":"function","title":"RDF.XSD.Decimal.value/1","doc":"Returns the value of a `RDF.Literal` of this or a derived datatype.","ref":"RDF.XSD.Decimal.html#value/1"},{"type":"type","title":"RDF.XSD.Decimal.invalid_value/0","doc":"","ref":"RDF.XSD.Decimal.html#t:invalid_value/0"},{"type":"type","title":"RDF.XSD.Decimal.t/0","doc":"","ref":"RDF.XSD.Decimal.html#t:t/0"},{"type":"type","title":"RDF.XSD.Decimal.valid_value/0","doc":"","ref":"RDF.XSD.Decimal.html#t:valid_value/0"},{"type":"type","title":"RDF.XSD.Decimal.value/0","doc":"","ref":"RDF.XSD.Decimal.html#t:value/0"},{"type":"module","title":"RDF.XSD.Double","doc":"`RDF.XSD.Datatype` for `xsd:double`.\n\nSee:","ref":"RDF.XSD.Double.html"},{"type":"function","title":"RDF.XSD.Double.canonical/1","doc":"Produces the canonical representation of a `RDF.Literal` of this datatype.","ref":"RDF.XSD.Double.html#canonical/1"},{"type":"function","title":"RDF.XSD.Double.canonical?/1","doc":"Determines if the lexical form of a `RDF.Literal` of this datatype is the canonical form.","ref":"RDF.XSD.Double.html#canonical?/1"},{"type":"function","title":"RDF.XSD.Double.canonical_lexical/1","doc":"Returns the canonical lexical form of a `RDF.Literal` of this datatype.","ref":"RDF.XSD.Double.html#canonical_lexical/1"},{"type":"function","title":"RDF.XSD.Double.cast/1","doc":"Casts a datatype literal of one type into a datatype literal of another type.\n\nReturns `nil` when the given arguments are not castable into this datatype or when the given argument is an\ninvalid literal.\n\nImplementations define the casting for a given value with the `c:RDF.Literal.Datatype.do_cast/1` callback.","ref":"RDF.XSD.Double.html#cast/1"},{"type":"function","title":"RDF.XSD.Double.compare/2","doc":"Compares two `RDF.Literal`s.\n\nIf the first literal is greater than the second `:gt` is returned, if less than `:lt` is returned.\nIf both literal are equal `:eq` is returned.\nIf the literals can not be compared either `nil` is returned, when they generally can be compared\ndue to their datatype, or `:indeterminate` is returned, when the order of the given values is\nnot defined on only partially ordered datatypes.","ref":"RDF.XSD.Double.html#compare/2"},{"type":"function","title":"RDF.XSD.Double.datatype?/1","doc":"Checks if the given literal has datatype this or a datatype that is derived of it.","ref":"RDF.XSD.Double.html#datatype?/1"},{"type":"function","title":"RDF.XSD.Double.equal_value?/2","doc":"Checks if two datatype literals are equal in terms of the values of their value space.\n\nNon-`RDF.Literal`s  are tried to be coerced via `RDF.Literal.coerce/1` before comparison.\n\nReturns `nil` when the given arguments are not comparable as literals of this\ndatatype.\n\nInvalid literals are only considered equal in this relation when both have the exact same\ndatatype and the same attributes (lexical form, language etc.).\n\nImplementations can customize this equivalence relation via the `c:RDF.Literal.Datatype.do_equal_value_different_datatypes?/2`\nand `c:RDF.Literal.Datatype.do_equal_value_different_datatypes?/2` callbacks.","ref":"RDF.XSD.Double.html#equal_value?/2"},{"type":"function","title":"RDF.XSD.Double.lexical/1","doc":"Returns the lexical form of a `RDF.Literal` of this datatype.","ref":"RDF.XSD.Double.html#lexical/1"},{"type":"function","title":"RDF.XSD.Double.new/2","doc":"Creates a new `RDF.Literal` with this datatype and the given `value`.","ref":"RDF.XSD.Double.html#new/2"},{"type":"function","title":"RDF.XSD.Double.new!/2","doc":"Creates a new `RDF.Literal` with this datatype and the given `value` or fails when it is not valid.","ref":"RDF.XSD.Double.html#new!/2"},{"type":"function","title":"RDF.XSD.Double.update/3","doc":"Updates the value of a `RDF.Literal` without changing everything else.","ref":"RDF.XSD.Double.html#update/3"},{"type":"function","title":"RDF.XSD.Double.valid?/1","doc":"Determines if a `RDF.Literal` of this or a derived datatype has a proper value of its value space.","ref":"RDF.XSD.Double.html#valid?/1"},{"type":"function","title":"RDF.XSD.Double.value/1","doc":"Returns the value of a `RDF.Literal` of this or a derived datatype.","ref":"RDF.XSD.Double.html#value/1"},{"type":"type","title":"RDF.XSD.Double.invalid_value/0","doc":"","ref":"RDF.XSD.Double.html#t:invalid_value/0"},{"type":"type","title":"RDF.XSD.Double.special_values/0","doc":"","ref":"RDF.XSD.Double.html#t:special_values/0"},{"type":"type","title":"RDF.XSD.Double.t/0","doc":"","ref":"RDF.XSD.Double.html#t:t/0"},{"type":"type","title":"RDF.XSD.Double.valid_value/0","doc":"","ref":"RDF.XSD.Double.html#t:valid_value/0"},{"type":"type","title":"RDF.XSD.Double.value/0","doc":"","ref":"RDF.XSD.Double.html#t:value/0"},{"type":"module","title":"RDF.XSD.Float","doc":"`RDF.XSD.Datatype` for `xsd:float`.\n\nAlthough the XSD spec defines floats as a primitive we derive it here from `XSD.Double`\nwith any further constraints, since Erlang doesn't support 32-bit floats.\n\nSee:","ref":"RDF.XSD.Float.html"},{"type":"function","title":"RDF.XSD.Float.canonical/1","doc":"Produces the canonical representation of a `RDF.Literal` of this datatype.","ref":"RDF.XSD.Float.html#canonical/1"},{"type":"function","title":"RDF.XSD.Float.canonical?/1","doc":"Determines if the lexical form of a `RDF.Literal` of this datatype is the canonical form.","ref":"RDF.XSD.Float.html#canonical?/1"},{"type":"function","title":"RDF.XSD.Float.canonical_lexical/1","doc":"Returns the canonical lexical form of a `RDF.Literal` of this datatype.","ref":"RDF.XSD.Float.html#canonical_lexical/1"},{"type":"function","title":"RDF.XSD.Float.cast/1","doc":"Casts a datatype literal of one type into a datatype literal of another type.\n\nReturns `nil` when the given arguments are not castable into this datatype or when the given argument is an\ninvalid literal.\n\nImplementations define the casting for a given value with the `c:RDF.Literal.Datatype.do_cast/1` callback.","ref":"RDF.XSD.Float.html#cast/1"},{"type":"function","title":"RDF.XSD.Float.compare/2","doc":"Compares two `RDF.Literal`s.\n\nIf the first literal is greater than the second `:gt` is returned, if less than `:lt` is returned.\nIf both literal are equal `:eq` is returned.\nIf the literals can not be compared either `nil` is returned, when they generally can be compared\ndue to their datatype, or `:indeterminate` is returned, when the order of the given values is\nnot defined on only partially ordered datatypes.","ref":"RDF.XSD.Float.html#compare/2"},{"type":"function","title":"RDF.XSD.Float.datatype?/1","doc":"Checks if the given literal has datatype this or a datatype that is derived of it.","ref":"RDF.XSD.Float.html#datatype?/1"},{"type":"function","title":"RDF.XSD.Float.equal_value?/2","doc":"Checks if two datatype literals are equal in terms of the values of their value space.\n\nNon-`RDF.Literal`s  are tried to be coerced via `RDF.Literal.coerce/1` before comparison.\n\nReturns `nil` when the given arguments are not comparable as literals of this\ndatatype.\n\nInvalid literals are only considered equal in this relation when both have the exact same\ndatatype and the same attributes (lexical form, language etc.).\n\nImplementations can customize this equivalence relation via the `c:RDF.Literal.Datatype.do_equal_value_different_datatypes?/2`\nand `c:RDF.Literal.Datatype.do_equal_value_different_datatypes?/2` callbacks.","ref":"RDF.XSD.Float.html#equal_value?/2"},{"type":"function","title":"RDF.XSD.Float.lexical/1","doc":"Returns the lexical form of a `RDF.Literal` of this datatype.","ref":"RDF.XSD.Float.html#lexical/1"},{"type":"function","title":"RDF.XSD.Float.new/2","doc":"Creates a new `RDF.Literal` with this datatype and the given `value`.","ref":"RDF.XSD.Float.html#new/2"},{"type":"function","title":"RDF.XSD.Float.new!/2","doc":"Creates a new `RDF.Literal` with this datatype and the given `value` or fails when it is not valid.","ref":"RDF.XSD.Float.html#new!/2"},{"type":"function","title":"RDF.XSD.Float.update/3","doc":"Updates the value of a `RDF.Literal` without changing everything else.","ref":"RDF.XSD.Float.html#update/3"},{"type":"function","title":"RDF.XSD.Float.valid?/1","doc":"Determines if a `RDF.Literal` of this or a derived datatype has a proper value of its value space.","ref":"RDF.XSD.Float.html#valid?/1"},{"type":"function","title":"RDF.XSD.Float.value/1","doc":"Returns the value of a `RDF.Literal` of this or a derived datatype.","ref":"RDF.XSD.Float.html#value/1"},{"type":"type","title":"RDF.XSD.Float.invalid_value/0","doc":"","ref":"RDF.XSD.Float.html#t:invalid_value/0"},{"type":"type","title":"RDF.XSD.Float.t/0","doc":"","ref":"RDF.XSD.Float.html#t:t/0"},{"type":"type","title":"RDF.XSD.Float.valid_value/0","doc":"","ref":"RDF.XSD.Float.html#t:valid_value/0"},{"type":"type","title":"RDF.XSD.Float.value/0","doc":"","ref":"RDF.XSD.Float.html#t:value/0"},{"type":"module","title":"RDF.XSD.Int","doc":"`RDF.XSD.Datatype` for `xsd:int`.\n\nSee:","ref":"RDF.XSD.Int.html"},{"type":"function","title":"RDF.XSD.Int.canonical/1","doc":"Produces the canonical representation of a `RDF.Literal` of this datatype.","ref":"RDF.XSD.Int.html#canonical/1"},{"type":"function","title":"RDF.XSD.Int.canonical?/1","doc":"Determines if the lexical form of a `RDF.Literal` of this datatype is the canonical form.","ref":"RDF.XSD.Int.html#canonical?/1"},{"type":"function","title":"RDF.XSD.Int.canonical_lexical/1","doc":"Returns the canonical lexical form of a `RDF.Literal` of this datatype.","ref":"RDF.XSD.Int.html#canonical_lexical/1"},{"type":"function","title":"RDF.XSD.Int.cast/1","doc":"Casts a datatype literal of one type into a datatype literal of another type.\n\nReturns `nil` when the given arguments are not castable into this datatype or when the given argument is an\ninvalid literal.\n\nImplementations define the casting for a given value with the `c:RDF.Literal.Datatype.do_cast/1` callback.","ref":"RDF.XSD.Int.html#cast/1"},{"type":"function","title":"RDF.XSD.Int.compare/2","doc":"Compares two `RDF.Literal`s.\n\nIf the first literal is greater than the second `:gt` is returned, if less than `:lt` is returned.\nIf both literal are equal `:eq` is returned.\nIf the literals can not be compared either `nil` is returned, when they generally can be compared\ndue to their datatype, or `:indeterminate` is returned, when the order of the given values is\nnot defined on only partially ordered datatypes.","ref":"RDF.XSD.Int.html#compare/2"},{"type":"function","title":"RDF.XSD.Int.datatype?/1","doc":"Checks if the given literal has datatype this or a datatype that is derived of it.","ref":"RDF.XSD.Int.html#datatype?/1"},{"type":"function","title":"RDF.XSD.Int.equal_value?/2","doc":"Checks if two datatype literals are equal in terms of the values of their value space.\n\nNon-`RDF.Literal`s  are tried to be coerced via `RDF.Literal.coerce/1` before comparison.\n\nReturns `nil` when the given arguments are not comparable as literals of this\ndatatype.\n\nInvalid literals are only considered equal in this relation when both have the exact same\ndatatype and the same attributes (lexical form, language etc.).\n\nImplementations can customize this equivalence relation via the `c:RDF.Literal.Datatype.do_equal_value_different_datatypes?/2`\nand `c:RDF.Literal.Datatype.do_equal_value_different_datatypes?/2` callbacks.","ref":"RDF.XSD.Int.html#equal_value?/2"},{"type":"function","title":"RDF.XSD.Int.lexical/1","doc":"Returns the lexical form of a `RDF.Literal` of this datatype.","ref":"RDF.XSD.Int.html#lexical/1"},{"type":"function","title":"RDF.XSD.Int.new/2","doc":"Creates a new `RDF.Literal` with this datatype and the given `value`.","ref":"RDF.XSD.Int.html#new/2"},{"type":"function","title":"RDF.XSD.Int.new!/2","doc":"Creates a new `RDF.Literal` with this datatype and the given `value` or fails when it is not valid.","ref":"RDF.XSD.Int.html#new!/2"},{"type":"function","title":"RDF.XSD.Int.update/3","doc":"Updates the value of a `RDF.Literal` without changing everything else.","ref":"RDF.XSD.Int.html#update/3"},{"type":"function","title":"RDF.XSD.Int.valid?/1","doc":"Determines if a `RDF.Literal` of this or a derived datatype has a proper value of its value space.","ref":"RDF.XSD.Int.html#valid?/1"},{"type":"function","title":"RDF.XSD.Int.value/1","doc":"Returns the value of a `RDF.Literal` of this or a derived datatype.","ref":"RDF.XSD.Int.html#value/1"},{"type":"type","title":"RDF.XSD.Int.invalid_value/0","doc":"","ref":"RDF.XSD.Int.html#t:invalid_value/0"},{"type":"type","title":"RDF.XSD.Int.t/0","doc":"","ref":"RDF.XSD.Int.html#t:t/0"},{"type":"type","title":"RDF.XSD.Int.valid_value/0","doc":"","ref":"RDF.XSD.Int.html#t:valid_value/0"},{"type":"type","title":"RDF.XSD.Int.value/0","doc":"","ref":"RDF.XSD.Int.html#t:value/0"},{"type":"module","title":"RDF.XSD.Integer","doc":"`RDF.XSD.Datatype` for `xsd:integer`.\n\nAlthough the XSD spec defines integers as derived from `xsd:decimal` we implement\nit here as a primitive datatype for simplicity and performance reasons.\n\nSee:","ref":"RDF.XSD.Integer.html"},{"type":"function","title":"RDF.XSD.Integer.canonical/1","doc":"Produces the canonical representation of a `RDF.Literal` of this datatype.","ref":"RDF.XSD.Integer.html#canonical/1"},{"type":"function","title":"RDF.XSD.Integer.canonical?/1","doc":"Determines if the lexical form of a `RDF.Literal` of this datatype is the canonical form.","ref":"RDF.XSD.Integer.html#canonical?/1"},{"type":"function","title":"RDF.XSD.Integer.canonical_lexical/1","doc":"Returns the canonical lexical form of a `RDF.Literal` of this datatype.","ref":"RDF.XSD.Integer.html#canonical_lexical/1"},{"type":"function","title":"RDF.XSD.Integer.cast/1","doc":"Casts a datatype literal of one type into a datatype literal of another type.\n\nReturns `nil` when the given arguments are not castable into this datatype or when the given argument is an\ninvalid literal.\n\nImplementations define the casting for a given value with the `c:RDF.Literal.Datatype.do_cast/1` callback.","ref":"RDF.XSD.Integer.html#cast/1"},{"type":"function","title":"RDF.XSD.Integer.compare/2","doc":"Compares two `RDF.Literal`s.\n\nIf the first literal is greater than the second `:gt` is returned, if less than `:lt` is returned.\nIf both literal are equal `:eq` is returned.\nIf the literals can not be compared either `nil` is returned, when they generally can be compared\ndue to their datatype, or `:indeterminate` is returned, when the order of the given values is\nnot defined on only partially ordered datatypes.","ref":"RDF.XSD.Integer.html#compare/2"},{"type":"function","title":"RDF.XSD.Integer.datatype?/1","doc":"Checks if the given literal has datatype this or a datatype that is derived of it.","ref":"RDF.XSD.Integer.html#datatype?/1"},{"type":"function","title":"RDF.XSD.Integer.digit_count/1","doc":"The number of digits in the XML Schema canonical form of the literal value.","ref":"RDF.XSD.Integer.html#digit_count/1"},{"type":"function","title":"RDF.XSD.Integer.equal_value?/2","doc":"Checks if two datatype literals are equal in terms of the values of their value space.\n\nNon-`RDF.Literal`s  are tried to be coerced via `RDF.Literal.coerce/1` before comparison.\n\nReturns `nil` when the given arguments are not comparable as literals of this\ndatatype.\n\nInvalid literals are only considered equal in this relation when both have the exact same\ndatatype and the same attributes (lexical form, language etc.).\n\nImplementations can customize this equivalence relation via the `c:RDF.Literal.Datatype.do_equal_value_different_datatypes?/2`\nand `c:RDF.Literal.Datatype.do_equal_value_different_datatypes?/2` callbacks.","ref":"RDF.XSD.Integer.html#equal_value?/2"},{"type":"function","title":"RDF.XSD.Integer.lexical/1","doc":"Returns the lexical form of a `RDF.Literal` of this datatype.","ref":"RDF.XSD.Integer.html#lexical/1"},{"type":"function","title":"RDF.XSD.Integer.new/2","doc":"Creates a new `RDF.Literal` with this datatype and the given `value`.","ref":"RDF.XSD.Integer.html#new/2"},{"type":"function","title":"RDF.XSD.Integer.new!/2","doc":"Creates a new `RDF.Literal` with this datatype and the given `value` or fails when it is not valid.","ref":"RDF.XSD.Integer.html#new!/2"},{"type":"function","title":"RDF.XSD.Integer.update/3","doc":"Updates the value of a `RDF.Literal` without changing everything else.","ref":"RDF.XSD.Integer.html#update/3"},{"type":"function","title":"RDF.XSD.Integer.valid?/1","doc":"Determines if a `RDF.Literal` of this or a derived datatype has a proper value of its value space.","ref":"RDF.XSD.Integer.html#valid?/1"},{"type":"function","title":"RDF.XSD.Integer.value/1","doc":"Returns the value of a `RDF.Literal` of this or a derived datatype.","ref":"RDF.XSD.Integer.html#value/1"},{"type":"type","title":"RDF.XSD.Integer.invalid_value/0","doc":"","ref":"RDF.XSD.Integer.html#t:invalid_value/0"},{"type":"type","title":"RDF.XSD.Integer.t/0","doc":"","ref":"RDF.XSD.Integer.html#t:t/0"},{"type":"type","title":"RDF.XSD.Integer.valid_value/0","doc":"","ref":"RDF.XSD.Integer.html#t:valid_value/0"},{"type":"type","title":"RDF.XSD.Integer.value/0","doc":"","ref":"RDF.XSD.Integer.html#t:value/0"},{"type":"module","title":"RDF.XSD.Long","doc":"`RDF.XSD.Datatype` for `xsd:long`.\n\nSee:","ref":"RDF.XSD.Long.html"},{"type":"function","title":"RDF.XSD.Long.canonical/1","doc":"Produces the canonical representation of a `RDF.Literal` of this datatype.","ref":"RDF.XSD.Long.html#canonical/1"},{"type":"function","title":"RDF.XSD.Long.canonical?/1","doc":"Determines if the lexical form of a `RDF.Literal` of this datatype is the canonical form.","ref":"RDF.XSD.Long.html#canonical?/1"},{"type":"function","title":"RDF.XSD.Long.canonical_lexical/1","doc":"Returns the canonical lexical form of a `RDF.Literal` of this datatype.","ref":"RDF.XSD.Long.html#canonical_lexical/1"},{"type":"function","title":"RDF.XSD.Long.cast/1","doc":"Casts a datatype literal of one type into a datatype literal of another type.\n\nReturns `nil` when the given arguments are not castable into this datatype or when the given argument is an\ninvalid literal.\n\nImplementations define the casting for a given value with the `c:RDF.Literal.Datatype.do_cast/1` callback.","ref":"RDF.XSD.Long.html#cast/1"},{"type":"function","title":"RDF.XSD.Long.compare/2","doc":"Compares two `RDF.Literal`s.\n\nIf the first literal is greater than the second `:gt` is returned, if less than `:lt` is returned.\nIf both literal are equal `:eq` is returned.\nIf the literals can not be compared either `nil` is returned, when they generally can be compared\ndue to their datatype, or `:indeterminate` is returned, when the order of the given values is\nnot defined on only partially ordered datatypes.","ref":"RDF.XSD.Long.html#compare/2"},{"type":"function","title":"RDF.XSD.Long.datatype?/1","doc":"Checks if the given literal has datatype this or a datatype that is derived of it.","ref":"RDF.XSD.Long.html#datatype?/1"},{"type":"function","title":"RDF.XSD.Long.equal_value?/2","doc":"Checks if two datatype literals are equal in terms of the values of their value space.\n\nNon-`RDF.Literal`s  are tried to be coerced via `RDF.Literal.coerce/1` before comparison.\n\nReturns `nil` when the given arguments are not comparable as literals of this\ndatatype.\n\nInvalid literals are only considered equal in this relation when both have the exact same\ndatatype and the same attributes (lexical form, language etc.).\n\nImplementations can customize this equivalence relation via the `c:RDF.Literal.Datatype.do_equal_value_different_datatypes?/2`\nand `c:RDF.Literal.Datatype.do_equal_value_different_datatypes?/2` callbacks.","ref":"RDF.XSD.Long.html#equal_value?/2"},{"type":"function","title":"RDF.XSD.Long.lexical/1","doc":"Returns the lexical form of a `RDF.Literal` of this datatype.","ref":"RDF.XSD.Long.html#lexical/1"},{"type":"function","title":"RDF.XSD.Long.new/2","doc":"Creates a new `RDF.Literal` with this datatype and the given `value`.","ref":"RDF.XSD.Long.html#new/2"},{"type":"function","title":"RDF.XSD.Long.new!/2","doc":"Creates a new `RDF.Literal` with this datatype and the given `value` or fails when it is not valid.","ref":"RDF.XSD.Long.html#new!/2"},{"type":"function","title":"RDF.XSD.Long.update/3","doc":"Updates the value of a `RDF.Literal` without changing everything else.","ref":"RDF.XSD.Long.html#update/3"},{"type":"function","title":"RDF.XSD.Long.valid?/1","doc":"Determines if a `RDF.Literal` of this or a derived datatype has a proper value of its value space.","ref":"RDF.XSD.Long.html#valid?/1"},{"type":"function","title":"RDF.XSD.Long.value/1","doc":"Returns the value of a `RDF.Literal` of this or a derived datatype.","ref":"RDF.XSD.Long.html#value/1"},{"type":"type","title":"RDF.XSD.Long.invalid_value/0","doc":"","ref":"RDF.XSD.Long.html#t:invalid_value/0"},{"type":"type","title":"RDF.XSD.Long.t/0","doc":"","ref":"RDF.XSD.Long.html#t:t/0"},{"type":"type","title":"RDF.XSD.Long.valid_value/0","doc":"","ref":"RDF.XSD.Long.html#t:valid_value/0"},{"type":"type","title":"RDF.XSD.Long.value/0","doc":"","ref":"RDF.XSD.Long.html#t:value/0"},{"type":"module","title":"RDF.XSD.NegativeInteger","doc":"`RDF.XSD.Datatype` for `xsd:negativeInteger`.\n\nSee:","ref":"RDF.XSD.NegativeInteger.html"},{"type":"function","title":"RDF.XSD.NegativeInteger.canonical/1","doc":"Produces the canonical representation of a `RDF.Literal` of this datatype.","ref":"RDF.XSD.NegativeInteger.html#canonical/1"},{"type":"function","title":"RDF.XSD.NegativeInteger.canonical?/1","doc":"Determines if the lexical form of a `RDF.Literal` of this datatype is the canonical form.","ref":"RDF.XSD.NegativeInteger.html#canonical?/1"},{"type":"function","title":"RDF.XSD.NegativeInteger.canonical_lexical/1","doc":"Returns the canonical lexical form of a `RDF.Literal` of this datatype.","ref":"RDF.XSD.NegativeInteger.html#canonical_lexical/1"},{"type":"function","title":"RDF.XSD.NegativeInteger.cast/1","doc":"Casts a datatype literal of one type into a datatype literal of another type.\n\nReturns `nil` when the given arguments are not castable into this datatype or when the given argument is an\ninvalid literal.\n\nImplementations define the casting for a given value with the `c:RDF.Literal.Datatype.do_cast/1` callback.","ref":"RDF.XSD.NegativeInteger.html#cast/1"},{"type":"function","title":"RDF.XSD.NegativeInteger.compare/2","doc":"Compares two `RDF.Literal`s.\n\nIf the first literal is greater than the second `:gt` is returned, if less than `:lt` is returned.\nIf both literal are equal `:eq` is returned.\nIf the literals can not be compared either `nil` is returned, when they generally can be compared\ndue to their datatype, or `:indeterminate` is returned, when the order of the given values is\nnot defined on only partially ordered datatypes.","ref":"RDF.XSD.NegativeInteger.html#compare/2"},{"type":"function","title":"RDF.XSD.NegativeInteger.datatype?/1","doc":"Checks if the given literal has datatype this or a datatype that is derived of it.","ref":"RDF.XSD.NegativeInteger.html#datatype?/1"},{"type":"function","title":"RDF.XSD.NegativeInteger.equal_value?/2","doc":"Checks if two datatype literals are equal in terms of the values of their value space.\n\nNon-`RDF.Literal`s  are tried to be coerced via `RDF.Literal.coerce/1` before comparison.\n\nReturns `nil` when the given arguments are not comparable as literals of this\ndatatype.\n\nInvalid literals are only considered equal in this relation when both have the exact same\ndatatype and the same attributes (lexical form, language etc.).\n\nImplementations can customize this equivalence relation via the `c:RDF.Literal.Datatype.do_equal_value_different_datatypes?/2`\nand `c:RDF.Literal.Datatype.do_equal_value_different_datatypes?/2` callbacks.","ref":"RDF.XSD.NegativeInteger.html#equal_value?/2"},{"type":"function","title":"RDF.XSD.NegativeInteger.lexical/1","doc":"Returns the lexical form of a `RDF.Literal` of this datatype.","ref":"RDF.XSD.NegativeInteger.html#lexical/1"},{"type":"function","title":"RDF.XSD.NegativeInteger.new/2","doc":"Creates a new `RDF.Literal` with this datatype and the given `value`.","ref":"RDF.XSD.NegativeInteger.html#new/2"},{"type":"function","title":"RDF.XSD.NegativeInteger.new!/2","doc":"Creates a new `RDF.Literal` with this datatype and the given `value` or fails when it is not valid.","ref":"RDF.XSD.NegativeInteger.html#new!/2"},{"type":"function","title":"RDF.XSD.NegativeInteger.update/3","doc":"Updates the value of a `RDF.Literal` without changing everything else.","ref":"RDF.XSD.NegativeInteger.html#update/3"},{"type":"function","title":"RDF.XSD.NegativeInteger.valid?/1","doc":"Determines if a `RDF.Literal` of this or a derived datatype has a proper value of its value space.","ref":"RDF.XSD.NegativeInteger.html#valid?/1"},{"type":"function","title":"RDF.XSD.NegativeInteger.value/1","doc":"Returns the value of a `RDF.Literal` of this or a derived datatype.","ref":"RDF.XSD.NegativeInteger.html#value/1"},{"type":"type","title":"RDF.XSD.NegativeInteger.invalid_value/0","doc":"","ref":"RDF.XSD.NegativeInteger.html#t:invalid_value/0"},{"type":"type","title":"RDF.XSD.NegativeInteger.t/0","doc":"","ref":"RDF.XSD.NegativeInteger.html#t:t/0"},{"type":"type","title":"RDF.XSD.NegativeInteger.valid_value/0","doc":"","ref":"RDF.XSD.NegativeInteger.html#t:valid_value/0"},{"type":"type","title":"RDF.XSD.NegativeInteger.value/0","doc":"","ref":"RDF.XSD.NegativeInteger.html#t:value/0"},{"type":"module","title":"RDF.XSD.NonNegativeInteger","doc":"`RDF.XSD.Datatype` for `xsd:nonNegativeInteger`.\n\nSee:","ref":"RDF.XSD.NonNegativeInteger.html"},{"type":"function","title":"RDF.XSD.NonNegativeInteger.canonical/1","doc":"Produces the canonical representation of a `RDF.Literal` of this datatype.","ref":"RDF.XSD.NonNegativeInteger.html#canonical/1"},{"type":"function","title":"RDF.XSD.NonNegativeInteger.canonical?/1","doc":"Determines if the lexical form of a `RDF.Literal` of this datatype is the canonical form.","ref":"RDF.XSD.NonNegativeInteger.html#canonical?/1"},{"type":"function","title":"RDF.XSD.NonNegativeInteger.canonical_lexical/1","doc":"Returns the canonical lexical form of a `RDF.Literal` of this datatype.","ref":"RDF.XSD.NonNegativeInteger.html#canonical_lexical/1"},{"type":"function","title":"RDF.XSD.NonNegativeInteger.cast/1","doc":"Casts a datatype literal of one type into a datatype literal of another type.\n\nReturns `nil` when the given arguments are not castable into this datatype or when the given argument is an\ninvalid literal.\n\nImplementations define the casting for a given value with the `c:RDF.Literal.Datatype.do_cast/1` callback.","ref":"RDF.XSD.NonNegativeInteger.html#cast/1"},{"type":"function","title":"RDF.XSD.NonNegativeInteger.compare/2","doc":"Compares two `RDF.Literal`s.\n\nIf the first literal is greater than the second `:gt` is returned, if less than `:lt` is returned.\nIf both literal are equal `:eq` is returned.\nIf the literals can not be compared either `nil` is returned, when they generally can be compared\ndue to their datatype, or `:indeterminate` is returned, when the order of the given values is\nnot defined on only partially ordered datatypes.","ref":"RDF.XSD.NonNegativeInteger.html#compare/2"},{"type":"function","title":"RDF.XSD.NonNegativeInteger.datatype?/1","doc":"Checks if the given literal has datatype this or a datatype that is derived of it.","ref":"RDF.XSD.NonNegativeInteger.html#datatype?/1"},{"type":"function","title":"RDF.XSD.NonNegativeInteger.equal_value?/2","doc":"Checks if two datatype literals are equal in terms of the values of their value space.\n\nNon-`RDF.Literal`s  are tried to be coerced via `RDF.Literal.coerce/1` before comparison.\n\nReturns `nil` when the given arguments are not comparable as literals of this\ndatatype.\n\nInvalid literals are only considered equal in this relation when both have the exact same\ndatatype and the same attributes (lexical form, language etc.).\n\nImplementations can customize this equivalence relation via the `c:RDF.Literal.Datatype.do_equal_value_different_datatypes?/2`\nand `c:RDF.Literal.Datatype.do_equal_value_different_datatypes?/2` callbacks.","ref":"RDF.XSD.NonNegativeInteger.html#equal_value?/2"},{"type":"function","title":"RDF.XSD.NonNegativeInteger.lexical/1","doc":"Returns the lexical form of a `RDF.Literal` of this datatype.","ref":"RDF.XSD.NonNegativeInteger.html#lexical/1"},{"type":"function","title":"RDF.XSD.NonNegativeInteger.new/2","doc":"Creates a new `RDF.Literal` with this datatype and the given `value`.","ref":"RDF.XSD.NonNegativeInteger.html#new/2"},{"type":"function","title":"RDF.XSD.NonNegativeInteger.new!/2","doc":"Creates a new `RDF.Literal` with this datatype and the given `value` or fails when it is not valid.","ref":"RDF.XSD.NonNegativeInteger.html#new!/2"},{"type":"function","title":"RDF.XSD.NonNegativeInteger.update/3","doc":"Updates the value of a `RDF.Literal` without changing everything else.","ref":"RDF.XSD.NonNegativeInteger.html#update/3"},{"type":"function","title":"RDF.XSD.NonNegativeInteger.valid?/1","doc":"Determines if a `RDF.Literal` of this or a derived datatype has a proper value of its value space.","ref":"RDF.XSD.NonNegativeInteger.html#valid?/1"},{"type":"function","title":"RDF.XSD.NonNegativeInteger.value/1","doc":"Returns the value of a `RDF.Literal` of this or a derived datatype.","ref":"RDF.XSD.NonNegativeInteger.html#value/1"},{"type":"type","title":"RDF.XSD.NonNegativeInteger.invalid_value/0","doc":"","ref":"RDF.XSD.NonNegativeInteger.html#t:invalid_value/0"},{"type":"type","title":"RDF.XSD.NonNegativeInteger.t/0","doc":"","ref":"RDF.XSD.NonNegativeInteger.html#t:t/0"},{"type":"type","title":"RDF.XSD.NonNegativeInteger.valid_value/0","doc":"","ref":"RDF.XSD.NonNegativeInteger.html#t:valid_value/0"},{"type":"type","title":"RDF.XSD.NonNegativeInteger.value/0","doc":"","ref":"RDF.XSD.NonNegativeInteger.html#t:value/0"},{"type":"module","title":"RDF.XSD.NonPositiveInteger","doc":"`RDF.XSD.Datatype` for `xsd:nonPositiveInteger`.\n\nSee:","ref":"RDF.XSD.NonPositiveInteger.html"},{"type":"function","title":"RDF.XSD.NonPositiveInteger.canonical/1","doc":"Produces the canonical representation of a `RDF.Literal` of this datatype.","ref":"RDF.XSD.NonPositiveInteger.html#canonical/1"},{"type":"function","title":"RDF.XSD.NonPositiveInteger.canonical?/1","doc":"Determines if the lexical form of a `RDF.Literal` of this datatype is the canonical form.","ref":"RDF.XSD.NonPositiveInteger.html#canonical?/1"},{"type":"function","title":"RDF.XSD.NonPositiveInteger.canonical_lexical/1","doc":"Returns the canonical lexical form of a `RDF.Literal` of this datatype.","ref":"RDF.XSD.NonPositiveInteger.html#canonical_lexical/1"},{"type":"function","title":"RDF.XSD.NonPositiveInteger.cast/1","doc":"Casts a datatype literal of one type into a datatype literal of another type.\n\nReturns `nil` when the given arguments are not castable into this datatype or when the given argument is an\ninvalid literal.\n\nImplementations define the casting for a given value with the `c:RDF.Literal.Datatype.do_cast/1` callback.","ref":"RDF.XSD.NonPositiveInteger.html#cast/1"},{"type":"function","title":"RDF.XSD.NonPositiveInteger.compare/2","doc":"Compares two `RDF.Literal`s.\n\nIf the first literal is greater than the second `:gt` is returned, if less than `:lt` is returned.\nIf both literal are equal `:eq` is returned.\nIf the literals can not be compared either `nil` is returned, when they generally can be compared\ndue to their datatype, or `:indeterminate` is returned, when the order of the given values is\nnot defined on only partially ordered datatypes.","ref":"RDF.XSD.NonPositiveInteger.html#compare/2"},{"type":"function","title":"RDF.XSD.NonPositiveInteger.datatype?/1","doc":"Checks if the given literal has datatype this or a datatype that is derived of it.","ref":"RDF.XSD.NonPositiveInteger.html#datatype?/1"},{"type":"function","title":"RDF.XSD.NonPositiveInteger.equal_value?/2","doc":"Checks if two datatype literals are equal in terms of the values of their value space.\n\nNon-`RDF.Literal`s  are tried to be coerced via `RDF.Literal.coerce/1` before comparison.\n\nReturns `nil` when the given arguments are not comparable as literals of this\ndatatype.\n\nInvalid literals are only considered equal in this relation when both have the exact same\ndatatype and the same attributes (lexical form, language etc.).\n\nImplementations can customize this equivalence relation via the `c:RDF.Literal.Datatype.do_equal_value_different_datatypes?/2`\nand `c:RDF.Literal.Datatype.do_equal_value_different_datatypes?/2` callbacks.","ref":"RDF.XSD.NonPositiveInteger.html#equal_value?/2"},{"type":"function","title":"RDF.XSD.NonPositiveInteger.lexical/1","doc":"Returns the lexical form of a `RDF.Literal` of this datatype.","ref":"RDF.XSD.NonPositiveInteger.html#lexical/1"},{"type":"function","title":"RDF.XSD.NonPositiveInteger.new/2","doc":"Creates a new `RDF.Literal` with this datatype and the given `value`.","ref":"RDF.XSD.NonPositiveInteger.html#new/2"},{"type":"function","title":"RDF.XSD.NonPositiveInteger.new!/2","doc":"Creates a new `RDF.Literal` with this datatype and the given `value` or fails when it is not valid.","ref":"RDF.XSD.NonPositiveInteger.html#new!/2"},{"type":"function","title":"RDF.XSD.NonPositiveInteger.update/3","doc":"Updates the value of a `RDF.Literal` without changing everything else.","ref":"RDF.XSD.NonPositiveInteger.html#update/3"},{"type":"function","title":"RDF.XSD.NonPositiveInteger.valid?/1","doc":"Determines if a `RDF.Literal` of this or a derived datatype has a proper value of its value space.","ref":"RDF.XSD.NonPositiveInteger.html#valid?/1"},{"type":"function","title":"RDF.XSD.NonPositiveInteger.value/1","doc":"Returns the value of a `RDF.Literal` of this or a derived datatype.","ref":"RDF.XSD.NonPositiveInteger.html#value/1"},{"type":"type","title":"RDF.XSD.NonPositiveInteger.invalid_value/0","doc":"","ref":"RDF.XSD.NonPositiveInteger.html#t:invalid_value/0"},{"type":"type","title":"RDF.XSD.NonPositiveInteger.t/0","doc":"","ref":"RDF.XSD.NonPositiveInteger.html#t:t/0"},{"type":"type","title":"RDF.XSD.NonPositiveInteger.valid_value/0","doc":"","ref":"RDF.XSD.NonPositiveInteger.html#t:valid_value/0"},{"type":"type","title":"RDF.XSD.NonPositiveInteger.value/0","doc":"","ref":"RDF.XSD.NonPositiveInteger.html#t:value/0"},{"type":"module","title":"RDF.XSD.Numeric","doc":"Collection of functions for numeric literals.","ref":"RDF.XSD.Numeric.html"},{"type":"function","title":"RDF.XSD.Numeric.abs/1","doc":"Returns the absolute value of a numeric literal.\n\nIf the given argument is not a numeric literal or a value which\ncan be coerced into a numeric literal, `nil` is returned.\n\nsee","ref":"RDF.XSD.Numeric.html#abs/1"},{"type":"function","title":"RDF.XSD.Numeric.add/2","doc":"Adds two numeric literals.\n\nFor `xsd:float` or `xsd:double` values, if one of the operands is a zero or a\nfinite number and the other is INF or -INF, INF or -INF is returned. If both\noperands are INF, INF is returned. If both operands are -INF, -INF is returned.\nIf one of the operands is INF and the other is -INF, NaN is returned.\n\nIf one of the given arguments is not a numeric literal or a value which\ncan be coerced into a numeric literal, `nil` is returned.\n\nsee","ref":"RDF.XSD.Numeric.html#add/2"},{"type":"function","title":"RDF.XSD.Numeric.ceil/1","doc":"Rounds a numeric literal upwards to a whole number literal.\n\nIf the given argument is not a numeric literal or a value which\ncan be coerced into a numeric literal, `nil` is returned.\n\nsee","ref":"RDF.XSD.Numeric.html#ceil/1"},{"type":"function","title":"RDF.XSD.Numeric.datatype?/1","doc":"","ref":"RDF.XSD.Numeric.html#datatype?/1"},{"type":"function","title":"RDF.XSD.Numeric.divide/2","doc":"Divides two numeric literals.\n\nFor `xsd:float` and `xsd:double` operands, floating point division is performed\nas specified in [IEEE 754-2008]. A positive number divided by positive zero\nreturns INF. A negative number divided by positive zero returns -INF. Division\nby negative zero returns -INF and INF, respectively. Positive or negative zero\ndivided by positive or negative zero returns NaN. Also, INF or -INF divided by\nINF or -INF returns NaN.\n\nIf one of the given arguments is not a numeric literal or a value which\ncan be coerced into a numeric literal, `nil` is returned.\n\n`nil` is also returned for `xsd:decimal` and `xsd:integer` operands, if the\ndivisor is (positive or negative) zero.\n\nsee","ref":"RDF.XSD.Numeric.html#divide/2"},{"type":"function","title":"RDF.XSD.Numeric.floor/1","doc":"Rounds a numeric literal downwards to a whole number literal.\n\nIf the given argument is not a numeric literal or a value which\ncan be coerced into a numeric literal, `nil` is returned.\n\nsee","ref":"RDF.XSD.Numeric.html#floor/1"},{"type":"function","title":"RDF.XSD.Numeric.multiply/2","doc":"Multiplies two numeric literals.\n\nFor `xsd:float` or `xsd:double` values, if one of the operands is a zero and\nthe other is an infinity, NaN is returned. If one of the operands is a non-zero\nnumber and the other is an infinity, an infinity with the appropriate sign is\nreturned.\n\nIf one of the given arguments is not a numeric literal or a value which\ncan be coerced into a numeric literal, `nil` is returned.\n\nsee","ref":"RDF.XSD.Numeric.html#multiply/2"},{"type":"function","title":"RDF.XSD.Numeric.negative_zero?/1","doc":"","ref":"RDF.XSD.Numeric.html#negative_zero?/1"},{"type":"function","title":"RDF.XSD.Numeric.round/2","doc":"Rounds a value to a specified number of decimal places, rounding upwards if two such values are equally near.\n\nThe function returns the nearest (that is, numerically closest) value to the\ngiven literal value that is a multiple of ten to the power of minus `precision`.\nIf two such values are equally near (for example, if the fractional part in the\nliteral value is exactly .5), the function returns the one that is closest to\npositive infinity.\n\nIf the given argument is not a numeric literal or a value which\ncan be coerced into a numeric literal, `nil` is returned.\n\nsee","ref":"RDF.XSD.Numeric.html#round/2"},{"type":"function","title":"RDF.XSD.Numeric.subtract/2","doc":"Subtracts two numeric literals.\n\nFor `xsd:float` or `xsd:double` values, if one of the operands is a zero or a\nfinite number and the other is INF or -INF, an infinity of the appropriate sign\nis returned. If both operands are INF or -INF, NaN is returned. If one of the\noperands is INF and the other is -INF, an infinity of the appropriate sign is\nreturned.\n\nIf one of the given arguments is not a numeric literal or a value which\ncan be coerced into a numeric literal, `nil` is returned.\n\nsee","ref":"RDF.XSD.Numeric.html#subtract/2"},{"type":"function","title":"RDF.XSD.Numeric.zero?/1","doc":"","ref":"RDF.XSD.Numeric.html#zero?/1"},{"type":"type","title":"RDF.XSD.Numeric.t/0","doc":"","ref":"RDF.XSD.Numeric.html#t:t/0"},{"type":"module","title":"RDF.XSD.PositiveInteger","doc":"`RDF.XSD.Datatype` for `xsd:positiveInteger`.\n\nSee:","ref":"RDF.XSD.PositiveInteger.html"},{"type":"function","title":"RDF.XSD.PositiveInteger.canonical/1","doc":"Produces the canonical representation of a `RDF.Literal` of this datatype.","ref":"RDF.XSD.PositiveInteger.html#canonical/1"},{"type":"function","title":"RDF.XSD.PositiveInteger.canonical?/1","doc":"Determines if the lexical form of a `RDF.Literal` of this datatype is the canonical form.","ref":"RDF.XSD.PositiveInteger.html#canonical?/1"},{"type":"function","title":"RDF.XSD.PositiveInteger.canonical_lexical/1","doc":"Returns the canonical lexical form of a `RDF.Literal` of this datatype.","ref":"RDF.XSD.PositiveInteger.html#canonical_lexical/1"},{"type":"function","title":"RDF.XSD.PositiveInteger.cast/1","doc":"Casts a datatype literal of one type into a datatype literal of another type.\n\nReturns `nil` when the given arguments are not castable into this datatype or when the given argument is an\ninvalid literal.\n\nImplementations define the casting for a given value with the `c:RDF.Literal.Datatype.do_cast/1` callback.","ref":"RDF.XSD.PositiveInteger.html#cast/1"},{"type":"function","title":"RDF.XSD.PositiveInteger.compare/2","doc":"Compares two `RDF.Literal`s.\n\nIf the first literal is greater than the second `:gt` is returned, if less than `:lt` is returned.\nIf both literal are equal `:eq` is returned.\nIf the literals can not be compared either `nil` is returned, when they generally can be compared\ndue to their datatype, or `:indeterminate` is returned, when the order of the given values is\nnot defined on only partially ordered datatypes.","ref":"RDF.XSD.PositiveInteger.html#compare/2"},{"type":"function","title":"RDF.XSD.PositiveInteger.datatype?/1","doc":"Checks if the given literal has datatype this or a datatype that is derived of it.","ref":"RDF.XSD.PositiveInteger.html#datatype?/1"},{"type":"function","title":"RDF.XSD.PositiveInteger.equal_value?/2","doc":"Checks if two datatype literals are equal in terms of the values of their value space.\n\nNon-`RDF.Literal`s  are tried to be coerced via `RDF.Literal.coerce/1` before comparison.\n\nReturns `nil` when the given arguments are not comparable as literals of this\ndatatype.\n\nInvalid literals are only considered equal in this relation when both have the exact same\ndatatype and the same attributes (lexical form, language etc.).\n\nImplementations can customize this equivalence relation via the `c:RDF.Literal.Datatype.do_equal_value_different_datatypes?/2`\nand `c:RDF.Literal.Datatype.do_equal_value_different_datatypes?/2` callbacks.","ref":"RDF.XSD.PositiveInteger.html#equal_value?/2"},{"type":"function","title":"RDF.XSD.PositiveInteger.lexical/1","doc":"Returns the lexical form of a `RDF.Literal` of this datatype.","ref":"RDF.XSD.PositiveInteger.html#lexical/1"},{"type":"function","title":"RDF.XSD.PositiveInteger.new/2","doc":"Creates a new `RDF.Literal` with this datatype and the given `value`.","ref":"RDF.XSD.PositiveInteger.html#new/2"},{"type":"function","title":"RDF.XSD.PositiveInteger.new!/2","doc":"Creates a new `RDF.Literal` with this datatype and the given `value` or fails when it is not valid.","ref":"RDF.XSD.PositiveInteger.html#new!/2"},{"type":"function","title":"RDF.XSD.PositiveInteger.update/3","doc":"Updates the value of a `RDF.Literal` without changing everything else.","ref":"RDF.XSD.PositiveInteger.html#update/3"},{"type":"function","title":"RDF.XSD.PositiveInteger.valid?/1","doc":"Determines if a `RDF.Literal` of this or a derived datatype has a proper value of its value space.","ref":"RDF.XSD.PositiveInteger.html#valid?/1"},{"type":"function","title":"RDF.XSD.PositiveInteger.value/1","doc":"Returns the value of a `RDF.Literal` of this or a derived datatype.","ref":"RDF.XSD.PositiveInteger.html#value/1"},{"type":"type","title":"RDF.XSD.PositiveInteger.invalid_value/0","doc":"","ref":"RDF.XSD.PositiveInteger.html#t:invalid_value/0"},{"type":"type","title":"RDF.XSD.PositiveInteger.t/0","doc":"","ref":"RDF.XSD.PositiveInteger.html#t:t/0"},{"type":"type","title":"RDF.XSD.PositiveInteger.valid_value/0","doc":"","ref":"RDF.XSD.PositiveInteger.html#t:valid_value/0"},{"type":"type","title":"RDF.XSD.PositiveInteger.value/0","doc":"","ref":"RDF.XSD.PositiveInteger.html#t:value/0"},{"type":"module","title":"RDF.XSD.Short","doc":"`RDF.XSD.Datatype` for `xsd:short`.\n\nSee:","ref":"RDF.XSD.Short.html"},{"type":"function","title":"RDF.XSD.Short.canonical/1","doc":"Produces the canonical representation of a `RDF.Literal` of this datatype.","ref":"RDF.XSD.Short.html#canonical/1"},{"type":"function","title":"RDF.XSD.Short.canonical?/1","doc":"Determines if the lexical form of a `RDF.Literal` of this datatype is the canonical form.","ref":"RDF.XSD.Short.html#canonical?/1"},{"type":"function","title":"RDF.XSD.Short.canonical_lexical/1","doc":"Returns the canonical lexical form of a `RDF.Literal` of this datatype.","ref":"RDF.XSD.Short.html#canonical_lexical/1"},{"type":"function","title":"RDF.XSD.Short.cast/1","doc":"Casts a datatype literal of one type into a datatype literal of another type.\n\nReturns `nil` when the given arguments are not castable into this datatype or when the given argument is an\ninvalid literal.\n\nImplementations define the casting for a given value with the `c:RDF.Literal.Datatype.do_cast/1` callback.","ref":"RDF.XSD.Short.html#cast/1"},{"type":"function","title":"RDF.XSD.Short.compare/2","doc":"Compares two `RDF.Literal`s.\n\nIf the first literal is greater than the second `:gt` is returned, if less than `:lt` is returned.\nIf both literal are equal `:eq` is returned.\nIf the literals can not be compared either `nil` is returned, when they generally can be compared\ndue to their datatype, or `:indeterminate` is returned, when the order of the given values is\nnot defined on only partially ordered datatypes.","ref":"RDF.XSD.Short.html#compare/2"},{"type":"function","title":"RDF.XSD.Short.datatype?/1","doc":"Checks if the given literal has datatype this or a datatype that is derived of it.","ref":"RDF.XSD.Short.html#datatype?/1"},{"type":"function","title":"RDF.XSD.Short.equal_value?/2","doc":"Checks if two datatype literals are equal in terms of the values of their value space.\n\nNon-`RDF.Literal`s  are tried to be coerced via `RDF.Literal.coerce/1` before comparison.\n\nReturns `nil` when the given arguments are not comparable as literals of this\ndatatype.\n\nInvalid literals are only considered equal in this relation when both have the exact same\ndatatype and the same attributes (lexical form, language etc.).\n\nImplementations can customize this equivalence relation via the `c:RDF.Literal.Datatype.do_equal_value_different_datatypes?/2`\nand `c:RDF.Literal.Datatype.do_equal_value_different_datatypes?/2` callbacks.","ref":"RDF.XSD.Short.html#equal_value?/2"},{"type":"function","title":"RDF.XSD.Short.lexical/1","doc":"Returns the lexical form of a `RDF.Literal` of this datatype.","ref":"RDF.XSD.Short.html#lexical/1"},{"type":"function","title":"RDF.XSD.Short.new/2","doc":"Creates a new `RDF.Literal` with this datatype and the given `value`.","ref":"RDF.XSD.Short.html#new/2"},{"type":"function","title":"RDF.XSD.Short.new!/2","doc":"Creates a new `RDF.Literal` with this datatype and the given `value` or fails when it is not valid.","ref":"RDF.XSD.Short.html#new!/2"},{"type":"function","title":"RDF.XSD.Short.update/3","doc":"Updates the value of a `RDF.Literal` without changing everything else.","ref":"RDF.XSD.Short.html#update/3"},{"type":"function","title":"RDF.XSD.Short.valid?/1","doc":"Determines if a `RDF.Literal` of this or a derived datatype has a proper value of its value space.","ref":"RDF.XSD.Short.html#valid?/1"},{"type":"function","title":"RDF.XSD.Short.value/1","doc":"Returns the value of a `RDF.Literal` of this or a derived datatype.","ref":"RDF.XSD.Short.html#value/1"},{"type":"type","title":"RDF.XSD.Short.invalid_value/0","doc":"","ref":"RDF.XSD.Short.html#t:invalid_value/0"},{"type":"type","title":"RDF.XSD.Short.t/0","doc":"","ref":"RDF.XSD.Short.html#t:t/0"},{"type":"type","title":"RDF.XSD.Short.valid_value/0","doc":"","ref":"RDF.XSD.Short.html#t:valid_value/0"},{"type":"type","title":"RDF.XSD.Short.value/0","doc":"","ref":"RDF.XSD.Short.html#t:value/0"},{"type":"module","title":"RDF.XSD.String","doc":"`RDF.XSD.Datatype` for `xsd:string`.\n\nSee:","ref":"RDF.XSD.String.html"},{"type":"function","title":"RDF.XSD.String.canonical/1","doc":"Produces the canonical representation of a `RDF.Literal` of this datatype.","ref":"RDF.XSD.String.html#canonical/1"},{"type":"function","title":"RDF.XSD.String.canonical?/1","doc":"Determines if the lexical form of a `RDF.Literal` of this datatype is the canonical form.","ref":"RDF.XSD.String.html#canonical?/1"},{"type":"function","title":"RDF.XSD.String.canonical_lexical/1","doc":"Returns the canonical lexical form of a `RDF.Literal` of this datatype.","ref":"RDF.XSD.String.html#canonical_lexical/1"},{"type":"function","title":"RDF.XSD.String.cast/1","doc":"Casts a datatype literal of one type into a datatype literal of another type.\n\nReturns `nil` when the given arguments are not castable into this datatype or when the given argument is an\ninvalid literal.\n\nImplementations define the casting for a given value with the `c:RDF.Literal.Datatype.do_cast/1` callback.","ref":"RDF.XSD.String.html#cast/1"},{"type":"function","title":"RDF.XSD.String.compare/2","doc":"Compares two `RDF.Literal`s.\n\nIf the first literal is greater than the second `:gt` is returned, if less than `:lt` is returned.\nIf both literal are equal `:eq` is returned.\nIf the literals can not be compared either `nil` is returned, when they generally can be compared\ndue to their datatype, or `:indeterminate` is returned, when the order of the given values is\nnot defined on only partially ordered datatypes.","ref":"RDF.XSD.String.html#compare/2"},{"type":"function","title":"RDF.XSD.String.datatype?/1","doc":"Checks if the given literal has datatype this or a datatype that is derived of it.","ref":"RDF.XSD.String.html#datatype?/1"},{"type":"function","title":"RDF.XSD.String.equal_value?/2","doc":"Checks if two datatype literals are equal in terms of the values of their value space.\n\nNon-`RDF.Literal`s  are tried to be coerced via `RDF.Literal.coerce/1` before comparison.\n\nReturns `nil` when the given arguments are not comparable as literals of this\ndatatype.\n\nInvalid literals are only considered equal in this relation when both have the exact same\ndatatype and the same attributes (lexical form, language etc.).\n\nImplementations can customize this equivalence relation via the `c:RDF.Literal.Datatype.do_equal_value_different_datatypes?/2`\nand `c:RDF.Literal.Datatype.do_equal_value_different_datatypes?/2` callbacks.","ref":"RDF.XSD.String.html#equal_value?/2"},{"type":"function","title":"RDF.XSD.String.lexical/1","doc":"Returns the lexical form of a `RDF.Literal` of this datatype.","ref":"RDF.XSD.String.html#lexical/1"},{"type":"function","title":"RDF.XSD.String.new/2","doc":"Creates a new `RDF.Literal` with this datatype and the given `value`.","ref":"RDF.XSD.String.html#new/2"},{"type":"function","title":"RDF.XSD.String.new!/2","doc":"Creates a new `RDF.Literal` with this datatype and the given `value` or fails when it is not valid.","ref":"RDF.XSD.String.html#new!/2"},{"type":"function","title":"RDF.XSD.String.update/3","doc":"Updates the value of a `RDF.Literal` without changing everything else.","ref":"RDF.XSD.String.html#update/3"},{"type":"function","title":"RDF.XSD.String.valid?/1","doc":"Determines if a `RDF.Literal` of this or a derived datatype has a proper value of its value space.","ref":"RDF.XSD.String.html#valid?/1"},{"type":"function","title":"RDF.XSD.String.value/1","doc":"Returns the value of a `RDF.Literal` of this or a derived datatype.","ref":"RDF.XSD.String.html#value/1"},{"type":"type","title":"RDF.XSD.String.invalid_value/0","doc":"","ref":"RDF.XSD.String.html#t:invalid_value/0"},{"type":"type","title":"RDF.XSD.String.t/0","doc":"","ref":"RDF.XSD.String.html#t:t/0"},{"type":"type","title":"RDF.XSD.String.valid_value/0","doc":"","ref":"RDF.XSD.String.html#t:valid_value/0"},{"type":"type","title":"RDF.XSD.String.value/0","doc":"","ref":"RDF.XSD.String.html#t:value/0"},{"type":"module","title":"RDF.XSD.Time","doc":"`RDF.XSD.Datatype` for `xsd:time`.\n\nOptions:\n\n- `tz`: this allows to specify a timezone which is not supported by Elixir's `Time` struct; note,\n  that it will also overwrite an eventually already present timezone in an input lexical\n\nSee:","ref":"RDF.XSD.Time.html"},{"type":"function","title":"RDF.XSD.Time.canonical/1","doc":"Produces the canonical representation of a `RDF.Literal` of this datatype.","ref":"RDF.XSD.Time.html#canonical/1"},{"type":"function","title":"RDF.XSD.Time.canonical?/1","doc":"Determines if the lexical form of a `RDF.Literal` of this datatype is the canonical form.","ref":"RDF.XSD.Time.html#canonical?/1"},{"type":"function","title":"RDF.XSD.Time.canonical_lexical/1","doc":"Returns the canonical lexical form of a `RDF.Literal` of this datatype.","ref":"RDF.XSD.Time.html#canonical_lexical/1"},{"type":"function","title":"RDF.XSD.Time.canonical_lexical_with_zone/1","doc":"Converts a time literal to a canonical string, preserving the zone information.","ref":"RDF.XSD.Time.html#canonical_lexical_with_zone/1"},{"type":"function","title":"RDF.XSD.Time.cast/1","doc":"Casts a datatype literal of one type into a datatype literal of another type.\n\nReturns `nil` when the given arguments are not castable into this datatype or when the given argument is an\ninvalid literal.\n\nImplementations define the casting for a given value with the `c:RDF.Literal.Datatype.do_cast/1` callback.","ref":"RDF.XSD.Time.html#cast/1"},{"type":"function","title":"RDF.XSD.Time.compare/2","doc":"Compares two `RDF.Literal`s.\n\nIf the first literal is greater than the second `:gt` is returned, if less than `:lt` is returned.\nIf both literal are equal `:eq` is returned.\nIf the literals can not be compared either `nil` is returned, when they generally can be compared\ndue to their datatype, or `:indeterminate` is returned, when the order of the given values is\nnot defined on only partially ordered datatypes.","ref":"RDF.XSD.Time.html#compare/2"},{"type":"function","title":"RDF.XSD.Time.datatype?/1","doc":"Checks if the given literal has datatype this or a datatype that is derived of it.","ref":"RDF.XSD.Time.html#datatype?/1"},{"type":"function","title":"RDF.XSD.Time.equal_value?/2","doc":"Checks if two datatype literals are equal in terms of the values of their value space.\n\nNon-`RDF.Literal`s  are tried to be coerced via `RDF.Literal.coerce/1` before comparison.\n\nReturns `nil` when the given arguments are not comparable as literals of this\ndatatype.\n\nInvalid literals are only considered equal in this relation when both have the exact same\ndatatype and the same attributes (lexical form, language etc.).\n\nImplementations can customize this equivalence relation via the `c:RDF.Literal.Datatype.do_equal_value_different_datatypes?/2`\nand `c:RDF.Literal.Datatype.do_equal_value_different_datatypes?/2` callbacks.","ref":"RDF.XSD.Time.html#equal_value?/2"},{"type":"function","title":"RDF.XSD.Time.lexical/1","doc":"Returns the lexical form of a `RDF.Literal` of this datatype.","ref":"RDF.XSD.Time.html#lexical/1"},{"type":"function","title":"RDF.XSD.Time.new/2","doc":"Creates a new `RDF.Literal` with this datatype and the given `value`.","ref":"RDF.XSD.Time.html#new/2"},{"type":"function","title":"RDF.XSD.Time.new!/2","doc":"Creates a new `RDF.Literal` with this datatype and the given `value` or fails when it is not valid.","ref":"RDF.XSD.Time.html#new!/2"},{"type":"function","title":"RDF.XSD.Time.tz/1","doc":"Extracts the timezone string from a `RDF.XSD.Time` value.","ref":"RDF.XSD.Time.html#tz/1"},{"type":"function","title":"RDF.XSD.Time.update/3","doc":"Updates the value of a `RDF.Literal` without changing everything else.","ref":"RDF.XSD.Time.html#update/3"},{"type":"function","title":"RDF.XSD.Time.valid?/1","doc":"Determines if a `RDF.Literal` of this or a derived datatype has a proper value of its value space.","ref":"RDF.XSD.Time.html#valid?/1"},{"type":"function","title":"RDF.XSD.Time.value/1","doc":"Returns the value of a `RDF.Literal` of this or a derived datatype.","ref":"RDF.XSD.Time.html#value/1"},{"type":"type","title":"RDF.XSD.Time.invalid_value/0","doc":"","ref":"RDF.XSD.Time.html#t:invalid_value/0"},{"type":"type","title":"RDF.XSD.Time.t/0","doc":"","ref":"RDF.XSD.Time.html#t:t/0"},{"type":"type","title":"RDF.XSD.Time.valid_value/0","doc":"","ref":"RDF.XSD.Time.html#t:valid_value/0"},{"type":"type","title":"RDF.XSD.Time.value/0","doc":"","ref":"RDF.XSD.Time.html#t:value/0"},{"type":"module","title":"RDF.XSD.UnsignedByte","doc":"`RDF.XSD.Datatype` for `xsd:unsignedByte`.\n\nSee:","ref":"RDF.XSD.UnsignedByte.html"},{"type":"function","title":"RDF.XSD.UnsignedByte.canonical/1","doc":"Produces the canonical representation of a `RDF.Literal` of this datatype.","ref":"RDF.XSD.UnsignedByte.html#canonical/1"},{"type":"function","title":"RDF.XSD.UnsignedByte.canonical?/1","doc":"Determines if the lexical form of a `RDF.Literal` of this datatype is the canonical form.","ref":"RDF.XSD.UnsignedByte.html#canonical?/1"},{"type":"function","title":"RDF.XSD.UnsignedByte.canonical_lexical/1","doc":"Returns the canonical lexical form of a `RDF.Literal` of this datatype.","ref":"RDF.XSD.UnsignedByte.html#canonical_lexical/1"},{"type":"function","title":"RDF.XSD.UnsignedByte.cast/1","doc":"Casts a datatype literal of one type into a datatype literal of another type.\n\nReturns `nil` when the given arguments are not castable into this datatype or when the given argument is an\ninvalid literal.\n\nImplementations define the casting for a given value with the `c:RDF.Literal.Datatype.do_cast/1` callback.","ref":"RDF.XSD.UnsignedByte.html#cast/1"},{"type":"function","title":"RDF.XSD.UnsignedByte.compare/2","doc":"Compares two `RDF.Literal`s.\n\nIf the first literal is greater than the second `:gt` is returned, if less than `:lt` is returned.\nIf both literal are equal `:eq` is returned.\nIf the literals can not be compared either `nil` is returned, when they generally can be compared\ndue to their datatype, or `:indeterminate` is returned, when the order of the given values is\nnot defined on only partially ordered datatypes.","ref":"RDF.XSD.UnsignedByte.html#compare/2"},{"type":"function","title":"RDF.XSD.UnsignedByte.datatype?/1","doc":"Checks if the given literal has datatype this or a datatype that is derived of it.","ref":"RDF.XSD.UnsignedByte.html#datatype?/1"},{"type":"function","title":"RDF.XSD.UnsignedByte.equal_value?/2","doc":"Checks if two datatype literals are equal in terms of the values of their value space.\n\nNon-`RDF.Literal`s  are tried to be coerced via `RDF.Literal.coerce/1` before comparison.\n\nReturns `nil` when the given arguments are not comparable as literals of this\ndatatype.\n\nInvalid literals are only considered equal in this relation when both have the exact same\ndatatype and the same attributes (lexical form, language etc.).\n\nImplementations can customize this equivalence relation via the `c:RDF.Literal.Datatype.do_equal_value_different_datatypes?/2`\nand `c:RDF.Literal.Datatype.do_equal_value_different_datatypes?/2` callbacks.","ref":"RDF.XSD.UnsignedByte.html#equal_value?/2"},{"type":"function","title":"RDF.XSD.UnsignedByte.lexical/1","doc":"Returns the lexical form of a `RDF.Literal` of this datatype.","ref":"RDF.XSD.UnsignedByte.html#lexical/1"},{"type":"function","title":"RDF.XSD.UnsignedByte.new/2","doc":"Creates a new `RDF.Literal` with this datatype and the given `value`.","ref":"RDF.XSD.UnsignedByte.html#new/2"},{"type":"function","title":"RDF.XSD.UnsignedByte.new!/2","doc":"Creates a new `RDF.Literal` with this datatype and the given `value` or fails when it is not valid.","ref":"RDF.XSD.UnsignedByte.html#new!/2"},{"type":"function","title":"RDF.XSD.UnsignedByte.update/3","doc":"Updates the value of a `RDF.Literal` without changing everything else.","ref":"RDF.XSD.UnsignedByte.html#update/3"},{"type":"function","title":"RDF.XSD.UnsignedByte.valid?/1","doc":"Determines if a `RDF.Literal` of this or a derived datatype has a proper value of its value space.","ref":"RDF.XSD.UnsignedByte.html#valid?/1"},{"type":"function","title":"RDF.XSD.UnsignedByte.value/1","doc":"Returns the value of a `RDF.Literal` of this or a derived datatype.","ref":"RDF.XSD.UnsignedByte.html#value/1"},{"type":"type","title":"RDF.XSD.UnsignedByte.invalid_value/0","doc":"","ref":"RDF.XSD.UnsignedByte.html#t:invalid_value/0"},{"type":"type","title":"RDF.XSD.UnsignedByte.t/0","doc":"","ref":"RDF.XSD.UnsignedByte.html#t:t/0"},{"type":"type","title":"RDF.XSD.UnsignedByte.valid_value/0","doc":"","ref":"RDF.XSD.UnsignedByte.html#t:valid_value/0"},{"type":"type","title":"RDF.XSD.UnsignedByte.value/0","doc":"","ref":"RDF.XSD.UnsignedByte.html#t:value/0"},{"type":"module","title":"RDF.XSD.UnsignedInt","doc":"`RDF.XSD.Datatype` for `xsd:unsignedInt`.\n\nSee:","ref":"RDF.XSD.UnsignedInt.html"},{"type":"function","title":"RDF.XSD.UnsignedInt.canonical/1","doc":"Produces the canonical representation of a `RDF.Literal` of this datatype.","ref":"RDF.XSD.UnsignedInt.html#canonical/1"},{"type":"function","title":"RDF.XSD.UnsignedInt.canonical?/1","doc":"Determines if the lexical form of a `RDF.Literal` of this datatype is the canonical form.","ref":"RDF.XSD.UnsignedInt.html#canonical?/1"},{"type":"function","title":"RDF.XSD.UnsignedInt.canonical_lexical/1","doc":"Returns the canonical lexical form of a `RDF.Literal` of this datatype.","ref":"RDF.XSD.UnsignedInt.html#canonical_lexical/1"},{"type":"function","title":"RDF.XSD.UnsignedInt.cast/1","doc":"Casts a datatype literal of one type into a datatype literal of another type.\n\nReturns `nil` when the given arguments are not castable into this datatype or when the given argument is an\ninvalid literal.\n\nImplementations define the casting for a given value with the `c:RDF.Literal.Datatype.do_cast/1` callback.","ref":"RDF.XSD.UnsignedInt.html#cast/1"},{"type":"function","title":"RDF.XSD.UnsignedInt.compare/2","doc":"Compares two `RDF.Literal`s.\n\nIf the first literal is greater than the second `:gt` is returned, if less than `:lt` is returned.\nIf both literal are equal `:eq` is returned.\nIf the literals can not be compared either `nil` is returned, when they generally can be compared\ndue to their datatype, or `:indeterminate` is returned, when the order of the given values is\nnot defined on only partially ordered datatypes.","ref":"RDF.XSD.UnsignedInt.html#compare/2"},{"type":"function","title":"RDF.XSD.UnsignedInt.datatype?/1","doc":"Checks if the given literal has datatype this or a datatype that is derived of it.","ref":"RDF.XSD.UnsignedInt.html#datatype?/1"},{"type":"function","title":"RDF.XSD.UnsignedInt.equal_value?/2","doc":"Checks if two datatype literals are equal in terms of the values of their value space.\n\nNon-`RDF.Literal`s  are tried to be coerced via `RDF.Literal.coerce/1` before comparison.\n\nReturns `nil` when the given arguments are not comparable as literals of this\ndatatype.\n\nInvalid literals are only considered equal in this relation when both have the exact same\ndatatype and the same attributes (lexical form, language etc.).\n\nImplementations can customize this equivalence relation via the `c:RDF.Literal.Datatype.do_equal_value_different_datatypes?/2`\nand `c:RDF.Literal.Datatype.do_equal_value_different_datatypes?/2` callbacks.","ref":"RDF.XSD.UnsignedInt.html#equal_value?/2"},{"type":"function","title":"RDF.XSD.UnsignedInt.lexical/1","doc":"Returns the lexical form of a `RDF.Literal` of this datatype.","ref":"RDF.XSD.UnsignedInt.html#lexical/1"},{"type":"function","title":"RDF.XSD.UnsignedInt.new/2","doc":"Creates a new `RDF.Literal` with this datatype and the given `value`.","ref":"RDF.XSD.UnsignedInt.html#new/2"},{"type":"function","title":"RDF.XSD.UnsignedInt.new!/2","doc":"Creates a new `RDF.Literal` with this datatype and the given `value` or fails when it is not valid.","ref":"RDF.XSD.UnsignedInt.html#new!/2"},{"type":"function","title":"RDF.XSD.UnsignedInt.update/3","doc":"Updates the value of a `RDF.Literal` without changing everything else.","ref":"RDF.XSD.UnsignedInt.html#update/3"},{"type":"function","title":"RDF.XSD.UnsignedInt.valid?/1","doc":"Determines if a `RDF.Literal` of this or a derived datatype has a proper value of its value space.","ref":"RDF.XSD.UnsignedInt.html#valid?/1"},{"type":"function","title":"RDF.XSD.UnsignedInt.value/1","doc":"Returns the value of a `RDF.Literal` of this or a derived datatype.","ref":"RDF.XSD.UnsignedInt.html#value/1"},{"type":"type","title":"RDF.XSD.UnsignedInt.invalid_value/0","doc":"","ref":"RDF.XSD.UnsignedInt.html#t:invalid_value/0"},{"type":"type","title":"RDF.XSD.UnsignedInt.t/0","doc":"","ref":"RDF.XSD.UnsignedInt.html#t:t/0"},{"type":"type","title":"RDF.XSD.UnsignedInt.valid_value/0","doc":"","ref":"RDF.XSD.UnsignedInt.html#t:valid_value/0"},{"type":"type","title":"RDF.XSD.UnsignedInt.value/0","doc":"","ref":"RDF.XSD.UnsignedInt.html#t:value/0"},{"type":"module","title":"RDF.XSD.UnsignedLong","doc":"`RDF.XSD.Datatype` for `xsd:unsignedLong`.\n\nSee:","ref":"RDF.XSD.UnsignedLong.html"},{"type":"function","title":"RDF.XSD.UnsignedLong.canonical/1","doc":"Produces the canonical representation of a `RDF.Literal` of this datatype.","ref":"RDF.XSD.UnsignedLong.html#canonical/1"},{"type":"function","title":"RDF.XSD.UnsignedLong.canonical?/1","doc":"Determines if the lexical form of a `RDF.Literal` of this datatype is the canonical form.","ref":"RDF.XSD.UnsignedLong.html#canonical?/1"},{"type":"function","title":"RDF.XSD.UnsignedLong.canonical_lexical/1","doc":"Returns the canonical lexical form of a `RDF.Literal` of this datatype.","ref":"RDF.XSD.UnsignedLong.html#canonical_lexical/1"},{"type":"function","title":"RDF.XSD.UnsignedLong.cast/1","doc":"Casts a datatype literal of one type into a datatype literal of another type.\n\nReturns `nil` when the given arguments are not castable into this datatype or when the given argument is an\ninvalid literal.\n\nImplementations define the casting for a given value with the `c:RDF.Literal.Datatype.do_cast/1` callback.","ref":"RDF.XSD.UnsignedLong.html#cast/1"},{"type":"function","title":"RDF.XSD.UnsignedLong.compare/2","doc":"Compares two `RDF.Literal`s.\n\nIf the first literal is greater than the second `:gt` is returned, if less than `:lt` is returned.\nIf both literal are equal `:eq` is returned.\nIf the literals can not be compared either `nil` is returned, when they generally can be compared\ndue to their datatype, or `:indeterminate` is returned, when the order of the given values is\nnot defined on only partially ordered datatypes.","ref":"RDF.XSD.UnsignedLong.html#compare/2"},{"type":"function","title":"RDF.XSD.UnsignedLong.datatype?/1","doc":"Checks if the given literal has datatype this or a datatype that is derived of it.","ref":"RDF.XSD.UnsignedLong.html#datatype?/1"},{"type":"function","title":"RDF.XSD.UnsignedLong.equal_value?/2","doc":"Checks if two datatype literals are equal in terms of the values of their value space.\n\nNon-`RDF.Literal`s  are tried to be coerced via `RDF.Literal.coerce/1` before comparison.\n\nReturns `nil` when the given arguments are not comparable as literals of this\ndatatype.\n\nInvalid literals are only considered equal in this relation when both have the exact same\ndatatype and the same attributes (lexical form, language etc.).\n\nImplementations can customize this equivalence relation via the `c:RDF.Literal.Datatype.do_equal_value_different_datatypes?/2`\nand `c:RDF.Literal.Datatype.do_equal_value_different_datatypes?/2` callbacks.","ref":"RDF.XSD.UnsignedLong.html#equal_value?/2"},{"type":"function","title":"RDF.XSD.UnsignedLong.lexical/1","doc":"Returns the lexical form of a `RDF.Literal` of this datatype.","ref":"RDF.XSD.UnsignedLong.html#lexical/1"},{"type":"function","title":"RDF.XSD.UnsignedLong.new/2","doc":"Creates a new `RDF.Literal` with this datatype and the given `value`.","ref":"RDF.XSD.UnsignedLong.html#new/2"},{"type":"function","title":"RDF.XSD.UnsignedLong.new!/2","doc":"Creates a new `RDF.Literal` with this datatype and the given `value` or fails when it is not valid.","ref":"RDF.XSD.UnsignedLong.html#new!/2"},{"type":"function","title":"RDF.XSD.UnsignedLong.update/3","doc":"Updates the value of a `RDF.Literal` without changing everything else.","ref":"RDF.XSD.UnsignedLong.html#update/3"},{"type":"function","title":"RDF.XSD.UnsignedLong.valid?/1","doc":"Determines if a `RDF.Literal` of this or a derived datatype has a proper value of its value space.","ref":"RDF.XSD.UnsignedLong.html#valid?/1"},{"type":"function","title":"RDF.XSD.UnsignedLong.value/1","doc":"Returns the value of a `RDF.Literal` of this or a derived datatype.","ref":"RDF.XSD.UnsignedLong.html#value/1"},{"type":"type","title":"RDF.XSD.UnsignedLong.invalid_value/0","doc":"","ref":"RDF.XSD.UnsignedLong.html#t:invalid_value/0"},{"type":"type","title":"RDF.XSD.UnsignedLong.t/0","doc":"","ref":"RDF.XSD.UnsignedLong.html#t:t/0"},{"type":"type","title":"RDF.XSD.UnsignedLong.valid_value/0","doc":"","ref":"RDF.XSD.UnsignedLong.html#t:valid_value/0"},{"type":"type","title":"RDF.XSD.UnsignedLong.value/0","doc":"","ref":"RDF.XSD.UnsignedLong.html#t:value/0"},{"type":"module","title":"RDF.XSD.UnsignedShort","doc":"`RDF.XSD.Datatype` for `xsd:unsignedShort`.\n\nSee:","ref":"RDF.XSD.UnsignedShort.html"},{"type":"function","title":"RDF.XSD.UnsignedShort.canonical/1","doc":"Produces the canonical representation of a `RDF.Literal` of this datatype.","ref":"RDF.XSD.UnsignedShort.html#canonical/1"},{"type":"function","title":"RDF.XSD.UnsignedShort.canonical?/1","doc":"Determines if the lexical form of a `RDF.Literal` of this datatype is the canonical form.","ref":"RDF.XSD.UnsignedShort.html#canonical?/1"},{"type":"function","title":"RDF.XSD.UnsignedShort.canonical_lexical/1","doc":"Returns the canonical lexical form of a `RDF.Literal` of this datatype.","ref":"RDF.XSD.UnsignedShort.html#canonical_lexical/1"},{"type":"function","title":"RDF.XSD.UnsignedShort.cast/1","doc":"Casts a datatype literal of one type into a datatype literal of another type.\n\nReturns `nil` when the given arguments are not castable into this datatype or when the given argument is an\ninvalid literal.\n\nImplementations define the casting for a given value with the `c:RDF.Literal.Datatype.do_cast/1` callback.","ref":"RDF.XSD.UnsignedShort.html#cast/1"},{"type":"function","title":"RDF.XSD.UnsignedShort.compare/2","doc":"Compares two `RDF.Literal`s.\n\nIf the first literal is greater than the second `:gt` is returned, if less than `:lt` is returned.\nIf both literal are equal `:eq` is returned.\nIf the literals can not be compared either `nil` is returned, when they generally can be compared\ndue to their datatype, or `:indeterminate` is returned, when the order of the given values is\nnot defined on only partially ordered datatypes.","ref":"RDF.XSD.UnsignedShort.html#compare/2"},{"type":"function","title":"RDF.XSD.UnsignedShort.datatype?/1","doc":"Checks if the given literal has datatype this or a datatype that is derived of it.","ref":"RDF.XSD.UnsignedShort.html#datatype?/1"},{"type":"function","title":"RDF.XSD.UnsignedShort.equal_value?/2","doc":"Checks if two datatype literals are equal in terms of the values of their value space.\n\nNon-`RDF.Literal`s  are tried to be coerced via `RDF.Literal.coerce/1` before comparison.\n\nReturns `nil` when the given arguments are not comparable as literals of this\ndatatype.\n\nInvalid literals are only considered equal in this relation when both have the exact same\ndatatype and the same attributes (lexical form, language etc.).\n\nImplementations can customize this equivalence relation via the `c:RDF.Literal.Datatype.do_equal_value_different_datatypes?/2`\nand `c:RDF.Literal.Datatype.do_equal_value_different_datatypes?/2` callbacks.","ref":"RDF.XSD.UnsignedShort.html#equal_value?/2"},{"type":"function","title":"RDF.XSD.UnsignedShort.lexical/1","doc":"Returns the lexical form of a `RDF.Literal` of this datatype.","ref":"RDF.XSD.UnsignedShort.html#lexical/1"},{"type":"function","title":"RDF.XSD.UnsignedShort.new/2","doc":"Creates a new `RDF.Literal` with this datatype and the given `value`.","ref":"RDF.XSD.UnsignedShort.html#new/2"},{"type":"function","title":"RDF.XSD.UnsignedShort.new!/2","doc":"Creates a new `RDF.Literal` with this datatype and the given `value` or fails when it is not valid.","ref":"RDF.XSD.UnsignedShort.html#new!/2"},{"type":"function","title":"RDF.XSD.UnsignedShort.update/3","doc":"Updates the value of a `RDF.Literal` without changing everything else.","ref":"RDF.XSD.UnsignedShort.html#update/3"},{"type":"function","title":"RDF.XSD.UnsignedShort.valid?/1","doc":"Determines if a `RDF.Literal` of this or a derived datatype has a proper value of its value space.","ref":"RDF.XSD.UnsignedShort.html#valid?/1"},{"type":"function","title":"RDF.XSD.UnsignedShort.value/1","doc":"Returns the value of a `RDF.Literal` of this or a derived datatype.","ref":"RDF.XSD.UnsignedShort.html#value/1"},{"type":"type","title":"RDF.XSD.UnsignedShort.invalid_value/0","doc":"","ref":"RDF.XSD.UnsignedShort.html#t:invalid_value/0"},{"type":"type","title":"RDF.XSD.UnsignedShort.t/0","doc":"","ref":"RDF.XSD.UnsignedShort.html#t:t/0"},{"type":"type","title":"RDF.XSD.UnsignedShort.valid_value/0","doc":"","ref":"RDF.XSD.UnsignedShort.html#t:valid_value/0"},{"type":"type","title":"RDF.XSD.UnsignedShort.value/0","doc":"","ref":"RDF.XSD.UnsignedShort.html#t:value/0"},{"type":"behaviour","title":"RDF.Literal.Datatype","doc":"A behaviour for datatypes for `RDF.Literal`s.\n\nAn implementation of this behaviour defines a struct for a datatype IRI and the semantics of its\nvalues via the functions defined by this behaviour.\n\nThere are three important groups of `RDF.Literal.Datatype` implementations:\n\n- `RDF.XSD.Datatype`: This is another, more specific behaviour for XSD datatypes. RDF.ex comes with\n  builtin implementations of this behaviour for the most important XSD datatypes, but you define\n  your own custom datatypes by deriving from these builtin datatypes and constraining them via\n  `RDF.XSD.Facet`s.\n- Non-XSD datatypes which implement the `RDF.Literal.Datatype` directly: There's currently only one\n  builtin datatype of this category - `RDF.LangString` for language tagged RDF literals.\n- `RDF.Literal.Generic`: This is a generic implementation which is used for `RDF.Literal`s with a\n  datatype that has no own `RDF.Literal.Datatype` implementation defining its semantics.","ref":"RDF.Literal.Datatype.html"},{"type":"callback","title":"RDF.Literal.Datatype.canonical/1","doc":"Produces the canonical representation of a `RDF.Literal`.","ref":"RDF.Literal.Datatype.html#c:canonical/1"},{"type":"callback","title":"RDF.Literal.Datatype.canonical?/1","doc":"Determines if the lexical form of a `RDF.Literal` is the canonical form.\n\nNote: For `RDF.Literal.Generic` literals with the canonical form not defined,\nthis always returns `true`.","ref":"RDF.Literal.Datatype.html#c:canonical?/1"},{"type":"callback","title":"RDF.Literal.Datatype.canonical_lexical/1","doc":"Returns the canonical lexical form of a `RDF.Literal`.\n\nIf the given literal is invalid, `nil` is returned.","ref":"RDF.Literal.Datatype.html#c:canonical_lexical/1"},{"type":"callback","title":"RDF.Literal.Datatype.datatype?/1","doc":"Checks if the given `RDF.Literal` has the datatype for which the `RDF.Literal.Datatype` is implemented or is derived from it.","ref":"RDF.Literal.Datatype.html#c:datatype?/1"},{"type":"callback","title":"Example - RDF.Literal.Datatype.datatype?/1","doc":"iex> RDF.XSD.byte(42) |> RDF.XSD.Integer.datatype?()\n    true","ref":"RDF.Literal.Datatype.html#c:datatype?/1-example"},{"type":"callback","title":"RDF.Literal.Datatype.datatype_id/1","doc":"The datatype IRI of the given `RDF.Literal`.","ref":"RDF.Literal.Datatype.html#c:datatype_id/1"},{"type":"callback","title":"RDF.Literal.Datatype.do_cast/1","doc":"Callback for datatype specific castings.\n\nThis callback is called by the auto-generated `cast/1` function on the implementations, which already deals with the basic cases.\nSo, implementations can assume the passed argument is a valid `RDF.Literal.Datatype` struct,\na `RDF.IRI` or a `RDF.BlankNode`.\n\nIf the given literal can not be converted into this datatype an implementation should return `nil`.\n\nA final catch-all clause should delegate to `super`. For example `RDF.XSD.Datatype`s will handle casting from derived\ndatatypes in the default implementation.","ref":"RDF.Literal.Datatype.html#c:do_cast/1"},{"type":"callback","title":"RDF.Literal.Datatype.do_compare/2","doc":"Callback for datatype specific `compare/2` comparisons between two `RDF.Literal`s.\n\nThis callback is called by auto-generated `compare/2` function on the implementations, which already deals with the basic cases.\nSo, implementations can assume the passed arguments are valid `RDF.Literal.Datatype` structs and\nhave the same datatypes or are derived from each other.\n\nShould return `:gt` if value of the first literal is greater than the value of the second in\nterms of their datatype and `:lt` for vice versa. If the two literals can be considered equal `:eq` should be returned.\nFor datatypes with only partial ordering `:indeterminate` should be returned when the\norder of the given literals is not defined.\n\n`nil` should be returned when the given arguments are not comparable datatypes or if one them is invalid.\n\nThe default implementation of the `_using__` macro of `RDF.Literal.Datatype`s\njust compares the values of the given literals.","ref":"RDF.Literal.Datatype.html#c:do_compare/2"},{"type":"callback","title":"RDF.Literal.Datatype.do_equal_value_different_datatypes?/2","doc":"Callback for datatype specific `equal_value?/2` comparisons when the given literals have different datatypes.\n\nThis callback is called by auto-generated `equal_value?/2` function when the given literals have\ndifferent datatypes and are not derived from each other.\n\nShould return `nil` when the given arguments are not comparable as literals of this\ndatatype. This behaviour is particularly important for SPARQL.ex where this\nfunction is used for the `=` operator, where comparisons between incomparable\nterms are treated as errors and immediately leads to a rejection of a possible\nmatch.\n\nSee also `c:do_equal_value_same_or_derived_datatypes?/2`.","ref":"RDF.Literal.Datatype.html#c:do_equal_value_different_datatypes?/2"},{"type":"callback","title":"RDF.Literal.Datatype.do_equal_value_same_or_derived_datatypes?/2","doc":"Callback for datatype specific `equal_value?/2` comparisons when the given literals have the same or derived datatypes.\n\nThis callback is called by auto-generated `equal_value?/2` function when the given literals have\nthe same datatype or one is derived from the other.\n\nShould return `nil` when the given arguments are not comparable as literals of this\ndatatype. This behaviour is particularly important for SPARQL.ex where this\nfunction is used for the `=` operator, where comparisons between incomparable\nterms are treated as errors and immediately leads to a rejection of a possible\nmatch.\n\nSee also `c:do_equal_value_different_datatypes?/2`.","ref":"RDF.Literal.Datatype.html#c:do_equal_value_same_or_derived_datatypes?/2"},{"type":"function","title":"RDF.Literal.Datatype.get/1","doc":"Returns the `RDF.Literal.Datatype` for a datatype IRI.","ref":"RDF.Literal.Datatype.html#get/1"},{"type":"callback","title":"RDF.Literal.Datatype.id/0","doc":"The IRI of the datatype.","ref":"RDF.Literal.Datatype.html#c:id/0"},{"type":"callback","title":"RDF.Literal.Datatype.language/1","doc":"The language of the given `RDF.Literal` if present.","ref":"RDF.Literal.Datatype.html#c:language/1"},{"type":"callback","title":"RDF.Literal.Datatype.lexical/1","doc":"Returns the lexical form of a `RDF.Literal`.","ref":"RDF.Literal.Datatype.html#c:lexical/1"},{"type":"callback","title":"RDF.Literal.Datatype.name/0","doc":"The name of the datatype.","ref":"RDF.Literal.Datatype.html#c:name/0"},{"type":"callback","title":"RDF.Literal.Datatype.new/1","doc":"","ref":"RDF.Literal.Datatype.html#c:new/1"},{"type":"callback","title":"RDF.Literal.Datatype.new/2","doc":"","ref":"RDF.Literal.Datatype.html#c:new/2"},{"type":"callback","title":"RDF.Literal.Datatype.new!/1","doc":"","ref":"RDF.Literal.Datatype.html#c:new!/1"},{"type":"callback","title":"RDF.Literal.Datatype.new!/2","doc":"","ref":"RDF.Literal.Datatype.html#c:new!/2"},{"type":"callback","title":"RDF.Literal.Datatype.update/2","doc":"Updates the value of a `RDF.Literal` without changing everything else.","ref":"RDF.Literal.Datatype.html#c:update/2"},{"type":"callback","title":"Example - RDF.Literal.Datatype.update/2","doc":"iex> RDF.XSD.integer(42) |> RDF.XSD.Integer.update(fn value -> value + 1 end)\n    RDF.XSD.integer(43)\n    iex> ~L\"foo\"de |> RDF.LangString.update(fn _ -> \"bar\" end)\n    ~L\"bar\"de\n    iex> RDF.literal(\"foo\", datatype: \"http://example.com/dt\") |> RDF.Literal.Generic.update(fn _ -> \"bar\" end)\n    RDF.literal(\"bar\", datatype: \"http://example.com/dt\")","ref":"RDF.Literal.Datatype.html#c:update/2-example"},{"type":"callback","title":"RDF.Literal.Datatype.update/3","doc":"Updates the value of a `RDF.Literal` without changing anything else.\n\nThis variant of `c:update/2` allows with the `:as` option to specify what will\nbe passed to `fun`, e.g. with `as: :lexical` the lexical is passed to the function.","ref":"RDF.Literal.Datatype.html#c:update/3"},{"type":"callback","title":"Example - RDF.Literal.Datatype.update/3","doc":"iex> RDF.XSD.integer(42) |> RDF.XSD.Integer.update(\n    ...>   fn value -> value <> \"1\" end, as: :lexical)\n    RDF.XSD.integer(421)","ref":"RDF.Literal.Datatype.html#c:update/3-example"},{"type":"callback","title":"RDF.Literal.Datatype.valid?/1","doc":"Determines if a `RDF.Literal` has a proper value of the value space of its datatype.\n\nThis function also accepts literals of derived datatypes.","ref":"RDF.Literal.Datatype.html#c:valid?/1"},{"type":"callback","title":"RDF.Literal.Datatype.value/1","doc":"Returns the value of a `RDF.Literal`.\n\nThis function also accepts literals of derived datatypes.","ref":"RDF.Literal.Datatype.html#c:value/1"},{"type":"type","title":"RDF.Literal.Datatype.comparison_result/0","doc":"","ref":"RDF.Literal.Datatype.html#t:comparison_result/0"},{"type":"type","title":"RDF.Literal.Datatype.literal/0","doc":"","ref":"RDF.Literal.Datatype.html#t:literal/0"},{"type":"type","title":"RDF.Literal.Datatype.t/0","doc":"","ref":"RDF.Literal.Datatype.html#t:t/0"},{"type":"module","title":"RDF.Literal.Datatype.Registry","doc":"Registry of literal datatypes.","ref":"RDF.Literal.Datatype.Registry.html"},{"type":"function","title":"RDF.Literal.Datatype.Registry.builtin_datatype?/1","doc":"Checks if the given module is a builtin datatype.\n\nNote: This doesn't include `RDF.Literal.Generic`.","ref":"RDF.Literal.Datatype.Registry.html#builtin_datatype?/1"},{"type":"function","title":"RDF.Literal.Datatype.Registry.builtin_datatypes/0","doc":"Returns a list of all builtin `RDF.Literal.Datatype` modules.","ref":"RDF.Literal.Datatype.Registry.html#builtin_datatypes/0"},{"type":"function","title":"RDF.Literal.Datatype.Registry.builtin_numeric_datatypes/0","doc":"Returns a list of all numeric datatype modules.","ref":"RDF.Literal.Datatype.Registry.html#builtin_numeric_datatypes/0"},{"type":"function","title":"RDF.Literal.Datatype.Registry.builtin_xsd_datatypes/0","doc":"Returns a list of all builtin `RDF.XSD.Datatype` modules.","ref":"RDF.Literal.Datatype.Registry.html#builtin_xsd_datatypes/0"},{"type":"function","title":"RDF.Literal.Datatype.Registry.datatype/1","doc":"Returns the `RDF.Literal.Datatype` for a datatype IRI.","ref":"RDF.Literal.Datatype.Registry.html#datatype/1"},{"type":"function","title":"RDF.Literal.Datatype.Registry.datatype?/1","doc":"Checks if the given module is a builtin datatype or a registered custom datatype implementing the `RDF.Literal.Datatype` behaviour.","ref":"RDF.Literal.Datatype.Registry.html#datatype?/1"},{"type":"function","title":"RDF.Literal.Datatype.Registry.numeric_datatype?/1","doc":"Returns if a given literal or datatype has or is a numeric datatype.","ref":"RDF.Literal.Datatype.Registry.html#numeric_datatype?/1"},{"type":"function","title":"RDF.Literal.Datatype.Registry.primitive_numeric_datatypes/0","doc":"The set of all primitive numeric datatypes.","ref":"RDF.Literal.Datatype.Registry.html#primitive_numeric_datatypes/0"},{"type":"function","title":"RDF.Literal.Datatype.Registry.xsd_datatype/1","doc":"Returns the `RDF.XSD.Datatype` for a datatype IRI.","ref":"RDF.Literal.Datatype.Registry.html#xsd_datatype/1"},{"type":"function","title":"RDF.Literal.Datatype.Registry.xsd_datatype?/1","doc":"Checks if the given module is a builtin XSD datatype or a registered custom datatype implementing the `RDF.XSD.Datatype` behaviour.","ref":"RDF.Literal.Datatype.Registry.html#xsd_datatype?/1"},{"type":"module","title":"RDF.XSD","doc":"An implementation of the XML Schema (XSD) datatype system for use within `RDF.Literal.Datatype` system.\n\nIt consists of\n\n- `RDF.XSD.Datatype`: a more specialized `RDF.Literal.Datatype` behaviour for XSD datatypes\n- `RDF.XSD.Datatype.Primitive`: macros for the definition of `RDF.Literal.Datatype` and\n  `RDF.XSD.Datatype` implementations for primitive XSD datatypes\n- `RDF.XSD.Datatype.Restriction`: macros for the definition of `RDF.Literal.Datatype` and\n  `RDF.XSD.Datatype` implementations for derived XSD datatypes\n- `RDF.XSD.Facet`: a behaviour for XSD facets which can be used to constrain values on\n  datatype derivations\n\nsee","ref":"RDF.XSD.html"},{"type":"function","title":"RDF.XSD.any_uri/1","doc":"","ref":"RDF.XSD.html#any_uri/1"},{"type":"function","title":"RDF.XSD.any_uri/2","doc":"","ref":"RDF.XSD.html#any_uri/2"},{"type":"function","title":"RDF.XSD.anyURI/1","doc":"","ref":"RDF.XSD.html#anyURI/1"},{"type":"function","title":"RDF.XSD.anyURI/2","doc":"","ref":"RDF.XSD.html#anyURI/2"},{"type":"function","title":"RDF.XSD.base64_binary/1","doc":"","ref":"RDF.XSD.html#base64_binary/1"},{"type":"function","title":"RDF.XSD.base64_binary/2","doc":"","ref":"RDF.XSD.html#base64_binary/2"},{"type":"function","title":"RDF.XSD.base64Binary/1","doc":"","ref":"RDF.XSD.html#base64Binary/1"},{"type":"function","title":"RDF.XSD.base64Binary/2","doc":"","ref":"RDF.XSD.html#base64Binary/2"},{"type":"function","title":"RDF.XSD.boolean/1","doc":"","ref":"RDF.XSD.html#boolean/1"},{"type":"function","title":"RDF.XSD.boolean/2","doc":"","ref":"RDF.XSD.html#boolean/2"},{"type":"function","title":"RDF.XSD.byte/1","doc":"","ref":"RDF.XSD.html#byte/1"},{"type":"function","title":"RDF.XSD.byte/2","doc":"","ref":"RDF.XSD.html#byte/2"},{"type":"function","title":"RDF.XSD.datatype?/1","doc":"Returns if the given value is a `RDF.XSD.Datatype` struct or `RDF.Literal` with a `RDF.XSD.Datatype`.","ref":"RDF.XSD.html#datatype?/1"},{"type":"function","title":"RDF.XSD.date/1","doc":"","ref":"RDF.XSD.html#date/1"},{"type":"function","title":"RDF.XSD.date/2","doc":"","ref":"RDF.XSD.html#date/2"},{"type":"function","title":"RDF.XSD.date_time/1","doc":"","ref":"RDF.XSD.html#date_time/1"},{"type":"function","title":"RDF.XSD.date_time/2","doc":"","ref":"RDF.XSD.html#date_time/2"},{"type":"function","title":"RDF.XSD.dateTime/1","doc":"","ref":"RDF.XSD.html#dateTime/1"},{"type":"function","title":"RDF.XSD.dateTime/2","doc":"","ref":"RDF.XSD.html#dateTime/2"},{"type":"function","title":"RDF.XSD.datetime/1","doc":"","ref":"RDF.XSD.html#datetime/1"},{"type":"function","title":"RDF.XSD.datetime/2","doc":"","ref":"RDF.XSD.html#datetime/2"},{"type":"function","title":"RDF.XSD.decimal/1","doc":"","ref":"RDF.XSD.html#decimal/1"},{"type":"function","title":"RDF.XSD.decimal/2","doc":"","ref":"RDF.XSD.html#decimal/2"},{"type":"function","title":"RDF.XSD.double/1","doc":"","ref":"RDF.XSD.html#double/1"},{"type":"function","title":"RDF.XSD.double/2","doc":"","ref":"RDF.XSD.html#double/2"},{"type":"function","title":"RDF.XSD.facet/1","doc":"Get a `RDF.XSD.Facet` by its name.","ref":"RDF.XSD.html#facet/1"},{"type":"function","title":"RDF.XSD.facets/0","doc":"The list of all XSD facets.","ref":"RDF.XSD.html#facets/0"},{"type":"function","title":"RDF.XSD.false/0","doc":"","ref":"RDF.XSD.html#false/0"},{"type":"function","title":"RDF.XSD.float/1","doc":"","ref":"RDF.XSD.html#float/1"},{"type":"function","title":"RDF.XSD.float/2","doc":"","ref":"RDF.XSD.html#float/2"},{"type":"function","title":"RDF.XSD.int/1","doc":"","ref":"RDF.XSD.html#int/1"},{"type":"function","title":"RDF.XSD.int/2","doc":"","ref":"RDF.XSD.html#int/2"},{"type":"function","title":"RDF.XSD.integer/1","doc":"","ref":"RDF.XSD.html#integer/1"},{"type":"function","title":"RDF.XSD.integer/2","doc":"","ref":"RDF.XSD.html#integer/2"},{"type":"function","title":"RDF.XSD.long/1","doc":"","ref":"RDF.XSD.html#long/1"},{"type":"function","title":"RDF.XSD.long/2","doc":"","ref":"RDF.XSD.html#long/2"},{"type":"function","title":"RDF.XSD.negative_integer/1","doc":"","ref":"RDF.XSD.html#negative_integer/1"},{"type":"function","title":"RDF.XSD.negative_integer/2","doc":"","ref":"RDF.XSD.html#negative_integer/2"},{"type":"function","title":"RDF.XSD.negativeInteger/1","doc":"","ref":"RDF.XSD.html#negativeInteger/1"},{"type":"function","title":"RDF.XSD.negativeInteger/2","doc":"","ref":"RDF.XSD.html#negativeInteger/2"},{"type":"function","title":"RDF.XSD.non_negative_integer/1","doc":"","ref":"RDF.XSD.html#non_negative_integer/1"},{"type":"function","title":"RDF.XSD.non_negative_integer/2","doc":"","ref":"RDF.XSD.html#non_negative_integer/2"},{"type":"function","title":"RDF.XSD.non_positive_integer/1","doc":"","ref":"RDF.XSD.html#non_positive_integer/1"},{"type":"function","title":"RDF.XSD.non_positive_integer/2","doc":"","ref":"RDF.XSD.html#non_positive_integer/2"},{"type":"function","title":"RDF.XSD.nonNegativeInteger/1","doc":"","ref":"RDF.XSD.html#nonNegativeInteger/1"},{"type":"function","title":"RDF.XSD.nonNegativeInteger/2","doc":"","ref":"RDF.XSD.html#nonNegativeInteger/2"},{"type":"function","title":"RDF.XSD.nonPositiveInteger/1","doc":"","ref":"RDF.XSD.html#nonPositiveInteger/1"},{"type":"function","title":"RDF.XSD.nonPositiveInteger/2","doc":"","ref":"RDF.XSD.html#nonPositiveInteger/2"},{"type":"function","title":"RDF.XSD.positive_integer/1","doc":"","ref":"RDF.XSD.html#positive_integer/1"},{"type":"function","title":"RDF.XSD.positive_integer/2","doc":"","ref":"RDF.XSD.html#positive_integer/2"},{"type":"function","title":"RDF.XSD.positiveInteger/1","doc":"","ref":"RDF.XSD.html#positiveInteger/1"},{"type":"function","title":"RDF.XSD.positiveInteger/2","doc":"","ref":"RDF.XSD.html#positiveInteger/2"},{"type":"function","title":"RDF.XSD.short/1","doc":"","ref":"RDF.XSD.html#short/1"},{"type":"function","title":"RDF.XSD.short/2","doc":"","ref":"RDF.XSD.html#short/2"},{"type":"function","title":"RDF.XSD.string/1","doc":"","ref":"RDF.XSD.html#string/1"},{"type":"function","title":"RDF.XSD.string/2","doc":"","ref":"RDF.XSD.html#string/2"},{"type":"function","title":"RDF.XSD.time/1","doc":"","ref":"RDF.XSD.html#time/1"},{"type":"function","title":"RDF.XSD.time/2","doc":"","ref":"RDF.XSD.html#time/2"},{"type":"function","title":"RDF.XSD.true/0","doc":"","ref":"RDF.XSD.html#true/0"},{"type":"function","title":"RDF.XSD.unsigned_byte/1","doc":"","ref":"RDF.XSD.html#unsigned_byte/1"},{"type":"function","title":"RDF.XSD.unsigned_byte/2","doc":"","ref":"RDF.XSD.html#unsigned_byte/2"},{"type":"function","title":"RDF.XSD.unsigned_int/1","doc":"","ref":"RDF.XSD.html#unsigned_int/1"},{"type":"function","title":"RDF.XSD.unsigned_int/2","doc":"","ref":"RDF.XSD.html#unsigned_int/2"},{"type":"function","title":"RDF.XSD.unsigned_long/1","doc":"","ref":"RDF.XSD.html#unsigned_long/1"},{"type":"function","title":"RDF.XSD.unsigned_long/2","doc":"","ref":"RDF.XSD.html#unsigned_long/2"},{"type":"function","title":"RDF.XSD.unsigned_short/1","doc":"","ref":"RDF.XSD.html#unsigned_short/1"},{"type":"function","title":"RDF.XSD.unsigned_short/2","doc":"","ref":"RDF.XSD.html#unsigned_short/2"},{"type":"function","title":"RDF.XSD.unsignedByte/1","doc":"","ref":"RDF.XSD.html#unsignedByte/1"},{"type":"function","title":"RDF.XSD.unsignedByte/2","doc":"","ref":"RDF.XSD.html#unsignedByte/2"},{"type":"function","title":"RDF.XSD.unsignedInt/1","doc":"","ref":"RDF.XSD.html#unsignedInt/1"},{"type":"function","title":"RDF.XSD.unsignedInt/2","doc":"","ref":"RDF.XSD.html#unsignedInt/2"},{"type":"function","title":"RDF.XSD.unsignedLong/1","doc":"","ref":"RDF.XSD.html#unsignedLong/1"},{"type":"function","title":"RDF.XSD.unsignedLong/2","doc":"","ref":"RDF.XSD.html#unsignedLong/2"},{"type":"function","title":"RDF.XSD.unsignedShort/1","doc":"","ref":"RDF.XSD.html#unsignedShort/1"},{"type":"function","title":"RDF.XSD.unsignedShort/2","doc":"","ref":"RDF.XSD.html#unsignedShort/2"},{"type":"behaviour","title":"RDF.XSD.Datatype","doc":"A behaviour for XSD datatypes.\n\nA XSD datatype has three properties:\n\n- A _value space_, which is a set of values.\n- A _lexical space_, which is a set of _literals_ used to denote the values.\n- A collection of functions associated with the datatype.","ref":"RDF.XSD.Datatype.html"},{"type":"behaviour","title":"Builtin XSD datatypes - RDF.XSD.Datatype","doc":"RDF.ex comes with the following builtin implementations of XSD datatypes:\n\n| `xsd:boolean` | `RDF.XSD.Boolean` |\n| `xsd:float` | `RDF.XSD.Float` |\n| `xsd:double` | `RDF.XSD.Double` |\n| `xsd:decimal` | `RDF.XSD.Decimal` |\n|   `xsd:integer` | `RDF.XSD.Integer` |\n|     `xsd:long` | `RDF.XSD.Long` |\n|       `xsd:int` | `RDF.XSD.Int` |\n|         `xsd:short` | `RDF.XSD.Short` |\n|           `xsd:byte` | `RDF.XSD.Byte` |\n|     `xsd:nonPositiveInteger` | `RDF.XSD.NonPositiveInteger` |\n|       `xsd:negativeInteger` | `RDF.XSD.NegativeInteger` |\n|     `xsd:nonNegativeInteger` | `RDF.XSD.NonNegativeInteger` |\n|       `xsd:positiveInteger` | `RDF.XSD.PositiveInteger` |\n|       `xsd:unsignedLong` | `RDF.XSD.UnsignedLong` |\n|         `xsd:unsignedInt` | `RDF.XSD.UnsignedInt` |\n|           `xsd:unsignedShort` | `RDF.XSD.UnsignedShort` |\n|             `xsd:unsignedByte` | `RDF.XSD.UnsignedByte` |\n| `xsd:string` | `RDF.XSD.String` |\n|   `xsd:normalizedString` | ❌ |\n|     `xsd:token` | ❌ |\n|       `xsd:language` | ❌ |\n|       `xsd:Name` | ❌ |\n|         `xsd:NCName` | ❌ |\n|           `xsd:ID` | ❌ |\n|           `xsd:IDREF` | ❌ |\n|           `xsd:ENTITY` | ❌ |\n|       `xsd:NMTOKEN` | ❌ |\n| `xsd:dateTime` | `RDF.XSD.DateTime` |\n|   `xsd:dateTimeStamp` | ❌ |\n| `xsd:date` | `RDF.XSD.Date` |\n| `xsd:time` | `RDF.XSD.Time` |\n| `xsd:duration` | ❌ |\n|  `xsd:dayTimeDuration` | ❌ |\n|  `xsd:yearMonthDuration` | ❌ |\n| `xsd:gYearMonth` | ❌ |\n| `xsd:gYear` | ❌ |\n| `xsd:gMonthDay` | ❌ |\n| `xsd:gDay` | ❌ |\n| `xsd:gMonth` | ❌ |\n| `xsd:base64Binary` | `RDF.XSD.Base64Binary` |\n| `xsd:hexBinary` | ❌ |\n| `xsd:anyURI` | `RDF.XSD.AnyURI` |\n| `xsd:QName` | ❌ |\n| `xsd:NOTATION` | ❌ |\n\nThere are some notable difference in the implementations of some datatypes compared to\nthe original spec:\n\n- `RDF.XSD.Integer` is not derived from `RDF.XSD.Decimal`, but implemented as a primitive datatype\n- `RDF.XSD.Float` is not implemented as a primitive datatype, but derived from `RDF.XSD.Double`\n  without further restrictions instead, since Erlang doesn't have a corresponding datatype\n\nsee","ref":"RDF.XSD.Datatype.html#module-builtin-xsd-datatypes"},{"type":"callback","title":"RDF.XSD.Datatype.applicable_facets/0","doc":"The set of applicable facets of a `RDF.XSD.Datatype`.","ref":"RDF.XSD.Datatype.html#c:applicable_facets/0"},{"type":"callback","title":"RDF.XSD.Datatype.base/0","doc":"The base datatype from which a `RDF.XSD.Datatype` is derived.\n\nNote: Since this library focuses on atomic types and the special `xsd:anyAtomicType`\nspecified as the base type of all primitive types in the W3C spec wouldn't serve any\npurpose here, all primitive datatypes just return `nil` instead.","ref":"RDF.XSD.Datatype.html#c:base/0"},{"type":"callback","title":"RDF.XSD.Datatype.base_primitive/0","doc":"The primitive `RDF.XSD.Datatype` from which a `RDF.XSD.Datatype` is derived.\n\nIn case of a primitive `RDF.XSD.Datatype` this function returns this `RDF.XSD.Datatype` itself.","ref":"RDF.XSD.Datatype.html#c:base_primitive/0"},{"type":"callback","title":"RDF.XSD.Datatype.canonical_mapping/1","doc":"Returns the standard lexical representation for a value of the value space of a `RDF.XSD.Datatype`.","ref":"RDF.XSD.Datatype.html#c:canonical_mapping/1"},{"type":"callback","title":"RDF.XSD.Datatype.derived_from?/1","doc":"Checks if the `RDF.XSD.Datatype` is directly or indirectly derived from the given `RDF.XSD.Datatype`.\n\nNote that this is just a basic datatype reflection function on the module level\nand does not work with `RDF.Literal`s. See `c:RDF.Literal.Datatype.datatype?/1` instead.","ref":"RDF.XSD.Datatype.html#c:derived_from?/1"},{"type":"callback","title":"RDF.XSD.Datatype.elixir_mapping/2","doc":"A mapping from Elixir values into the value space of a `RDF.XSD.Datatype`.\n\nIf the Elixir mapping for the given value can not be mapped into value space of\nthe XSD datatype an implementation should return `@invalid_value`\n(which is just `nil` at the moment, so `nil` is never a valid value of a value space).\n\nOtherwise, a tuple `{value, lexical}` with `value` being the internal representation\nof the mapped value from the value space and `lexical` being the lexical representation\nto be used for the Elixir value or `nil` if `c:init_valid_lexical/3` should be used\nto determine the lexical form in general (i.e. also when initialized with a string\nvia the `c:lexical_mapping/2`). Since the later case is most often what you want,\nyou can also return `value` directly, as long as it is not a two element tuple.","ref":"RDF.XSD.Datatype.html#c:elixir_mapping/2"},{"type":"function","title":"RDF.XSD.Datatype.get/1","doc":"Returns the `RDF.XSD.Datatype` for a datatype IRI.","ref":"RDF.XSD.Datatype.html#get/1"},{"type":"callback","title":"RDF.XSD.Datatype.init_invalid_lexical/2","doc":"Produces the lexical representation of an invalid value.\n\nThe default implementation of the `_using__` macro just returns the `to_string/1`\nrepresentation of the value.","ref":"RDF.XSD.Datatype.html#c:init_invalid_lexical/2"},{"type":"callback","title":"RDF.XSD.Datatype.init_valid_lexical/3","doc":"Produces the lexical representation to be used for a `RDF.XSD.Datatype` literal.\n\nBy default, the lexical representation of a `RDF.XSD.Datatype` is either the\ncanonical form in case it is created from a non-string Elixir value or, if it\nis created from a string, just with that string as the lexical form.\n\nBut there can be various reasons for why this should be different for certain\ndatatypes. For example, for `RDF.XSD.Double`s given as Elixir floats, we want the\ndefault lexical representation to be the decimal and not the canonical\nexponential form. Another reason might be that additional options are given\nwhich should be taken into account in the lexical form.\n\nIf the lexical representation for a given `value` and `lexical` should be the\ncanonical one, an implementation should return `nil`.","ref":"RDF.XSD.Datatype.html#c:init_valid_lexical/3"},{"type":"callback","title":"RDF.XSD.Datatype.lexical_mapping/2","doc":"A mapping from the lexical space of a `RDF.XSD.Datatype` into its value space.","ref":"RDF.XSD.Datatype.html#c:lexical_mapping/2"},{"type":"callback","title":"RDF.XSD.Datatype.primitive?/0","doc":"Returns if the `RDF.XSD.Datatype` is a primitive datatype.","ref":"RDF.XSD.Datatype.html#c:primitive?/0"},{"type":"type","title":"RDF.XSD.Datatype.literal/0","doc":"","ref":"RDF.XSD.Datatype.html#t:literal/0"},{"type":"type","title":"RDF.XSD.Datatype.t/0","doc":"","ref":"RDF.XSD.Datatype.html#t:t/0"},{"type":"type","title":"RDF.XSD.Datatype.uncanonical_lexical/0","doc":"","ref":"RDF.XSD.Datatype.html#t:uncanonical_lexical/0"},{"type":"module","title":"RDF.XSD.Datatype.Primitive","doc":"Macros for the definition of primitive XSD datatypes.","ref":"RDF.XSD.Datatype.Primitive.html"},{"type":"macro","title":"RDF.XSD.Datatype.Primitive.def_applicable_facet/1","doc":"Specifies the applicability of the given XSD `facet` on a primitive datatype.\n\nFor a facet with the name `example_facet` this requires a function\n\n    def example_facet_conform?(example_facet_value, literal_value, lexical) do\n\n    end\n\nto be defined on the primitive datatype.","ref":"RDF.XSD.Datatype.Primitive.html#def_applicable_facet/1"},{"type":"module","title":"RDF.XSD.Datatype.Restriction","doc":"A `__using__` macro for the derivation of restricted XSD datatypes.","ref":"RDF.XSD.Datatype.Restriction.html"},{"type":"module","title":"Example - RDF.XSD.Datatype.Restriction","doc":"A new custom datatype can be derived by defining a new datatype module and `use` this module,\nspecifying a `name`, `id` and `base` datatype and restricting it by specifying some\napplicable facets of the base datatype:\n\n    defmodule MyApp.PersonAge do\n      use RDF.XSD.Datatype.Restriction,\n          name: \"person_age\",\n          id: \"http://example.com/person_age\",\n          base: RDF.XSD.NonNegativeInteger\n\n      def_facet_constraint RDF.XSD.Facets.MaxInclusive, 150\n    end\n\nSee `RDF.XSD.Facet` on which facets are available on the existing datatypes.","ref":"RDF.XSD.Datatype.Restriction.html#module-example"},{"type":"behaviour","title":"RDF.XSD.Facet","doc":"A behaviour for XSD restriction facets.\n\nHere's a list of all the `RDF.XSD.Facet`s RDF.ex implements out-of-the-box:\n\n| XSD facet        | `RDF.XSD.Facet`                   |\n| :--------------  | :-------------                    |\n| length           | `RDF.XSD.Facets.Length`           |\n| minLength        | `RDF.XSD.Facets.MinLength`        |\n| maxLength        | `RDF.XSD.Facets.MaxLength`        |\n| maxInclusive     | `RDF.XSD.Facets.MaxInclusive`     |\n| maxExclusive     | `RDF.XSD.Facets.MaxExclusive`     |\n| minInclusive     | `RDF.XSD.Facets.MinInclusive`     |\n| minExclusive     | `RDF.XSD.Facets.MinExclusive`     |\n| totalDigits      | `RDF.XSD.Facets.TotalDigits`      |\n| fractionDigits   | `RDF.XSD.Facets.FractionDigits`   |\n| explicitTimezone | `RDF.XSD.Facets.ExplicitTimezone` |\n| pattern          | `RDF.XSD.Facets.Pattern`          |\n| whiteSpace       | ❌                                |\n| enumeration      | ❌                                |\n| assertions       | ❌                                |\n\nEvery `RDF.XSD.Datatype.Primitive` defines a set of applicable constraining facets which are can\nbe used on derivations of this primitive or any of its existing derivations:\n\n| Primitive datatype | Applicable facets |\n| :----------------- | :---------------- |\n|string | `RDF.XSD.Facets.Length`, `RDF.XSD.Facets.MaxLength`, `RDF.XSD.Facets.MinLength`, `RDF.XSD.Facets.Pattern` |\n|boolean | `RDF.XSD.Facets.Pattern` |\n|float | `RDF.XSD.Facets.MaxExclusive`, `RDF.XSD.Facets.MaxInclusive`, `RDF.XSD.Facets.MinExclusive`, `RDF.XSD.Facets.MinInclusive`, `RDF.XSD.Facets.Pattern` |\n|double | `RDF.XSD.Facets.MaxExclusive`, `RDF.XSD.Facets.MaxInclusive`, `RDF.XSD.Facets.MinExclusive`, `RDF.XSD.Facets.MinInclusive`, `RDF.XSD.Facets.Pattern` |\n|decimal | `RDF.XSD.Facets.MaxExclusive`, `RDF.XSD.Facets.MaxInclusive`, `RDF.XSD.Facets.MinExclusive`, `RDF.XSD.Facets.MinInclusive`, `RDF.XSD.Facets.Pattern`, `RDF.XSD.Facets.TotalDigits`, `RDF.XSD.Facets.FractionDigits` |\n|decimal | `RDF.XSD.Facets.MaxExclusive`, `RDF.XSD.Facets.MaxInclusive`, `RDF.XSD.Facets.MinExclusive`, `RDF.XSD.Facets.MinInclusive`, `RDF.XSD.Facets.Pattern`, `RDF.XSD.Facets.TotalDigits` |\n|duration | `RDF.XSD.Facets.MaxExclusive`, `RDF.XSD.Facets.MaxInclusive`, `RDF.XSD.Facets.MinExclusive`, `RDF.XSD.Facets.MinInclusive`, `RDF.XSD.Facets.Pattern` |\n|dateTime | `RDF.XSD.Facets.ExplicitTimezone`, `RDF.XSD.Facets.MaxExclusive`, `RDF.XSD.Facets.MaxInclusive`, `RDF.XSD.Facets.MinExclusive`, `RDF.XSD.Facets.MinInclusive`, `RDF.XSD.Facets.Pattern` |\n|time | `RDF.XSD.Facets.ExplicitTimezone`, `RDF.XSD.Facets.MaxExclusive`, `RDF.XSD.Facets.MaxInclusive`, `RDF.XSD.Facets.MinExclusive`, `RDF.XSD.Facets.MinInclusive`, `RDF.XSD.Facets.Pattern` |\n|date | `RDF.XSD.Facets.ExplicitTimezone`, `RDF.XSD.Facets.MaxExclusive`, `RDF.XSD.Facets.MaxInclusive`, `RDF.XSD.Facets.MinExclusive`, `RDF.XSD.Facets.MinInclusive`, `RDF.XSD.Facets.Pattern` |\n|anyURI | `RDF.XSD.Facets.Length`, `RDF.XSD.Facets.MaxLength`, `RDF.XSD.Facets.MinLength`, `RDF.XSD.Facets.Pattern` |","ref":"RDF.XSD.Facet.html"},{"type":"macro","title":"RDF.XSD.Facet.def_facet_constraint/2","doc":"Macro for the definition of concrete constraining `value` for a `RDF.XSD.Facet` on a `RDF.XSD.Datatype`.","ref":"RDF.XSD.Facet.html#def_facet_constraint/2"},{"type":"callback","title":"RDF.XSD.Facet.name/0","doc":"The name of a `RDF.XSD.Facet`.","ref":"RDF.XSD.Facet.html#c:name/0"},{"type":"type","title":"RDF.XSD.Facet.t/0","doc":"","ref":"RDF.XSD.Facet.html#t:t/0"},{"type":"behaviour","title":"RDF.XSD.Facets.ExplicitTimezone","doc":"`RDF.XSD.Facet` for `explicitTimezone`.\n\n`explicitTimezone` is a three-valued facet which can can be used to require\nor prohibit the time zone offset in date/time datatypes.\n\nsee","ref":"RDF.XSD.Facets.ExplicitTimezone.html"},{"type":"function","title":"RDF.XSD.Facets.ExplicitTimezone.conform?/3","doc":"Checks if a `value` and `lexical` conforms with the `c:explicit_timezone_conform?/3` implementation on the `datatype` `RDF.XSD.Datatype`.","ref":"RDF.XSD.Facets.ExplicitTimezone.html#conform?/3"},{"type":"callback","title":"RDF.XSD.Facets.ExplicitTimezone.explicit_timezone/0","doc":"Returns the value of this `RDF.XSD.Facet` on specific `RDF.XSD.Datatype`.","ref":"RDF.XSD.Facets.ExplicitTimezone.html#c:explicit_timezone/0"},{"type":"callback","title":"RDF.XSD.Facets.ExplicitTimezone.explicit_timezone_conform?/3","doc":"Validates if a `value` and `lexical` conforms with a concrete `facet_constraint_value` for this `RDF.XSD.Facet`.\n\nThis function must be implemented on a `RDF.XSD.Datatype` using this `RDF.XSD.Facet`.","ref":"RDF.XSD.Facets.ExplicitTimezone.html#c:explicit_timezone_conform?/3"},{"type":"type","title":"RDF.XSD.Facets.ExplicitTimezone.t/0","doc":"","ref":"RDF.XSD.Facets.ExplicitTimezone.html#t:t/0"},{"type":"behaviour","title":"RDF.XSD.Facets.FractionDigits","doc":"`RDF.XSD.Facet` for `fractionDigits`.\n\n`fractionDigits` places an upper limit on the arithmetic precision of decimal\nvalues: if the `{value}` of `fractionDigits = f`, then the value space is\nrestricted to values equal to `i / 10n` for some integers `i` and `n` and\n`0 ≤ n ≤ f`. The value of `fractionDigits` must be a nonNegativeInteger.\n\nsee","ref":"RDF.XSD.Facets.FractionDigits.html"},{"type":"function","title":"RDF.XSD.Facets.FractionDigits.conform?/3","doc":"Checks if a `value` and `lexical` conforms with the `c:fraction_digits_conform?/3` implementation on the `datatype` `RDF.XSD.Datatype`.","ref":"RDF.XSD.Facets.FractionDigits.html#conform?/3"},{"type":"callback","title":"RDF.XSD.Facets.FractionDigits.fraction_digits/0","doc":"Returns the value of this `RDF.XSD.Facet` on specific `RDF.XSD.Datatype`.","ref":"RDF.XSD.Facets.FractionDigits.html#c:fraction_digits/0"},{"type":"callback","title":"RDF.XSD.Facets.FractionDigits.fraction_digits_conform?/3","doc":"Validates if a `value` and `lexical` conforms with a concrete `facet_constraint_value` for this `RDF.XSD.Facet`.\n\nThis function must be implemented on a `RDF.XSD.Datatype` using this `RDF.XSD.Facet`.","ref":"RDF.XSD.Facets.FractionDigits.html#c:fraction_digits_conform?/3"},{"type":"behaviour","title":"RDF.XSD.Facets.Length","doc":"`RDF.XSD.Facet` for `length`.\n\n`length` is the number of units of length, where units of length varies\ndepending on the type that is being derived from.\nThe value of `length` must be a `nonNegativeInteger`.\n\nsee","ref":"RDF.XSD.Facets.Length.html"},{"type":"function","title":"RDF.XSD.Facets.Length.conform?/3","doc":"Checks if a `value` and `lexical` conforms with the `c:length_conform?/3` implementation on the `datatype` `RDF.XSD.Datatype`.","ref":"RDF.XSD.Facets.Length.html#conform?/3"},{"type":"callback","title":"RDF.XSD.Facets.Length.length/0","doc":"Returns the value of this `RDF.XSD.Facet` on specific `RDF.XSD.Datatype`.","ref":"RDF.XSD.Facets.Length.html#c:length/0"},{"type":"callback","title":"RDF.XSD.Facets.Length.length_conform?/3","doc":"Validates if a `value` and `lexical` conforms with a concrete `facet_constraint_value` for this `RDF.XSD.Facet`.\n\nThis function must be implemented on a `RDF.XSD.Datatype` using this `RDF.XSD.Facet`.","ref":"RDF.XSD.Facets.Length.html#c:length_conform?/3"},{"type":"behaviour","title":"RDF.XSD.Facets.MaxExclusive","doc":"`RDF.XSD.Facet` for `maxExclusive`.\n\n`maxExclusive` is the exclusive upper bound of the value space for a datatype\nwith the ordered property.\nThe value of `maxExclusive` must be equal to some value in the value space\nof the base type or be equal to `{value}` in `{base type definition}`.\n\nsee","ref":"RDF.XSD.Facets.MaxExclusive.html"},{"type":"function","title":"RDF.XSD.Facets.MaxExclusive.conform?/3","doc":"Checks if a `value` and `lexical` conforms with the `c:max_exclusive_conform?/3` implementation on the `datatype` `RDF.XSD.Datatype`.","ref":"RDF.XSD.Facets.MaxExclusive.html#conform?/3"},{"type":"callback","title":"RDF.XSD.Facets.MaxExclusive.max_exclusive/0","doc":"Returns the value of this `RDF.XSD.Facet` on specific `RDF.XSD.Datatype`.","ref":"RDF.XSD.Facets.MaxExclusive.html#c:max_exclusive/0"},{"type":"callback","title":"RDF.XSD.Facets.MaxExclusive.max_exclusive_conform?/3","doc":"Validates if a `value` and `lexical` conforms with a concrete `facet_constraint_value` for this `RDF.XSD.Facet`.\n\nThis function must be implemented on a `RDF.XSD.Datatype` using this `RDF.XSD.Facet`.","ref":"RDF.XSD.Facets.MaxExclusive.html#c:max_exclusive_conform?/3"},{"type":"behaviour","title":"RDF.XSD.Facets.MaxInclusive","doc":"`RDF.XSD.Facet` for `maxInclusive`.\n\n`maxInclusive` is the inclusive upper bound of the value space for a datatype\nwith the ordered property.\nThe value of `maxInclusive` must be equal to some value in the value space of\nthe base type.\n\nsee","ref":"RDF.XSD.Facets.MaxInclusive.html"},{"type":"function","title":"RDF.XSD.Facets.MaxInclusive.conform?/3","doc":"Checks if a `value` and `lexical` conforms with the `c:max_inclusive_conform?/3` implementation on the `datatype` `RDF.XSD.Datatype`.","ref":"RDF.XSD.Facets.MaxInclusive.html#conform?/3"},{"type":"callback","title":"RDF.XSD.Facets.MaxInclusive.max_inclusive/0","doc":"Returns the value of this `RDF.XSD.Facet` on specific `RDF.XSD.Datatype`.","ref":"RDF.XSD.Facets.MaxInclusive.html#c:max_inclusive/0"},{"type":"callback","title":"RDF.XSD.Facets.MaxInclusive.max_inclusive_conform?/3","doc":"Validates if a `value` and `lexical` conforms with a concrete `facet_constraint_value` for this `RDF.XSD.Facet`.\n\nThis function must be implemented on a `RDF.XSD.Datatype` using this `RDF.XSD.Facet`.","ref":"RDF.XSD.Facets.MaxInclusive.html#c:max_inclusive_conform?/3"},{"type":"behaviour","title":"RDF.XSD.Facets.MaxLength","doc":"`RDF.XSD.Facet` for `maxLength`.\n\n`maxLength` is the maximum number of units of length, where units of length\nvaries depending on the type that is being derived from.\nThe value of `maxLength` must be a `nonNegativeInteger`.\n\nsee","ref":"RDF.XSD.Facets.MaxLength.html"},{"type":"function","title":"RDF.XSD.Facets.MaxLength.conform?/3","doc":"Checks if a `value` and `lexical` conforms with the `c:max_length_conform?/3` implementation on the `datatype` `RDF.XSD.Datatype`.","ref":"RDF.XSD.Facets.MaxLength.html#conform?/3"},{"type":"callback","title":"RDF.XSD.Facets.MaxLength.max_length/0","doc":"Returns the value of this `RDF.XSD.Facet` on specific `RDF.XSD.Datatype`.","ref":"RDF.XSD.Facets.MaxLength.html#c:max_length/0"},{"type":"callback","title":"RDF.XSD.Facets.MaxLength.max_length_conform?/3","doc":"Validates if a `value` and `lexical` conforms with a concrete `facet_constraint_value` for this `RDF.XSD.Facet`.\n\nThis function must be implemented on a `RDF.XSD.Datatype` using this `RDF.XSD.Facet`.","ref":"RDF.XSD.Facets.MaxLength.html#c:max_length_conform?/3"},{"type":"behaviour","title":"RDF.XSD.Facets.MinExclusive","doc":"`RDF.XSD.Facet` for `minExclusive`.\n\n`minExclusive` is the exclusive lower bound of the value space for a datatype\nwith the ordered property.\nThe value of `minExclusive` must be equal to some value in the value space of\nthe base type or be equal to `{value}` in `{base type definition}`.\n\nsee","ref":"RDF.XSD.Facets.MinExclusive.html"},{"type":"function","title":"RDF.XSD.Facets.MinExclusive.conform?/3","doc":"Checks if a `value` and `lexical` conforms with the `c:min_exclusive_conform?/3` implementation on the `datatype` `RDF.XSD.Datatype`.","ref":"RDF.XSD.Facets.MinExclusive.html#conform?/3"},{"type":"callback","title":"RDF.XSD.Facets.MinExclusive.min_exclusive/0","doc":"Returns the value of this `RDF.XSD.Facet` on specific `RDF.XSD.Datatype`.","ref":"RDF.XSD.Facets.MinExclusive.html#c:min_exclusive/0"},{"type":"callback","title":"RDF.XSD.Facets.MinExclusive.min_exclusive_conform?/3","doc":"Validates if a `value` and `lexical` conforms with a concrete `facet_constraint_value` for this `RDF.XSD.Facet`.\n\nThis function must be implemented on a `RDF.XSD.Datatype` using this `RDF.XSD.Facet`.","ref":"RDF.XSD.Facets.MinExclusive.html#c:min_exclusive_conform?/3"},{"type":"behaviour","title":"RDF.XSD.Facets.MinInclusive","doc":"`RDF.XSD.Facet` for `minInclusive`.\n\n`minInclusive` is the inclusive lower bound of the value space for a datatype\nwith the ordered property.\nThe value of `minInclusive` must be equal to some value in the value space of\nthe base type.\n\nsee","ref":"RDF.XSD.Facets.MinInclusive.html"},{"type":"function","title":"RDF.XSD.Facets.MinInclusive.conform?/3","doc":"Checks if a `value` and `lexical` conforms with the `c:min_inclusive_conform?/3` implementation on the `datatype` `RDF.XSD.Datatype`.","ref":"RDF.XSD.Facets.MinInclusive.html#conform?/3"},{"type":"callback","title":"RDF.XSD.Facets.MinInclusive.min_inclusive/0","doc":"Returns the value of this `RDF.XSD.Facet` on specific `RDF.XSD.Datatype`.","ref":"RDF.XSD.Facets.MinInclusive.html#c:min_inclusive/0"},{"type":"callback","title":"RDF.XSD.Facets.MinInclusive.min_inclusive_conform?/3","doc":"Validates if a `value` and `lexical` conforms with a concrete `facet_constraint_value` for this `RDF.XSD.Facet`.\n\nThis function must be implemented on a `RDF.XSD.Datatype` using this `RDF.XSD.Facet`.","ref":"RDF.XSD.Facets.MinInclusive.html#c:min_inclusive_conform?/3"},{"type":"behaviour","title":"RDF.XSD.Facets.MinLength","doc":"`RDF.XSD.Facet` for `minLength`.\n\n`minLength` is the minimum number of units of length, where units of length\nvaries depending on the type that is being derived from.\nThe value of `minLength`  must be a `nonNegativeInteger`.\n\nsee","ref":"RDF.XSD.Facets.MinLength.html"},{"type":"function","title":"RDF.XSD.Facets.MinLength.conform?/3","doc":"Checks if a `value` and `lexical` conforms with the `c:min_length_conform?/3` implementation on the `datatype` `RDF.XSD.Datatype`.","ref":"RDF.XSD.Facets.MinLength.html#conform?/3"},{"type":"callback","title":"RDF.XSD.Facets.MinLength.min_length/0","doc":"Returns the value of this `RDF.XSD.Facet` on specific `RDF.XSD.Datatype`.","ref":"RDF.XSD.Facets.MinLength.html#c:min_length/0"},{"type":"callback","title":"RDF.XSD.Facets.MinLength.min_length_conform?/3","doc":"Validates if a `value` and `lexical` conforms with a concrete `facet_constraint_value` for this `RDF.XSD.Facet`.\n\nThis function must be implemented on a `RDF.XSD.Datatype` using this `RDF.XSD.Facet`.","ref":"RDF.XSD.Facets.MinLength.html#c:min_length_conform?/3"},{"type":"behaviour","title":"RDF.XSD.Facets.Pattern","doc":"`RDF.XSD.Facet` for `pattern`.\n\n`pattern` is a constraint on the value space of a datatype which is achieved\nby constraining the lexical space to literals which match each member of a\nset of regular expressions.\nThe value of pattern  must be a set of regular expressions.\n\nsee","ref":"RDF.XSD.Facets.Pattern.html"},{"type":"function","title":"RDF.XSD.Facets.Pattern.conform?/3","doc":"Checks if a `value` and `lexical` conforms with the `c:pattern_conform?/3` implementation on the `datatype` `RDF.XSD.Datatype`.","ref":"RDF.XSD.Facets.Pattern.html#conform?/3"},{"type":"callback","title":"RDF.XSD.Facets.Pattern.pattern/0","doc":"Returns the value of this `RDF.XSD.Facet` on specific `RDF.XSD.Datatype`.","ref":"RDF.XSD.Facets.Pattern.html#c:pattern/0"},{"type":"callback","title":"RDF.XSD.Facets.Pattern.pattern_conform?/3","doc":"Validates if a `value` and `lexical` conforms with a concrete `facet_constraint_value` for this `RDF.XSD.Facet`.\n\nThis function must be implemented on a `RDF.XSD.Datatype` using this `RDF.XSD.Facet`.","ref":"RDF.XSD.Facets.Pattern.html#c:pattern_conform?/3"},{"type":"behaviour","title":"RDF.XSD.Facets.TotalDigits","doc":"`RDF.XSD.Facet` for `totalDigits`.\n\n`totalDigits` restricts the magnitude and arithmetic precision of values in\nthe value spaces of decimal and datatypes derived from it.\n\nsee","ref":"RDF.XSD.Facets.TotalDigits.html"},{"type":"function","title":"RDF.XSD.Facets.TotalDigits.conform?/3","doc":"Checks if a `value` and `lexical` conforms with the `c:total_digits_conform?/3` implementation on the `datatype` `RDF.XSD.Datatype`.","ref":"RDF.XSD.Facets.TotalDigits.html#conform?/3"},{"type":"callback","title":"RDF.XSD.Facets.TotalDigits.total_digits/0","doc":"Returns the value of this `RDF.XSD.Facet` on specific `RDF.XSD.Datatype`.","ref":"RDF.XSD.Facets.TotalDigits.html#c:total_digits/0"},{"type":"callback","title":"RDF.XSD.Facets.TotalDigits.total_digits_conform?/3","doc":"Validates if a `value` and `lexical` conforms with a concrete `facet_constraint_value` for this `RDF.XSD.Facet`.\n\nThis function must be implemented on a `RDF.XSD.Datatype` using this `RDF.XSD.Facet`.","ref":"RDF.XSD.Facets.TotalDigits.html#c:total_digits_conform?/3"},{"type":"module","title":"RDF.BlankNode.Generator","doc":"A GenServer which generates `RDF.BlankNode`s using a `RDF.BlankNode.Generator.Algorithm`.\n\nThis module implements the `RDF.Resource.Generator` behaviour.\nThe only `RDF.Resource.Generator` configuration it requires is the process\nidentifier. The actual configuration of the behaviour of this generator\nis done on the GenServer itself via `start_link/2` or `start/2`.","ref":"RDF.BlankNode.Generator.html"},{"type":"function","title":"RDF.BlankNode.Generator.child_spec/1","doc":"Returns a specification to start this module under a supervisor.\n\nSee `Supervisor`.","ref":"RDF.BlankNode.Generator.html#child_spec/1"},{"type":"function","title":"RDF.BlankNode.Generator.generate/1","doc":"Generates a new blank node according to the `RDF.BlankNode.Generator.Algorithm` set up.","ref":"RDF.BlankNode.Generator.html#generate/1"},{"type":"function","title":"RDF.BlankNode.Generator.generate_for/2","doc":"Generates a blank node for a given value according to the `RDF.BlankNode.Generator.Algorithm` set up.","ref":"RDF.BlankNode.Generator.html#generate_for/2"},{"type":"function","title":"RDF.BlankNode.Generator.start/2","doc":"Starts a blank node generator process without links (outside a supervision tree).\n\nThe options are handled the same as `start_link/1`.","ref":"RDF.BlankNode.Generator.html#start/2"},{"type":"function","title":"RDF.BlankNode.Generator.start_link/2","doc":"Starts a blank node generator linked to the current process.\n\nThe `RDF.BlankNode.Generator.Algorithm` can be given either as a respective\nstruct or just the module, in which case a struct is created implicitly\nwith the default values of its fields.","ref":"RDF.BlankNode.Generator.html#start_link/2"},{"type":"function","title":"RDF.BlankNode.Generator.stop/3","doc":"Synchronously stops the blank node generator with the given `reason`.\n\nIt returns `:ok` if the GenServer terminates with the given reason.\nIf the GenServer terminates with another reason, the call will exit.\n\nThis function keeps OTP semantics regarding error reporting.\nIf the reason is any other than `:normal`, `:shutdown` or `{:shutdown, _}`, an\nerror report will be logged.","ref":"RDF.BlankNode.Generator.html#stop/3"},{"type":"behaviour","title":"RDF.BlankNode.Generator.Algorithm","doc":"A behaviour for implementations of blank node identifier generation algorithms.\n\nThe `RDF.BlankNode.Generator` executes such an algorithm and holds its state.","ref":"RDF.BlankNode.Generator.Algorithm.html"},{"type":"callback","title":"RDF.BlankNode.Generator.Algorithm.generate/1","doc":"Generates a blank node.\n\nAn implementation should compute a blank node from the given state and return\na tuple consisting of the generated blank node and the new state.","ref":"RDF.BlankNode.Generator.Algorithm.html#c:generate/1"},{"type":"callback","title":"RDF.BlankNode.Generator.Algorithm.generate_for/2","doc":"Generates a blank node for a given string.\n\nEvery call with the same string must return the same blank node.\n\nAn implementation should compute a blank node for the given value from the\ngiven state and return a tuple consisting of the generated blank node and the\nnew state.","ref":"RDF.BlankNode.Generator.Algorithm.html#c:generate_for/2"},{"type":"type","title":"RDF.BlankNode.Generator.Algorithm.t/0","doc":"","ref":"RDF.BlankNode.Generator.Algorithm.html#t:t/0"},{"type":"type","title":"RDF.BlankNode.Generator.Algorithm.type/0","doc":"","ref":"RDF.BlankNode.Generator.Algorithm.html#t:type/0"},{"type":"module","title":"RDF.BlankNode.Generator.Increment","doc":"An implementation of a `RDF.BlankNode.Generator.Algorithm` which returns `RDF.BlankNode`s with incremented identifiers.","ref":"RDF.BlankNode.Generator.Increment.html"},{"type":"function","title":"RDF.BlankNode.Generator.Increment.new/1","doc":"Creates a struct with the state of the algorithm.","ref":"RDF.BlankNode.Generator.Increment.html#new/1"},{"type":"function","title":"Options - RDF.BlankNode.Generator.Increment.new/1","doc":"- `prefix`: a string prepended to the generated blank node identifier\n- `counter`: the number from which the incremented counter starts","ref":"RDF.BlankNode.Generator.Increment.html#new/1-options"},{"type":"type","title":"RDF.BlankNode.Generator.Increment.t/0","doc":"","ref":"RDF.BlankNode.Generator.Increment.html#t:t/0"},{"type":"module","title":"RDF.BlankNode.Generator.Random","doc":"An implementation of a `RDF.BlankNode.Generator.Algorithm` which returns `RDF.BlankNode`s with random identifiers.\n\nNote, although this generator is faster than the `RDF.BlankNode.Generator.UUID` generator,\nwhich also produces random identifiers, the random identifiers produced by\n`RDF.BlankNode.Generator.Random` are not unique across multiple application runs,\nsince they are based on numbers returned by `:erlang.unique_integer/1`.","ref":"RDF.BlankNode.Generator.Random.html"},{"type":"function","title":"RDF.BlankNode.Generator.Random.new/1","doc":"Creates a struct with the state of the algorithm.","ref":"RDF.BlankNode.Generator.Random.html#new/1"},{"type":"function","title":"Options - RDF.BlankNode.Generator.Random.new/1","doc":"- `prefix`: a string prepended to the generated blank node identifier","ref":"RDF.BlankNode.Generator.Random.html#new/1-options"},{"type":"type","title":"RDF.BlankNode.Generator.Random.t/0","doc":"","ref":"RDF.BlankNode.Generator.Random.html#t:t/0"},{"type":"module","title":"RDF.BlankNode.Generator.UUID","doc":"An implementation of a `RDF.BlankNode.Generator.Algorithm` which returns `RDF.BlankNode`s with random UUID identifiers.","ref":"RDF.BlankNode.Generator.UUID.html"},{"type":"function","title":"RDF.BlankNode.Generator.UUID.new/1","doc":"Creates a struct with the state of the algorithm.","ref":"RDF.BlankNode.Generator.UUID.html#new/1"},{"type":"function","title":"Options - RDF.BlankNode.Generator.UUID.new/1","doc":"- `prefix`: a string prepended to the generated blank node identifier","ref":"RDF.BlankNode.Generator.UUID.html#new/1-options"},{"type":"type","title":"RDF.BlankNode.Generator.UUID.t/0","doc":"","ref":"RDF.BlankNode.Generator.UUID.html#t:t/0"},{"type":"module","title":"RDF.IRI.UUID.Generator","doc":"A `RDF.Resource.Generator` for various kinds of UUID-based IRI identifiers.","ref":"RDF.IRI.UUID.Generator.html"},{"type":"module","title":"Configuration options - RDF.IRI.UUID.Generator","doc":"- `:prefix`: The URI prefix to be prepended to the generated UUID.\n  It can be given also as `RDF.Vocabulary.Namespace` module.\n  If the `:uuid_format` is set explicitly to something other than `:urn`\n  (which is the default), this is a required parameter.\n- `:uuid_version`: The UUID version to be used. Can be any of the\n  integers 1 and 4 for random-based identifiers (4 being the default) and\n  3 and 5 for value-based identifiers (5 being the default).\n- `:uuid_format`: The format of the UUID to be generated. Can be any of the\n  following atoms:\n  - `:urn`: a standard UUID representation, prefixed with the UUID URN\n    (in this case the `:prefix` is not used) (the default when no `:prefix` given)\n  - `:default`: a standard UUID representation, appended to the `:prefix` value\n    (the default when a `:prefix` is given)\n  - `:hex`: a standard UUID without the `-` (dash) characters, appended to the\n    `:prefix` value\n- `:uuid_namespace` (only with `:uuid_version` 3 and 5, where it is a required parameter)\n\nWhen your generator configuration is just for a function producing one of\nthe two kinds of identifiers, you can use these options directly.\nOtherwise, you must provide the identifier-specific configuration under one\nof the keys `:random_based` and `:value_based`.","ref":"RDF.IRI.UUID.Generator.html#module-configuration-options"},{"type":"module","title":"Example configuration - RDF.IRI.UUID.Generator","doc":"config :example, :id,\n      generator: RDF.IRI.UUID.Generator,\n      prefix: \"http://example.com/\",\n      uuid_format: :hex,\n      random_based: [\n        uuid_version: 1\n      ],\n      value_based: [\n        uuid_version: 3,\n        uuid_namespace: UUID.uuid5(:url, \"http://your.application.com/example\")\n      ]","ref":"RDF.IRI.UUID.Generator.html#module-example-configuration"},{"type":"behaviour","title":"RDF.Resource.Generator","doc":"A configurable and customizable way to generate resource identifiers.\n\nThe basis are different implementations of the behaviour defined in this\nmodule for configurable resource identifier generation methods.\n\nGenerally two kinds of identifiers are differentiated:\n\n1. parameter-less identifiers which are generally random\n2. identifiers which are based on some value, where every attempt to create\n   an identifier for the same value, should produce the same identifier\n\nNot all implementations must support both kind of identifiers.\n\nThe `RDF.Resource.Generator` module provides two `generate` functions for the\nkindes of identifiers, `generate/1` for random-based and `generate/2` for\nvalue-based identifiers.\nThe `config` keyword list they take must contain a `:generator` key, which\nprovides the module implementing the `RDF.Resource.Generator` behaviour.\nAll other keywords are specific to the generator implementation.\nWhen the generator is configured differently for the different\nidentifier types, the identifier-type specific configuration can be put under\nthe keys `:random_based` and `:value_based` respectively.\nThe `RDF.Resource.Generator.generate` implementations will be called with the\ngeneral configuration options from the top-level merged with the identifier-type\nspecific configuration.\n\nThe `generate` functions however are usually not called directly.\nSee the [guide](https://rdf-elixir.dev/rdf-ex/resource-generators.html) on\nhow they are meant to be used.\n\nThe following `RDF.Resource.Generator` implementations are provided with RDF.ex:\n\n- `RDF.BlankNode`\n- `RDF.BlankNode.Generator`\n- `RDF.IRI.UUID.Generator`","ref":"RDF.Resource.Generator.html"},{"type":"function","title":"RDF.Resource.Generator.generate/1","doc":"Generates a random resource identifier based on the given `config`.\n\nSee the [guide](https://rdf-elixir.dev/rdf-ex/resource-generators.html) on\nhow it is meant to be used.","ref":"RDF.Resource.Generator.html#generate/1"},{"type":"callback","title":"RDF.Resource.Generator.generate/1","doc":"Generates a random resource identifier based on the given `config`.","ref":"RDF.Resource.Generator.html#c:generate/1"},{"type":"function","title":"RDF.Resource.Generator.generate/2","doc":"Generates a resource identifier based on the given `config` and `value`.\n\nSee the [guide](https://rdf-elixir.dev/rdf-ex/resource-generators.html) on\nhow it is meant to be used.","ref":"RDF.Resource.Generator.html#generate/2"},{"type":"callback","title":"RDF.Resource.Generator.generate/2","doc":"Generates a resource identifier based on the given `config` and `value`.","ref":"RDF.Resource.Generator.html#c:generate/2"},{"type":"callback","title":"RDF.Resource.Generator.generator_config/2","doc":"Allows to normalize the configuration.\n\nThis callback is optional. A default implementation is generated which\nreturns the configuration as-is.","ref":"RDF.Resource.Generator.html#c:generator_config/2"},{"type":"type","title":"RDF.Resource.Generator.id_type/0","doc":"","ref":"RDF.Resource.Generator.html#t:id_type/0"},{"type":"module","title":"RDF.NQuads","doc":"`RDF.NQuads` provides support for the N-Quads serialization format.\n\nN-Quads is a line-based plain-text format for encoding an RDF dataset, i.e. a\ncollection of RDF graphs.\n\nAn example of an RDF statement in N-Quads format:\n\n        \"Hex\"   .\n\nsee","ref":"RDF.NQuads.html"},{"type":"function","title":"RDF.NQuads.read_file/2","doc":"Deserializes a graph or dataset from a file.\n\nIt returns an `{:ok, data}` tuple, with `data` being the deserialized graph or\ndataset, or `{:error, reason}` if an error occurs.","ref":"RDF.NQuads.html#read_file/2"},{"type":"function","title":"Options - RDF.NQuads.read_file/2","doc":"General serialization-independent options:\n\n- `:stream`: Allows to enable reading the data from a file directly via a\nstream (default: `false` on this function, `true` on the bang version)\n- `:gzip`: Allows to read directly from a gzipped file (default: `false`)\n- `:file_mode`: A list with the Elixir `File.open` modes to be used for reading\n  (default: `[:read, :utf8]`)\n\nSee the [module documentation of the decoder](`Elixir.RDF.NQuads.Decoder`) for the\navailable format-specific options, all of which can be used in this\nfunction and will be passed them through to the decoder.","ref":"RDF.NQuads.html#read_file/2-options"},{"type":"function","title":"RDF.NQuads.read_file!/2","doc":"Deserializes a graph or dataset from a file.\n\nAs opposed to `read_file/2`, it raises an exception if an error occurs and\ndefaults to `stream: true`.\n\nSee `read_file/3` for the available format-independent options.\n\nSee the [module documentation of the decoder](`Elixir.RDF.NQuads.Decoder`) for the\navailable format-specific options, all of which can be used in this\nfunction and will be passed them through to the decoder.","ref":"RDF.NQuads.html#read_file!/2"},{"type":"function","title":"RDF.NQuads.read_stream/2","doc":"Deserializes a graph or dataset from a stream.\n\nIt returns an `{:ok, data}` tuple, with `data` being the deserialized graph or\ndataset, or `{:error, reason}` if an error occurs.\n\nSee the [module documentation of the decoder](`Elixir.RDF.NQuads.Decoder`) for the\navailable format-specific options, all of which can be used in this\nfunction and will be passed them through to the decoder.","ref":"RDF.NQuads.html#read_stream/2"},{"type":"function","title":"RDF.NQuads.read_stream!/2","doc":"Deserializes a graph or dataset from a stream.\n\nAs opposed to `read_stream/2`, it raises an exception if an error occurs.\n\nSee the [module documentation of the decoder](`Elixir.RDF.NQuads.Decoder`) for the\navailable format-specific options, all of which can be used in this\nfunction and will be passed them through to the decoder.","ref":"RDF.NQuads.html#read_stream!/2"},{"type":"function","title":"RDF.NQuads.read_string/2","doc":"Deserializes a graph or dataset from a string.\n\nIt returns an `{:ok, data}` tuple, with `data` being the deserialized graph or\ndataset, or `{:error, reason}` if an error occurs.\n\nSee the [module documentation of the decoder](`Elixir.RDF.NQuads.Decoder`) for the\navailable format-specific options, all of which can be used in this\nfunction and will be passed them through to the decoder.","ref":"RDF.NQuads.html#read_string/2"},{"type":"function","title":"RDF.NQuads.read_string!/2","doc":"Deserializes a graph or dataset from a string.\n\nAs opposed to `read_string/2`, it raises an exception if an error occurs.\n\nSee the [module documentation of the decoder](`Elixir.RDF.NQuads.Decoder`) for the\navailable format-specific options, all of which can be used in this\nfunction and will be passed them through to the decoder.","ref":"RDF.NQuads.html#read_string!/2"},{"type":"function","title":"RDF.NQuads.write_file/3","doc":"Serializes an RDF data structure to a file.\n\nIt returns `:ok` if successful or `{:error, reason}` if an error occurs.","ref":"RDF.NQuads.html#write_file/3"},{"type":"function","title":"Options - RDF.NQuads.write_file/3","doc":"General serialization-independent options:\n\n- `:stream`: Allows to enable writing the serialized data to the file directly\n  via a stream. Possible values: `:string` or `:iodata` for writing to the file\n  with a stream of strings respective IO lists, `true` if you want to use streams,\n  but don't care for the exact method or `false` for not writing with\n  a stream (default: `false` on this function, `:iodata` on the bang version)\n- `:gzip`: Allows to write directly to a gzipped file (default: `false`)\n- `:force`: If not set to `true`, an error is raised when the given file\n  already exists (default: `false`)\n- `:file_mode`: A list with the Elixir `File.open` modes to be used for writing\n  (default: `[:write, :exclusive]`)\n\nSee the [module documentation of the encoder](`Elixir.RDF.NQuads.Encoder`) for the\navailable format-specific options, all of which can be used in this\nfunction and will be passed them through to the encoder.","ref":"RDF.NQuads.html#write_file/3-options"},{"type":"function","title":"RDF.NQuads.write_file!/3","doc":"Serializes an RDF data structure to a file.\n\nAs opposed to `write_file/3`, it raises an exception if an error occurs.\n\nSee `write_file/3` for the available format-independent options.\n\nSee the [module documentation of the encoder](`Elixir.RDF.NQuads.Encoder`) for the\navailable format-specific options, all of which can be used in this\nfunction and will be passed them through to the encoder.","ref":"RDF.NQuads.html#write_file!/3"},{"type":"function","title":"RDF.NQuads.write_stream/2","doc":"Serializes an RDF data structure to a stream.\n\nSee the [module documentation of the encoder](`Elixir.RDF.NQuads.Encoder`) for the\navailable format-specific options, all of which can be used in this\nfunction and will be passed them through to the encoder.","ref":"RDF.NQuads.html#write_stream/2"},{"type":"function","title":"RDF.NQuads.write_string/2","doc":"Serializes an RDF data structure to a string.\n\nIt returns an `{:ok, string}` tuple, with `string` being the serialized graph or\ndataset, or `{:error, reason}` if an error occurs.\n\nSee the [module documentation of the encoder](`Elixir.RDF.NQuads.Encoder`) for the\navailable format-specific options, all of which can be used in this\nfunction and will be passed them through to the encoder.","ref":"RDF.NQuads.html#write_string/2"},{"type":"function","title":"RDF.NQuads.write_string!/2","doc":"Serializes an RDF data structure to a string.\n\nAs opposed to `write_string/2`, it raises an exception if an error occurs.\n\nSee the [module documentation of the encoder](`Elixir.RDF.NQuads.Encoder`) for the\navailable format-specific options, all of which can be used in this\nfunction and will be passed them through to the encoder.","ref":"RDF.NQuads.html#write_string!/2"},{"type":"module","title":"RDF.NQuads.Decoder","doc":"A decoder for N-Quads serializations to `RDF.Dataset`s.\n\nAs for all decoders of `RDF.Serialization.Format`s, you normally won't use these\nfunctions directly, but via one of the `read_` functions on the `RDF.NQuads` format\nmodule or the generic `RDF.Serialization` module.","ref":"RDF.NQuads.Decoder.html"},{"type":"module","title":"RDF.NQuads.Encoder","doc":"An encoder for N-Quads serializations of RDF.ex data structures.\n\nAs for all encoders of `RDF.Serialization.Format`s, you normally won't use these\nfunctions directly, but via one of the `write_` functions on the `RDF.NQuads`\nformat module or the generic `RDF.Serialization` module.","ref":"RDF.NQuads.Encoder.html"},{"type":"module","title":"Options - RDF.NQuads.Encoder","doc":"- `:default_graph_name`: The graph name to be used as the default for triples\n  from a `RDF.Graph` or `RDF.Description`. When the input to be encoded is a\n  `RDF.Description` the default is `nil` for the default graph. In case of a\n  `RDF.Graph` the default is the `RDF.Graph.name/1`. The option doesn't\n  have any effect at all when the input to be encoded is a `RDF.Dataset`.\n- `:sort`: Boolean flag which specifies if the encoded statements should\n  be sorted into Unicode code point order (default: `false`).\n  This option is available only on `encode/2`.\n- `:mode`: Allows to specify if the encoded statements should be emitted as\n  strings or IO lists using the value `:string` or `:iodata` respectively\n  (default: `:string`). This option is available only on `stream/2`.","ref":"RDF.NQuads.Encoder.html#module-options"},{"type":"function","title":"RDF.NQuads.Encoder.encode/2","doc":"Encodes the given RDF data in N-Quads format.\n\nSee module documentation for available options.","ref":"RDF.NQuads.Encoder.html#encode/2"},{"type":"function","title":"RDF.NQuads.Encoder.iolist_statement/2","doc":"","ref":"RDF.NQuads.Encoder.html#iolist_statement/2"},{"type":"function","title":"RDF.NQuads.Encoder.iolist_term/1","doc":"","ref":"RDF.NQuads.Encoder.html#iolist_term/1"},{"type":"function","title":"RDF.NQuads.Encoder.statement/2","doc":"","ref":"RDF.NQuads.Encoder.html#statement/2"},{"type":"function","title":"RDF.NQuads.Encoder.stream/2","doc":"Encodes the given RDF data into a stream of N-Quads.\n\nSee module documentation for available options.","ref":"RDF.NQuads.Encoder.html#stream/2"},{"type":"function","title":"RDF.NQuads.Encoder.term/1","doc":"","ref":"RDF.NQuads.Encoder.html#term/1"},{"type":"module","title":"RDF.NTriples","doc":"`RDF.NTriples` provides support for the N-Triples serialization format.\n\nN-Triples is a line-based plain-text format for encoding an RDF graph.\nIt is a very restricted, explicit and well-defined subset of both\n[Turtle](http://www.w3.org/TeamSubmission/turtle/) and\n[Notation3](http://www.w3.org/TeamSubmission/n3/) (N3).\n\nAn example of an RDF statement in N-Triples format:\n\n```ntriples\n    \"Hex\" .\n```\n\nsee","ref":"RDF.NTriples.html"},{"type":"function","title":"RDF.NTriples.read_file/2","doc":"Deserializes a graph or dataset from a file.\n\nIt returns an `{:ok, data}` tuple, with `data` being the deserialized graph or\ndataset, or `{:error, reason}` if an error occurs.","ref":"RDF.NTriples.html#read_file/2"},{"type":"function","title":"Options - RDF.NTriples.read_file/2","doc":"General serialization-independent options:\n\n- `:stream`: Allows to enable reading the data from a file directly via a\nstream (default: `false` on this function, `true` on the bang version)\n- `:gzip`: Allows to read directly from a gzipped file (default: `false`)\n- `:file_mode`: A list with the Elixir `File.open` modes to be used for reading\n  (default: `[:read, :utf8]`)\n\nSee the [module documentation of the decoder](`Elixir.RDF.NTriples.Decoder`) for the\navailable format-specific options, all of which can be used in this\nfunction and will be passed them through to the decoder.","ref":"RDF.NTriples.html#read_file/2-options"},{"type":"function","title":"RDF.NTriples.read_file!/2","doc":"Deserializes a graph or dataset from a file.\n\nAs opposed to `read_file/2`, it raises an exception if an error occurs and\ndefaults to `stream: true`.\n\nSee `read_file/3` for the available format-independent options.\n\nSee the [module documentation of the decoder](`Elixir.RDF.NTriples.Decoder`) for the\navailable format-specific options, all of which can be used in this\nfunction and will be passed them through to the decoder.","ref":"RDF.NTriples.html#read_file!/2"},{"type":"function","title":"RDF.NTriples.read_stream/2","doc":"Deserializes a graph or dataset from a stream.\n\nIt returns an `{:ok, data}` tuple, with `data` being the deserialized graph or\ndataset, or `{:error, reason}` if an error occurs.\n\nSee the [module documentation of the decoder](`Elixir.RDF.NTriples.Decoder`) for the\navailable format-specific options, all of which can be used in this\nfunction and will be passed them through to the decoder.","ref":"RDF.NTriples.html#read_stream/2"},{"type":"function","title":"RDF.NTriples.read_stream!/2","doc":"Deserializes a graph or dataset from a stream.\n\nAs opposed to `read_stream/2`, it raises an exception if an error occurs.\n\nSee the [module documentation of the decoder](`Elixir.RDF.NTriples.Decoder`) for the\navailable format-specific options, all of which can be used in this\nfunction and will be passed them through to the decoder.","ref":"RDF.NTriples.html#read_stream!/2"},{"type":"function","title":"RDF.NTriples.read_string/2","doc":"Deserializes a graph or dataset from a string.\n\nIt returns an `{:ok, data}` tuple, with `data` being the deserialized graph or\ndataset, or `{:error, reason}` if an error occurs.\n\nSee the [module documentation of the decoder](`Elixir.RDF.NTriples.Decoder`) for the\navailable format-specific options, all of which can be used in this\nfunction and will be passed them through to the decoder.","ref":"RDF.NTriples.html#read_string/2"},{"type":"function","title":"RDF.NTriples.read_string!/2","doc":"Deserializes a graph or dataset from a string.\n\nAs opposed to `read_string/2`, it raises an exception if an error occurs.\n\nSee the [module documentation of the decoder](`Elixir.RDF.NTriples.Decoder`) for the\navailable format-specific options, all of which can be used in this\nfunction and will be passed them through to the decoder.","ref":"RDF.NTriples.html#read_string!/2"},{"type":"function","title":"RDF.NTriples.write_file/3","doc":"Serializes an RDF data structure to a file.\n\nIt returns `:ok` if successful or `{:error, reason}` if an error occurs.","ref":"RDF.NTriples.html#write_file/3"},{"type":"function","title":"Options - RDF.NTriples.write_file/3","doc":"General serialization-independent options:\n\n- `:stream`: Allows to enable writing the serialized data to the file directly\n  via a stream. Possible values: `:string` or `:iodata` for writing to the file\n  with a stream of strings respective IO lists, `true` if you want to use streams,\n  but don't care for the exact method or `false` for not writing with\n  a stream (default: `false` on this function, `:iodata` on the bang version)\n- `:gzip`: Allows to write directly to a gzipped file (default: `false`)\n- `:force`: If not set to `true`, an error is raised when the given file\n  already exists (default: `false`)\n- `:file_mode`: A list with the Elixir `File.open` modes to be used for writing\n  (default: `[:write, :exclusive]`)\n\nSee the [module documentation of the encoder](`Elixir.RDF.NTriples.Encoder`) for the\navailable format-specific options, all of which can be used in this\nfunction and will be passed them through to the encoder.","ref":"RDF.NTriples.html#write_file/3-options"},{"type":"function","title":"RDF.NTriples.write_file!/3","doc":"Serializes an RDF data structure to a file.\n\nAs opposed to `write_file/3`, it raises an exception if an error occurs.\n\nSee `write_file/3` for the available format-independent options.\n\nSee the [module documentation of the encoder](`Elixir.RDF.NTriples.Encoder`) for the\navailable format-specific options, all of which can be used in this\nfunction and will be passed them through to the encoder.","ref":"RDF.NTriples.html#write_file!/3"},{"type":"function","title":"RDF.NTriples.write_stream/2","doc":"Serializes an RDF data structure to a stream.\n\nSee the [module documentation of the encoder](`Elixir.RDF.NTriples.Encoder`) for the\navailable format-specific options, all of which can be used in this\nfunction and will be passed them through to the encoder.","ref":"RDF.NTriples.html#write_stream/2"},{"type":"function","title":"RDF.NTriples.write_string/2","doc":"Serializes an RDF data structure to a string.\n\nIt returns an `{:ok, string}` tuple, with `string` being the serialized graph or\ndataset, or `{:error, reason}` if an error occurs.\n\nSee the [module documentation of the encoder](`Elixir.RDF.NTriples.Encoder`) for the\navailable format-specific options, all of which can be used in this\nfunction and will be passed them through to the encoder.","ref":"RDF.NTriples.html#write_string/2"},{"type":"function","title":"RDF.NTriples.write_string!/2","doc":"Serializes an RDF data structure to a string.\n\nAs opposed to `write_string/2`, it raises an exception if an error occurs.\n\nSee the [module documentation of the encoder](`Elixir.RDF.NTriples.Encoder`) for the\navailable format-specific options, all of which can be used in this\nfunction and will be passed them through to the encoder.","ref":"RDF.NTriples.html#write_string!/2"},{"type":"module","title":"RDF.NTriples.Decoder","doc":"A decoder for N-Triples serializations to `RDF.Graph`s.\n\nAs for all decoders of `RDF.Serialization.Format`s, you normally won't use these\nfunctions directly, but via one of the `read_` functions on the `RDF.NTriples` format\nmodule or the generic `RDF.Serialization` module.","ref":"RDF.NTriples.Decoder.html"},{"type":"module","title":"RDF.NTriples.Encoder","doc":"An encoder for N-Triples serializations of RDF.ex data structures.\n\nAs for all encoders of `RDF.Serialization.Format`s, you normally won't use these\nfunctions directly, but via one of the `write_` functions on the `RDF.NTriples`\nformat module or the generic `RDF.Serialization` module.","ref":"RDF.NTriples.Encoder.html"},{"type":"function","title":"RDF.NTriples.Encoder.encode/2","doc":"Encodes the given RDF data in N-Triples format.","ref":"RDF.NTriples.Encoder.html#encode/2"},{"type":"function","title":"Options - RDF.NTriples.Encoder.encode/2","doc":"- `:sort`: Boolean flag which specifies if the encoded triples should\n  be sorted into Unicode code point order (Default: `false`)","ref":"RDF.NTriples.Encoder.html#encode/2-options"},{"type":"function","title":"RDF.NTriples.Encoder.iolist_statement/1","doc":"","ref":"RDF.NTriples.Encoder.html#iolist_statement/1"},{"type":"function","title":"RDF.NTriples.Encoder.iolist_term/1","doc":"","ref":"RDF.NTriples.Encoder.html#iolist_term/1"},{"type":"function","title":"RDF.NTriples.Encoder.statement/1","doc":"","ref":"RDF.NTriples.Encoder.html#statement/1"},{"type":"function","title":"RDF.NTriples.Encoder.stream/2","doc":"Encodes the given RDF data into a stream of N-Triples.","ref":"RDF.NTriples.Encoder.html#stream/2"},{"type":"function","title":"Options - RDF.NTriples.Encoder.stream/2","doc":"- `:mode`: Allows to specify if the encoded statements should be emitted as\n  strings or IO lists using the value `:string` or `:iodata` respectively\n  (Default: `:string`)","ref":"RDF.NTriples.Encoder.html#stream/2-options"},{"type":"function","title":"RDF.NTriples.Encoder.term/1","doc":"","ref":"RDF.NTriples.Encoder.html#term/1"},{"type":"module","title":"RDF.Serialization","doc":"Functions for working with RDF serializations generically.\n\nBesides some reflection functions regarding available serialization formats,\nthis module includes the full serialization reader and writer API from the\nserialization format modules.\nAs opposed to calling the reader and writer functions statically on the\nserialization format module, they can be used more dynamically on this module\neither by providing the format by name or media type with the `:format` option\nor in the case of the read and write function on files by relying on detection\nof the format by file extension.","ref":"RDF.Serialization.html"},{"type":"function","title":"RDF.Serialization.available_formats/0","doc":"The list of all available `RDF.Serialization.Format`s in an application.\n\nA known format might not be available in an application, when the format is\nimplemented in an external library and this not specified as a Mix dependency\nof this application.","ref":"RDF.Serialization.html#available_formats/0"},{"type":"function","title":"Examples - RDF.Serialization.available_formats/0","doc":"iex> RDF.Serialization.available_formats\n    [RDF.Turtle, RDF.TriG, RDF.NTriples, RDF.NQuads]","ref":"RDF.Serialization.html#available_formats/0-examples"},{"type":"function","title":"RDF.Serialization.format/1","doc":"Returns the `RDF.Serialization.Format` with the given name, if available.","ref":"RDF.Serialization.html#format/1"},{"type":"function","title":"Examples - RDF.Serialization.format/1","doc":"iex> RDF.Serialization.format(:turtle)\n    RDF.Turtle\n    iex> RDF.Serialization.format(\"turtle\")\n    RDF.Turtle\n    iex> RDF.Serialization.format(:jsonld)\n    nil  # unless json_ld is defined as a dependency of the application","ref":"RDF.Serialization.html#format/1-examples"},{"type":"function","title":"RDF.Serialization.format_by_extension/1","doc":"Returns the proper `RDF.Serialization.Format` for the given file extension, if available.","ref":"RDF.Serialization.html#format_by_extension/1"},{"type":"function","title":"Examples - RDF.Serialization.format_by_extension/1","doc":"iex> RDF.Serialization.format_by_extension(\"ttl\")\n    RDF.Turtle\n    iex> RDF.Serialization.format_by_extension(\".ttl\")\n    RDF.Turtle\n    iex> RDF.Serialization.format_by_extension(\"jsonld\")\n    nil  # unless json_ld is defined as a dependency of the application","ref":"RDF.Serialization.html#format_by_extension/1-examples"},{"type":"function","title":"RDF.Serialization.format_by_media_type/1","doc":"Returns the `RDF.Serialization.Format` with the given media type, if available.","ref":"RDF.Serialization.html#format_by_media_type/1"},{"type":"function","title":"Examples - RDF.Serialization.format_by_media_type/1","doc":"iex> RDF.Serialization.format_by_media_type(\"text/turtle\")\n    RDF.Turtle\n    iex> RDF.Serialization.format_by_media_type(\"application/ld+json\")\n    nil  # unless json_ld is defined as a dependency of the application","ref":"RDF.Serialization.html#format_by_media_type/1-examples"},{"type":"function","title":"RDF.Serialization.formats/0","doc":"The list of all known `RDF.Serialization.Format`s in the RDF.ex eco-system.\n\nNote: Not all known formats might be available to an application, see `available_formats/0`.","ref":"RDF.Serialization.html#formats/0"},{"type":"function","title":"Examples - RDF.Serialization.formats/0","doc":"iex> RDF.Serialization.formats\n    [RDF.Turtle, RDF.TriG, JSON.LD, RDF.NTriples, RDF.NQuads, RDF.XML]","ref":"RDF.Serialization.html#formats/0-examples"},{"type":"function","title":"RDF.Serialization.read_file/2","doc":"Deserializes a graph or dataset from a file.\n\nIt returns an `{:ok, data}` tuple, with `data` being the deserialized graph or\ndataset, or `{:error, reason}` if an error occurs.","ref":"RDF.Serialization.html#read_file/2"},{"type":"function","title":"Options - RDF.Serialization.read_file/2","doc":"The format can be specified with the `format` option and a format name or the\n`media_type` option and the media type of the format. If none of these are \ngiven, the format gets inferred from the extension of the given file name. \n\nOther available serialization-independent options:\n\n- `:stream`: Allows to enable reading the data from a file directly via a\n  stream (default: `false` on this function, `true` on the bang version)\n- `:gzip`: Allows to read directly from a gzipped file (default: `false`)\n- `:file_mode`: A list with the Elixir `File.open` modes to be used for reading\n  (default: `[:read, :utf8]`)\n\nPlease refer to the documentation of the decoder of a RDF serialization format\nfor format-specific options.","ref":"RDF.Serialization.html#read_file/2-options"},{"type":"function","title":"RDF.Serialization.read_file!/2","doc":"Deserializes a graph or dataset from a file.\n\nAs opposed to `read_file/2`, it raises an exception if an error occurs and\ndefaults to `stream: true`.\n\nThe format can be specified with the `format` option and a format name or the \n`media_type` option and the media type of the format. If none of these are \ngiven, the format gets inferred from the extension of the given file name. \n\nSee `read_file/3` for the available format-independent options.\n\nPlease refer to the documentation of the decoder of a RDF serialization format\nfor format-specific options.","ref":"RDF.Serialization.html#read_file!/2"},{"type":"function","title":"RDF.Serialization.read_stream/2","doc":"Deserializes a graph or dataset from a stream.\n\nIt returns an `{:ok, data}` tuple, with `data` being the deserialized graph or\ndataset, or `{:error, reason}` if an error occurs.\n\nThe format must be specified with the `format` option and a format name or the\n`media_type` option and the media type of the format.\n\nPlease refer to the documentation of the decoder of a RDF serialization format\nfor format-specific options.","ref":"RDF.Serialization.html#read_stream/2"},{"type":"function","title":"RDF.Serialization.read_stream!/2","doc":"Deserializes a graph or dataset from a stream.\n\nAs opposed to `read_stream/2`, it raises an exception if an error occurs.\n\nThe format must be specified with the `format` option and a format name or the\n`media_type` option and the media type of the format.\n\nPlease refer to the documentation of the decoder of a RDF serialization format\nfor format-specific options.","ref":"RDF.Serialization.html#read_stream!/2"},{"type":"function","title":"RDF.Serialization.read_string/2","doc":"Deserializes a graph or dataset from a string.\n\nIt returns an `{:ok, data}` tuple, with `data` being the deserialized graph or\ndataset, or `{:error, reason}` if an error occurs.\n\nThe format must be specified with the `format` option and a format name or the\n`media_type` option and the media type of the format.\n\nPlease refer to the documentation of the decoder of a RDF serialization format\nfor format-specific options.","ref":"RDF.Serialization.html#read_string/2"},{"type":"function","title":"RDF.Serialization.read_string!/2","doc":"Deserializes a graph or dataset from a string.\n\nAs opposed to `read_string/2`, it raises an exception if an error occurs.\n\nThe format must be specified with the `format` option and a format name or the\n`media_type` option and the media type of the format.\n\nPlease refer to the documentation of the decoder of a RDF serialization format\nfor format-specific options.","ref":"RDF.Serialization.html#read_string!/2"},{"type":"function","title":"RDF.Serialization.write_file/3","doc":"Serializes a RDF data structure to a file.\n\nIt returns `:ok` if successful or `{:error, reason}` if an error occurs.","ref":"RDF.Serialization.html#write_file/3"},{"type":"function","title":"Options - RDF.Serialization.write_file/3","doc":"The format can be specified with the `format` option and a format name or the\n`media_type` option and the media type of the format. If none of these are\ngiven, the format gets inferred from the extension of the given file name.\n\nOther available serialization-independent options:\n\n- `:stream`: Allows to enable writing the serialized data to the file directly\n  via a stream. Possible values: `:string` or `:iodata` for writing to the file\n  with a stream of strings respective IO lists, `true` if you want to use streams,\n  but don't care for the exact method or `false` for not writing with\n  a stream (default: `false` on this function, `:iodata` on the bang version)\n- `:gzip`: Allows to write directly to a gzipped file (default: `false`)\n- `:force`: If not set to `true`, an error is raised when the given file\n  already exists (default: `false`)\n- `:file_mode`: A list with the Elixir `File.open` modes to be used for writing\n  (default: `[:write, :exclusive]`)\n\nPlease refer to the documentation of the encoder of a RDF serialization format\nfor format-specific options.","ref":"RDF.Serialization.html#write_file/3-options"},{"type":"function","title":"RDF.Serialization.write_file!/3","doc":"Serializes a RDF data structure to a file.\n\nAs opposed to `write_file/3`, it raises an exception if an error occurs.\n\nSee `write_file/3` for the available format-independent options.\n\nPlease refer to the documentation of the encoder of a RDF serialization format\nfor format-specific options.","ref":"RDF.Serialization.html#write_file!/3"},{"type":"function","title":"RDF.Serialization.write_stream/2","doc":"Serializes a RDF data structure to a stream.\n\nThe format must be specified with the `format` option and a format name or the\n`media_type` option and the media type of the format.\n\nPlease refer to the documentation of the encoder of a RDF serialization format\nfor format-specific options and what the stream emits.","ref":"RDF.Serialization.html#write_stream/2"},{"type":"function","title":"RDF.Serialization.write_string/2","doc":"Serializes a RDF data structure to a string.\n\nIt returns an `{:ok, string}` tuple, with `string` being the serialized graph or\ndataset, or `{:error, reason}` if an error occurs.\n\nThe format must be specified with the `format` option and a format name or the\n`media_type` option and the media type of the format.\n\nPlease refer to the documentation of the encoder of a RDF serialization format\nfor format-specific options.","ref":"RDF.Serialization.html#write_string/2"},{"type":"function","title":"RDF.Serialization.write_string!/2","doc":"Serializes a RDF data structure to a string.\n\nAs opposed to `write_string/2`, it raises an exception if an error occurs.\n\nThe format must be specified with the `format` option and a format name or the\n`media_type` option and the media type of the format.\n\nPlease refer to the documentation of the encoder of a RDF serialization format\nfor format-specific options.","ref":"RDF.Serialization.html#write_string!/2"},{"type":"type","title":"RDF.Serialization.format/0","doc":"","ref":"RDF.Serialization.html#t:format/0"},{"type":"behaviour","title":"RDF.Serialization.Decoder","doc":"A behaviour for decoders of strings encoded in a specific `RDF.Serialization` format.","ref":"RDF.Serialization.Decoder.html"},{"type":"callback","title":"RDF.Serialization.Decoder.decode/1","doc":"Decodes a serialized `RDF.Graph` or `RDF.Dataset` from a string.\n\nIt returns an `{:ok, data}` tuple, with `data` being the deserialized graph or\ndataset, or `{:error, reason}` if an error occurs.","ref":"RDF.Serialization.Decoder.html#c:decode/1"},{"type":"callback","title":"RDF.Serialization.Decoder.decode/2","doc":"Decodes a serialized `RDF.Graph` or `RDF.Dataset` from a string.\n\nIt returns an `{:ok, data}` tuple, with `data` being the deserialized graph or\ndataset, or `{:error, reason}` if an error occurs.","ref":"RDF.Serialization.Decoder.html#c:decode/2"},{"type":"callback","title":"RDF.Serialization.Decoder.decode!/1","doc":"Decodes a serialized `RDF.Graph` or `RDF.Dataset` from a string.\n\nAs opposed to `decode/2`, it raises an exception if an error occurs.\n\nNote: The `__using__` macro automatically provides an overridable default\nimplementation based on the non-bang `decode` function.","ref":"RDF.Serialization.Decoder.html#c:decode!/1"},{"type":"callback","title":"RDF.Serialization.Decoder.decode!/2","doc":"Decodes a serialized `RDF.Graph` or `RDF.Dataset` from a string.\n\nAs opposed to `decode/2`, it raises an exception if an error occurs.\n\nNote: The `__using__` macro automatically provides an overridable default\nimplementation based on the non-bang `decode` function.","ref":"RDF.Serialization.Decoder.html#c:decode!/2"},{"type":"callback","title":"RDF.Serialization.Decoder.decode_from_stream/2","doc":"Decodes a serialized `RDF.Graph` or `RDF.Dataset` from a stream.\n\nIt returns an `{:ok, data}` tuple, with `data` being the deserialized graph or\ndataset, or `{:error, reason}` if an error occurs.","ref":"RDF.Serialization.Decoder.html#c:decode_from_stream/2"},{"type":"callback","title":"RDF.Serialization.Decoder.decode_from_stream!/2","doc":"Decodes a serialized `RDF.Graph` or `RDF.Dataset` from a stream.\n\nAs opposed to `decode_from_stream/2`, it raises an exception if an error occurs.\n\nNote: The `__using__` macro automatically provides an overridable default\nimplementation based on the non-bang `decode` function.","ref":"RDF.Serialization.Decoder.html#c:decode_from_stream!/2"},{"type":"behaviour","title":"RDF.Serialization.Encoder","doc":"A behaviour for encoders of RDF data structures in a specific `RDF.Serialization` format.","ref":"RDF.Serialization.Encoder.html"},{"type":"callback","title":"RDF.Serialization.Encoder.encode/1","doc":"Serializes an RDF data structure into a string.\n\nIt should return an `{:ok, string}` tuple, with `string` being the serialized\nRDF data structure, or `{:error, reason}` if an error occurs.","ref":"RDF.Serialization.Encoder.html#c:encode/1"},{"type":"callback","title":"RDF.Serialization.Encoder.encode/2","doc":"Serializes an RDF data structure into a string.\n\nIt should return an `{:ok, string}` tuple, with `string` being the serialized\nRDF data structure, or `{:error, reason}` if an error occurs.","ref":"RDF.Serialization.Encoder.html#c:encode/2"},{"type":"callback","title":"RDF.Serialization.Encoder.encode!/1","doc":"Serializes an RDF data structure into a string.\n\nAs opposed to `encode`, it raises an exception if an error occurs.\n\nNote: The `__using__` macro automatically provides an overridable default\nimplementation based on the non-bang `encode` function.","ref":"RDF.Serialization.Encoder.html#c:encode!/1"},{"type":"callback","title":"RDF.Serialization.Encoder.encode!/2","doc":"Serializes an RDF data structure into a string.\n\nAs opposed to `encode`, it raises an exception if an error occurs.\n\nNote: The `__using__` macro automatically provides an overridable default\nimplementation based on the non-bang `encode` function.","ref":"RDF.Serialization.Encoder.html#c:encode!/2"},{"type":"callback","title":"RDF.Serialization.Encoder.stream/2","doc":"Serializes an RDF data structure into a stream.\n\nIt should return a stream emitting either strings or iodata of the\nserialized RDF data structure. If both forms are supported the form\nshould be configurable via the `:mode` option and its values `:string`\nrespective `:iodata`.","ref":"RDF.Serialization.Encoder.html#c:stream/2"},{"type":"behaviour","title":"RDF.Serialization.Format","doc":"A behaviour for RDF serialization formats.\n\nA serialization format can be implemented like this\n\n    defmodule SomeFormat do\n      use RDF.Serialization.Format\n      import RDF.Sigils\n\n      @id         ~I \n      @name       :some_format\n      @extension  \"ext\"\n      @media_type \"application/some-format\"\n    end\n\nWhen `@id`, `@name`, `@extension` and `@media_type` module attributes are\ndefined the resp. behaviour functions are generated automatically and return\nthese values.\n\nThen you'll have to do the main work by implementing a\n`RDF.Serialization.Encoder` and a `RDF.Serialization.Decoder` for the format.\n\nBy default, it is assumed that these are defined in `Encoder` and `Decoder`\nmodules under the `RDF.Serialization.Format` module of the format, i.e. in the\nexample above in `SomeFormat.Encoder` and `SomeFormat.Decoder`. If you want\nthem in another module, you'll have to override the `encoder/0` and/or\n`decoder/0` functions in your `RDF.Serialization.Format` module.","ref":"RDF.Serialization.Format.html"},{"type":"callback","title":"RDF.Serialization.Format.decoder/0","doc":"The `RDF.Serialization.Decoder` module for the serialization format.","ref":"RDF.Serialization.Format.html#c:decoder/0"},{"type":"callback","title":"RDF.Serialization.Format.encoder/0","doc":"The `RDF.Serialization.Encoder` module for the serialization format.","ref":"RDF.Serialization.Format.html#c:encoder/0"},{"type":"callback","title":"RDF.Serialization.Format.extension/0","doc":"The usual file extension for the serialization format.","ref":"RDF.Serialization.Format.html#c:extension/0"},{"type":"callback","title":"RDF.Serialization.Format.id/0","doc":"An IRI of the serialization format.","ref":"RDF.Serialization.Format.html#c:id/0"},{"type":"callback","title":"RDF.Serialization.Format.media_type/0","doc":"The MIME type of the serialization format.","ref":"RDF.Serialization.Format.html#c:media_type/0"},{"type":"callback","title":"RDF.Serialization.Format.name/0","doc":"The name atom of the serialization format.","ref":"RDF.Serialization.Format.html#c:name/0"},{"type":"module","title":"RDF.TriG","doc":"`RDF.TriG` provides support for the TriG serialization format.\n\nSee `RDF.TriG.Decoder` and `RDF.TriG.Encoder` for the available options\non the read and write functions.\n\nFor more on TriG see  .","ref":"RDF.TriG.html"},{"type":"function","title":"RDF.TriG.read_file/2","doc":"Deserializes a graph or dataset from a file.\n\nIt returns an `{:ok, data}` tuple, with `data` being the deserialized graph or\ndataset, or `{:error, reason}` if an error occurs.","ref":"RDF.TriG.html#read_file/2"},{"type":"function","title":"Options - RDF.TriG.read_file/2","doc":"General serialization-independent options:\n\n- `:stream`: Allows to enable reading the data from a file directly via a\nstream (default: `false` on this function, `true` on the bang version)\n- `:gzip`: Allows to read directly from a gzipped file (default: `false`)\n- `:file_mode`: A list with the Elixir `File.open` modes to be used for reading\n  (default: `[:read, :utf8]`)\n\nSee the [module documentation of the decoder](`Elixir.RDF.TriG.Decoder`) for the\navailable format-specific options, all of which can be used in this\nfunction and will be passed them through to the decoder.","ref":"RDF.TriG.html#read_file/2-options"},{"type":"function","title":"RDF.TriG.read_file!/2","doc":"Deserializes a graph or dataset from a file.\n\nAs opposed to `read_file/2`, it raises an exception if an error occurs and\ndefaults to `stream: true`.\n\nSee `read_file/3` for the available format-independent options.\n\nSee the [module documentation of the decoder](`Elixir.RDF.TriG.Decoder`) for the\navailable format-specific options, all of which can be used in this\nfunction and will be passed them through to the decoder.","ref":"RDF.TriG.html#read_file!/2"},{"type":"function","title":"RDF.TriG.read_stream/2","doc":"Deserializes a graph or dataset from a stream.\n\nIt returns an `{:ok, data}` tuple, with `data` being the deserialized graph or\ndataset, or `{:error, reason}` if an error occurs.\n\nSee the [module documentation of the decoder](`Elixir.RDF.TriG.Decoder`) for the\navailable format-specific options, all of which can be used in this\nfunction and will be passed them through to the decoder.","ref":"RDF.TriG.html#read_stream/2"},{"type":"function","title":"RDF.TriG.read_stream!/2","doc":"Deserializes a graph or dataset from a stream.\n\nAs opposed to `read_stream/2`, it raises an exception if an error occurs.\n\nSee the [module documentation of the decoder](`Elixir.RDF.TriG.Decoder`) for the\navailable format-specific options, all of which can be used in this\nfunction and will be passed them through to the decoder.","ref":"RDF.TriG.html#read_stream!/2"},{"type":"function","title":"RDF.TriG.read_string/2","doc":"Deserializes a graph or dataset from a string.\n\nIt returns an `{:ok, data}` tuple, with `data` being the deserialized graph or\ndataset, or `{:error, reason}` if an error occurs.\n\nSee the [module documentation of the decoder](`Elixir.RDF.TriG.Decoder`) for the\navailable format-specific options, all of which can be used in this\nfunction and will be passed them through to the decoder.","ref":"RDF.TriG.html#read_string/2"},{"type":"function","title":"RDF.TriG.read_string!/2","doc":"Deserializes a graph or dataset from a string.\n\nAs opposed to `read_string/2`, it raises an exception if an error occurs.\n\nSee the [module documentation of the decoder](`Elixir.RDF.TriG.Decoder`) for the\navailable format-specific options, all of which can be used in this\nfunction and will be passed them through to the decoder.","ref":"RDF.TriG.html#read_string!/2"},{"type":"function","title":"RDF.TriG.write_file/3","doc":"Serializes an RDF data structure to a file.\n\nIt returns `:ok` if successful or `{:error, reason}` if an error occurs.","ref":"RDF.TriG.html#write_file/3"},{"type":"function","title":"Options - RDF.TriG.write_file/3","doc":"General serialization-independent options:\n\n- `:stream`: Allows to enable writing the serialized data to the file directly\n  via a stream. Possible values: `:string` or `:iodata` for writing to the file\n  with a stream of strings respective IO lists, `true` if you want to use streams,\n  but don't care for the exact method or `false` for not writing with\n  a stream (default: `false` on this function, `:iodata` on the bang version)\n- `:gzip`: Allows to write directly to a gzipped file (default: `false`)\n- `:force`: If not set to `true`, an error is raised when the given file\n  already exists (default: `false`)\n- `:file_mode`: A list with the Elixir `File.open` modes to be used for writing\n  (default: `[:write, :exclusive]`)\n\nSee the [module documentation of the encoder](`Elixir.RDF.TriG.Encoder`) for the\navailable format-specific options, all of which can be used in this\nfunction and will be passed them through to the encoder.","ref":"RDF.TriG.html#write_file/3-options"},{"type":"function","title":"RDF.TriG.write_file!/3","doc":"Serializes an RDF data structure to a file.\n\nAs opposed to `write_file/3`, it raises an exception if an error occurs.\n\nSee `write_file/3` for the available format-independent options.\n\nSee the [module documentation of the encoder](`Elixir.RDF.TriG.Encoder`) for the\navailable format-specific options, all of which can be used in this\nfunction and will be passed them through to the encoder.","ref":"RDF.TriG.html#write_file!/3"},{"type":"function","title":"RDF.TriG.write_string/2","doc":"Serializes an RDF data structure to a string.\n\nIt returns an `{:ok, string}` tuple, with `string` being the serialized graph or\ndataset, or `{:error, reason}` if an error occurs.\n\nSee the [module documentation of the encoder](`Elixir.RDF.TriG.Encoder`) for the\navailable format-specific options, all of which can be used in this\nfunction and will be passed them through to the encoder.","ref":"RDF.TriG.html#write_string/2"},{"type":"function","title":"RDF.TriG.write_string!/2","doc":"Serializes an RDF data structure to a string.\n\nAs opposed to `write_string/2`, it raises an exception if an error occurs.\n\nSee the [module documentation of the encoder](`Elixir.RDF.TriG.Encoder`) for the\navailable format-specific options, all of which can be used in this\nfunction and will be passed them through to the encoder.","ref":"RDF.TriG.html#write_string!/2"},{"type":"module","title":"RDF.TriG.Decoder","doc":"A decoder for TriG serializations to `RDF.Dataset`s.\n\nAs for all decoders of `RDF.Serialization.Format`s, you normally won't use these\nfunctions directly, but via one of the `read_` functions on the `RDF.TriG` format\nmodule or the generic `RDF.Serialization` module.","ref":"RDF.TriG.Decoder.html"},{"type":"module","title":"Blank Node Generation - RDF.TriG.Decoder","doc":"When interpreting blank node descriptions, the decoder generates blank node\nidentifiers. By default, it uses `RDF.BlankNode.Generator.UUID` to create\nrandom identifiers, ensuring uniqueness across multiple parsing operations.\nThis behavior prevents unintended merging of unrelated blank nodes,\nwhich could occur with deterministic identifiers, e.g. from\n`RDF.BlankNode.Generator.Increment`.\n\nYou can customize blank node generation using the `bnode_gen` option and\nproviding either a module implementing `RDF.BlankNode.Generator.Algorithm`\nor an instantiated `RDF.BlankNode.Generator.Algorithm` struct in case you\nwant to customize the generator. See the respective\n`RDF.BlankNode.Generator.Algorithm` implementation on what fields can be set.\nYou can also use `:uuid`, `:random` or `:increment` as short values for the\nrespective `RDF.BlankNode.Generator.Algorithm` implementations.\n\nExample usage:\n\n    RDF.Turtle.Decoder.decode!(turtle_string,\n      bnode_gen: RDF.BlankNode.Generator.Increment.new(prefix: \"x\", counter: 42))\n\nTo set a global or environment-specific default, use the `turtle_trig_decoder_bnode_gen`\napplication config (e.g. the `RDF.BlankNode.Generator.Increment` implementation,\ngenerating deterministic blank nodes, can make testing easier):\n\n    config :rdf,\n      turtle_trig_decoder_bnode_gen: :increment","ref":"RDF.TriG.Decoder.html#module-blank-node-generation"},{"type":"module","title":"Other options - RDF.TriG.Decoder","doc":"- `:base`: allows to specify the base URI to be used against relative URIs\n  when no base URI is defined with a `@base` directive within the document","ref":"RDF.TriG.Decoder.html#module-other-options"},{"type":"function","title":"RDF.TriG.Decoder.parse/1","doc":"","ref":"RDF.TriG.Decoder.html#parse/1"},{"type":"function","title":"RDF.TriG.Decoder.tokenize/1","doc":"","ref":"RDF.TriG.Decoder.html#tokenize/1"},{"type":"module","title":"RDF.TriG.Encoder","doc":"An encoder for TriG serializations of RDF.ex data structures.\n\nAs for all encoders of `RDF.Serialization.Format`s, you normally won't use these\nfunctions directly, but via one of the `write_` functions on the `RDF.TriG`\nformat module or the generic `RDF.Serialization` module.","ref":"RDF.TriG.Encoder.html"},{"type":"module","title":"Options - RDF.TriG.Encoder","doc":"- `:content`: Allows specifying the content and structure of the Turtle document\n  to be rendered and defining which parts should be generated in which order.\n  This option accepts lists of the values `:base`, `:prefixes`, `:default_graph` and `:named_graphs`.\n  You can also use `:directives` to specify `[:base, :prefixes]` and `:graphs`\n  to specify `[:default_graph, :named_graphs]` as a group.\n  Additionally, arbitrary strings can be included at desired positions to customize\n  the document.\n\n      RDF.TriG.write_string(dataset, content: [\n        \"# === HEADER ===\\n\\n\",\n        :directives,\n        \"\\n# === NAMED GRAPHS ===\\n\\n\",\n        :named_graphs\n        \"\\n# === DEFAULT GRAPH ===\\n\\n\",\n        :default_graph\n      ])\n\n- `:prefixes`: Allows to specify the prefixes to be used as a `RDF.PrefixMap` or\n  anything from which a `RDF.PrefixMap` can be created with `RDF.PrefixMap.new/1`.\n  If not specified the prefixes from all the graphs of the given dataset are used\n  or if these are also not present the `RDF.default_prefixes/0`.\n- `:base`: : Allows to specify the base URI to be used for a `@base` directive.\n  If not specified the `RDF.default_base_iri/0` is used.\n- `:directive_style`: Specifies the style of directives to be used in the document.\n  Possible values are `:turtle` and `:sparql` (default: `:turtle`).\n- `:implicit_base`: This boolean flag allows to use a base URI to get relative IRIs\n  without embedding it explicitly in the content with a `@base` directive, so that\n  the URIs will be resolved according to the remaining strategy specified in\n  section 5.1 of [RFC3986](https://www.ietf.org/rfc/rfc3986.txt) (default: `false`).\n- `:base_description`: Allows to provide a description of the resource denoted by\n  the base URI. This option is especially useful when the base URI is actually not\n  specified, e.g. in the common use case of wanting to describe the document\n  itself, which should be denoted by the URL where it is hosted as the implicit base\n  URI.\n- `:line_prefix`: Allows to specify a function returning prefixes for the encoded lines.\n  When this function is defined, the `:single_triple_lines` option is implicitly set, so\n  that each line encodes at most one triple.\n  The function receives three arguments:\n  1. `type` - one of the following values specifying the content of the line: `:triple`,\n    `:description`, `:graph` (for named graphs in TriG only), `:closing`\n  2. `value` - a `type` specific value for the content in this line\n      - for `:triple`: the `RDF.Triple` encoded in this line\n      - for `:description`: the subject whose description is started in this line\n      - for `:graph`: the name of the graph, opened in this line\n      - for `:closing`: a value specifying which element is closed in this line\n  3. `graph_name` - the name of graph (in Turtle this is always `nil`)\n- `:single_triple_lines`: When set to `true` each line encodes at most one triple, i.e.\n   no object lists with multiple objects are used and no Turtle list encodings are used.\n   This option is in of itself is not very useful. It is set implicitly when defining\n   a `:line_prefix` function which depends on this mode to produce useful results.\n- `:indent`: Allows to specify the number of spaces the output should be indented.\n- `:indent_width`: Allows to specify the number of spaces that should be used for\n  indentations (default: 4).\n- `:pn_local_validation`: This option controls how IRIs are validated the check\n   whether they can encoded as a prefixed name. Available settings are:\n  - `:fast` (default): Provides a quick and efficient validation that covers most\n    common cases. It does not handle every possible valid scenario, focusing instead\n    on typical structures encountered in prefixed names.\n  - `:none`: Disables validation entirely. Use this mode if you are confident that\n    all your IRIs are already compliant with prefixed name requirements, allowing you\n    to bypass validation checks for increased performance.\n  - Note: Currently, a `:strict` mode, which would provide comprehensive validation\n    conforming strictly to the Turtle specification, is not implemented.\n    Contributions for implementing this mode are welcome.\n- `:rdf_star`: Allows to skip a RDF-star related preprocessing step. This can be\n   used to improve performance a little bit when you know the encoded data doesn't\n   include any RDF-star statements. Defaults to the returned value of `RDF.star?/0`.","ref":"RDF.TriG.Encoder.html#module-options"},{"type":"module","title":"RDF.Turtle","doc":"`RDF.Turtle` provides support for the Turtle serialization format.\n\nSee `RDF.Turtle.Decoder` and `RDF.Turtle.Encoder` for the available options\non the read and write functions.\n\nFor more on Turtle see  .","ref":"RDF.Turtle.html"},{"type":"function","title":"RDF.Turtle.read_file/2","doc":"Deserializes a graph or dataset from a file.\n\nIt returns an `{:ok, data}` tuple, with `data` being the deserialized graph or\ndataset, or `{:error, reason}` if an error occurs.","ref":"RDF.Turtle.html#read_file/2"},{"type":"function","title":"Options - RDF.Turtle.read_file/2","doc":"General serialization-independent options:\n\n- `:stream`: Allows to enable reading the data from a file directly via a\nstream (default: `false` on this function, `true` on the bang version)\n- `:gzip`: Allows to read directly from a gzipped file (default: `false`)\n- `:file_mode`: A list with the Elixir `File.open` modes to be used for reading\n  (default: `[:read, :utf8]`)\n\nSee the [module documentation of the decoder](`Elixir.RDF.Turtle.Decoder`) for the\navailable format-specific options, all of which can be used in this\nfunction and will be passed them through to the decoder.","ref":"RDF.Turtle.html#read_file/2-options"},{"type":"function","title":"RDF.Turtle.read_file!/2","doc":"Deserializes a graph or dataset from a file.\n\nAs opposed to `read_file/2`, it raises an exception if an error occurs and\ndefaults to `stream: true`.\n\nSee `read_file/3` for the available format-independent options.\n\nSee the [module documentation of the decoder](`Elixir.RDF.Turtle.Decoder`) for the\navailable format-specific options, all of which can be used in this\nfunction and will be passed them through to the decoder.","ref":"RDF.Turtle.html#read_file!/2"},{"type":"function","title":"RDF.Turtle.read_stream/2","doc":"Deserializes a graph or dataset from a stream.\n\nIt returns an `{:ok, data}` tuple, with `data` being the deserialized graph or\ndataset, or `{:error, reason}` if an error occurs.\n\nSee the [module documentation of the decoder](`Elixir.RDF.Turtle.Decoder`) for the\navailable format-specific options, all of which can be used in this\nfunction and will be passed them through to the decoder.","ref":"RDF.Turtle.html#read_stream/2"},{"type":"function","title":"RDF.Turtle.read_stream!/2","doc":"Deserializes a graph or dataset from a stream.\n\nAs opposed to `read_stream/2`, it raises an exception if an error occurs.\n\nSee the [module documentation of the decoder](`Elixir.RDF.Turtle.Decoder`) for the\navailable format-specific options, all of which can be used in this\nfunction and will be passed them through to the decoder.","ref":"RDF.Turtle.html#read_stream!/2"},{"type":"function","title":"RDF.Turtle.read_string/2","doc":"Deserializes a graph or dataset from a string.\n\nIt returns an `{:ok, data}` tuple, with `data` being the deserialized graph or\ndataset, or `{:error, reason}` if an error occurs.\n\nSee the [module documentation of the decoder](`Elixir.RDF.Turtle.Decoder`) for the\navailable format-specific options, all of which can be used in this\nfunction and will be passed them through to the decoder.","ref":"RDF.Turtle.html#read_string/2"},{"type":"function","title":"RDF.Turtle.read_string!/2","doc":"Deserializes a graph or dataset from a string.\n\nAs opposed to `read_string/2`, it raises an exception if an error occurs.\n\nSee the [module documentation of the decoder](`Elixir.RDF.Turtle.Decoder`) for the\navailable format-specific options, all of which can be used in this\nfunction and will be passed them through to the decoder.","ref":"RDF.Turtle.html#read_string!/2"},{"type":"function","title":"RDF.Turtle.write_file/3","doc":"Serializes an RDF data structure to a file.\n\nIt returns `:ok` if successful or `{:error, reason}` if an error occurs.","ref":"RDF.Turtle.html#write_file/3"},{"type":"function","title":"Options - RDF.Turtle.write_file/3","doc":"General serialization-independent options:\n\n- `:stream`: Allows to enable writing the serialized data to the file directly\n  via a stream. Possible values: `:string` or `:iodata` for writing to the file\n  with a stream of strings respective IO lists, `true` if you want to use streams,\n  but don't care for the exact method or `false` for not writing with\n  a stream (default: `false` on this function, `:iodata` on the bang version)\n- `:gzip`: Allows to write directly to a gzipped file (default: `false`)\n- `:force`: If not set to `true`, an error is raised when the given file\n  already exists (default: `false`)\n- `:file_mode`: A list with the Elixir `File.open` modes to be used for writing\n  (default: `[:write, :exclusive]`)\n\nSee the [module documentation of the encoder](`Elixir.RDF.Turtle.Encoder`) for the\navailable format-specific options, all of which can be used in this\nfunction and will be passed them through to the encoder.","ref":"RDF.Turtle.html#write_file/3-options"},{"type":"function","title":"RDF.Turtle.write_file!/3","doc":"Serializes an RDF data structure to a file.\n\nAs opposed to `write_file/3`, it raises an exception if an error occurs.\n\nSee `write_file/3` for the available format-independent options.\n\nSee the [module documentation of the encoder](`Elixir.RDF.Turtle.Encoder`) for the\navailable format-specific options, all of which can be used in this\nfunction and will be passed them through to the encoder.","ref":"RDF.Turtle.html#write_file!/3"},{"type":"function","title":"RDF.Turtle.write_string/2","doc":"Serializes an RDF data structure to a string.\n\nIt returns an `{:ok, string}` tuple, with `string` being the serialized graph or\ndataset, or `{:error, reason}` if an error occurs.\n\nSee the [module documentation of the encoder](`Elixir.RDF.Turtle.Encoder`) for the\navailable format-specific options, all of which can be used in this\nfunction and will be passed them through to the encoder.","ref":"RDF.Turtle.html#write_string/2"},{"type":"function","title":"RDF.Turtle.write_string!/2","doc":"Serializes an RDF data structure to a string.\n\nAs opposed to `write_string/2`, it raises an exception if an error occurs.\n\nSee the [module documentation of the encoder](`Elixir.RDF.Turtle.Encoder`) for the\navailable format-specific options, all of which can be used in this\nfunction and will be passed them through to the encoder.","ref":"RDF.Turtle.html#write_string!/2"},{"type":"module","title":"RDF.Turtle.Decoder","doc":"A decoder for Turtle serializations to `RDF.Graph`s.\n\nAs for all decoders of `RDF.Serialization.Format`s, you normally won't use these\nfunctions directly, but via one of the `read_` functions on the `RDF.Turtle` format\nmodule or the generic `RDF.Serialization` module.","ref":"RDF.Turtle.Decoder.html"},{"type":"module","title":"Blank Node Generation - RDF.Turtle.Decoder","doc":"When interpreting blank node descriptions, the decoder generates blank node\nidentifiers. By default, it uses `RDF.BlankNode.Generator.UUID` to create\nrandom identifiers, ensuring uniqueness across multiple parsing operations.\nThis behavior prevents unintended merging of unrelated blank nodes,\nwhich could occur with deterministic identifiers, e.g. from\n`RDF.BlankNode.Generator.Increment`.\n\nYou can customize blank node generation using the `bnode_gen` option and\nproviding either a module implementing `RDF.BlankNode.Generator.Algorithm`\nor an instantiated `RDF.BlankNode.Generator.Algorithm` struct in case you\nwant to customize the generator. See the respective\n`RDF.BlankNode.Generator.Algorithm` implementation on what fields can be set.\nYou can also use `:uuid`, `:random` or `:increment` as short values for the\nrespective `RDF.BlankNode.Generator.Algorithm` implementations.\n\nExample usage:\n\n    RDF.Turtle.Decoder.decode!(turtle_string,\n      bnode_gen: RDF.BlankNode.Generator.Increment.new(prefix: \"x\", counter: 42))\n\nTo set a global or environment-specific default, use the `turtle_trig_decoder_bnode_gen`\napplication config (e.g. the `RDF.BlankNode.Generator.Increment` implementation,\ngenerating deterministic blank nodes, can make testing easier):\n\n    config :rdf,\n      turtle_trig_decoder_bnode_gen: :increment","ref":"RDF.Turtle.Decoder.html#module-blank-node-generation"},{"type":"module","title":"Other options - RDF.Turtle.Decoder","doc":"- `:base`: allows to specify the base URI to be used against relative URIs\n  when no base URI is defined with a `@base` directive within the document","ref":"RDF.Turtle.Decoder.html#module-other-options"},{"type":"function","title":"RDF.Turtle.Decoder.parse/1","doc":"","ref":"RDF.Turtle.Decoder.html#parse/1"},{"type":"function","title":"RDF.Turtle.Decoder.tokenize/1","doc":"","ref":"RDF.Turtle.Decoder.html#tokenize/1"},{"type":"module","title":"RDF.Turtle.Encoder","doc":"An encoder for Turtle serializations of RDF.ex data structures.\n\nAs for all encoders of `RDF.Serialization.Format`s, you normally won't use these\nfunctions directly, but via one of the `write_` functions on the `RDF.Turtle`\nformat module or the generic `RDF.Serialization` module.","ref":"RDF.Turtle.Encoder.html"},{"type":"module","title":"Options - RDF.Turtle.Encoder","doc":"- `:content`: Allows specifying the content and structure of the Turtle document\n  to be rendered and defining which parts should be generated in which order.\n  This option accepts lists of the values `:base`, `:prefixes`, and `:triples`.\n  You can also use `:directives` to specify `[:base, :prefixes]` as a group.\n  Additionally, arbitrary strings can be included at desired positions to customize\n  the document.\n\n      RDF.Turtle.write_string(graph, content: [\n        \"# === HEADER ===\",\n        :directives,\n        \"\\n# === TRIPLES ===\",\n        :triples\n      ])\n\n- `:prefixes`: Allows to specify the prefixes to be used as a `RDF.PrefixMap` or\n  anything from which a `RDF.PrefixMap` can be created with `RDF.PrefixMap.new/1`.\n  If not specified the ones from the given graph are used or if these are also not\n  present the `RDF.default_prefixes/0`. If you explicitly want to omit the prefixes\n  use `[]` as a value.\n- `:base`: : Allows to specify the base URI to be used for a `@base` directive.\n  If not specified the one from the given graph is used or if there is also none\n  specified for the graph the `RDF.default_base_iri/0`.\n- `:directive_style`: Specifies the style of directives to be used in the document.\n  Possible values are `:turtle` and `:sparql` (default: `:turtle`).\n- `:implicit_base`: This boolean flag allows to use a base URI to get relative IRIs\n  without embedding it explicitly in the content with a `@base` directive, so that\n  the URIs will be resolved according to the remaining strategy specified in\n  section 5.1 of [RFC3986](https://www.ietf.org/rfc/rfc3986.txt) (default: `false`).\n- `:base_description`: Allows to provide a description of the resource denoted by\n  the base URI. This option is especially useful when the base URI is actually not\n  specified, e.g. in the common use case of wanting to describe the document\n  itself, which should be denoted by the URL where it is hosted as the implicit base\n  URI.\n- `:line_prefix`: Allows to specify a function returning prefixes for the encoded lines.\n  When this function is defined, the `:single_triple_lines` option is implicitly set, so\n  that each line encodes at most one triple.\n  The function receives three arguments:\n  1. `type` - one of the following values specifying the content of the line: `:triple`,\n    `:description`, `:graph` (for named graphs in TriG only), `:closing`\n  2. `value` - a `type` specific value for the content in this line\n      - for `:triple`: the `RDF.Triple` encoded in this line\n      - for `:description`: the subject whose description is started in this line\n      - for `:graph`: the name of the graph, opened in this line\n      - for `:closing`: a value specifying which element is closed in this line\n  3. `graph_name` - the name of graph (in Turtle this is always `nil`)\n- `:single_triple_lines`: When set to `true` each line encodes at most one triple, i.e.\n   no object lists with multiple objects are used and no Turtle list encodings are used.\n   This option is in of itself is not very useful. It is set implicitly when defining\n   a `:line_prefix` function which depends on this mode to produce useful results.\n- `:indent`: Allows to specify the number of spaces the output should be indented.\n- `:indent_width`: Allows to specify the number of spaces that should be used for\n  indentations (default: 4).\n- `:pn_local_validation`: This option controls how IRIs are validated the check\n   whether they can encoded as a prefixed name. Available settings are:\n  - `:fast` (default): Provides a quick and efficient validation that covers most\n    common cases. It does not handle every possible valid scenario, focusing instead\n    on typical structures encountered in prefixed names.\n  - `:none`: Disables validation entirely. Use this mode if you are confident that\n    all your IRIs are already compliant with prefixed name requirements, allowing you\n    to bypass validation checks for increased performance.\n  - Note: Currently, a `:strict` mode, which would provide comprehensive validation\n    conforming strictly to the Turtle specification, is not implemented.\n    Contributions for implementing this mode are welcome.\n- `:rdf_star`: Allows to skip a RDF-star related preprocessing step. This can be\n   used to improve performance a little bit when you know the encoded data doesn't\n   include any RDF-star statements. Defaults to the returned value of `RDF.star?/0`.","ref":"RDF.Turtle.Encoder.html#module-options"},{"type":"module","title":"RDF.Query","doc":"The RDF Graph query API.","ref":"RDF.Query.html"},{"type":"function","title":"RDF.Query.bgp/1","doc":"Creates a `RDF.Query.BGP` struct.\n\nA basic graph pattern consist of single or list of triple patterns.\nA triple pattern is a tuple which consists of RDF terms or variables for\nthe subject, predicate and object of an RDF triple.\n\nAs RDF terms `RDF.IRI`s, `RDF.BlankNode`s, `RDF.Literal`s or all Elixir\nvalues which can be coerced to any of those are allowed, i.e.\n`RDF.Vocabulary.Namespace` atoms or Elixir values which can be coerced to RDF\nliterals with `RDF.Literal.coerce/1` (only on object position). On predicate\nposition the `:a` atom can be used for the `rdf:type` property.\n\nVariables are written as atoms ending with a question mark. Blank nodes which\nin a graph query patterns act like a variable which doesn't show up in the\nresults can be written as atoms starting with an underscore.\n\nHere's a basic graph pattern example:\n\n```elixir\n[\n  {:s?, :a, EX.Foo},\n  {:s?, :a, EX.Bar},\n  {:s?, RDFS.label, \"foo\"},\n  {:s?, :p?, :o?}\n]\n```\n\nMultiple triple patterns sharing the same subject and/or predicate can be grouped:\n\n- Multiple objects to the same subject-predicate pair can be written by just\n  writing them one by one on the same triple pattern.\n- Multiple predicate-objects pair on the same subject can be written by\n  grouping them with square brackets.\n\nWith these, the previous example can be shortened to:\n\n```elixir\n{\n  :s?,\n    [:a, EX.Foo, EX.Bar],\n    [RDFS.label, \"foo\"],\n    [:p?, :o?]\n}\n```","ref":"RDF.Query.html#bgp/1"},{"type":"function","title":"RDF.Query.execute/3","doc":"Execute the given `query` against the given `graph`.\n\nThe `query` can be given directly as `RDF.Query.BGP` struct created with one\nof the builder functions in this module or as basic graph pattern expression\naccepted by `bgp/1`.\n\nThe result is a list of maps with the  solutions for the variables in the graph\npattern query and will be returned in a `:ok` tuple. In case of an error a\n`:error` tuple is returned.","ref":"RDF.Query.html#execute/3"},{"type":"function","title":"Example - RDF.Query.execute/3","doc":"Let's assume we have an `example_graph` with these triples:\n\n```turtle\n@prefix foaf:   .\n@prefix ex:     .\n\nex:Outlaw\n  foaf:name   \"Johnny Lee Outlaw\" ;\n  foaf:mbox     .\n\nex:Goodguy\n  foaf:name   \"Peter Goodguy\" ;\n  foaf:mbox     ;\n  foaf:friend ex:Outlaw .\n```\n\n    iex> {:_, FOAF.name, :name?} |> RDF.Query.execute(example_graph())\n    {:ok, [%{name: ~L\"Peter Goodguy\"}, %{name: ~L\"Johnny Lee Outlaw\"}]}\n\n    iex> [\n    ...>   {:_, FOAF.name, :name?},\n    ...>   {:_, FOAF.mbox, :mbox?},\n    ...> ] |> RDF.Query.execute(example_graph())\n    {:ok, [\n      %{name: ~L\"Peter Goodguy\", mbox: ~I },\n      %{name: ~L\"Johnny Lee Outlaw\", mbox: ~I }\n    ]}\n\n    iex> query = [\n    ...>   {:_, FOAF.name, :name?},\n    ...>   {:_, FOAF.mbox, :mbox?},\n    ...> ] |> RDF.Query.bgp()\n    ...> RDF.Query.execute(query, example_graph())\n    {:ok, [\n      %{name: ~L\"Peter Goodguy\", mbox: ~I },\n      %{name: ~L\"Johnny Lee Outlaw\", mbox: ~I }\n    ]}\n\n    iex> [\n    ...>   EX.Goodguy, FOAF.friend, FOAF.name, :name?\n    ...> ] |> RDF.Query.path() |> RDF.Query.execute(example_graph())\n    {:ok, [%{name: ~L\"Johnny Lee Outlaw\"}]}","ref":"RDF.Query.html#execute/3-example"},{"type":"function","title":"RDF.Query.execute!/3","doc":"Execute the given `query` against the given `graph`.\n\nAs opposed to `execute/3` this function returns the results directly or fails\nwith an exception.","ref":"RDF.Query.html#execute!/3"},{"type":"function","title":"RDF.Query.path/2","doc":"Creates a `RDF.Query.BGP` struct for a path through a graph.\n\nThe elements of the path can consist of the same RDF terms and variable\nexpressions allowed in `bgp/1` expressions.","ref":"RDF.Query.html#path/2"},{"type":"function","title":"Example - RDF.Query.path/2","doc":"The `RDF.Query.BGP` struct build with this:\n\n    RDF.Query.path [EX.S, EX.p, RDFS.label, :name?]\n\nis the same as the one build by this `bgp/1` call:\n\n    RDF.Query.bgp [\n      {EX.S, EX.p, :_o},\n      {:_o, RDFS.label, :name?},\n    ]","ref":"RDF.Query.html#path/2-example"},{"type":"function","title":"RDF.Query.stream/3","doc":"Returns a `Stream` for the execution of the given `query` against the given `graph`.\n\nJust like on `execute/3` the `query` can be given directly as `RDF.Query.BGP` struct\ncreated with one of the builder functions in this module or as basic graph pattern\nexpression accepted by `bgp/1`.\n\nThe stream of solutions for variable bindings will be returned in a `:ok` tuple.\nIn case of an error a `:error` tuple is returned.","ref":"RDF.Query.html#stream/3"},{"type":"function","title":"Example - RDF.Query.stream/3","doc":"Let's assume we have an `example_graph` with these triples:\n\n```turtle\n@prefix foaf:   .\n@prefix ex:     .\n\nex:Outlaw\n  foaf:name   \"Johnny Lee Outlaw\" ;\n  foaf:mbox     .\n\nex:Goodguy\n  foaf:name   \"Peter Goodguy\" ;\n  foaf:mbox     ;\n  foaf:friend ex:Outlaw .\n```\n\n    iex> {:ok, stream} = {:_, FOAF.name, :name?} |> RDF.Query.stream(example_graph())\n    ...> Enum.to_list(stream)\n    [%{name: ~L\"Peter Goodguy\"}, %{name: ~L\"Johnny Lee Outlaw\"}]\n\n    iex> {:ok, stream} = [\n    ...>   {:_, FOAF.name, :name?},\n    ...>   {:_, FOAF.mbox, :mbox?},\n    ...> ] |> RDF.Query.stream(example_graph())\n    ...> Enum.take(stream, 1)\n    [\n      %{name: ~L\"Peter Goodguy\", mbox: ~I },\n    ]","ref":"RDF.Query.html#stream/3-example"},{"type":"function","title":"RDF.Query.stream!/3","doc":"Returns a `Stream` for the execution of the given `query` against the given `graph`.\n\nAs opposed to `stream/3` this function returns the stream directly or fails\nwith an exception.","ref":"RDF.Query.html#stream!/3"},{"type":"module","title":"RDF.Query.BGP","doc":"A struct for Basic Graph Pattern queries.\n\nSee `RDF.Query` and its functions on how to construct this query struct and\napply it on `RDF.Graph`s.","ref":"RDF.Query.BGP.html"},{"type":"function","title":"RDF.Query.BGP.variables/1","doc":"Return a list of all variables in a BGP.","ref":"RDF.Query.BGP.html#variables/1"},{"type":"type","title":"RDF.Query.BGP.t/0","doc":"","ref":"RDF.Query.BGP.html#t:t/0"},{"type":"type","title":"RDF.Query.BGP.triple_pattern/0","doc":"","ref":"RDF.Query.BGP.html#t:triple_pattern/0"},{"type":"type","title":"RDF.Query.BGP.triple_patterns/0","doc":"","ref":"RDF.Query.BGP.html#t:triple_patterns/0"},{"type":"type","title":"RDF.Query.BGP.variable/0","doc":"","ref":"RDF.Query.BGP.html#t:variable/0"},{"type":"module","title":"RDF.Canonicalization","doc":"An implementation of the standard RDF Dataset Canonicalization Algorithm.\n\nSee  .","ref":"RDF.Canonicalization.html"},{"type":"module","title":"Options - RDF.Canonicalization","doc":"All functions in this module support the following options:\n\n- `:hash_algorithm`: Allows to set the hash algorithm to be used. Any of the `:crypto.hash_algorithm()`\n  values of Erlang's `:crypto` module are allowed.\n  Defaults to the runtime configured `:canon_hash_algorithm` of the `:rdf` application\n  or `:sha256` if not configured otherwise.\n\n      config :rdf,\n        canon_hash_algorithm: :sha512\n\n- `:hndq_call_limit`: This algorithm has to go through complex cycles that may in extreme situations\n  result in an unreasonably long canonicalization process. Although this never occurs in practice,\n  attackers may use some \"poison graphs\" to create such situations\n  (see the [security consideration section](https://www.w3.org/TR/rdf-canon/#security-considerations) in the specification).\n  This implementation sets a maximum call limit for the Hash N-Degree Quads algorithm\n  which can be configured with this value. Note, that actual limit is the product\n  of the multiplication of the given value with the number blank nodes in the input graph.\n  Defaults to the runtime configured `:hndq_call_limit` of the `:rdf` application\n  or `50` if not configured otherwise.\n\n      config :rdf,\n        hndq_call_limit: 10","ref":"RDF.Canonicalization.html#module-options"},{"type":"function","title":"RDF.Canonicalization.canonicalize/2","doc":"Canonicalizes the blank nodes of a graph or dataset according to the RDF Dataset Canonicalization spec.\n\nThis function always returns a `RDF.Dataset` and wraps it in a tuple with the\nresulting internal state from which the blank node mapping can be retrieved.\nIf you want to get just a `RDF.Dataset` back, use `RDF.Dataset.canonicalize/2`.\nIf you want to canonicalize just a `RDF.Graph` and get a `RDF.Graph` back,\nuse `RDF.Graph.canonicalize/2`.\n\nSee module documentation on the available options.","ref":"RDF.Canonicalization.html#canonicalize/2"},{"type":"function","title":"RDF.Canonicalization.isomorphic?/3","doc":"Checks whether two graphs or datasets are equal, regardless of the concrete names of the blank nodes they contain.\n\nSee module documentation on the available options.","ref":"RDF.Canonicalization.html#isomorphic?/3"},{"type":"function","title":"Examples - RDF.Canonicalization.isomorphic?/3","doc":"iex> RDF.Graph.new([{~B , EX.p(), ~B }, {~B , EX.p(), 42}])\n    ...> |> RDF.Canonicalization.isomorphic?(\n    ...>      RDF.Graph.new([{~B , EX.p(), ~B }, {~B , EX.p(), 42}]))\n    true\n\n    iex> RDF.Graph.new([{~B , EX.p(), ~B }, {~B , EX.p(), 42}])\n    ...> |> RDF.Canonicalization.isomorphic?(\n    ...>      RDF.Graph.new([{~B , EX.p(), ~B }, {~B , EX.p(), 42}]))\n    false","ref":"RDF.Canonicalization.html#isomorphic?/3-examples"},{"type":"module","title":"RDF.Canonicalization.IdentifierIssuer","doc":"An identifier issuer is used to issue new blank node identifier.\n\nSee","ref":"RDF.Canonicalization.IdentifierIssuer.html"},{"type":"function","title":"RDF.Canonicalization.IdentifierIssuer.canonical/0","doc":"","ref":"RDF.Canonicalization.IdentifierIssuer.html#canonical/0"},{"type":"function","title":"RDF.Canonicalization.IdentifierIssuer.copy/1","doc":"","ref":"RDF.Canonicalization.IdentifierIssuer.html#copy/1"},{"type":"function","title":"RDF.Canonicalization.IdentifierIssuer.identifier/2","doc":"","ref":"RDF.Canonicalization.IdentifierIssuer.html#identifier/2"},{"type":"function","title":"RDF.Canonicalization.IdentifierIssuer.issue_identifier/2","doc":"Issues a new blank node identifier for a given existing blank node identifier.\n\nSee","ref":"RDF.Canonicalization.IdentifierIssuer.html#issue_identifier/2"},{"type":"function","title":"RDF.Canonicalization.IdentifierIssuer.issued?/2","doc":"","ref":"RDF.Canonicalization.IdentifierIssuer.html#issued?/2"},{"type":"function","title":"RDF.Canonicalization.IdentifierIssuer.issued_identifiers/1","doc":"","ref":"RDF.Canonicalization.IdentifierIssuer.html#issued_identifiers/1"},{"type":"function","title":"RDF.Canonicalization.IdentifierIssuer.new/1","doc":"","ref":"RDF.Canonicalization.IdentifierIssuer.html#new/1"},{"type":"module","title":"RDF.Canonicalization.State","doc":"State of the `RDF.Canonicalization` algorithm.","ref":"RDF.Canonicalization.State.html"},{"type":"function","title":"RDF.Canonicalization.State.add_bnode_hash/3","doc":"","ref":"RDF.Canonicalization.State.html#add_bnode_hash/3"},{"type":"function","title":"RDF.Canonicalization.State.clear_hash_to_bnodes/1","doc":"","ref":"RDF.Canonicalization.State.html#clear_hash_to_bnodes/1"},{"type":"function","title":"RDF.Canonicalization.State.default_hash_algorithm/0","doc":"","ref":"RDF.Canonicalization.State.html#default_hash_algorithm/0"},{"type":"function","title":"RDF.Canonicalization.State.default_hndq_call_limit/0","doc":"","ref":"RDF.Canonicalization.State.html#default_hndq_call_limit/0"},{"type":"function","title":"RDF.Canonicalization.State.delete_bnode_hash/2","doc":"","ref":"RDF.Canonicalization.State.html#delete_bnode_hash/2"},{"type":"function","title":"RDF.Canonicalization.State.issue_canonical_identifier/2","doc":"","ref":"RDF.Canonicalization.State.html#issue_canonical_identifier/2"},{"type":"function","title":"RDF.Canonicalization.State.max_calls/1","doc":"","ref":"RDF.Canonicalization.State.html#max_calls/1"},{"type":"function","title":"RDF.Canonicalization.State.new/2","doc":"","ref":"RDF.Canonicalization.State.html#new/2"},{"type":"type","title":"RDF.Canonicalization.State.t/0","doc":"","ref":"RDF.Canonicalization.State.html#t:t/0"},{"type":"module","title":"RDF.Star.Quad","doc":"Helper functions for RDF-star quads.\n\nAn RDF-star quad is represented as a plain Elixir tuple consisting of four valid\nRDF values for subject, predicate, object and a graph name.\nAs opposed to an `RDF.Quad` the subject or object can be a triple.","ref":"RDF.Star.Quad.html"},{"type":"function","title":"RDF.Star.Quad.new/2","doc":"Creates a `RDF.Star.Quad` with proper RDF-star values.\n\nAn error is raised when the given elements are not coercible to RDF-star values.\n\nNote: The `RDF.quad` function is a shortcut to this function.","ref":"RDF.Star.Quad.html#new/2"},{"type":"function","title":"Examples - RDF.Star.Quad.new/2","doc":"iex> RDF.Star.Quad.new {\"http://example.com/S\", \"http://example.com/p\", 42, \"http://example.com/Graph\"}\n    {~I , ~I , RDF.literal(42), ~I }\n\n    iex> RDF.Star.Quad.new {EX.S, EX.p, 42, EX.Graph}\n    {RDF.iri(\"http://example.com/S\"), RDF.iri(\"http://example.com/p\"), RDF.literal(42), RDF.iri(\"http://example.com/Graph\")}\n\n    iex> RDF.Star.Quad.new {EX.S, EX.p, 42}\n    {RDF.iri(\"http://example.com/S\"), RDF.iri(\"http://example.com/p\"), RDF.literal(42), nil}\n\n    iex> RDF.Star.Quad.new {EX.S, :p, 42, EX.Graph}, RDF.PropertyMap.new(p: EX.p)\n    {RDF.iri(\"http://example.com/S\"), RDF.iri(\"http://example.com/p\"), RDF.literal(42), RDF.iri(\"http://example.com/Graph\")}\n\n    iex> RDF.Star.Quad.new({{EX.S, :p, 42}, :p2, 43, EX.Graph}, RDF.PropertyMap.new(p: EX.p, p2: EX.p2))\n    {{~I , ~I , RDF.literal(42)}, ~I , RDF.literal(43), ~I }","ref":"RDF.Star.Quad.html#new/2-examples"},{"type":"function","title":"RDF.Star.Quad.new/5","doc":"Creates a `RDF.Star.Quad` with proper RDF-star values.\n\nAn error is raised when the given elements are not coercible to RDF-star values.\n\nNote: The `RDF.quad` function is a shortcut to this function.","ref":"RDF.Star.Quad.html#new/5"},{"type":"function","title":"Examples - RDF.Star.Quad.new/5","doc":"iex> RDF.Star.Quad.new(\"http://example.com/S\", \"http://example.com/p\", 42, \"http://example.com/Graph\")\n    {~I , ~I , RDF.literal(42), ~I }\n\n    iex> RDF.Star.Quad.new(EX.S, EX.p, 42, EX.Graph)\n    {RDF.iri(\"http://example.com/S\"), RDF.iri(\"http://example.com/p\"), RDF.literal(42), RDF.iri(\"http://example.com/Graph\")}\n\n    iex> RDF.Star.Quad.new(EX.S, :p, 42, EX.Graph, RDF.PropertyMap.new(p: EX.p))\n    {RDF.iri(\"http://example.com/S\"), RDF.iri(\"http://example.com/p\"), RDF.literal(42), RDF.iri(\"http://example.com/Graph\")}\n\n    iex> RDF.Star.Quad.new(EX.S, :p, 42, EX.Graph, RDF.PropertyMap.new(p: EX.p))\n    {RDF.iri(\"http://example.com/S\"), RDF.iri(\"http://example.com/p\"), RDF.literal(42), RDF.iri(\"http://example.com/Graph\")}\n\n    iex> RDF.Star.Quad.new({EX.S, :p, 42}, :p2, 43, EX.Graph, RDF.PropertyMap.new(p: EX.p, p2: EX.p2))\n    {{~I , ~I , RDF.literal(42)}, ~I , RDF.literal(43), ~I }","ref":"RDF.Star.Quad.html#new/5-examples"},{"type":"function","title":"RDF.Star.Quad.valid?/1","doc":"Checks if the given tuple is a valid RDF quad.\n\nThe elements of a valid RDF-star quad must be RDF terms. On the subject position\nonly IRIs, blank nodes and triples are allowed, while on the predicate and graph name\nposition only IRIs allowed. The object position can be any RDF term or triple.","ref":"RDF.Star.Quad.html#valid?/1"},{"type":"type","title":"RDF.Star.Quad.coercible/0","doc":"","ref":"RDF.Star.Quad.html#t:coercible/0"},{"type":"type","title":"RDF.Star.Quad.t/0","doc":"","ref":"RDF.Star.Quad.html#t:t/0"},{"type":"module","title":"RDF.Star.Statement","doc":"Helper functions for RDF-star statements.\n\nAn RDF-star statement is either a `RDF.Star.Triple` or a `RDF.Star.Quad`.","ref":"RDF.Star.Statement.html"},{"type":"function","title":"RDF.Star.Statement.coerce/2","doc":"Creates a `RDF.Star.Statement` tuple with proper RDF values.\n\nAn error is raised when the given elements are not coercible to RDF-star values.","ref":"RDF.Star.Statement.html#coerce/2"},{"type":"function","title":"Examples - RDF.Star.Statement.coerce/2","doc":"iex> RDF.Star.Statement.coerce {\"http://example.com/S\", \"http://example.com/p\", 42}\n    {~I , ~I , RDF.literal(42)}\n    iex> RDF.Star.Statement.coerce {\"http://example.com/S\", \"http://example.com/p\", 42, \"http://example.com/Graph\"}\n    {~I , ~I , RDF.literal(42), ~I }","ref":"RDF.Star.Statement.html#coerce/2-examples"},{"type":"function","title":"RDF.Star.Statement.coerce_graph_name/1","doc":"","ref":"RDF.Star.Statement.html#coerce_graph_name/1"},{"type":"function","title":"RDF.Star.Statement.coerce_object/2","doc":"Coerces the given `value` to a valid object of an RDF-star statement.","ref":"RDF.Star.Statement.html#coerce_object/2"},{"type":"function","title":"RDF.Star.Statement.coerce_predicate/1","doc":"","ref":"RDF.Star.Statement.html#coerce_predicate/1"},{"type":"function","title":"RDF.Star.Statement.coerce_predicate/2","doc":"","ref":"RDF.Star.Statement.html#coerce_predicate/2"},{"type":"function","title":"RDF.Star.Statement.coerce_subject/2","doc":"Coerces the given `value` to a valid subject of an RDF-star statement.\n\nRaises an `RDF.Triple.InvalidSubjectError` when the value can not be coerced.","ref":"RDF.Star.Statement.html#coerce_subject/2"},{"type":"function","title":"RDF.Star.Statement.new/2","doc":"Creates a `RDF.Star.Triple` or `RDF.Star.Quad` with proper RDF values.\n\nAn error is raised when the given elements are not coercible to RDF-star values.\n\nNote: The `RDF.statement` function is a shortcut to this function.","ref":"RDF.Star.Statement.html#new/2"},{"type":"function","title":"Examples - RDF.Star.Statement.new/2","doc":"iex> RDF.Star.Statement.new({EX.S, EX.p, 42})\n    {RDF.iri(\"http://example.com/S\"), RDF.iri(\"http://example.com/p\"), RDF.literal(42)}\n\n    iex> RDF.Star.Statement.new({EX.S, EX.p, 42, EX.Graph})\n    {RDF.iri(\"http://example.com/S\"), RDF.iri(\"http://example.com/p\"), RDF.literal(42), RDF.iri(\"http://example.com/Graph\")}\n\n    iex> RDF.Star.Statement.new({EX.S, :p, 42, EX.Graph}, RDF.PropertyMap.new(p: EX.p))\n    {RDF.iri(\"http://example.com/S\"), RDF.iri(\"http://example.com/p\"), RDF.literal(42), RDF.iri(\"http://example.com/Graph\")}","ref":"RDF.Star.Statement.html#new/2-examples"},{"type":"function","title":"RDF.Star.Statement.new/3","doc":"","ref":"RDF.Star.Statement.html#new/3"},{"type":"function","title":"RDF.Star.Statement.new/4","doc":"","ref":"RDF.Star.Statement.html#new/4"},{"type":"function","title":"RDF.Star.Statement.star_statement?/1","doc":"Checks if the given tuple is an RDF-star statement with a quoted triple on subject or object position.\n\nNote: This function won't check if the given tuple or the quoted triple is valid.\nUse `valid?/1` for this purpose.","ref":"RDF.Star.Statement.html#star_statement?/1"},{"type":"function","title":"Examples - RDF.Star.Statement.star_statement?/1","doc":"iex> RDF.Star.Statement.star_statement?({EX.S, EX.P, EX.O})\n    false\n    iex> RDF.Star.Statement.star_statement?({EX.AS, EX.AP, {EX.S, EX.P, EX.O}})\n    true\n    iex> RDF.Star.Statement.star_statement?({{EX.S, EX.P, EX.O}, EX.AP, EX.AO})\n    true","ref":"RDF.Star.Statement.html#star_statement?/1-examples"},{"type":"function","title":"RDF.Star.Statement.valid?/1","doc":"Checks if the given tuple is a valid RDF-star statement, i.e. RDF-star triple or quad.\n\nThe elements of a valid RDF-star statement must be RDF terms. On the subject\nposition only IRIs, blank nodes and triples allowed, while on the predicate and graph\ncontext position only IRIs allowed. The object position can be any RDF term or a triple.","ref":"RDF.Star.Statement.html#valid?/1"},{"type":"function","title":"RDF.Star.Statement.valid_graph_name?/1","doc":"","ref":"RDF.Star.Statement.html#valid_graph_name?/1"},{"type":"function","title":"RDF.Star.Statement.valid_object?/1","doc":"","ref":"RDF.Star.Statement.html#valid_object?/1"},{"type":"function","title":"RDF.Star.Statement.valid_predicate?/1","doc":"","ref":"RDF.Star.Statement.html#valid_predicate?/1"},{"type":"function","title":"RDF.Star.Statement.valid_subject?/1","doc":"","ref":"RDF.Star.Statement.html#valid_subject?/1"},{"type":"type","title":"RDF.Star.Statement.coercible/0","doc":"","ref":"RDF.Star.Statement.html#t:coercible/0"},{"type":"type","title":"RDF.Star.Statement.coercible_graph_name/0","doc":"","ref":"RDF.Star.Statement.html#t:coercible_graph_name/0"},{"type":"type","title":"RDF.Star.Statement.coercible_object/0","doc":"","ref":"RDF.Star.Statement.html#t:coercible_object/0"},{"type":"type","title":"RDF.Star.Statement.coercible_predicate/0","doc":"","ref":"RDF.Star.Statement.html#t:coercible_predicate/0"},{"type":"type","title":"RDF.Star.Statement.coercible_subject/0","doc":"","ref":"RDF.Star.Statement.html#t:coercible_subject/0"},{"type":"type","title":"RDF.Star.Statement.graph_name/0","doc":"","ref":"RDF.Star.Statement.html#t:graph_name/0"},{"type":"type","title":"RDF.Star.Statement.object/0","doc":"","ref":"RDF.Star.Statement.html#t:object/0"},{"type":"type","title":"RDF.Star.Statement.predicate/0","doc":"","ref":"RDF.Star.Statement.html#t:predicate/0"},{"type":"type","title":"RDF.Star.Statement.subject/0","doc":"","ref":"RDF.Star.Statement.html#t:subject/0"},{"type":"type","title":"RDF.Star.Statement.t/0","doc":"","ref":"RDF.Star.Statement.html#t:t/0"},{"type":"type","title":"RDF.Star.Statement.term_mapping/0","doc":"","ref":"RDF.Star.Statement.html#t:term_mapping/0"},{"type":"module","title":"RDF.Star.Triple","doc":"Helper functions for RDF-star triples.\n\nAn RDF-star triple is represented as a plain Elixir tuple consisting of three valid\nRDF values for subject, predicate and object.\nAs opposed to an `RDF.Triple` the subject or object can be a triple itself.","ref":"RDF.Star.Triple.html"},{"type":"function","title":"RDF.Star.Triple.new/2","doc":"Creates a `RDF.Star.Triple` with proper RDF-star values.\n\nAn error is raised when the given elements are not coercible to RDF-star values.\n\nNote: The `RDF.triple` function is a shortcut to this function.","ref":"RDF.Star.Triple.html#new/2"},{"type":"function","title":"Examples - RDF.Star.Triple.new/2","doc":"iex> RDF.Star.Triple.new {\"http://example.com/S\", \"http://example.com/p\", 42}\n    {~I , ~I , RDF.literal(42)}\n\n    iex> RDF.Star.Triple.new {EX.S, EX.p, 42}\n    {RDF.iri(\"http://example.com/S\"), RDF.iri(\"http://example.com/p\"), RDF.literal(42)}\n\n    iex> RDF.Star.Triple.new {EX.S, EX.p, 42, EX.Graph}\n    {RDF.iri(\"http://example.com/S\"), RDF.iri(\"http://example.com/p\"), RDF.literal(42)}\n\n    iex> RDF.Star.Triple.new {EX.S, :p, 42}, RDF.PropertyMap.new(p: EX.p)\n    {RDF.iri(\"http://example.com/S\"), RDF.iri(\"http://example.com/p\"), RDF.literal(42)}\n\n    iex> RDF.Star.Triple.new({{EX.S, :p, 42}, :p2, 43}, RDF.PropertyMap.new(p: EX.p, p2: EX.p2))\n    {{~I , ~I , RDF.literal(42)}, ~I , RDF.literal(43)}","ref":"RDF.Star.Triple.html#new/2-examples"},{"type":"function","title":"RDF.Star.Triple.new/4","doc":"Creates a `RDF.Star.Triple` with proper RDF-star values.\n\nAn error is raised when the given elements are not coercible to RDF-star values.\n\nNote: The `RDF.triple` function is a shortcut to this function.","ref":"RDF.Star.Triple.html#new/4"},{"type":"function","title":"Examples - RDF.Star.Triple.new/4","doc":"iex> RDF.Star.Triple.new({\"http://example.com/S\", \"http://example.com/p\", 42}, \"http://example.com/p2\", 43)\n    {{~I , ~I , RDF.literal(42)}, ~I , RDF.literal(43)}\n\n    iex> RDF.Star.Triple.new({EX.S, EX.p, 42}, EX.p2, 43)\n    {{~I , ~I , RDF.literal(42)}, ~I , RDF.literal(43)}\n\n    iex> RDF.Star.Triple.new(EX.S, EX.p, 42)\n    {RDF.iri(\"http://example.com/S\"), RDF.iri(\"http://example.com/p\"), RDF.literal(42)}\n\n    iex> RDF.Star.Triple.new({EX.S, :p, 42}, :p2, 43, RDF.PropertyMap.new(p: EX.p, p2: EX.p2))\n    {{~I , ~I , RDF.literal(42)}, ~I , RDF.literal(43)}","ref":"RDF.Star.Triple.html#new/4-examples"},{"type":"function","title":"RDF.Star.Triple.valid?/1","doc":"Checks if the given tuple is a valid RDF-star triple.\n\nThe elements of a valid RDF-star triple must be RDF terms. On the subject\nposition only IRIs, blank nodes and triples are allowed, while on the predicate\nposition only IRIs allowed. The object position can be any RDF term or triple.","ref":"RDF.Star.Triple.html#valid?/1"},{"type":"type","title":"RDF.Star.Triple.coercible/0","doc":"","ref":"RDF.Star.Triple.html#t:coercible/0"},{"type":"type","title":"RDF.Star.Triple.t/0","doc":"","ref":"RDF.Star.Triple.html#t:t/0"},{"type":"module","title":"RDF.EarlFormatter","doc":"An `ExUnit.Formatter` implementation that generates EARL reports.\n\nsee","ref":"RDF.EarlFormatter.html"},{"type":"function","title":"RDF.EarlFormatter.child_spec/1","doc":"Returns a specification to start this module under a supervisor.\n\nSee `Supervisor`.","ref":"RDF.EarlFormatter.html#child_spec/1"},{"type":"function","title":"RDF.EarlFormatter.config/0","doc":"","ref":"RDF.EarlFormatter.html#config/0"},{"type":"exception","title":"RDF.Graph.Builder.Error","doc":"","ref":"RDF.Graph.Builder.Error.html"},{"type":"exception","title":"RDF.Graph.EmptyDescriptionError","doc":"","ref":"RDF.Graph.EmptyDescriptionError.html"},{"type":"function","title":"RDF.Graph.EmptyDescriptionError.message/1","doc":"","ref":"RDF.Graph.EmptyDescriptionError.html#message/1"},{"type":"exception","title":"RDF.IRI.InvalidError","doc":"","ref":"RDF.IRI.InvalidError.html"},{"type":"exception","title":"RDF.Literal.InvalidError","doc":"","ref":"RDF.Literal.InvalidError.html"},{"type":"exception","title":"RDF.Namespace.InvalidTermError","doc":"","ref":"RDF.Namespace.InvalidTermError.html"},{"type":"exception","title":"RDF.Namespace.UndefinedTermError","doc":"","ref":"RDF.Namespace.UndefinedTermError.html"},{"type":"exception","title":"RDF.Quad.InvalidGraphContextError","doc":"","ref":"RDF.Quad.InvalidGraphContextError.html"},{"type":"function","title":"RDF.Quad.InvalidGraphContextError.message/1","doc":"","ref":"RDF.Quad.InvalidGraphContextError.html#message/1"},{"type":"exception","title":"RDF.Query.InvalidError","doc":"","ref":"RDF.Query.InvalidError.html"},{"type":"exception","title":"RDF.Resource.Generator.ConfigError","doc":"","ref":"RDF.Resource.Generator.ConfigError.html"},{"type":"exception","title":"RDF.Triple.InvalidPredicateError","doc":"","ref":"RDF.Triple.InvalidPredicateError.html"},{"type":"function","title":"RDF.Triple.InvalidPredicateError.message/1","doc":"","ref":"RDF.Triple.InvalidPredicateError.html#message/1"},{"type":"exception","title":"RDF.Triple.InvalidSubjectError","doc":"","ref":"RDF.Triple.InvalidSubjectError.html"},{"type":"function","title":"RDF.Triple.InvalidSubjectError.message/1","doc":"","ref":"RDF.Triple.InvalidSubjectError.html#message/1"},{"type":"exception","title":"RDF.Vocabulary.Namespace.CaseValidation.CaseViolationError","doc":"","ref":"RDF.Vocabulary.Namespace.CaseValidation.CaseViolationError.html"},{"type":"exception","title":"RDF.Vocabulary.Namespace.CompileError","doc":"","ref":"RDF.Vocabulary.Namespace.CompileError.html"},{"type":"exception","title":"RDF.Vocabulary.Namespace.TermMapping.InvalidAliasError","doc":"","ref":"RDF.Vocabulary.Namespace.TermMapping.InvalidAliasError.html"},{"type":"exception","title":"RDF.Vocabulary.Namespace.TermMapping.InvalidIgnoreTermError","doc":"","ref":"RDF.Vocabulary.Namespace.TermMapping.InvalidIgnoreTermError.html"},{"type":"exception","title":"RDF.Vocabulary.Namespace.TermMapping.InvalidTermError","doc":"","ref":"RDF.Vocabulary.Namespace.TermMapping.InvalidTermError.html"},{"type":"exception","title":"RDF.Vocabulary.Namespace.TermMapping.InvalidVocabBaseIRIError","doc":"","ref":"RDF.Vocabulary.Namespace.TermMapping.InvalidVocabBaseIRIError.html"},{"type":"exception","title":"RDF.Vocabulary.Namespace.TermMapping.TermHandlerError","doc":"","ref":"RDF.Vocabulary.Namespace.TermMapping.TermHandlerError.html"},{"type":"exception","title":"RDF.Vocabulary.Namespace.TermMapping.UnknownTermError","doc":"","ref":"RDF.Vocabulary.Namespace.TermMapping.UnknownTermError.html"},{"type":"exception","title":"RDF.XSD.Datatype.MismatchError","doc":"","ref":"RDF.XSD.Datatype.MismatchError.html"},{"type":"function","title":"RDF.XSD.Datatype.MismatchError.message/1","doc":"","ref":"RDF.XSD.Datatype.MismatchError.html#message/1"},{"type":"extras","title":"About","doc":"# RDF.ex\n\n[![Hex.pm](https://img.shields.io/hexpm/v/rdf.svg?style=flat-square)](https://hex.pm/packages/rdf)\n[![Hex Docs](https://img.shields.io/badge/hex-docs-lightgreen.svg)](https://hexdocs.pm/rdf/)\n[![Total Download](https://img.shields.io/hexpm/dt/rdf.svg)](https://hex.pm/packages/rdf)\n[![License](https://img.shields.io/hexpm/l/rdf.svg)](https://github.com/rdf-elixir/rdf-ex/blob/master/LICENSE.md)\n\n[![ExUnit Tests](https://github.com/rdf-elixir/rdf-ex/actions/workflows/elixir-build-and-test.yml/badge.svg)](https://github.com/rdf-elixir/rdf-ex/actions/workflows/elixir-build-and-test.yml)\n[![Dialyzer](https://github.com/rdf-elixir/rdf-ex/actions/workflows/elixir-dialyzer.yml/badge.svg)](https://github.com/rdf-elixir/rdf-ex/actions/workflows/elixir-dialyzer.yml)\n[![Quality Checks](https://github.com/rdf-elixir/rdf-ex/actions/workflows/elixir-quality-checks.yml/badge.svg)](https://github.com/rdf-elixir/rdf-ex/actions/workflows/elixir-quality-checks.yml)\n\n\nAn implementation of the [RDF](https://www.w3.org/TR/rdf11-primer/) data model in Elixir.\n\nThe API documentation can be found [here](https://hexdocs.pm/rdf/). For a guide and more information about RDF.ex and it's related projects, go to  .\n\nMigration guides for the various versions can be found in the [Wiki](https://github.com/rdf-elixir/rdf-ex/wiki).","ref":"readme.html"},{"type":"extras","title":"Features - About","doc":"- fully compatible with the RDF 1.1 specification\n- support of the [RDF-star] extension\n- in-memory data structures for RDF descriptions, RDF graphs and RDF datasets\n- basic graph pattern matching against the in-memory data structures with streaming-support\n- execution of [SPARQL] queries against the in-memory data structures with the [SPARQL.ex] package or against any SPARQL endpoint with the [SPARQL.Client] package\n- RDF vocabularies as Elixir modules for safe, i.e. compile-time checked and concise usage of IRIs\n- most of the important XML schema datatypes for RDF literals\n- support for custom datatypes for RDF literals, incl. as derivations of XSD datatypes via facets \n- sigils for the most common types of nodes, i.e. IRIs, literals, blank nodes and lists\n- a DSL resembling Turtle to build RDF descriptions or full RDF graphs in Elixir\n- implementations for the [N-Triples], [N-Quads], [Turtle] and [TriG] serialization formats (including the respective RDF-star extensions); [JSON-LD] and [RDF-XML] are available with the separate [JSON-LD.ex] and [RDF-XML.ex] packages\n- implementation of the [RDF Dataset Canonicalization] algorithm  \n- validation of RDF data against [ShEx] schemas with the [ShEx.ex] package\n- mapping of RDF data structures to Elixir structs and back with [Grax]","ref":"readme.html#features"},{"type":"extras","title":"Contributing - About","doc":"There's still much to do for a complete RDF ecosystem for Elixir, which means there are plenty of opportunities to contribute. Here are some suggestions:\n\n- more serialization formats, like [RDFa], [N3], [CSVW], [HDT] etc.\n- more XSD datatypes\n- improving the documentation\n\nSee [CONTRIBUTING](CONTRIBUTING.md) for details.","ref":"readme.html#contributing"},{"type":"extras","title":"Consulting - About","doc":"If you need help with your Elixir and Linked Data projects, just contact [NinjaConcept](https://www.ninjaconcept.com/) via  .","ref":"readme.html#consulting"},{"type":"extras","title":"Acknowledgements - About","doc":"The development of this project was partly sponsored by [NetzeBW](https://www.netze-bw.de/) for [NETZlive](https://www.netze-bw.de/unsernetz/netzinnovationen/digitalisierung/netzlive) and the [NLnet foundation](https://nlnet.nl/) as part of the funding of [K-Gen](https://nlnet.nl/project/K-Gen/).\n\n[JetBrains](https://www.jetbrains.com/?from=RDF.ex) supports the project with complimentary access to its development environments.","ref":"readme.html#acknowledgements"},{"type":"extras","title":"License and Copyright - About","doc":"(c) 2016-present Marcel Otto. MIT Licensed, see [LICENSE](LICENSE.md) for details.\n\n\n[RDF.ex]:               https://hex.pm/packages/rdf\n[JSON-LD.ex]:           https://hex.pm/packages/json_ld\n[RDF-XML.ex]:           https://hex.pm/packages/rdf_xml\n[SPARQL.ex]:            https://hex.pm/packages/sparql\n[SPARQL.Client]:        https://hex.pm/packages/sparql_client\n[ShEx.ex]:              https://hex.pm/packages/shex\n[Grax]:                 https://hex.pm/packages/grax\n[RDF-star]:             https://w3c.github.io/rdf-star/cg-spec\n[N-Triples]:            https://www.w3.org/TR/n-triples/\n[N-Quads]:              https://www.w3.org/TR/n-quads/\n[Turtle]:               https://www.w3.org/TR/turtle/\n[TriG]:                 https://www.w3.org/TR/trig/\n[N3]:                   https://www.w3.org/TeamSubmission/n3/\n[JSON-LD]:              https://www.w3.org/TR/json-ld/\n[RDFa]:                 https://www.w3.org/TR/rdfa-syntax/\n[RDF-XML]:              https://www.w3.org/TR/rdf-syntax-grammar/\n[CSVW]:                 https://www.w3.org/TR/tabular-data-model/\n[HDT]:                  http://www.rdfhdt.org/\n[SPARQL]:               https://www.w3.org/TR/sparql11-overview/\n[ShEx]:                 https://shex.io/\n[RDF Dataset Canonicalization]: https://www.w3.org/TR/rdf-canon/","ref":"readme.html#license-and-copyright"},{"type":"extras","title":"CHANGELOG","doc":"# Changelog\n\nAll notable changes to this project will be documented in this file.\nThis project adheres to [Semantic Versioning](http://semver.org/) and\n[Keep a CHANGELOG](http://keepachangelog.com).","ref":"changelog.html"},{"type":"extras","title":"2.0.0 - 2024-07-08 - CHANGELOG","doc":"Elixir versions < 1.13 and OTP version < 23 are no longer supported\n\nAn update to the recent more extensive Turtle test suite revealed that a bug in  \nElixir's `URI.merge/2` function affects the relative URI handling in the Turtle decoder. \nIt is therefore strongly recommended to use the Turtle decoder with \nElixir v1.15 or later, where this issue has been resolved.","ref":"changelog.html#2-0-0-2024-07-08"},{"type":"extras","title":"Added - CHANGELOG","doc":"- `RDF.TriG` with an implementation of the TriG serialization language. \n- Several new options on the Turtle/TriG encoders for more customizations and \n  performance optimizations:\n  - Capability to add custom content on the Turtle/TriG encoders with the `:content` option.\n  - `:line_prefix` for a function defining custom line prefixes\n  - `:indent_width` to customize the indentation width\n  - `:pn_local_validation` for controlling IRI validation when encoding prefixed names\n  - `:rdf_star` allowing to skip an RDF-star related preprocessing step\n- `RDF.Dataset.named_graphs/1` to get a list of all named graphs of a dataset.\n- `RDF.Dataset.graph_names/1` to get a list of all graph names of a dataset.\n- `RDF.Dataset.update_all_graphs/2` to apply a function on all graphs of a dataset.\n- `RDF.Graph.update_all_descriptions/2` to apply a function on all descriptions of a graph.\n- `RDF.Description.update_all_predicates/2` and `RDF.Description.update_all_objects/2`\n  to apply a function on all predications resp. objects of a description.\n- `RDF.Graph.rename_resource/2` and `RDF.Description.rename_resource/2` to replace all \n  occurrences of an id.\n- `RDF.turtle_prefixes/1` and `RDF.sparql_prefixes/1` for creating respective prefix headers\n- `RDF.Graph.prefixes/2` which allows to specify a custom return value when the prefixes \n  are empty.\n- `RDF.PrefixMap.empty?/1` to check of a `RDF.PrefixMap` is empty.\n- `RDF.PrefixMap.limit/2` to limit a `RDF.PrefixMap` to a subset of some given prefixes.\n- `RDF.BlankNode.Generator.UUID` and `RDF.BlankNode.Generator.Random` implementations\n  of `RDF.BlankNode.Generator.Algorithm`\n- `:bnode_gen` option on the Turtle/TriG decoders, allowing customization of blank node \n  generation and a `turtle_trig_decoder_bnode_gen` application config for setting the \n  default blank node generator globally.\n- Performance improvements of N-Triples and N-Quads encoders.","ref":"changelog.html#added"},{"type":"extras","title":"Changed - CHANGELOG","doc":"- Default blank node generation in Turtle decoder now generates UUID blank node \n  identifiers instead of the previous deterministic incremented identifiers. \n  This change ensures unique blank nodes across multiple parsing operations.\n  You can opt back to the previous behaviour with the new `turtle_trig_decoder_bnode_gen` \n  application config using the `:increment` value.\n- Aliases defined within `RDF.Graph.build` blocks are no longer supported due to changes  \n  in Elixir 1.17. Aliases from the caller context are still available and automatically  \n  re-aliased in the build block. However, instead of using aliases for vocabulary namespaces, \n  use `@prefix` declarations inside the build block, as it provides additional benefits. \n  Please refer to the [user guide](https://rdf-elixir.dev/rdf-ex/description-and-graph-dsl.html#graph-builder) for more information.\n- The `prefixes` of an `RDF.Graph` are now always a `RDF.PrefixMap` and no longer `nil`\n  initially, since this had the confusing consequence that an `RDF.Graph` where all \n  prefixes were deleted was not equal to same graph where the deleted were never set,\n  e.g. `RDF.graph() |> Graph.add_prefixes(ex: EX) |> Graph.delete_prefixes(:ex) == RDF.graph()`\n  did not hold previously. This behaviour was used before to differentiate graphs which\n  should use the `RDF.default_prefixes/0` (in case `prefixes` was `nil`) from those which\n  should not use any prefixes (empty `PrefixMap`) when serialized to Turtle. \n  You'll now have to add the `prefixes: []` on Turtle serialization explicitly. \n  The old behaviour of getting `nil` on empty prefixes can be achieved with the new \n  `RDF.Graph.prefixes/2` function.\n- Update to change in N-Triples and N-Quads specs disallowing colons in bnode labels.\n- Rename `:only` option of `RDF.Turtle.Encoder` to `:content` to reflect the enhanced \n  capabilities.\n- The `RDF.BlankNode.Generator` and `RDF.BlankNode.Generator.Algorithm` behaviour \n  used internally at various places was redesigned.\n- Deprecated `RDF.Diff.merge/2` was removed. Use `RDF.Diff.union/2` instead.\n- Replacement of `elixir_uuid` with `uniq` dependency for UUID generation and\n  make it no longer optional","ref":"changelog.html#changed"},{"type":"extras","title":"Fixed - CHANGELOG","doc":"- The `RDF.Turtle.Encoder` was not falling back to using `RDF.default_prefixes/0` when\n  the encoded graph had prefixes which were removed afterwards.\n- Fixed the `RDF.Turtle.Encoder` validation to ensure IRIs with permissible characters, \n  such as hyphens, can be correctly encoded as prefixed names. Previously, the validation \n  was overly strict, preventing some valid IRIs from being encoded as prefixed names.\n- `RDF.NTriples.Encoder` and `RDF.NQuads.Encoder` could not stream quoted RDF-star \n  triples could as iodata.\n\n\n[Compare v1.2.0...v2.0.0](https://github.com/rdf-elixir/rdf-ex/compare/v1.2.0...v2.0.0)","ref":"changelog.html#fixed"},{"type":"extras","title":"1.2.0 - 2024-03-18 - CHANGELOG","doc":"Elixir versions < 1.12 are no longer supported","ref":"changelog.html#1-2-0-2024-03-18"},{"type":"extras","title":"Added - CHANGELOG","doc":"- `RDF.Namespace.act_as_namespace/1` macro which can be used to let a module act \n  as a specified `RDF.Namespace` or `RDF.Vocabulary.Namespace`.\n- `canonical_hash/2` function on `RDF.Dataset`, `RDF.Graph` and `RDF.Description` which\n  computes a hash value for the data based on the `RDF.Canonicalization` algorithm\n- `intersection/2` function on `RDF.Dataset`, `RDF.Graph` and `RDF.Description` which\n  create respective graph data intersections. Since this feature relies on `Map.intersect/3` \n  that was added in Elixir v1.15, it is only available with a respective Elixir version.  \n- `RDF.Dataset.put_graph/3` adds new graphs overwriting any existing graphs\n- `RDF.Dataset.update/4` to update graphs in a `RDF.Dataset`\n- `RDF.Graph.delete_predications/3` to delete all statements in a `RDF.Graph` with \n  the given subjects and predicates\n- `RDF.PrefixMap.to_header/3`, `RDF.PrefixMap.to_turtle/1` and `RDF.PrefixMap.to_sparql/1`\n  to get header string representations of a `RDF.PrefixMap` in the respective style\n- `RDF.PrefixMap.to_sorted_list/1` which returns the prefix map as keyword list \n  sorted by prefix (this should become useful with OTP 26)\n- `RDF.PropertyMap.to_sorted_list/1` which returns the property map as keyword list\n  sorted by property  \n- The Turtle encoder now sorts the prefixes (based on `RDF.PrefixMap.to_sorted_list/1`), \n  which has become necessary, since OTP 26 maps are now unordered even in smaller cases \n  (previously only larger maps were unordered).\n- The N-Triples and N-Quads encoders now support a flag option `:sort` which, when  \n  activated, encodes the statements sorted in Unicode code point order.\n- The hash algorithm to be used for RDF canonicalization can be configured either\n  with the `:hash_algorithm` keyword option or the `:canon_hash_algorithm` application \n  runtime configuration.\n- Add Hash N-Degree Quads algorithm call limit to canonicalization as a countermeasure\n  against [poison dataset attacks](https://www.w3.org/TR/rdf-canon/#dataset-poisoning)\n- Compile-time application configuration `:optimize_regexes` that allows to switch \n  internal usage to the faster Erlang `:re.run/2` function for regex pattern matching\n  ([@jkrueger](https://github.com/jkrueger))\n- Some optimizations on `RDF.IRI` ([@jkrueger](https://github.com/jkrueger))\n- `RDF.EarlFormatter` as an `ExUnit.Formatter` implementation that generates EARL reports","ref":"changelog.html#added"},{"type":"extras","title":"Changed - CHANGELOG","doc":"- `RDF.Canonicalization.canonicalize/2` now returns the canonicalized dataset in a \n  tuple along with final state containing the _input blank node identifier map_ and\n  the _issued identifiers map_ as required by the RDF dataset canonicalization \n  specification\n- `RDF.Diff.merge/2` was deprecated and will be replaced in future versions with a \n  different merge algorithm. Use `RDF.Diff.union/2` now for the current algorithm.\n- Statements as lists (instead of tuples) in the `Collectable` implementations of\n  `RDF.Description`, `RDF.Graph` and `RDF.Dataset` were deprecated.\n  Support of those will be removed in RDF.ex v2.0. \n- The following deprecated types were removed:\n  - `RDF.Statement.coercible_t` (new type: `RDF.Statement.coercible`)\n  - `RDF.Star.Statement.coercible_t` (new type: `RDF.Star.Statement.coercible`)\n  - `RDF.Triple.t_values` (new type: `RDF.Triple.mapping_value`)\n  - `RDF.Quad.t_values` (new type: `RDF.Quad.mapping_value`)","ref":"changelog.html#changed"},{"type":"extras","title":"Fixed - CHANGELOG","doc":"- `RDF.Dataset.put/3` with a `RDF.Dataset` input didn't respect the `:graph` option to \n  aggregate everything into single target graph\n\n\n[Compare v1.1.1...v1.2.0](https://github.com/rdf-elixir/rdf-ex/compare/v1.1.1...v1.2.0)","ref":"changelog.html#fixed"},{"type":"extras","title":"1.1.1 - 2023-03-31 - CHANGELOG","doc":"","ref":"changelog.html#1-1-1-2023-03-31"},{"type":"extras","title":"Added - CHANGELOG","doc":"- a custom option `:content_only` on the `Inspect` implementation of `RDF.Graph` \n  which returns only the (possibly abbreviated) Turtle representation of the graph;\n  this can be used in other `Inspect` implementations that want to include \n  this `RDF.Graph` representation\n- `RDF.prefixes/1` as another alias for the creation of a `RDF.PrefixMap`","ref":"changelog.html#added"},{"type":"extras","title":"Fixed - CHANGELOG","doc":"- `RDF.Graph.new/2` didn't respect the `:init` opt when the first argument was a `RDF.Graph` \n\n\n[Compare v1.1.0...v1.1.1](https://github.com/rdf-elixir/rdf-ex/compare/v1.1.0...v1.1.1)","ref":"changelog.html#fixed"},{"type":"extras","title":"1.1.0 - 2022-12-19 - CHANGELOG","doc":"","ref":"changelog.html#1-1-0-2022-12-19"},{"type":"extras","title":"Added - CHANGELOG","doc":"- implementation of the [Standard RDF Dataset Canonicalization Algorithm](https://www.w3.org/TR/rdf-canon/)\n  which can be used with `RDF.Graph.canonicalize/1` and `RDF.Dataset.canonicalize/1` functions\n- `RDF.Graph.isomorphic?/2` and `RDF.Dataset.isomorphic?/2` to compare if two\n  graphs or datasets are the same, regardless of the concrete names of the \n  blank nodes they contain\n- `RDF.Statement.bnodes/1`, `RDF.Triple.bnodes/1`, `RDF.Quad.bnodes/1` to get a list\n  of all blank nodes within a statement\n- `RDF.Statement.include_value?/2`, `RDF.Triple.include_value?/2`, `RDF.Quad.include_value?/2` \n  to check whether a given value is a component of a statement\n- performance improvements of the `RDF.Turtle.Encoder`","ref":"changelog.html#added"},{"type":"extras","title":"Changed - CHANGELOG","doc":"- `RDF.XSD.Double` and `RDF.XSD.Float` literals created from Elixir floats and integers\n  are now interpreted to be in the canonical lexical form\n- `RDF.BlankNode.new/1` ignores the prefix `\"_:\"` in a given blank node name","ref":"changelog.html#changed"},{"type":"extras","title":"Fixed - CHANGELOG","doc":"- the N-Triples, N-Quads and Turtle encoder were creating too many backslashes,\n  when escaping a backslash in a string;  \n  BEWARE: You'll have to fix the generated Turtle files you've produced with earlier versions!\n- the N-Triples, N-Quads and Turtle encoder didn't apply proper escaping in typed literals \n  of unknown type in general\n- the Turtle encoder didn't encode the descriptions of blank nodes which occurred in\n  a blank node cycle, e.g. in `_:b1 :p1 _:b2 . _:b2 :p2 _:b1 .` neither the description \n  of `_:b1` nor of `_:b2` were rendered\n- the Turtle encoder now preserves the lexical form of a literal instead of always  \n  encoding the canonical form\n- a regression in `defvocab` prevented its use with fully qualified vocabulary \n  namespace module names (i.e. which include a dot)\n- the `term_to_iri/1` macro didn't work properly in all types of pattern matches\n- the `Inspect` protocol implementation for decimal literals wasn't using the lexical\n  in case of an uncanonical lexical form of a decimal literal \n\n\n[Compare v1.0.0...v1.1.0](https://github.com/rdf-elixir/rdf-ex/compare/v1.0.0...v1.1.0)","ref":"changelog.html#fixed"},{"type":"extras","title":"1.0.0 - 2022-11-03 - CHANGELOG","doc":"In this version `RDF.Namespace` and `RDF.Vocabulary.Namespace` were completely rewritten.\nThe generated namespaces are much more flexible now and compile faster.\n\nFor more details on how to migrate from an earlier version read [this wiki page](https://github.com/rdf-elixir/rdf-ex/wiki/Upgrading-to-RDF.ex-1.0).\n\nElixir versions < 1.11 are no longer supported","ref":"changelog.html#1-0-0-2022-11-03"},{"type":"extras","title":"Added - CHANGELOG","doc":"- `RDF.Vocabulary.Namespace.create/5` for dynamic creation of `RDF.Vocabulary.Namespace`s\n- `RDF.Namespace` builders `defnamespace/3` and `create/4`\n  inside of pattern matches\n- `RDF.Vocabulary.Namespace` modules now have a `__file__/0` function which returns\n  the path to the vocabulary file they were generated from\n- `RDF.Vocabulary.path/1` returning the path to the vocabulary directory of an\n  application and `RDF.Vocabulary.path/2` returning the path to the files within it\n- The property functions on the `RDF.Namespace` and `RDF.Vocabulary.Namespace` modules\n  now also have a single argument variant, which allows to query the objects for the\n  respective property from a `RDF.Description`\n- Aliases on a `RDF.Vocabulary.Namespace` can now be specified directly in the\n  `:terms` list.\n- The `:terms` option can now also be used in conjunction with the `:file` and\n  `:data` options to restrict the terms loaded from the vocabulary data with a\n  list of the terms or a restriction function. \n- The `case_violations` option of `defvocab` now supports an `:auto_fix` option \n  which adapts the first letter of violating term accordingly. It also supports\n  custom handler functions, either as an inline function or as a function on a \n  separate module.\n- New option `allow_lowercase_resource_terms` option which can be set to `true`\n  to no longer complain about lowercased terms for non-property resources.\n- `RDF.Graph.build/2` now supports the creation of ad-hoc vocabulary namespaces\n  with a `@prefix` declaration providing the URI of the namespace as a string\n- `RDF.Namespace.IRI.term_to_iri/1` macro which allows to resolve `RDF.Namespace` terms\n- a lot of new `RDF.Guards`: `is_rdf_iri/1`, `is_rdf_bnode/1`, `is_rdf_literal/1`,\n  `is_rdf_literal/2`, `is_plain_rdf_literal/1`, `is_typed_rdf_literal/1`,\n  `is_rdf_resource/1`, `is_rdf_term/1`, `is_rdf_triple/1`, `is_rdf_quad/1` and\n  `is_rdf_statement/1`\n- an implementation of `__using__` on the top-level `RDF` module, which allows to\n  add basic imports and aliases with a simple `use RDF` \n- `RDF.IRI.starts_with?/2` and `RDF.IRI.ends_with?/2`\n- `RDF.Graph.quads/2` and `RDF.Dataset.quads/2` to get all statements of a \n  `RDF.Graph` and `RDF.Dataset` as quads\n- `RDF.Dataset.triples/2` to get all statements of a `RDF.Dataset` as triples\n- `RDF.PrefixMap.to_list/1`\n- `RDF.PropertyMap.to_list/1`\n- support for Elixir 1.14\n- support for Decimal v2","ref":"changelog.html#added"},{"type":"extras","title":"Changed - CHANGELOG","doc":"#### Breaking\n\n- Support for passing multiple objects as separate arguments to the property\n  functions of the description DSL on the vocabulary namespaces was removed\n  to create space for further arguments for other purposes in the future.\n  Multiple objects must be given now in a list instead.\n- All errors found during the compilation of `RDF.Vocabulary.Namespace` are \n  now collectively reported under a single `RDF.Vocabulary.Namespace.CompileError`.\n- An `ignore` term in a `defvocab` definition which actually is not a term of\n  the vocabulary namespace is now considered an error.\n- When defining an alias for a term of vocabulary which would be invalid as an\n  Elixir term, the original term is now implicitly ignored and won't any longer\n  be returned by the `__terms__/0` function of a `RDF.Vocabulary.Namespace`.\n- `RDF.Graph.build/2` blocks are now wrapped in a function, so the aliases and\n  import no longer affect the caller context. `alias`es in the caller context are\n  still available in the build block, but `import`s not and must be reimported in\n  the build block. Variables in the caller context are also no longer available\n  in a `build` block but must be passed explicitly as bindings in a keyword list\n  on the new optional first argument of `RDF.Graph.build/3`.\n- `RDF.BlankNode.Increment` was renamed to `RDF.BlankNode.Generator.Increment`\n- `RDF.XSD.Datatype.Mismatch` exception was renamed to\n  `RDF.XSD.Datatype.MismatchError` for consistency reasons\n\n#### Non-breaking\n\n- The `defvocab` macro can now be safely used in any module and guarantees cleanliness\n  of the base module. So, a surrounding namespace (like `NS`) is no longer necessary.\n  Although still useful for foreign vocabularies, this can be useful eg. to define a\n  `MyApplication.Vocab` module directly under the root module of the application.\n- The `:base_iri` specified in `defvocab` can now be given in any form supported\n  by `RDF.IRI.new/1`. There are also no longer restrictions on the expression \n  of this value. While previously the value had to be provided as a literal value,\n  now any expression returning a value accepted by `RDF.IRI.new/1` can be given \n  (e.g. function calls, module attributes etc.).\n  The `:base_iri` also no longer has to end with a `/` or `#`.\n- `RDF.Data.merge/2` and `RDF.Data.equal?/2` are now commutative, i.e. structs\n  which implement the `RDF.Data` protocol can be given also as the second argument\n  (previously custom structs with `RDF.Data` protocol implementations always\n  had to be given as the first argument).\n- the `Inspect` implementation for the `RDF.Literal`, `RDF.PrefixMap` and  \n  `RDF.PropertyMap` structs now return a string with a valid Elixir expression\n  that recreates the struct when evaluated\n- several performance improvements","ref":"changelog.html#changed"},{"type":"extras","title":"Fixed - CHANGELOG","doc":"- The RDF vocabulary namespaces used in `@prefix` and `@base` declarations in a\n  `RDF.Graph.build` block no longer have to be written out, which had to be done\n  previously even when parts of the module were available as an alias.\n- No warning on lowercased non-property resources in vocabularies\n\n\n[Compare v0.12.0...v1.0.0](https://github.com/rdf-elixir/rdf-ex/compare/v0.12.0...v1.0.0)","ref":"changelog.html#fixed"},{"type":"extras","title":"0.12.0 - 2022-04-11 - CHANGELOG","doc":"This version introduces a new graph builder DSL. See the [new guide](https://rdf-elixir.dev/rdf-ex/description-and-graph-dsl.html)\nfor an introduction.","ref":"changelog.html#0-12-0-2022-04-11"},{"type":"extras","title":"Added - CHANGELOG","doc":"- a `RDF.Graph` builder DSL available under the `RDF.Graph.build/2` function\n- new `RDF.Sigils` `~i`, `~b` and `~l` as variants of the `~I`, `~B` and `~L`\n  sigils, which support string interpolation   \n- `RDF.Graph.new/2` and `RDF.Graph.add/2` support the addition of `RDF.Dataset`s\n- `RDF.Description.empty?/1`, `RDF.Graph.empty?/1`, `RDF.Dataset.empty?/1` and\n  `RDF.Data.empty?/1` which are significantly faster than `Enum.empty?/1`\n  - By replacing all `Enum.empty?/1` uses over the RDF data structures with these\n    new `empty?/1` functions throughout the code base, several functions benefit\n    from this performance improvement.\n- `RDF.Description.first/2` now has a `RDF.Description.first/3` variant which\n  supports a default value\n- new guards in `RDF.Guards`: `is_statement/1` and `is_quad/1`\n- `RDF.PropertyMap.terms/1` and `RDF.PropertyMap.iris/1`","ref":"changelog.html#added"},{"type":"extras","title":"Changed - CHANGELOG","doc":"- `RDF.Graph.description/2` is no longer an alias for `RDF.Graph.get/2`, but\n  has a different behaviour now: it will return an empty description when no\n  description for the requested subject exists in the graph\n- The inspect string of `RDF.Description` now includes the subject separately, so \n  it can be seen also when the description is empty.","ref":"changelog.html#changed"},{"type":"extras","title":"Fixed - CHANGELOG","doc":"- When triples with an empty object list where added to an `RDF.Graph`, it \n  included empty descriptions, which lead to inconsistent behaviour \n  (for example it would be counted in `RDF.Graph.subject_count/1`).\n- When an `RDF.Graph` contained empty descriptions these were rendered by \n  the `RDF.Turtle.Encoder` to a subject without predicates and objects, i.e.\n  invalid Turtle. This actually shouldn't happen and is either caused by \n  misuse or a bug. So instead, a `RDF.Graph.EmptyDescriptionError` with a \n  detailed message will be raised now when this case is detected.\n\n\n[Compare v0.11.0...v0.12.0](https://github.com/rdf-elixir/rdf-ex/compare/v0.11.0...v0.12.0)","ref":"changelog.html#fixed"},{"type":"extras","title":"0.11.0 - 2022-03-22 - CHANGELOG","doc":"The main feature of this version are the `RDF.Resource.Generator`s.\nFor an introduction see [this guide](https://rdf-elixir.dev/rdf-ex/resource-generators.html).","ref":"changelog.html#0-11-0-2022-03-22"},{"type":"extras","title":"Added - CHANGELOG","doc":"- `RDF.Resource.Generator`s which can be used to generate configurable ids\n- `:implicit_base` option on the `RDF.Turtle.Encoder`\n- `:base_description` option on the `RDF.Turtle.Encoder`\n- several new types: \n  - `RDF.Resource.t` for all node identifiers, i.e. `RDF.IRI`s and `RDF.BlankNode`s \n  - `RDF.Triple.coercible`, `RDF.Quad.coercible`, `RDF.Star.Triple.coercible`\n    and `RDF.Star.Quad.coercible` for tuples which can be coerced to the\n    respective statements","ref":"changelog.html#added"},{"type":"extras","title":"Changed - CHANGELOG","doc":"- some types were renamed for consistency reasons; the old types were deprecated\n  and will be removed\n  - `RDF.Statement.coercible_t` -> `RDF.Statement.coercible`\n  - `RDF.Star.Statement.coercible_t` -> `RDF.Star.Statement.coercible`\n  - `RDF.Triple.t_values` -> `RDF.Triple.mapping_value`\n  - `RDF.Quad.t_values` -> `RDF.Quad.mapping_value`","ref":"changelog.html#changed"},{"type":"extras","title":"Fixed - CHANGELOG","doc":"- the interface of `RDF.BlankNode.Generator.start_link/1` was fixed, so that\n  generators can be started supervised\n\n\n[Compare v0.10.0...v0.11.0](https://github.com/rdf-elixir/rdf-ex/compare/v0.10.0...v0.11.0)","ref":"changelog.html#fixed"},{"type":"extras","title":"0.10.0 - 2021-12-13 - CHANGELOG","doc":"This release adds RDF-star support on the RDF data structures, the N-Triples, N-Quads, \nTurtle encoders and decoders and the BGP query engine. \nFor an introduction read the new [page on the RDF.ex guide](https://rdf-elixir.dev/rdf-ex/rdf-star.html).\nFor more details on how to migrate from an earlier version read [this wiki page](https://github.com/rdf-elixir/rdf-ex/wiki/Upgrading-to-RDF.ex-0.10).\n\nElixir versions < 1.10 are no longer supported","ref":"changelog.html#0-10-0-2021-12-13"},{"type":"extras","title":"Added - CHANGELOG","doc":"- Support for `RDF.PropertyMap` on `RDF.Statement.new/2` and `RDF.Statement.coerce/2`.\n- `RDF.Dataset.graph_count/1`\n- The `RDF.NQuads.Encoder` now supports a `:default_graph_name` option, which\n  allows to specify the graph name to be used as the default for triples\n  from a `RDF.Graph` or `RDF.Description`.","ref":"changelog.html#added"},{"type":"extras","title":"Changed - CHANGELOG","doc":"- The `RDF.Turtle.Encoder` no longer supports the encoding of `RDF.Dataset`s.   \n  You'll have to aggregate a `RDF.Dataset` to a `RDF.Graph` on your own now.\n- The `RDF.NQuads.Encoder` now uses the `RDF.Graph.name/1` as the graph name for  \n  the triples of a `RDF.Graph`.\n  Previously the triples of an `RDF.Graph` were always encoded as part of default \n  graph. You can use the new `:default_graph_name` option and set it to `nil` to get\n  the old behaviour.\n\n  \n[Compare v0.9.4...v0.10.0](https://github.com/rdf-elixir/rdf-ex/compare/v0.9.4...v0.10.0)","ref":"changelog.html#changed"},{"type":"extras","title":"0.9.4 - 2021-05-26 - CHANGELOG","doc":"","ref":"changelog.html#0-9-4-2021-05-26"},{"type":"extras","title":"Added - CHANGELOG","doc":"- `RDF.statement/1`, `RDF.statement/3` and `RDF.statement/4` constructor functions\n- the `:default_prefixes` configuration option now allows to set a `{mod, fun}`\n  tuple, with a function which should be called to determine the default prefixes\n- the `:default_base_iri` configuration option now allows to set a `{mod, fun}`\n  tuple, with a function which should be called to determine the default base IRI\n- support for Elixir 1.12 and OTP 24","ref":"changelog.html#added"},{"type":"extras","title":"Fixed - CHANGELOG","doc":"- the Turtle encoder was encoding IRIs as prefixed names even when they were\n  resulting in non-conform prefixed names\n- the Turtle encoder didn't properly escape special characters in language-tagged \n  literals\n- the N-Triples and N-Quads encoders didn't properly escape special characters in \n  both language-tagged and plain literals\n- the `Inspect` protocol implementation for `RDF.Diff` was causing an error when\n  both graphs had prefixes defined\n  \nNote: In the canonical form of -0.0 in XSD doubles and floats the sign is removed\nin OTP versions < 24 although this is not standard conform. This has the\nconsequence that the sign of -0.0 is also removed when casting these doubles and\nfloats to decimals. These bugs won't be fixed. If you rely on the correct behavior\nin these cases, you'll have to upgrade to OTP 24 and a respective Elixir version.\n\n\n[Compare v0.9.3...v0.9.4](https://github.com/rdf-elixir/rdf-ex/compare/v0.9.3...v0.9.4)","ref":"changelog.html#fixed"},{"type":"extras","title":"0.9.3 - 2021-03-09 - CHANGELOG","doc":"","ref":"changelog.html#0-9-3-2021-03-09"},{"type":"extras","title":"Added - CHANGELOG","doc":"- `:indent` option on `RDF.Turtle.Encoder`, which allows to specify the number\n  of spaces the output should be indented","ref":"changelog.html#added"},{"type":"extras","title":"Changed - CHANGELOG","doc":"- the performance of the `Enumerable` protocol implementations of the RDF data \n  structures was significantly improved (for graphs almost 10x), which in turn\n  increases the performance of all functions built on top of that, eg. \n  the N-Triples and N-Quads encoders\n- improvement of the Inspect forms of the RDF data structures: the content is\n  now enclosed in angle brackets and indented","ref":"changelog.html#changed"},{"type":"extras","title":"Fixed - CHANGELOG","doc":"- strings of the form `\".0\"` and `\"0.\"` weren't recognized as valid XSD float  \n  and double literals\n- the Turtle encoder handles base URIs without a trailing slash or hash properly  \n  (no longer raising a warning and ignoring them) \n \n\n[Compare v0.9.2...v0.9.3](https://github.com/rdf-elixir/rdf-ex/compare/v0.9.2...v0.9.3)","ref":"changelog.html#fixed"},{"type":"extras","title":"0.9.2 - 2021-01-06 - CHANGELOG","doc":"","ref":"changelog.html#0-9-2-2021-01-06"},{"type":"extras","title":"Added - CHANGELOG","doc":"- `RDF.XSD.Base64Binary` datatype ([@pukkamustard](https://github.com/pukkamustard))","ref":"changelog.html#added"},{"type":"extras","title":"Changed - CHANGELOG","doc":"- a new option `:as_value` to enforce interpretation of an input string as a value\n  instead of a lexical, which is needed on datatypes where the lexical space and\n  the value space both consist of strings\n- `RDF.XSD.Date` and `RDF.XSD.Time` both can now be initialized with tuples of an\n  Elixir `Date` resp. `Time` value and a timezone string (previously XSD date and \n  time values with time zones could only be created from strings)\n\n\n[Compare v0.9.1...v0.9.2](https://github.com/rdf-elixir/rdf-ex/compare/v0.9.1...v0.9.2)","ref":"changelog.html#changed"},{"type":"extras","title":"0.9.1 - 2020-11-16 - CHANGELOG","doc":"Elixir versions < 1.9 are no longer supported","ref":"changelog.html#0-9-1-2020-11-16"},{"type":"extras","title":"Added - CHANGELOG","doc":"- general serialization functions for reading from and writing to streams\n  and implementations for N-Triples and N-Quads (Turtle still to come)\n- a `:gzip` option flag on all `read_file/3` and `write_file/3` functions\n  allows to read and write all supported serialization formats from and to\n  gzipped files (works also with the new possibility to read and write files via streams)\n- `RDF.Dataset.prefixes/1` for getting an aggregated `RDF.PrefixMap` over all graphs\n- `RDF.PrefixMap.put/3` for adding a prefix mapping and overwrite an existing one\n- `RDF.BlankNode.value/1` for getting the internal string representation of a blank node\n- `RDF.IRI.in_namespace?/2` for determining whether an IRI lies in a namespace","ref":"changelog.html#added"},{"type":"extras","title":"Changed - CHANGELOG","doc":"- all `read_file/3` and `write_file/3` functions on `RDF.Serialization` and the\n  modules of RDF serialization formats can use streaming via the `:stream` flag\n  option; for `read_file/3` and `write_file/3` it defaults to `false`, while for\n  `read_file!/3` and `write_file!/3` it defaults to `true` when the respective\n  format supports streams\n- the Inspect form of the RDF data structures are now Turtle-based and respect\n  the usual `:limit` behaviour\n- more compact Inspect form for `RDF.PrefixMap`\n- the `RDF.Turtle.Encoder` accepts `RDF.Vocabulary.Namespace` modules as `base`\n- the performance of the `RDF.Turtle.Encoder` was improved (by using a for most \n  use cases more efficient method for resolving IRIs to prefixed names)\n- `RDF.BlankNode.new/0` creates integer-based blank nodes, which is much more\n  efficient in terms of performance and memory consumption than the previous\n  ref-based blank nodes","ref":"changelog.html#changed"},{"type":"extras","title":"Fixed - CHANGELOG","doc":"- `RDF.BlankNode`s based on refs weren't serializable to Turtle\n- `RDF.Vocabulary.Namespace`s couldn't contain terms conflicting with functions\n  from Elixirs Kernel module; most of them are supported now, while for the  \n  remaining unsupported ones a proper error message is produced during compilation \n\n\n[Compare v0.9.0...v0.9.1](https://github.com/rdf-elixir/rdf-ex/compare/v0.9.0...v0.9.1)","ref":"changelog.html#fixed"},{"type":"extras","title":"0.9.0 - 2020-10-13 - CHANGELOG","doc":"The API of the all three RDF datastructures `RDF.Dataset`, `RDF.Graph` and \n`RDF.Description` were changed, so that the functions taking input data consist only\nof one field in order to open the possibility of introducing options on these \nfunctions. The supported ways with which RDF statements can be passed to the \nRDF data structures were extended and unified to be supported across all functions \naccepting input data. This includes also the way in which patterns for BGP queries\nare specified. Also, the performance for adding data has been improved.\n\nFor an introduction on the new data structure API and the commonly supported input formats\nread the updated [page on the RDF data structures in the guide](https://rdf-elixir.dev/rdf-ex/data-structures.html). \nFor more details on how to migrate from an earlier version read [this wiki page](https://github.com/rdf-elixir/rdf-ex/wiki/Upgrading-to-RDF.ex-0.9).","ref":"changelog.html#0-9-0-2020-10-13"},{"type":"extras","title":"Added - CHANGELOG","doc":"- `RDF.PropertyMap` which allow definition of atoms for RDF properties. \n  Such property maps can be provided to all RDF data structure functions \n  accepting input data and BGP query patterns with the `:context` opt, \n  allowing the use of the atoms from the property map in the input data. \n- on `RDF.Description`\n    - `RDF.Description.subject/1` \n    - `RDF.Description.change_subject/2`\n- on `RDF.Graph`\n    - `RDF.Graph.name/1` \n    - `RDF.Graph.change_name/2`\n    - `RDF.Graph.base_iri/1` \n    - `RDF.Graph.prefixes/1`\n    - `RDF.Graph.put_properties/3`\n- on `RDF.Dataset`\n    - `RDF.Dataset.name/1` \n    - `RDF.Dataset.change_name/2`\n    - `RDF.Dataset.put_properties/3`\n- `RDF.IRI.append/2`","ref":"changelog.html#added"},{"type":"extras","title":"Changed - CHANGELOG","doc":"- the format for the specification of BGP queries with `RDF.Graph.query/2`, \n  `RDF.Graph.query_stream/2` and `RDF.Query.bgp/1` has been changed to be consistent   \n  with the supported formats for input data in the rest of the library   \n- `RDF.Description.new` now requires the `subject` to be passed always as first argument;\n  if you want to add some initial data this must be done with the `:init` option\n- The `put/3` functions on `RDF.Graph` and `RDF.Dataset` now overwrite all \n  statements with same subject. Previously only statements with the same subject \n  AND predicate were overwritten, which was probably not the expected behaviour, \n  since it's not inline with the common `put` semantics in Elixir. \n  A function with the previous behaviour was added on `RDF.Graph` and `RDF.Dataset` \n  with the `put_properties/3` function.\n    - **CAUTION: This means the `RDF.Graph.put/2` and `RDF.Dataset.put/2` function have become more destructive now when not specified otherwise.**\n    - Note: Although one could argue, that following this route `RDF.Dataset.put/3`\n      would consequently have to overwrite whole graphs, this was not implemented\n      for practical reasons. It's probably not what's wanted in most cases.\n- The `Access` protocol implementation of `get_and_update/3` on `RDF.Graph` and\n  `RDF.Dataset` previously relied on the `put/2` functions with the old behaviour\n  of overwriting only statements with the same subject and predicate, which was\n  almost never the expected behaviour. This is fixed now by relying on the new\n  `put/2` behaviour.\n- the `values/2` functions of `RDF.Statement`, `RDF.Triple`, `RDF.Quad`, `RDF.Description`,\n  `RDF.Graph` and `RDF.Dataset` now accept on their second argument an optional \n  `RDF.PropertyMap`which will be used to map predicates accordingly; the variant of \n  these `values/2` functions to provide a custom mapping function was extracted into \n  a new function `map/2` on all of these modules \n- for consistency reasons the internal `:id` struct field of `RDF.BlankNode` was renamed\n  to `:value`\n- allow the `base_iri` of `RDF.Vocabulary.Namespace`s to end with a `.` to support\n  vocabularies which use dots in the IRIs for further structuring (e.g. CIM-based formats like CGMES)\n- `RDF.Triple.new/1` now also accepts four-element tuples and simple ignores fourth element   \n- `RDF.Quad.new/1` now also accepts three-element tuples and simple assumes the fourth \n  element to be `nil`","ref":"changelog.html#changed"},{"type":"extras","title":"Fixed - CHANGELOG","doc":"- the `put` functions on `RDF.Description`, `RDF.Graph` and `RDF.Dataset` didn't add all\n  statements properly under certain circumstances\n- `RDF.Graph.put/2` ignores empty descriptions; this should be the final piece to ensure\n  that `RDF.Graph`s never contain empty descriptions, which would distort results of \n  functions like `RDF.Graph.subjects/1`, `RDF.Graph.subject_count/1`, `RDF.Graph.descriptions/1`   \n\n\n[Compare v0.8.2...v0.9.0](https://github.com/rdf-elixir/rdf-ex/compare/v0.8.2...v0.9.0)","ref":"changelog.html#fixed"},{"type":"extras","title":"0.8.2 - 2020-09-21 - CHANGELOG","doc":"","ref":"changelog.html#0-8-2-2020-09-21"},{"type":"extras","title":"Added - CHANGELOG","doc":"- the Turtle encoder can now produce partial Turtle documents with the `:only` option\n  and any combination of the following values: `:triples`, `:directives`, `:base`, `:prefixes`  \n- the style of the Turtle directives produced by the Turtle encoder can be\n  switched to SPARQL style with the option `:directive_style` and the value `:sparql`\n- the most common conflict resolution strategies on `RDF.PrefixMap.merge/3` can now\n  be chosen directly with the atoms `:ignore` and `:overwrite` \n- `RDF.PrefixMap.prefixed_name/2` to convert an IRI to a prefixed name\n- `RDF.PrefixMap.prefixed_name_to_iri/2` to convert a prefixed name to an IRI","ref":"changelog.html#added"},{"type":"extras","title":"Changed - CHANGELOG","doc":"- when serializing a `RDF.Dataset` with the Turtle encoder the prefixes of all of its graphs \n  are used now","ref":"changelog.html#changed"},{"type":"extras","title":"Fixed - CHANGELOG","doc":"- adding an empty `RDF.Description` with a subject to an empty `RDF.Graph` resulted in \n  an invalid non-empty graph ([@pukkamustard](https://github.com/pukkamustard))\n\n\n[Compare v0.8.1...v0.8.2](https://github.com/rdf-elixir/rdf-ex/compare/v0.8.1...v0.8.2)","ref":"changelog.html#fixed"},{"type":"extras","title":"0.8.1 - 2020-06-16 - CHANGELOG","doc":"","ref":"changelog.html#0-8-1-2020-06-16"},{"type":"extras","title":"Added - CHANGELOG","doc":"- query functions for basic graph pattern matching (incl. streaming-support)\n\n\n[Compare v0.8.0...v0.8.1](https://github.com/rdf-elixir/rdf-ex/compare/v0.8.0...v0.8.1)","ref":"changelog.html#added"},{"type":"extras","title":"0.8.0 - 2020-06-01 - CHANGELOG","doc":"RDF literals and their datatypes were completely redesigned to support derived XSD datatypes and\nallow for defining custom datatypes. \nFor an introduction on how literals work now read the updated [page on literals in the guide](https://rdf-elixir.dev/rdf-ex/literals.html). \nFor more details on how to migrate from an earlier version read [this wiki page](https://github.com/rdf-elixir/rdf-ex/wiki/Upgrading-to-RDF.ex-0.8).\n\nElixir versions < 1.8 are no longer supported","ref":"changelog.html#0-8-0-2020-06-01"},{"type":"extras","title":"Added - CHANGELOG","doc":"- a lot of new datatypes like `xsd:float`, `xsd:byte` or `xsd:anyURI` -- all numeric XSD datatypes \n  are now available; see [this page of the API documentation](https://hexdocs.pm/rdf/RDF.XSD.Datatype.html#module-builtin-xsd-datatypes)\n  for an up-to-date list of all supported and missing XSD datatypes\n- an implementation of XSD facet system now makes it easy to define own custom datatypes via \n  restriction of the existing XSD datatypes\n- `RDF.Literal.update/2` updates the value of a `RDF.Literal` without changing anything else, \n  eg. the language or datatype","ref":"changelog.html#added"},{"type":"extras","title":"Changed - CHANGELOG","doc":"- the `RDF.Literal` struct now consists entirely of a datatype-specific structs in the `literal` field, \n  which besides being more memory-efficient (since literals no longer consist of all possible fields a literal might have),\n  allows pattern matching now on the datatype of literals.\n- RDF XSD datatypes are now defined in the `RDF.XSD` namespace\n- alias constructor functions for the XSD datatypes are now defined on `RDF.XSD`\n- `matches?`, `less_than?`, `greater_than` as higher level functions were removed from the \n  `RDF.Literal.Datatype` modules \n- `less_than?`, `greater_than?` now always return a boolean and no longer `nil` when incomparable;\n  you can still determine if two terms are comparable by checking if `compare/2` returns `nil`\n- the `language` option is not supported on the `RDF.XSD.String.new/2` constructor  \n- the `language` option on `RDF.Literal.new/2` is no longer ignored if it's empty (`nil` or `\"\"`), \n  so this either produces an invalid `RDF.LangString` now or, if another `datatype` is provided will \n  fail with an `ArgumentError`\n- `canonical` now performs implicit coercions when passed plain Elixir values\n- the inspect format for literals was changed and is now much more informative and uniform, since\n  you now always see the value, the lexical form and if the literal is valid\n- `RDF.Namespace.resolve_term/1` now returns ok or error tuples, but a new function \n  `RDF.Namespace.resolve_term!/1` with the old behaviour was added","ref":"changelog.html#changed"},{"type":"extras","title":"Fixed - CHANGELOG","doc":"- numeric operations on invalid numeric literals no longer fail, but return `nil` instead    \n- Datetimes preserve the original lexical form of the timezone when casting from a date\n- BEAM error warnings when trying to use top-level modules as vocabulary terms \n\n\n[Compare v0.7.1...v0.8.0](https://github.com/rdf-elixir/rdf-ex/compare/v0.7.1...v0.8.0)","ref":"changelog.html#fixed"},{"type":"extras","title":"0.7.1 - 2020-03-11 - CHANGELOG","doc":"","ref":"changelog.html#0-7-1-2020-03-11"},{"type":"extras","title":"Added - CHANGELOG","doc":"- proper typespecs so that Dialyzer passes without warnings ([@rustra](https://github.com/rustra))","ref":"changelog.html#added"},{"type":"extras","title":"Fixed - CHANGELOG","doc":"- `RDF.XSD.Time` didn't handle 24h overflows with an offset correctly\n\n\n[Compare v0.7.0...v0.7.1](https://github.com/rdf-elixir/rdf-ex/compare/v0.7.0...v0.7.1)","ref":"changelog.html#fixed"},{"type":"extras","title":"0.7.0 - 2019-11-22 - CHANGELOG","doc":"","ref":"changelog.html#0-7-0-2019-11-22"},{"type":"extras","title":"Added - CHANGELOG","doc":"- `RDF.Diff` data structure for diffs between RDF graphs and descriptions \n- `RDF.Description.update/4` updates the objects of a predicate in a description \n  with a custom update function\n- `RDF.Graph.update/4` updates the descriptions of a subject in a graph \n  with a custom update function\n- `RDF.Description.take/2` creates a description from another one by limiting \n  its statements to a set of predicates\n- `RDF.Graph.take/3` creates a graph from another one by limiting \n  its statements to a set of subjects and optionally also a set of predicates\n- `RDF.Graph.clear/1` removes the triples from a graph\n- Mix formatter configuration for using `defvocab` without parens","ref":"changelog.html#added"},{"type":"extras","title":"Changed - CHANGELOG","doc":"- `RDF.Serialization.Writer.write_file/4` which is the basis used by all the\n  `write_file/3` and `write_file!/3` functions of all serialization format modules\n  like `RDF.NTriples`, `RDF.Turtle`, `JSON.LD` etc. now opens file in a different \n  mode: it no longer opens them with the [`:utf8` option](https://hexdocs.pm/elixir/File.html#open/2).\n  First, this by default slowed down the writing, but more importantly could lead\n  to unexpected encoding issues.\n  This is a **breaking change**: If your code relied on this file mode, you can\n  get the old behaviour, by specifying the `file_mode` on these functions\n  accordingly as `[:utf8, :write, :exclusive]`. For example, to write a Turtle\n  file with the old behaviour, you can do it like this:\n  \n```elixir\nRDF.Turtle.write_file!(some_data, some_path, file_mode: ~w[utf8 write exclusive]a)\n``` \n\n\n[Compare v0.6.2...v0.7.0](https://github.com/rdf-elixir/rdf-ex/compare/v0.6.2...v0.7.0)","ref":"changelog.html#changed"},{"type":"extras","title":"0.6.2 - 2019-09-08 - CHANGELOG","doc":"","ref":"changelog.html#0-6-2-2019-09-08"},{"type":"extras","title":"Added - CHANGELOG","doc":"- field `base_iri` on `RDF.Graph` structure which can be set via new `base_iri` \n  option on `RDF.Graph.new` or the new functions `RDF.Graph.set_base_iri/2` \n  and `RDF.Graph.clear_base_iri/1`\n- `RDF.Graph.clear_metadata/1` which clears the base IRI and the prefixes\n- `RDF.IRI.coerce_base/1` which coerces base IRIs; as opposed to `RDF.IRI.new/1`\n  it also accepts bare `RDF.Vocabulary.Namespace` modules","ref":"changelog.html#added"},{"type":"extras","title":"Changed - CHANGELOG","doc":"- `RDF.Turtle.Decoder` saves the base IRI in the `RDF.Graph` now\n- `RDF.Turtle.Encoder` now takes the base IRI to be used during serialization in  \n  the following order of precedence:\n\t- from the `base` option or its new alias `base_iri`\n\t- from the `base_iri` field of the given graph\n\t- from the `RDF.default_base_iri` returning the one from the application \n\t  configuration\n- `RDF.PrefixMap.new` and `RDF.PrefixMap.add` now also accepts terms from \n  `RDF.Vocabulary.Namespace`s as namespaces","ref":"changelog.html#changed"},{"type":"extras","title":"Fixed - CHANGELOG","doc":"- Vocabulary namespace modules weren't always detected properly\n\n\n[Compare v0.6.1...v0.6.2](https://github.com/rdf-elixir/rdf-ex/compare/v0.6.1...v0.6.2)","ref":"changelog.html#fixed"},{"type":"extras","title":"0.6.1 - 2019-07-15 - CHANGELOG","doc":"","ref":"changelog.html#0-6-1-2019-07-15"},{"type":"extras","title":"Added - CHANGELOG","doc":"- `RDF.IRI.to_string/1` returns the string representation of an `RDF.IRI`  \n  (implicitly resolving vocabulary namespace terms)\n- `RDF.Literal.matches?/3` for XQuery regex pattern matching\n- `RDF.Decimal.digit_count/1` and `RDF.Decimal.fraction_digit_count/1` for  \n  determining the number of digits of decimal literals","ref":"changelog.html#added"},{"type":"extras","title":"Fixed - CHANGELOG","doc":"- language literals were not properly unescaped during Turtle parsing\n- `RDF.Literal.new/1` can take decimals and infers the datatype `xsd:decimal` \n  correctly\n- `true` and `false` with capital letters are no longer valid `RDF.Boolean`s \n  following the XSD specification; the same applies for booleans in Turtle\n- `+INF` is no longer a valid `RDF.Double` (positive infinity doesn't expect a sign)\n- slightly improve output of errors during parsing of Turtle, N-Triples and N-Quads  \n\n\n[Compare v0.6.0...v0.6.1](https://github.com/rdf-elixir/rdf-ex/compare/v0.6.0...v0.6.1)","ref":"changelog.html#fixed"},{"type":"extras","title":"0.6.0 - 2019-04-06 - CHANGELOG","doc":"see [here](https://github.com/rdf-elixir/rdf-ex/wiki/Upgrading-to-RDF.ex-0.6) for\nupgrading notes to RDF.ex 0.6","ref":"changelog.html#0-6-0-2019-04-06"},{"type":"extras","title":"Added - CHANGELOG","doc":"- `RDF.PrefixMap`\n- prefix management of `RDF.Graph`s:\n\t- the structure now has a `prefixes` field with an optional `RDF.PrefixMap`\n\t- new functions `add_prefixes/2`, `delete_prefixes/2` and `clear_prefixes/1` \n- configurable `RDF.default_prefixes`\n- `RDF.Description.equal?/2`, `RDF.Graph.equal?/2`, `RDF.Dataset.equal?/2` and \n  `RDF.Data.equal?/2`","ref":"changelog.html#added"},{"type":"extras","title":"Changed - CHANGELOG","doc":"- the constructor functions for `RDF.Graph`s and `RDF.Dataset`s now take the \n  graph name resp. dataset name through a `name` option, instead of the first\n  argument\n- `RDF.Graph.new` supports an additional `prefixes` argument to initialize the \n\t`prefixes` field\n- when `RDF.Graph.add` and `RDF.Graph.put` are called with another graph, its\n  prefixes are merged \n- `RDF.Turtle.Decoder` saves the prefixes now\n- `RDF.Turtle.Encoder` now takes the prefixes to be serialized in the following \n  order of precedence:\n\t- from the `prefixes` option (as before)\n\t- from the `prefixes` field of the given graph\n\t- from the `RDF.default_prefixes`\n- drop support for OTP < 20, since prefixes can consist of UTF characters which\n  are not supported in atoms on these versions  \t\n\n\n[Compare v0.5.4...v0.6.0](https://github.com/rdf-elixir/rdf-ex/compare/v0.5.4...v0.6.0)","ref":"changelog.html#changed"},{"type":"extras","title":"0.5.4 - 2019-01-17 - CHANGELOG","doc":"","ref":"changelog.html#0-5-4-2019-01-17"},{"type":"extras","title":"Fixed - CHANGELOG","doc":"- issue with Elixir 1.8\n- `RDF.write_file` and `RDF.write_file!` delegators had wrong signatures\n\n\n[Compare v0.5.3...v0.5.4](https://github.com/rdf-elixir/rdf-ex/compare/v0.5.3...v0.5.4)","ref":"changelog.html#fixed"},{"type":"extras","title":"0.5.3 - 2018-11-11 - CHANGELOG","doc":"","ref":"changelog.html#0-5-3-2018-11-11"},{"type":"extras","title":"Added - CHANGELOG","doc":"- `RDF.Triple.valid?/1`, `RDF.Quad.valid?/1` and `RDF.Statement.valid?/1`, which\n  validate if a tuple is a valid RDF triple or RDF quad\n\n\n[Compare v0.5.2...v0.5.3](https://github.com/rdf-elixir/rdf-ex/compare/v0.5.2...v0.5.3)","ref":"changelog.html#added"},{"type":"extras","title":"0.5.2 - 2018-11-04 - CHANGELOG","doc":"","ref":"changelog.html#0-5-2-2018-11-04"},{"type":"extras","title":"Added - CHANGELOG","doc":"- `RDF.Term.value/1` returning the native Elixir value of a RDF term\n- `RDF.Statement.values/1`, `RDF.Triple.values/1` and `RDF.Quad.values/1` \n  returning a tuple of `RDF.Term.value/1` converted native Elixir values from a \n  tuple of RDF terms\n- `RDF.Description.values/1`, `RDF.Graph.values/1`, `RDF.Dataset.values/1` and\n\t`RDF.Data.values/1` returning a map of `RDF.Term.value/1` converted native \n\tElixir values from the respective structure of RDF terms\n- for all of aforementioned `values/1` functions a variant `values/2` which \n  allows to specify custom mapping function to be applied when creating the resp.\n  structure\n- `RDF.Literal.compare/2`, `RDF.Literal.less_than?/2` and `RDF.Literal.greater_than?/2`  \n  for `RDF.Datatype` aware comparisons of `RDF.Literal`s","ref":"changelog.html#added"},{"type":"extras","title":"Fixed - CHANGELOG","doc":"- `RDF.DateTime.equal_value?/2` and `RDF.Date.equal_value?/2` did not handle \n  timezones correctly\n- `-00:00` is a valid timezone offset on `RDF.DateTime`\n\n\n[Compare v0.5.1...v0.5.2](https://github.com/rdf-elixir/rdf-ex/compare/v0.5.1...v0.5.2)","ref":"changelog.html#fixed"},{"type":"extras","title":"0.5.1 - 2018-09-17 - CHANGELOG","doc":"","ref":"changelog.html#0-5-1-2018-09-17"},{"type":"extras","title":"Fixed - CHANGELOG","doc":"- generated Erlang output files of Leex and Yecc are excluded from Hex package\n\n\n[Compare v0.5.0...v0.5.1](https://github.com/rdf-elixir/rdf-ex/compare/v0.5.0...v0.5.1)","ref":"changelog.html#fixed"},{"type":"extras","title":"0.5.0 - 2018-09-17 - CHANGELOG","doc":"Elixir versions < 1.6 are no longer supported","ref":"changelog.html#0-5-0-2018-09-17"},{"type":"extras","title":"Added - CHANGELOG","doc":"- Possibility to execute simple SPARQL queries against `RDF.Graph`s with \n  [SPARQL 0.2](https://github.com/rdf-elixir/sparql-ex/blob/master/CHANGELOG.md)\n- New `RDF.Term` protocol implemented for all structs representing RDF nodes and  \n  all native Elixir datatypes which are coercible to those modules. For now, it  \n  mainly offers, besides the coercion, just the function `RDF.Term.equal?/2` and \n  `RDF.Term.equal_value?/2` for term- and value comparisons.\n- New `RDF.Decimal` datatype for `xsd:decimal` literals and support for decimal \n\tliterals in Turtle encoder\n- `RDF.Numeric` module with a list of all numeric datatypes and shared functions\n\tfor all numeric literals, e.g. arithmetic functions\n- Various new `RDF.Datatype` function \n\t- `RDF.Datatype.cast/1` for casting between `RDF.Literal`s  as specified in the \n\t\tXSD spec on all `RDF.Datatype`s \n\t- logical operators and the Effective Boolean Value (EBV) coercion algorithm \n\t\tfrom the XPath and SPARQL specs on `RDF.Boolean`\n\t- various functions on the `RDF.DateTime` and `RDF.Time` datatypes\n\t- `RDF.LangString.match_language?/2`\n- Many new convenience functions on the top-level `RDF` module \n\t- constructors for all the supported `RDF.Datatype`s\n\t- constant functions `RDF.true` and `RDF.false` for the two boolean `RDF.Literal` values\n- `RDF.Literal.Guards` which allow pattern matching of common literal datatypes\n- `RDF.BlankNode.Generator`\n- Possibility to configure an application-specific default base IRI; for now it \n  is used only on reading of RDF serializations (when no `base` specified)","ref":"changelog.html#added"},{"type":"extras","title":"Changed - CHANGELOG","doc":"- `RDF.String.new/2` and `RDF.String.new!/2` produce a `rdf:langString` when \n  given a language tag\n- Some of the defined structs now enforce keys at compile-time (via Elixirs \n  `@enforce_keys` feature) when not setting the corresponding fields would lead \n  to invalid structs, namely the following fields: \n  - `RDF.IRI.value`\n  - `RDF.BlankNode.id`\n  - `RDF.Description.subject`\n  - `RDF.List.head`","ref":"changelog.html#changed"},{"type":"extras","title":"Fixed - CHANGELOG","doc":"- `RDF.resource?/1` does not fail anymore when called with unresolvable atoms \n  but returns `false` instead\n- `RDF.IRI.absolute/2` does not fail with a `FunctionClauseError` when the given \n  base is not absolute, but returns `nil` instead \n- `RDF.DateTime` and `RDF.Time` store microseconds\n- `RDF.DateTime`: '24:00:00' is a valid time in a xsd:dateTime; the dateTime \n  value so represented is the first instant of the following day\n- `RDF.LangString`: non-strings or the empty string as language produce invalid\n  literals\n\n\n[Compare v0.4.1...v0.5.0](https://github.com/rdf-elixir/rdf-ex/compare/v0.4.1...v0.5.0)","ref":"changelog.html#fixed"},{"type":"extras","title":"0.4.1 - 2018-03-19 - CHANGELOG","doc":"","ref":"changelog.html#0-4-1-2018-03-19"},{"type":"extras","title":"Added - CHANGELOG","doc":"- `RDF.Literal.new!/2` which fails when creating an invalid literal","ref":"changelog.html#added"},{"type":"extras","title":"Changed - CHANGELOG","doc":"- `RDF.Literal.new/2` can create `rdf:langString` literals without failing, they  \n  are simply invalid; if you want to fail without a language tag use the new \n  `RDF.Literal.new!/2` function\n\n\n[Compare v0.4.0...v0.4.1](https://github.com/rdf-elixir/rdf-ex/compare/v0.4.0...v0.4.1)","ref":"changelog.html#changed"},{"type":"extras","title":"0.4.0 - 2018-03-10 - CHANGELOG","doc":"","ref":"changelog.html#0-4-0-2018-03-10"},{"type":"extras","title":"Changed - CHANGELOG","doc":"- renamed `RDF.Serialization` behaviour to `RDF.Serialization.Format`; the new\n  `RDF.Serialization` module contains just simple RDF serialization related functions \n- renamed `RDF.Serialization.Format` function `content_type/0` to `media_type/0`\n- moved `RDF.Reader` and `RDF.Writer` into `RDF.Serialization` module \n- removed the limitation to serialization formats defined in the core RDF.ex package\n  for use as a source of `RDF.Vocabulary.Namespace`s; so you can now also define\n  vocabulary namespaces from JSON-LD files for example, provided that the corresponding \n  Hex package is defined as a dependency","ref":"changelog.html#changed"},{"type":"extras","title":"Added - CHANGELOG","doc":"- `RDF.Serialization.Format`s define a `name` atom\n- all `RDF.Serialization.Reader` and `RDF.Serialization.Writer` functions are now\n  available on the `RDF.Serialization` module (or aliased on the top-level `RDF` \n  module) and the format can be specified instead of a `RDF.Serialization.Format` \n  argument, via the `format` or `media_type` option or in case of `*_file` \n  functions, without explicit specification of the format, but inferred from file\n  name extension instead; see the updated README section about RDF serializations\n- the following functions to access available `RDF.Serialization.Format`s:\n  - `RDF.Serialization.formats/0`\n  - `RDF.Serialization.available_formats/0`\n  - `RDF.Serialization.format/1`\n  - `RDF.Serialization.format_by_media_type/1`\n  - `RDF.Serialization.format_by_extension/1`\n\n\n[Compare v0.3.1...v0.4.0](https://github.com/rdf-elixir/rdf-ex/compare/v0.3.1...v0.4.0)","ref":"changelog.html#added"},{"type":"extras","title":"0.3.1 - 2018-01-19 - CHANGELOG","doc":"","ref":"changelog.html#0-3-1-2018-01-19"},{"type":"extras","title":"Added - CHANGELOG","doc":"- `Collectable` implementations for all `RDF.Data` structures, so they can be \n  used as destinations of `Enum.into` and `for` comprehensions\n- `RDF.Quad` can be created from triple and `RDF.Triple` can be created from quad\n- `RDF.Statement.map/2` which creates a statement with mapped nodes from another statement\n- `RDF.Statement` functions to get the coerced components of a statement","ref":"changelog.html#added"},{"type":"extras","title":"Fixed - CHANGELOG","doc":"- Fix `unescape_map` in `parse_helper` for Elixir 1.6 ([@ajkeys](https://github.com/ajkeys))\n\n\n[Compare v0.3.0...v0.3.1](https://github.com/rdf-elixir/rdf-ex/compare/v0.3.0...v0.3.1)","ref":"changelog.html#fixed"},{"type":"extras","title":"0.3.0 - 2017-08-24 - CHANGELOG","doc":"","ref":"changelog.html#0-3-0-2017-08-24"},{"type":"extras","title":"Added - CHANGELOG","doc":"- `RDF.IRI` as a more suitable URI/IRI representation for RDF, bringing enormous\n  performance and memory consumption benefits (see [here](https://github.com/rdf-elixir/rdf-ex/issues/1) \n  for the details about the improvements)","ref":"changelog.html#added"},{"type":"extras","title":"Changed - CHANGELOG","doc":"- use `RDF.IRI` instead of Elixirs `URI` everywhere\n- use the term _iri_ instead of _uri_ consistently, leading to the following \n  function renamings:\n    - `base_iri` instead of `base_uri` for the definition of `RDF.Vocabulary.Namespace`s\n    - `__base_iri__` instead of `__base_uri__` in all `RDF.Vocabulary.Namespace`s\n    - `__iris__` instead of `__uris__` in all `RDF.Vocabulary.Namespace`s\n    - `RDF.IRI.InvalidError` instead of `RDF.InvalidURIError`\n    - `RDF.Literal.InvalidError` instead of `RDF.InvalidLiteralError`\n    - `RDF.Namespace.InvalidVocabBaseIRIError` instead of `RDF.Namespace.InvalidVocabBaseURIError`\n- show compilation message of vocabulary namespaces always to be able to relate\n  resp. errors and warnings","ref":"changelog.html#changed"},{"type":"extras","title":"Fixed - CHANGELOG","doc":"- when trying to resolve a term from an undefined module a `RDF.Namespace.UndefinedTermError`\n  exception\n\n\n[Compare v0.2.0...v0.3.0](https://github.com/rdf-elixir/rdf-ex/compare/v0.2.0...v0.3.0)","ref":"changelog.html#fixed"},{"type":"extras","title":"0.2.0 - 2017-08-12 - CHANGELOG","doc":"Elixir versions < 1.4 are no longer supported","ref":"changelog.html#0-2-0-2017-08-12"},{"type":"extras","title":"Added - CHANGELOG","doc":"- full Turtle support\n- `RDF.List` structure for the representation of RDF lists\n- `describes?/1` on `RDF.Data` protocol and all RDF data structures which checks  \n  if statements about a given resource exist\n- `RDF.Data.descriptions/1` which returns all descriptions within an RDF data structure \n- `RDF.Description.first/2` which returns a single object to a predicate of a `RDF.Description`\n- `RDF.Description.objects/2` now supports a custom filter function\n- `RDF.bnode?/1` which checks if the given value is a blank node","ref":"changelog.html#added"},{"type":"extras","title":"Changed - CHANGELOG","doc":"- Rename `RDF.Statement.convert*` functions to `RDF.Statement.coerce*`","ref":"changelog.html#changed"},{"type":"extras","title":"Fixed - CHANGELOG","doc":"- `RDF.uri/1` and URI parsing of N-Triples and N-Quads decoders preserve empty fragments   \n- booleans weren't recognized as coercible literals on object positions\n- N-Triples and N-Quads decoder didn't handle escaping properly\n\n\n[Compare v0.1.1...v0.2.0](https://github.com/rdf-elixir/rdf-ex/compare/v0.1.1...v0.2.0)","ref":"changelog.html#fixed"},{"type":"extras","title":"0.1.1 - 2017-06-25 - CHANGELOG","doc":"","ref":"changelog.html#0-1-1-2017-06-25"},{"type":"extras","title":"Fixed - CHANGELOG","doc":"- Add `src` directory to package files.\n\n[Compare v0.1.0...v0.1.1](https://github.com/rdf-elixir/rdf-ex/compare/v0.1.0...v0.1.1)","ref":"changelog.html#fixed"},{"type":"extras","title":"0.1.0 - 2017-06-25 - CHANGELOG","doc":"Initial release\n\nNote: This version is not usable, since the `src` directory is not part of the \npackage, which has been immediately fixed on version 0.1.1.","ref":"changelog.html#0-1-0-2017-06-25"},{"type":"extras","title":"CONTRIBUTING","doc":"1. Fork it (   )\n2. Create your feature branch (`git checkout -b my-new-feature`)\n3. Make your changes, with new passing tests. Follow this [style guide].\n4. Execute all tests and quality checks (`mix check && mix dialyzer`).\n5. Commit your changes (`git commit -am 'Add some feature'`)\n6. Push to the branch (`git push origin my-new-feature`)\n7. Create a new Pull Request\n\n[style guide]:  https://github.com/christopheradams/elixir_style_guide","ref":"contributing.html"},{"type":"extras","title":"License","doc":"# MIT License\n\nCopyright (c) 2016-2024 Marcel Otto\n\nPermission is hereby granted, free of charge, to any person obtaining\na copy of this software and associated documentation files (the\n\"Software\"), to deal in the Software without restriction, including\nwithout limitation the rights to use, copy, modify, merge, publish,\ndistribute, sublicense, and/or sell copies of the Software, and to\npermit persons to whom the Software is furnished to do so, subject to\nthe following conditions:\n\nThe above copyright notice and this permission notice shall be\nincluded in all copies or substantial portions of the Software.\n\nTHE SOFTWARE IS PROVIDED \"AS IS\", WITHOUT WARRANTY OF ANY KIND,\nEXPRESS OR IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF\nMERCHANTABILITY, FITNESS FOR A PARTICULAR PURPOSE AND\nNONINFRINGEMENT. IN NO EVENT SHALL THE AUTHORS OR COPYRIGHT HOLDERS BE\nLIABLE FOR ANY CLAIM, DAMAGES OR OTHER LIABILITY, WHETHER IN AN ACTION\nOF CONTRACT, TORT OR OTHERWISE, ARISING FROM, OUT OF OR IN CONNECTION\nWITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE SOFTWARE.","ref":"license.html"}],"content_type":"text/markdown","producer":{"name":"ex_doc","version":[48,46,51,52,46,50]}}